##Preparation

library(readxl)
options(na.action = "na.exclude")

#Endangered plants
es_endangered <- read_excel("Appendix_S1.xlsx", sheet = 1)
w1 <- 1/es_endangered$v1
size <- 0.5 + 3 * (w1 - min(w1))/(max(w1) - min(w1))

#Invasive plants
es_invasive <- read_excel("Appendix_S2.xlsx", sheet = 1)
w2 <- 1/es_invasive$v1
size2 <- 0.5 + 3 * (w2 - min(w2))/(max(w2) - min(w2))


##Weighted linear regression plot (gray scale)

#Fst
#par(mar=c(2, 2, 2, 2) + 0.1)
plot(es_endangered$Fst,es_endangered$y1, pch = 19, col='gray', cex = size,xlim=c(0,1),ylim = c(-6,2), xlab="", ylab="",axes=FALSE)
axis(1, col="black", col.ticks="black", col.axis="black", cex.axis=1.5, lwd=3, font=2)
axis(2, col="black", col.ticks="black", col.axis="black", cex.axis=1.5, lwd=3, font=2)
mtext("Population differentiation", side=1, line=3, col="black", cex=1.5, font=2)
mtext("Genetic diversity (lnRR)", side=2, line=3, col="black", cex=1.5, font=2)
Fst_end_lm <- lm(es_endangered$y1~es_endangered$Fst,data=es_endangered,weights=(1/v1))
abline(Fst_end_lm, col='gray', lwd=3)#The ones that are not significant are indicated by dotted lines, lty=2
summary(Fst_end_lm)
legend("bottomright",c("P < 0.001, R^2 = 0.0274"),bty="n",cex=1.5, text.col='gray', text.font=2)

points(es_invasive$Fst, es_invasive$y1,pch = 19, col='black', cex = size2)
Fst_inv_lm <- lm(es_invasive$y1~es_invasive$Fst,data=es_invasive,weights=(1/v1))
abline(Fst_inv_lm, col='black', lwd=3)
summary(Fst_inv_lm)
legend("bottomleft",c("P < 0.0001, R^2 = 0.2569"),bty="n",cex=1.5, text.col='black', text.font=2)

#FIS
plot(es_endangered$FIS,es_endangered$y1, pch = 19, col='gray', cex = size,xlim=c(-1,1),ylim = c(-6,2), xlab="", ylab="",axes=FALSE)
axis(1, col="black", col.ticks="black", col.axis="black", cex.axis=1.5, lwd=3, font=2)
axis(2, col="black", col.ticks="black", col.axis="black", cex.axis=1.5, lwd=3, font=2)
mtext("Coefficient of inbreeding", side=1, line=3, col="black", cex=1.5, font=2)
mtext("Genetic diversity (lnRR)", side=2, line=3, col="black", cex=1.5, font=2)
FIS_end_lm <- lm(es_endangered$y1~es_endangered$FIS,data=es_endangered,weights=(1/v1))
abline(FIS_end_lm, col='gray', lwd=3)
summary(FIS_end_lm)
legend("bottomright",c("P < 0.001, R^2 = 0.0334"),bty="n",cex=1.5, text.col='gray', text.font=2)

points(es_invasive$FIS, es_invasive$y1,pch = 19, col='black', cex = size2)
FIS_inv_lm <- lm(es_invasive$y1~es_invasive$FIS,data=es_invasive,weights=(1/v1))
abline(FIS_inv_lm, col='black', lwd=3)
summary(FIS_inv_lm)
legend("bottomleft",c("P < 0.01, R^2 = 0.0613"),bty="n",cex=1.5, text.col='black', text.font=2)

#Nm
plot(es_endangered$Nm,es_endangered$y1, pch = 19, col='gray', cex = size, xlim=c(0,50), ylim = c(-6,2), xlab="", ylab="",axes=FALSE)
axis(1, col="black", col.ticks="black", col.axis="black", cex.axis=1.5, lwd=3, font=2)
axis(2, col="black", col.ticks="black", col.axis="black", cex.axis=1.5, lwd=3, font=2)
mtext("Gene Flow", side=1, line=3, col="black", cex=1.5, font=2)
mtext("Genetic diversity (lnRR)", side=2, line=3, col="black", cex=1.5, font=2)
Nm_end_lm <- lm(es_endangered$y1~es_endangered$Nm,data=es_endangered,weights=(1/v1))
abline(Nm_end_lm, col='gray', lwd=3)
summary(Nm_end_lm)
legend("bottomright",c("P < 0.05, R^2 = 0.0087"),bty="n",cex=1.5, text.col='gray', text.font=2)

points(es_invasive$Nm, es_invasive$y1,pch = 19, col='black', cex = size2)
Nm_inv_lm <- lm(es_invasive$y1~es_invasive$Nm,data=es_invasive,weights=(1/v1))
abline(Nm_inv_lm, col='black', lwd=3)
summary(Nm_inv_lm)
legend("bottomleft",c("P < 0.0001, R^2 = 0.1117"),bty="n",cex=1.5, text.col='black', text.font=2)

plot(log(es_endangered$Nm),es_endangered$y1, pch = 19, col='gray', cex = size,xlim=c(-6,6),ylim = c(-6,2), xlab="", ylab="",axes=FALSE)
axis(1, col="black", col.ticks="black", col.axis="black", cex.axis=1.5, lwd=3, font=2)
axis(2, col="black", col.ticks="black", col.axis="black", cex.axis=1.5, lwd=3, font=2)
mtext("Gene Flow (lnNm)", side=1, line=3, col="black", cex=1.5, font=2)
mtext("Genetic diversity (lnRR)", side=2, line=3, col="black", cex=1.5, font=2)
Nm_end_lm <- lm(es_endangered$y1~log(es_endangered$Nm),data=es_endangered,weights=(1/v1))
abline(Nm_end_lm, col='gray', lwd=3)
summary(Nm_end_lm)
legend("bottomright",c("P < 0.05, R^2 = 0.0087"),bty="n",cex=1.5, text.col='gray', text.font=2)

points(log(es_invasive$Nm), es_invasive$y1,pch = 19, col='black', cex = size2)
Nm_inv_lm <- lm(es_invasive$y1~log(es_invasive$Nm),data=es_invasive,weights=(1/v1))
abline(Nm_inv_lm, col='black', lwd=3)
summary(Nm_inv_lm)
legend("bottomleft",c("P < 0.001, R^2 = 0.2272"),bty="n",cex=1.5, text.col='black', text.font=2)

#Nm - Outlier removal
es_endangered_Nm_noout <- es_endangered[order(-es_endangered$Nm), ]
View(es_endangered_Nm_noout)
es_endangered_Nm_noout <- es_endangered_Nm_noout[es_endangered_Nm_noout$Nm <= 20, , drop = FALSE]
es_endangered_Nm_noout <- es_endangered_Nm_noout[rowSums(is.na(es_endangered_Nm_noout)) != ncol(es_endangered_Nm_noout), ]
w1_Nm_noout <- 1/es_endangered_Nm_noout$v1
size_Nm_noout <- 0.5 + 3 * (w1_Nm_noout - min(w1_Nm_noout))/(max(w1_Nm_noout) - min(w1_Nm_noout))

plot(es_endangered_Nm_noout$Nm,es_endangered_Nm_noout$y1, pch = 19, col='gray', cex = size_Nm_noout, xlim=c(0,20), ylim = c(-6,2), xlab="", ylab="",axes=FALSE)
axis(1, col="black", col.ticks="black", col.axis="black", cex.axis=1.5, lwd=3, font=2)
axis(2, col="black", col.ticks="black", col.axis="black", cex.axis=1.5, lwd=3, font=2)
mtext("Gene Flow", side=1, line=3, col="black", cex=1.5, font=2)
mtext("Genetic diversity (lnRR)", side=2, line=3, col="black", cex=1.5, font=2)
Nm_end_lm <- lm(es_endangered_Nm_noout$y1~es_endangered_Nm_noout$Nm,data=es_endangered_Nm_noout,weights=(1/v1))
abline(Nm_end_lm, col='gray', lwd=3)
summary(Nm_end_lm)#0.09992    0.02889   3.458 0.000609 ***,Multiple R-squared:  0.03206,	Adjusted R-squared:  0.02938, p-value: 0.0006092
legend("bottomright",c("P < 0.001, R^2 = 0.0294"),bty="n",cex=1.5, text.col='gray', text.font=2)

points(es_invasive$Nm, es_invasive$y1,pch = 19, col='black', cex = size2)
Nm_inv_lm <- lm(es_invasive$y1~es_invasive$Nm,data=es_invasive,weights=(1/v1))
abline(Nm_inv_lm, col='black', lwd=3)
summary(Nm_inv_lm)
legend("bottomleft",c("P < 0.0001, R^2 = 0.1117"),bty="n",cex=1.5, text.col='black', text.font=2)

plot(log(es_endangered_Nm_noout$Nm),es_endangered_Nm_noout$y1, pch = 19, col='gray', cex = size_Nm_noout,xlim=c(-6,4),ylim = c(-6,2), xlab="", ylab="",axes=FALSE)
axis(1, col="black", col.ticks="black", col.axis="black", cex.axis=1.5, lwd=3, font=2)
axis(2, col="black", col.ticks="black", col.axis="black", cex.axis=1.5, lwd=3, font=2)
mtext("Gene Flow (lnNm)", side=1, line=3, col="black", cex=1.5, font=2)
mtext("Genetic diversity (lnRR)", side=2, line=3, col="black", cex=1.5, font=2)
Nm_end_lm <- lm(es_endangered_Nm_noout$y1~log(es_endangered_Nm_noout$Nm),data=es_endangered_Nm_noout,weights=(1/v1))
abline(Nm_end_lm, col='gray', lwd=3)
summary(Nm_end_lm)#0.09992    0.02889   3.458 0.000609 ***; Multiple R-squared:  0.03206,	Adjusted R-squared:  0.02938,  p-value: 0.0006092
legend("bottomright",c("P < 0.001, R^2 = 0.0294"),bty="n",cex=1.5, text.col='gray', text.font=2)

points(log(es_invasive$Nm), es_invasive$y1,pch = 19, col='black', cex = size2)
Nm_inv_lm <- lm(es_invasive$y1~log(es_invasive$Nm),data=es_invasive,weights=(1/v1))
abline(Nm_inv_lm, col='black', lwd=3)
summary(Nm_inv_lm)
legend("bottomleft",c("P < 0.001, R^2 = 0.2272"),bty="n",cex=1.5, text.col='black', text.font=2)


#Na(i.e., Nc)
plot(es_endangered$Na,es_endangered$y1, pch = 19, col='gray', cex = size, ylim = c(-6,2), xlab="", ylab="",axes=FALSE)
axis(1, col="black", col.ticks="black", col.axis="black", cex.axis=1.5, lwd=3, font=2)
axis(2, col="black", col.ticks="black", col.axis="black", cex.axis=1.5, lwd=3, font=2)
mtext("Census Population Size", side=1, line=3, col="black", cex=1.5, font=2)
mtext("Genetic diversity (lnRR)", side=2, line=3, col="black", cex=1.5, font=2)
Na_end_lm <- lm(es_endangered$y1~es_endangered$Na,data=es_endangered,weights=(1/v1))
abline(Na_end_lm, col='gray', lwd=3, lty=2)
summary(Na_end_lm)
legend("bottomright",c("P > 0.05, R^2 = 0.0009"),bty="n",cex=1.5, text.col='gray', text.font=2)

points(es_invasive$Na, es_invasive$y1,pch = 19, col='black', cex = size2)
Na_inv_lm <- lm(es_invasive$y1~es_invasive$Na,data=es_invasive,weights=(1/v1))
abline(Na_inv_lm, col='black', lwd=3, lty=2)
summary(Na_inv_lm)
legend("bottomleft",c("P > 0.05, R^2 = 0.0232"),bty="n",cex=1.5, text.col='black', text.font=2)

plot(log(es_endangered$Na),es_endangered$y1, pch = 19, col='gray', cex = size, xlim=c(0,14), ylim = c(-6,2), xlab="", ylab="",axes=FALSE)
axis(1, col="black", col.ticks="black", col.axis="black", cex.axis=1.5, lwd=3, font=2)
axis(2, col="black", col.ticks="black", col.axis="black", cex.axis=1.5, lwd=3, font=2)
mtext("Census Population Size (lnNc)", side=1, line=3, col="black", cex=1.5, font=2)
mtext("Genetic diversity (lnRR)", side=2, line=3, col="black", cex=1.5, font=2)
Na_end_lm <- lm(es_endangered$y1~log(es_endangered$Na),data=es_endangered,weights=(1/v1))
abline(Na_end_lm, col='gray', lwd=3, lty=2)
summary(Na_end_lm)
legend("bottomright",c("P > 0.05, R^2 = 0.0047"),bty="n",cex=1.5, text.col='gray', text.font=2)

points(log(es_invasive$Na), es_invasive$y1,pch = 19, col='black', cex = size2)
Na_inv_lm <- lm(es_invasive$y1~log(es_invasive$Na),data=es_invasive,weights=(1/v1))
abline(Na_inv_lm, col='black', lwd=3, lty=2)
summary(Na_inv_lm)
legend("bottomleft",c("P > 0.05, R^2 = -0.0146"),bty="n",cex=1.5, text.col='black', text.font=2)

#Nc - Outlier removal
es_endangered_Nc_noout <- es_endangered[order(-es_endangered$Na), ]
View(es_endangered_Nc_noout)
es_endangered_Nc_noout <- es_endangered_Nc_noout[es_endangered_Nc_noout$Na <= 6000, , drop = FALSE]
es_endangered_Nc_noout <- es_endangered_Nc_noout[rowSums(is.na(es_endangered_Nc_noout)) != ncol(es_endangered_Nc_noout), ]
w1_Nc_noout <- 1/es_endangered_Nc_noout$v1
size_Nc_noout <- 0.5 + 3 * (w1_Nc_noout - min(w1_Nc_noout))/(max(w1_Nc_noout) - min(w1_Nc_noout))

plot(es_endangered_Nc_noout$Na,es_endangered_Nc_noout$y1, pch = 19, col='gray', cex = size_Nc_noout, xlim = c(0,6000), ylim = c(-6,2), xlab="", ylab="",axes=FALSE)
axis(1, col="black", col.ticks="black", col.axis="black", cex.axis=1.5, lwd=3, font=2)
axis(2, col="black", col.ticks="black", col.axis="black", cex.axis=1.5, lwd=3, font=2)
mtext("Census Population Size", side=1, line=3, col="black", cex=1.5, font=2)
mtext("Genetic diversity (lnRR)", side=2, line=3, col="black", cex=1.5, font=2)
Na_end_lm <- lm(es_endangered_Nc_noout$y1~es_endangered_Nc_noout$Na,data=es_endangered_Nc_noout,weights=(1/v1))
abline(Na_end_lm, col='gray', lwd=3, lty=2)
summary(Na_end_lm)#Adjusted R-squared:  -0.0006901,  p-value: 0.3795
legend("bottomright",c("P > 0.05, R^2 = -0.0007"),bty="n",cex=1.5, text.col='gray', text.font=2)

points(es_invasive$Na, es_invasive$y1,pch = 19, col='black', cex = size2)
Na_inv_lm <- lm(es_invasive$y1~es_invasive$Na,data=es_invasive,weights=(1/v1))
abline(Na_inv_lm, col='black', lwd=3, lty=2)
summary(Na_inv_lm)
legend("bottomleft",c("P > 0.05, R^2 = 0.0232"),bty="n",cex=1.5, text.col='black', text.font=2)

plot(log(es_endangered_Nc_noout$Na),es_endangered_Nc_noout$y1, pch = 19, col='gray', cex = size_Nc_noout, xlim=c(0,10), ylim = c(-6,2), xlab="", ylab="",axes=FALSE)
axis(1, col="black", col.ticks="black", col.axis="black", cex.axis=1.5, lwd=3, font=2)
axis(2, col="black", col.ticks="black", col.axis="black", cex.axis=1.5, lwd=3, font=2)
mtext("Census Population Size (lnNc)", side=1, line=3, col="black", cex=1.5, font=2)
mtext("Genetic diversity (lnRR)", side=2, line=3, col="black", cex=1.5, font=2)
Na_end_lm <- lm(es_endangered_Nc_noout$y1~log(es_endangered_Nc_noout$Na),data=es_endangered_Nc_noout,weights=(1/v1))
abline(Na_end_lm, col='gray', lwd=3, lty=2)
summary(Na_end_lm)#Adjusted R-squared:  -0.002548,  p-value: 0.6813
legend("bottomright",c("P > 0.05, R^2 = -0.0025"),bty="n",cex=1.5, text.col='gray', text.font=2)

points(log(es_invasive$Na), es_invasive$y1,pch = 19, col='black', cex = size2)
Na_inv_lm <- lm(es_invasive$y1~log(es_invasive$Na),data=es_invasive,weights=(1/v1))
abline(Na_inv_lm, col='black', lwd=3, lty=2)
summary(Na_inv_lm)
legend("bottomleft",c("P > 0.05, R^2 = -0.0146"),bty="n",cex=1.5, text.col='black', text.font=2)


#Ne
plot(log(es_endangered$Ne),es_endangered$y1, pch = 19, col='gray', cex = size, xlim=c(0,14), ylim = c(-2,2), xlab="", ylab="",axes=FALSE)
axis(1, col="black", col.ticks="black", col.axis="black", cex.axis=1.5, lwd=3, font=2)
axis(2, col="black", col.ticks="black", col.axis="black", cex.axis=1.5, lwd=3, font=2)
mtext("Effective Population Size (lnNe)", side=1, line=3, col="black", cex=1.5, font=2)
mtext("Genetic diversity (lnRR)", side=2, line=3, col="black", cex=1.5, font=2)
Ne_end_lm <- lm(es_endangered$y1~log(es_endangered$Ne),data=es_endangered,weights=(1/v1))
abline(Ne_end_lm, col='gray', lwd=3, lty=2)
summary(Ne_end_lm)
legend("bottomright",c("P > 0.05, R^2 = -0.0009"),bty="n",cex=1.5, text.col='gray', text.font=2)
#Because the observed number of invasive plants Ne was too small (3), it was not fit

plot(es_endangered$Ne,es_endangered$y1, pch = 19, col='gray', cex = size, ylim = c(-2,2), xlab="", ylab="",axes=FALSE)
axis(1, col="black", col.ticks="black", col.axis="black", cex.axis=1.5, lwd=3, font=2)
axis(2, col="black", col.ticks="black", col.axis="black", cex.axis=1.5, lwd=3, font=2)
mtext("Effective Population Size", side=1, line=3, col="black", cex=1.5, font=2)
mtext("Genetic diversity (lnRR)", side=2, line=3, col="black", cex=1.5, font=2)
Ne_end_lm <- lm(es_endangered$y1~es_endangered$Ne,data=es_endangered,weights=(1/v1))
abline(Ne_end_lm, col='gray', lwd=3, lty=2)
summary(Ne_end_lm)
legend("bottomright",c("P > 0.05, R^2 = 0.0495"),bty="n",cex=1.5, text.col='gray', text.font=2)
#Because the observed number of invasive plants Ne was too small (3), it was not fit

#pri_num
plot(log(es_endangered$pri_num),es_endangered$y1, pch = 19, col='gray', cex = size, ylim = c(-6,2), xlab="", ylab="",axes=FALSE)
axis(1, col="black", col.ticks="black", col.axis="black", cex.axis=1.5, lwd=3, font=2)
axis(2, col="black", col.ticks="black", col.axis="black", cex.axis=1.5, lwd=3, font=2)
mtext("Number of loci (lnNL)", side=1, line=3, col="black", cex=1.5, font=2)
mtext("Genetic diversity (lnRR)", side=2, line=3, col="black", cex=1.5, font=2)
Pn_end_lm <- lm(es_endangered$y1~log(es_endangered$pri_num),data=es_endangered,weights=(1/v1))
abline(Pn_end_lm, col='gray', lwd=3, lty=2)
summary(Pn_end_lm)
legend("bottomright",c("P > 0.05, R^2 = 0.0004"),bty="n",cex=1.5, text.col='gray', text.font=2)

points(log(es_invasive$pri_num), es_invasive$y1,pch = 19, col='black', cex = size2)
Pn_inv_lm <- lm(es_invasive$y1~log(es_invasive$pri_num),data=es_invasive,weights=(1/v1))
abline(Pn_inv_lm, col='black', lwd=3, lty=2)
summary(Pn_inv_lm)
legend("bottomleft",c("P > 0.05, R^2 = 0.0031"),bty="n",cex=1.5, text.col='black', text.font=2)

plot(es_endangered$pri_num,es_endangered$y1, pch = 19, col='gray', cex = size, ylim = c(-6,2), xlab="", ylab="",axes=FALSE)
axis(1, col="black", col.ticks="black", col.axis="black", cex.axis=1.5, lwd=3, font=2)
axis(2, col="black", col.ticks="black", col.axis="black", cex.axis=1.5, lwd=3, font=2)
mtext("Number of loci", side=1, line=3, col="black", cex=1.5, font=2)
mtext("Genetic diversity (lnRR)", side=2, line=3, col="black", cex=1.5, font=2)
Pn_end_lm <- lm(es_endangered$y1~es_endangered$pri_num,data=es_endangered,weights=(1/v1))
abline(Pn_end_lm, col='gray', lwd=3)
summary(Pn_end_lm)
legend("bottomright",c("P < 0.001, R^2 = 0.0174"),bty="n",cex=1.5, text.col='gray', text.font=2)

points(es_invasive$pri_num, es_invasive$y1,pch = 19, col='black', cex = size2)
Pn_inv_lm <- lm(es_invasive$y1~es_invasive$pri_num,data=es_invasive,weights=(1/v1))
abline(Pn_inv_lm, col='black', lwd=3)
summary(Pn_inv_lm)
legend("bottomleft",c("P < 0.001, R^2 = 0.0359"),bty="n",cex=1.5, text.col='black', text.font=2)
