##Preparation

library(readxl)
options(na.action = "na.exclude")

#Endangered plants
es_endangered <- read_excel("your_path/Appendix_S4.xlsx", sheet = 1)
w1 <- 1/es_endangered$vi
size <- 0.5 + 3 * (w1 - min(w1))/(max(w1) - min(w1))

#Invasive plants
es_invasive <- read_excel("your_path/Appendix_S5.xlsx", sheet = 1)
w2 <- 1/es_invasive$vi
size2 <- 0.5 + 3 * (w2 - min(w2))/(max(w2) - min(w2))


##Weighted linear regression plot (gray scale)

#Fst
#par(mar=c(2, 2, 2, 2) + 0.1)
plot(es_endangered$Fst,es_endangered$yi, pch = 19, col='gray', cex = size,xlim=c(0,1),ylim = c(-3,1), xlab="", ylab="",axes=FALSE)
axis(1, col="black", col.ticks="black", col.axis="black", cex.axis=1.5, lwd=3, font=2)
axis(2, col="black", col.ticks="black", col.axis="black", cex.axis=1.5, lwd=3, font=2)
mtext("Population differentiation", side=1, line=3, col="black", cex=1.5, font=2)
mtext("Genetic diversity (lnRR)", side=2, line=3, col="black", cex=1.5, font=2)
Fst_end_lm <- lm(es_endangered$yi~es_endangered$Fst,data=es_endangered,weights=(1/vi))
abline(Fst_end_lm, col='gray', lwd=3)#The ones that are not significant are indicated by dotted lines, lty=2
summary(Fst_end_lm)
legend("bottomright",c("P < 0.001, R^2 = 0.6133"),bty="n",cex=1.5, text.col='gray', text.font=2)

points(es_invasive$Fst, es_invasive$yi,pch = 19, col='black', cex = size2)
Fst_inv_lm <- lm(es_invasive$yi~es_invasive$Fst,data=es_invasive,weights=(1/vi))
abline(Fst_inv_lm, col='black', lwd=3)
summary(Fst_inv_lm)
legend("bottomleft",c("P < 0.001, R^2 = 0.5512"),bty="n",cex=1.5, text.col='black', text.font=2)

#FIS
plot(es_endangered$FIS,es_endangered$yi, pch = 19, col='gray', cex = size,xlim=c(-1,1),ylim = c(-6,2), xlab="", ylab="",axes=FALSE)
axis(1, col="black", col.ticks="black", col.axis="black", cex.axis=1.5, lwd=3, font=2)
axis(2, col="black", col.ticks="black", col.axis="black", cex.axis=1.5, lwd=3, font=2)
mtext("Coefficient of inbreeding", side=1, line=3, col="black", cex=1.5, font=2)
mtext("Genetic diversity (lnRR)", side=2, line=3, col="black", cex=1.5, font=2)
FIS_end_lm <- lm(es_endangered$yi~es_endangered$FIS,data=es_endangered,weights=(1/vi))
abline(FIS_end_lm, col='gray', lwd=3)
summary(FIS_end_lm)
legend("bottomright",c("P < 0.0001, R^2 = 0.5905"),bty="n",cex=1.5, text.col='gray', text.font=2)

points(es_invasive$FIS, es_invasive$yi,pch = 19, col='black', cex = size2)
FIS_inv_lm <- lm(es_invasive$yi~es_invasive$FIS,data=es_invasive,weights=(1/vi))
abline(FIS_inv_lm, col='black', lwd=3)
summary(FIS_inv_lm)
legend("bottomleft",c("P < 0.05, R^2 = 0.4170"),bty="n",cex=1.5, text.col='black', text.font=2)

#Remove the two over weight data of endangered plants
es_endangered_sorted <- es_endangered[order(es_endangered$vi), ]#Arrange the table in ascending vi order
es_endangered_sorted <- es_endangered_sorted[-c(1, 2), ]
w1_sorted <- 1/es_endangered_sorted$vi
size_sorted <- 0.5 + 3 * (w1_sorted - min(w1_sorted))/(max(w1_sorted) - min(w1_sorted))
plot(es_endangered_sorted$FIS,es_endangered_sorted$yi, pch = 19, col='gray', cex = size_sorted,xlim=c(-1,1),ylim = c(-6,2), xlab="", ylab="",axes=FALSE)
axis(1, col="black", col.ticks="black", col.axis="black", cex.axis=1.5, lwd=3, font=2)
axis(2, col="black", col.ticks="black", col.axis="black", cex.axis=1.5, lwd=3, font=2)
mtext("Coefficient of inbreeding", side=1, line=3, col="black", cex=1.5, font=2)
mtext("Genetic diversity (lnRR)", side=2, line=3, col="black", cex=1.5, font=2)
FIS_end_lm_sorted <- lm(es_endangered_sorted$yi~es_endangered_sorted$FIS,data=es_endangered_sorted,weights=(1/vi))
abline(FIS_end_lm_sorted, col='gray', lwd=3, lty=2)
summary(FIS_end_lm_sorted)
legend("bottomright",c("P = 0.2366, R^2 = 0.0292"),bty="n",cex=1.5, text.col='gray', text.font=2)


#Nm
plot(es_endangered$Nm,es_endangered$yi, pch = 19, col='gray', cex = size, xlim=c(0,6), ylim = c(-3,1), xlab="", ylab="",axes=FALSE)
axis(1, col="black", col.ticks="black", col.axis="black", cex.axis=1.5, lwd=3, font=2)
axis(2, col="black", col.ticks="black", col.axis="black", cex.axis=1.5, lwd=3, font=2)
mtext("Gene Flow", side=1, line=3, col="black", cex=1.5, font=2)
mtext("Genetic diversity (lnRR)", side=2, line=3, col="black", cex=1.5, font=2)
Nm_end_lm <- lm(es_endangered$yi~es_endangered$Nm,data=es_endangered,weights=(1/vi))
abline(Nm_end_lm, col='gray', lwd=3, lty=2)
summary(Nm_end_lm)
legend("bottomright",c("P > 0.05, R^2 = 0.0593"),bty="n",cex=1.5, text.col='gray', text.font=2)

points(es_invasive$Nm, es_invasive$yi,pch = 19, col='black', cex = size2)
Nm_inv_lm <- lm(es_invasive$yi~es_invasive$Nm,data=es_invasive,weights=(1/vi))
abline(Nm_inv_lm, col='black', lwd=3)
summary(Nm_inv_lm)
legend("bottomleft",c("P < 0.05, R^2 = 0.2377"),bty="n",cex=1.5, text.col='black', text.font=2)

plot(log(es_endangered$Nm),es_endangered$yi, pch = 19, col='gray', cex = size,xlim=c(-4,4),ylim = c(-3,1), xlab="", ylab="",axes=FALSE)
axis(1, col="black", col.ticks="black", col.axis="black", cex.axis=1.5, lwd=3, font=2)
axis(2, col="black", col.ticks="black", col.axis="black", cex.axis=1.5, lwd=3, font=2)
mtext("Gene Flow (lnNm)", side=1, line=3, col="black", cex=1.5, font=2)
mtext("Genetic diversity (lnRR)", side=2, line=3, col="black", cex=1.5, font=2)
Nm_end_lm <- lm(es_endangered$yi~log(es_endangered$Nm),data=es_endangered,weights=(1/vi))
abline(Nm_end_lm, col='gray', lwd=3, lty=2)
summary(Nm_end_lm)
legend("bottomright",c("P > 0.05, R^2 = 0.0593"),bty="n",cex=1.5, text.col='gray', text.font=2)

points(log(es_invasive$Nm), es_invasive$yi,pch = 19, col='black', cex = size2)
Nm_inv_lm <- lm(es_invasive$yi~log(es_invasive$Nm),data=es_invasive,weights=(1/vi))
abline(Nm_inv_lm, col='black', lwd=3)
summary(Nm_inv_lm)
legend("bottomleft",c("P < 0.01, R^2 = 0.5015"),bty="n",cex=1.5, text.col='black', text.font=2)

#Na(i.e., Nc)
plot(es_endangered$Na,es_endangered$yi, pch = 19, col='gray', cex = size, ylim = c(-3,1), xlab="", ylab="",axes=FALSE)
axis(1, col="black", col.ticks="black", col.axis="black", cex.axis=1.5, lwd=3, font=2)
axis(2, col="black", col.ticks="black", col.axis="black", cex.axis=1.5, lwd=3, font=2)
mtext("Census Population Size", side=1, line=3, col="black", cex=1.5, font=2)
mtext("Genetic diversity (lnRR)", side=2, line=3, col="black", cex=1.5, font=2)
Na_end_lm <- lm(es_endangered$yi~es_endangered$Na,data=es_endangered,weights=(1/vi))
abline(Na_end_lm, col='gray', lwd=3, lty=2)
summary(Na_end_lm)
legend("bottomright",c("P > 0.05, R^2 = -0.1643"),bty="n",cex=1.5, text.col='gray', text.font=2)

plot(log(es_endangered$Na),es_endangered$yi, pch = 19, col='gray', cex = size, xlim=c(4,10), ylim = c(-3,1), xlab="", ylab="",axes=FALSE)
axis(1, col="black", col.ticks="black", col.axis="black", cex.axis=1.5, lwd=3, font=2)
axis(2, col="black", col.ticks="black", col.axis="black", cex.axis=1.5, lwd=3, font=2)
mtext("Census Population Size (lnNc)", side=1, line=3, col="black", cex=1.5, font=2)
mtext("Genetic diversity (lnRR)", side=2, line=3, col="black", cex=1.5, font=2)
Na_end_lm <- lm(es_endangered$yi~log(es_endangered$Na),data=es_endangered,weights=(1/vi))
abline(Na_end_lm, col='gray', lwd=3, lty=2)
summary(Na_end_lm)
legend("bottomright",c("P > 0.05, R^2 = 0.0806"),bty="n",cex=1.5, text.col='gray', text.font=2)

#Nc - Outlier removal
es_endangered_Nc_noout <- es_endangered[order(-es_endangered$Na), ]
View(es_endangered_Nc_noout)
es_endangered_Nc_noout <- es_endangered_Nc_noout[es_endangered_Nc_noout$Na <= 6000, , drop = FALSE]
es_endangered_Nc_noout <- es_endangered_Nc_noout[rowSums(is.na(es_endangered_Nc_noout)) != ncol(es_endangered_Nc_noout), ]
w1_Nc_noout <- 1/es_endangered_Nc_noout$vi
size_Nc_noout <- 0.5 + 3 * (w1_Nc_noout - min(w1_Nc_noout))/(max(w1_Nc_noout) - min(w1_Nc_noout))

plot(es_endangered_Nc_noout$Na,es_endangered_Nc_noout$yi, pch = 19, col='gray', cex = size_Nc_noout, ylim = c(-3,1), xlab="", ylab="",axes=FALSE)
axis(1, col="black", col.ticks="black", col.axis="black", cex.axis=1.5, lwd=3, font=2)
axis(2, col="black", col.ticks="black", col.axis="black", cex.axis=1.5, lwd=3, font=2)
mtext("Census Population Size", side=1, line=3, col="black", cex=1.5, font=2)
mtext("Genetic diversity (lnRR)", side=2, line=3, col="black", cex=1.5, font=2)
Na_end_lm <- lm(es_endangered_Nc_noout$yi~es_endangered_Nc_noout$Na,data=es_endangered_Nc_noout,weights=(1/vi))
abline(Na_end_lm, col='gray', lwd=3, lty=2)
summary(Na_end_lm)#Adjusted R-squared:  0.2644,  p-value: 0.1697
legend("bottomright",c("P > 0.05, R^2 = 0.2644"),bty="n",cex=1.5, text.col='gray', text.font=2)

plot(log(es_endangered_Nc_noout$Na),es_endangered_Nc_noout$yi, pch = 19, col='gray', cex = size_Nc_noout, ylim = c(-3,1), xlab="", ylab="",axes=FALSE)
axis(1, col="black", col.ticks="black", col.axis="black", cex.axis=1.5, lwd=3, font=2)
axis(2, col="black", col.ticks="black", col.axis="black", cex.axis=1.5, lwd=3, font=2)
mtext("Census Population Size (lnNc)", side=1, line=3, col="black", cex=1.5, font=2)
mtext("Genetic diversity (lnRR)", side=2, line=3, col="black", cex=1.5, font=2)
Na_end_lm <- lm(es_endangered_Nc_noout$yi~log(es_endangered_Nc_noout$Na),data=es_endangered_Nc_noout,weights=(1/vi))
abline(Na_end_lm, col='gray', lwd=3, lty=2)
summary(Na_end_lm)#Adjusted R-squared:  0.4466,  p-value: 0.08825
legend("bottomright",c("P > 0.05, R^2 = 0.4466"),bty="n",cex=1.5, text.col='gray', text.font=2)


#pri_num
plot(log(es_endangered$pri_num),es_endangered$yi, pch = 19, col='gray', cex = size, xlim = c(1,3.5), ylim = c(-3,1), xlab="", ylab="",axes=FALSE)
axis(1, col="black", col.ticks="black", col.axis="black", cex.axis=1.5, lwd=3, font=2)
axis(2, col="black", col.ticks="black", col.axis="black", cex.axis=1.5, lwd=3, font=2)
mtext("Number of loci (lnNL)", side=1, line=3, col="black", cex=1.5, font=2)
mtext("Genetic diversity (lnRR)", side=2, line=3, col="black", cex=1.5, font=2)
Pn_end_lm <- lm(es_endangered$yi~log(es_endangered$pri_num),data=es_endangered,weights=(1/vi))
abline(Pn_end_lm, col='gray', lwd=3)
summary(Pn_end_lm)
legend("bottomright",c("P < 0.0001, R^2 = 0.5942"),bty="n",cex=1.5, text.col='gray', text.font=2)

points(log(es_invasive$pri_num), es_invasive$yi,pch = 19, col='black', cex = size2)
Pn_inv_lm <- lm(es_invasive$yi~log(es_invasive$pri_num),data=es_invasive,weights=(1/vi))
abline(Pn_inv_lm, col='black', lwd=3)
summary(Pn_inv_lm)
legend("bottomleft",c("P < 0.01, R^2 = 0.2170"),bty="n",cex=1.5, text.col='black', text.font=2)

plot(es_endangered$pri_num,es_endangered$yi, pch = 19, col='gray', cex = size, xlim = c(0,25), ylim = c(-3,1), xlab="", ylab="",axes=FALSE)
axis(1, col="black", col.ticks="black", col.axis="black", cex.axis=1.5, lwd=3, font=2)
axis(2, col="black", col.ticks="black", col.axis="black", cex.axis=1.5, lwd=3, font=2)
mtext("Number of loci", side=1, line=3, col="black", cex=1.5, font=2)
mtext("Genetic diversity (lnRR)", side=2, line=3, col="black", cex=1.5, font=2)
Pn_end_lm <- lm(es_endangered$yi~es_endangered$pri_num,data=es_endangered,weights=(1/vi))
abline(Pn_end_lm, col='gray', lwd=3)
summary(Pn_end_lm)
legend("bottomright",c("P < 0.0001, R^2 = 0.6166"),bty="n",cex=1.5, text.col='gray', text.font=2)

points(es_invasive$pri_num, es_invasive$yi,pch = 19, col='black', cex = size2)
Pn_inv_lm <- lm(es_invasive$yi~es_invasive$pri_num,data=es_invasive,weights=(1/vi))
abline(Pn_inv_lm, col='black', lwd=3)
summary(Pn_inv_lm)
legend("bottomleft",c("P < 0.0001, R^2 = 0.4939"),bty="n",cex=1.5, text.col='black', text.font=2)
