library(metafor)
library(MuMIn)
library(readxl)
es_invasive <- read_excel("your_path/Appendix_S6.xlsx", sheet = 1)

#Set the random factor
es_invasive$taxon<-as.factor(es_invasive$taxon)
es_invasive$gene_meth<-as.factor(es_invasive$gene_meth)
es_invasive$DNA_sou<-as.factor(es_invasive$DNA_sou)

#invasion_time

es_invasive$invasion_time<-as.numeric(es_invasive$invasion_time)
model_invasion_time <- rma.mv(y1, v1, mods= ~ invasion_time, random = list(~ 1 | taxon, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = es_invasive)
summary(model_invasion_time)#QE(df = 413) = 15638.5960, p-val < .0001; QM(df = 1) = 35.8953, p-val < .0001; ***

#WLR
options(na.action = "na.exclude")
w2 <- 1/es_invasive$v1
size2 <- 0.5 + 3 * (w2 - min(w2))/(max(w2) - min(w2))

plot(es_invasive$invasion_time,es_invasive$y1, pch = 19, col='black', cex = size2, xlim=c(0,505),ylim = c(-6,2), xlab="", ylab="",axes=FALSE)
axis(1, col="black", col.ticks="black", col.axis="black", cex.axis=1.5, lwd=3, font=2)
axis(2, col="black", col.ticks="black", col.axis="black", cex.axis=1.5, lwd=3, font=2)
mtext("Invasion time", side=1, line=3, col="black", cex=1.5, font=2)
mtext("Genetic diversity (lnRR)", side=2, line=3, col="black", cex=1.5, font=2)
invasion_time_lm <- lm(es_invasive$y1~es_invasive$invasion_time,data=es_invasive,weights=(1/v1))
abline(invasion_time_lm, col='black', lwd=3, lty=2)#The ones that are not significant are indicated by dotted lines
summary(invasion_time_lm)
legend("bottomright",c("P > 0.05, R^2 = -0.0024"),bty="n",cex=1.5, text.col='black', text.font=2)

shapiro.test(es_invasive$invasion_time)
shapiro.test(log10(es_invasive$invasion_time))
shapiro.test(sqrt(es_invasive$invasion_time))
shapiro.test(gamma(es_invasive$invasion_time))


plot(log(es_invasive$invasion_time),es_invasive$y1, pch = 19, col='black', cex = size2, xlim=c(0,7),ylim = c(-6,2), xlab="", ylab="",axes=FALSE)
axis(1, col="black", col.ticks="black", col.axis="black", cex.axis=1.5, lwd=3, font=2)
axis(2, col="black", col.ticks="black", col.axis="black", cex.axis=1.5, lwd=3, font=2)
mtext("Invasion time (lnIt)", side=1, line=3, col="black", cex=1.5, font=2)
mtext("Genetic diversity (lnRR)", side=2, line=3, col="black", cex=1.5, font=2)
invasion_time_lm_ln <- lm(es_invasive$y1~log(es_invasive$invasion_time),data=es_invasive,weights=(1/v1))
abline(invasion_time_lm_ln, col='black', lwd=3, lty=2)
summary(invasion_time_lm_ln)
legend("bottomright",c("P > 0.05, R^2 = -0.0014"),bty="n",cex=1.5, text.col='black', text.font=2)