library(metafor)
library(MuMIn)
library(readxl)
es_invasive <- read_excel("your_path/Appendix_S7.xlsx", sheet = 1)

#Set the random factor
es_invasive$taxon_exp<-as.factor(es_invasive$taxon_exp)
es_invasive$taxon_ctrl<-as.factor(es_invasive$taxon_ctrl)
es_invasive$gene_meth<-as.factor(es_invasive$gene_meth)
es_invasive$DNA_sou<-as.factor(es_invasive$DNA_sou)

#invasion_time

es_invasive$invasion_time<-as.numeric(es_invasive$invasion_time)
model_invasion_time <- rma.mv(yi, vi, mods= ~ invasion_time, random = list(~ 1 | taxon_exp, ~ 1 | taxon_ctrl, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = es_invasive)
summary(model_invasion_time)#QE(df = 18) = 618.2907, p-val < .0001; QM(df = 1) = 0.3923, p-val = 0.5311; ns

#WLR
options(na.action = "na.exclude")
w2 <- 1/es_invasive$vi
size2 <- 0.5 + 3 * (w2 - min(w2))/(max(w2) - min(w2))

plot(es_invasive$invasion_time,es_invasive$yi, pch = 19, col='black', cex = size2, xlim=c(0,300),ylim = c(-3,1), xlab="", ylab="",axes=FALSE)
axis(1, col="black", col.ticks="black", col.axis="black", cex.axis=1.5, lwd=3, font=2)
axis(2, col="black", col.ticks="black", col.axis="black", cex.axis=1.5, lwd=3, font=2)
mtext("Invasion time", side=1, line=3, col="black", cex=1.5, font=2)
mtext("Genetic diversity (lnRR)", side=2, line=3, col="black", cex=1.5, font=2)
invasion_time_lm <- lm(es_invasive$yi~es_invasive$invasion_time,data=es_invasive,weights=(1/vi))
abline(invasion_time_lm, col='black', lwd=3, lty=2)#The ones that are not significant are indicated by dotted lines
summary(invasion_time_lm)
legend("bottomright",c("P > 0.05, R^2 = 0.0249"),bty="n",cex=1.5, text.col='black', text.font=2)

shapiro.test(es_invasive$invasion_time)#W = 0.9615, p-value = 0.5743
shapiro.test(log10(es_invasive$invasion_time))#W = 0.91808, p-value = 0.09101
shapiro.test(sqrt(es_invasive$invasion_time))#W = 0.96688, p-value = 0.6881
shapiro.test(gamma(es_invasive$invasion_time))#W = NaN, p-value = NA


plot(log(es_invasive$invasion_time),es_invasive$yi, pch = 19, col='black', cex = size2, xlim=c(3,6),ylim = c(-3,1), xlab="", ylab="",axes=FALSE)
axis(1, col="black", col.ticks="black", col.axis="black", cex.axis=1.5, lwd=3, font=2)
axis(2, col="black", col.ticks="black", col.axis="black", cex.axis=1.5, lwd=3, font=2)
mtext("Invasion time (lnIt)", side=1, line=3, col="black", cex=1.5, font=2)
mtext("Genetic diversity (lnRR)", side=2, line=3, col="black", cex=1.5, font=2)
invasion_time_lm_ln <- lm(es_invasive$yi~log(es_invasive$invasion_time),data=es_invasive,weights=(1/vi))
abline(invasion_time_lm_ln, col='black', lwd=3, lty=2)
summary(invasion_time_lm_ln)
legend("bottomright",c("P > 0.05, R^2 = 0.0197"),bty="n",cex=1.5, text.col='black', text.font=2)