library(metafor)
library(MuMIn)
library(readxl)

es_endangered <- read_excel("your_path/Appendix_S1.xlsx", sheet = 1)
es_invasive <- read_excel("your_path/Appendix_S2.xlsx", sheet = 1)

#Set the random factors
es_endangered$taxon<-as.factor(es_endangered$taxon)
es_endangered$gene_meth<-as.factor(es_endangered$gene_meth)
es_endangered$DNA_sou<-as.factor(es_endangered$DNA_sou)


es_invasive$taxon<-as.factor(es_invasive$taxon)
es_invasive$gene_meth<-as.factor(es_invasive$gene_meth)
es_invasive$DNA_sou<-as.factor(es_invasive$DNA_sou)


#Set the other factors
es_endangered$pri_num<-as.numeric(es_endangered$pri_num)
es_endangered$scale<-as.factor(es_endangered$scale)
es_endangered$latitude<-as.numeric(es_endangered$latitude)
es_endangered$longitude<-as.numeric(es_endangered$longitude)

es_invasive$pri_num<-as.numeric(es_invasive$pri_num)
es_invasive$scale<-as.factor(es_invasive$scale)
es_invasive$latitude<-as.numeric(es_invasive$latitude)
es_invasive$longitude<-as.numeric(es_invasive$longitude)

##Calculate the cumulative effect size
ces_end_3 <- rma.mv(y1, v1, mods= ~ 1, random = list(~ 1 | taxon, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = es_endangered)
summary(ces_end_3)#k = 1096; Q(df = 1095) = 32806.7474, p-val < .0001; estimate -0.4350      se 0.2265     zval -1.9205    pval 0.0548    ci.lb -0.8789   ci.ub 0.0089; .
ces_inv_3 <- rma.mv(y1, v1, mods= ~ 1, random = list(~ 1 | taxon, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = es_invasive)
summary(ces_inv_3)#k = 540; Q(df = 539) = 18755.5022, p-val < .0001; estimate -0.8087      se 0.3727     zval -2.1700    pval 0.0300    ci.lb -1.5391    ci.ub -0.0783; * 

##Publish bias
#Rosenthal fail safe number
fsn(y1, v1, data=es_endangered,type="Rosenthal",alpha=.05, digits=4)#Observed Significance Level: <.0001; Target Significance Level:   0.05; Fail-safe N: 642415 > 5*1096+10=5490
fsn(y1, v1, data=es_invasive,type="Rosenthal",alpha=.05, digits=4)#Observed Significance Level: <.0001; Target Significance Level:   0.05; Fail-safe N: 301965 > 5*540+10=2710
#funnel plot
funnel(ces_end_3)
funnel(ces_end_3, xlab = "Risk Ratio (log scale)",level=c(90, 95, 99), shade=c("white","gray", "darkgray"), refline=0, atransf=exp,at=log(c(.10, .25, .5, 1, 2, 4, 10)))
legend(2, 0.02, c("0.1 > p > 0.05", "0.05 > p >0.01", "< 0.01"), fill=c("white", "gray", "darkgray"))#super funnel!
funnel(ces_inv_3)
funnel(ces_inv_3, xlab = "Risk Ratio (log scale)",level=c(90, 95, 99), shade=c("white","gray", "darkgray"), refline=0, atransf=exp,at=log(c(.10, .25, .5, 1, 2, 4, 10)))
legend(2, 0.02, c("0.1 > p > 0.05", "0.05 > p >0.01", "< 0.01"), fill=c("white", "gray", "darkgray"))#super funnel!
#Although the points with large standard  error at the bottom of the funnel plot are not very symmetrical, most of the samples are distributed in areas with small standard  error at the top, and most of the asymmetric points are distributed in areas with no statistical significance.

##Population genetics related variables

#Na

es_endangered$Na<-as.numeric(es_endangered$Na)
model_Na_end <- rma.mv(y1, v1, mods= ~ Na, random = list(~ 1 | taxon, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = es_endangered)
summary(model_Na_end)#QE(df = 337) = 9093.4604, p-val < .0001; QM(df = 1) = 0.5583, p-val = 0.4549; ns0

es_invasive$Na<-as.numeric(es_invasive$Na)
model_Na_inv <- rma.mv(y1, v1, mods= ~ Na, random = list(~ 1 | taxon, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = es_invasive)
summary(model_Na_inv)#QE(df = 66) = 1331.6979, p-val < .0001; QM(df = 1) = 4.4064, p-val = 0.0358; *0

#Ne

es_endangered$Ne<-as.numeric(es_endangered$Ne)
model_Ne_end <- rma.mv(y1, v1, mods= ~ Ne, random = list(~ 1 | taxon, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = es_endangered)
summary(model_Ne_end)#QE(df = 23) = 541.9211, p-val < .0001; QM(df = 1) = 0.0771, p-val = 0.7812; ns0

es_invasive$Ne<-as.numeric(es_invasive$Ne)
model_Ne_inv <- rma.mv(y1, v1, mods= ~ Ne, random = list(~ 1 | taxon, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = es_invasive)
summary(model_Ne_inv)#QE(df = 2) = 22.0672, p-val < .0001; QM(df = 1) = 8.0952, p-val = 0.0044; **-

#FIS

es_endangered$FIS<-as.numeric(es_endangered$FIS)
model_FIS_end <- rma.mv(y1, v1, mods= ~ FIS, random = list(~ 1 | taxon, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = es_endangered)
summary(model_FIS_end)#QE(df = 441) = 13765.7062, p-val < .0001; QM(df = 1) = 0.2694, p-val = 0.6037; FIS -0.0424  0.0816  -0.5190  0.6037  -0.2023  0.1176 ns-
model_FIS_end_Na <- rma.mv(y1, v1, mods= ~ FIS + Na, random = list(~ 1 | taxon, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = es_endangered)
summary(model_FIS_end_Na)#QE(df = 124) = 3621.8080, p-val < .0001; QM(df = 2) = 20.1062, p-val < .0001; FIS -0.6667  0.1509  -4.4173  <.0001  -0.9625  -0.3709  ***-; Na 0.0000  0.0000   1.6023  0.1091  -0.0000   0.0000

es_invasive$FIS<-as.numeric(es_invasive$FIS)
model_FIS_inv <- rma.mv(y1, v1, mods= ~ FIS, random = list(~ 1 | taxon, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = es_invasive)
summary(model_FIS_inv)#QE(df = 123) = 2571.3036, p-val < .0001; QM(df = 1) = 40.2920, p-val < .0001; FIS 0.6364  0.1003   6.3476  <.0001   0.4399  0.8329 ***+
model_FIS_inv_Na <- rma.mv(y1, v1, mods= ~ FIS + Na, random = list(~ 1 | taxon, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = es_invasive)
summary(model_FIS_inv_Na)#QE(df = 0) = 0.0000, p-val = 1.0000; QM(df = 2) = 0.1564, p-val = 0.9248; FIS 0.7316  5.6675   0.1291  0.8973  -10.3765  11.8397 ns+;Na -0.0005  0.0019  -0.2543  0.7993   -0.0041   0.0032 

#Fst

es_endangered$Fst<-as.numeric(es_endangered$Fst)
model_Fst_end <- rma.mv(y1, v1, mods= ~ Fst, random = list(~ 1 | taxon, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = es_endangered)
summary(model_Fst_end)#QE(df = 366) = 10816.2739, p-val < .0001; QM(df = 1) = 17.6458, p-val < .0001; Fst -0.5326  0.1268  -4.2007  <.0001  -0.7810  -0.2841 ***-
model_Fst_end_Na <- rma.mv(y1, v1, mods= ~ Fst + Na, random = list(~ 1 | taxon, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = es_endangered)
summary(model_Fst_end_Na)#QE(df = 119) = 2777.3516, p-val < .0001; QM(df = 2) = 5.1357, p-val = 0.0767; Fst -0.3741  0.1662  -2.2511  0.0244  -0.6999  -0.0484  *- ;Na 0.0000  0.0000   0.2704  0.7869  -0.0000   0.0000

es_invasive$Fst<-as.numeric(es_invasive$Fst)
model_Fst_inv <- rma.mv(y1, v1, mods= ~ Fst, random = list(~ 1 | taxon, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = es_invasive)
summary(model_Fst_inv)#QE(df = 147) = 4084.7377, p-val < .0001;QM(df = 1) = 19.0827, p-val < .0001; Fst -0.9100  0.2083  -4.3684  <.0001  -1.3183  -0.5017 ***-
model_Fst_inv_Na <- rma.mv(y1, v1, mods= ~ Fst + Na, random = list(~ 1 | taxon, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = es_invasive)
summary(model_Fst_inv_Na)#QE(df = 14) = 25.9981, p-val = 0.0259; QM(df = 2) = 0.4413, p-val = 0.8020; Fst 0.8730  2.1633   0.4036  0.6865  -3.3669  5.1130 ns+; Na 0.0001  0.0002   0.5846  0.5588  -0.0002  0.0004

#Nm

es_endangered$Nm<-as.numeric(es_endangered$Nm)
model_Nm_end <- rma.mv(y1, v1, mods= ~ Nm, random = list(~ 1 | taxon, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = es_endangered)
summary(model_Nm_end)#QE(df = 366) = 10939.8564, p-val < .0001; QM(df = 1) = 7.6806, p-val = 0.0056**; Nm  0.0272  0.0098   2.7714  0.0056   0.0080  0.0465  **+ 
model_Nm_end_Na <- rma.mv(y1, v1, mods= ~ Nm + Na, random = list(~ 1 | taxon, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = es_endangered)
summary(model_Nm_end_Na)#QE(df = 118) = 2771.0240, p-val < .0001; QM(df = 2) = 4.6348, p-val = 0.0985; Nm 0.0346  0.0162   2.1370  0.0326   0.0029  0.0663  *+; Na 0.0000  0.0000   0.3103  0.7564  -0.0000  0.0000

es_invasive$Nm<-as.numeric(es_invasive$Nm)
model_Nm_inv <- rma.mv(y1, v1, mods= ~ Nm, random = list(~ 1 | taxon, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = es_invasive)
summary(model_Nm_inv)#QE(df = 147) = 4883.0803, p-val < .0001; QM(df = 1) = 21.2054, p-val < .0001; Nm 0.0759  0.0165   4.6049  <.0001   0.0436   0.1082 ***+
model_Nm_inv_Na <- rma.mv(y1, v1, mods= ~ Nm + Na, random = list(~ 1 | taxon, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = es_invasive)
summary(model_Nm_inv_Na)#QE(df = 14) = 22.9656, p-val = 0.0608; QE(df = 14) = 22.9656, p-val = 0.0608; Nm -0.0565  0.0698  -0.8090  0.4185  -0.1933  0.0804 ns- ; Na 0.0001  0.0002   0.6734  0.5007  -0.0002  0.0004

##Methods related variables

#pri_num

es_endangered$pri_num<-as.numeric(es_endangered$pri_num)
model_pri_num_end <- rma.mv(y1, v1, mods= ~ pri_num, random = list(~ 1 | taxon, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = es_endangered)
summary(model_pri_num_end)#QE(df = 1094) = 32205.7094, p-val < .0001;QM(df = 1) = 130.2175, p-val < .0001;***-

es_invasive$pri_num<-as.numeric(es_invasive$pri_num)
model_pri_num_inv <- rma.mv(y1, v1, mods= ~ pri_num, random = list(~ 1 | taxon, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = es_invasive)
summary(model_pri_num_inv)#QE(df = 538) = 18049.0119, p-val < .0001; QM(df = 1) = 13.1681, p-val = 0.0003;***+

#scale

es_endangered$scale<-as.factor(es_endangered$scale)
model_scale_end <- rma.mv(y1, v1, mods= ~ scale, random = list(~ 1 | taxon, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = es_endangered)
summary(model_scale_end)#QE(df = 1094) = 32806.3698, p-val < .0001; QM(df = 1) = 91.5355, p-val < .0001
model_scale_end_local  <- rma.mv(y1, v1, subset = (scale == "local"), random = list(~ 1 | taxon, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = es_endangered)
summary(model_scale_end_local)#k = 626; estimate      se     zval    pval    ci.lb   ci.ub  -0.7838  0.4882  -1.6056  0.1084  -1.7407  0.1730 
model_scale_end_region  <- rma.mv(y1, v1, subset = (scale == "region"), random = list(~ 1 | taxon, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = es_endangered)
summary(model_scale_end_region)#k = 470; estimate      se     zval    pval    ci.lb   ci.ub  -0.2728  0.2052  -1.3294  0.1837  -0.6750  0.1294 

es_invasive$scale<-as.factor(es_invasive$scale)
model_scale_inv <- rma.mv(y1, v1, mods= ~ scale, random = list(~ 1 | taxon, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = es_invasive)
summary(model_scale_inv)#QE(df = 538) = 18753.8877, p-val < .0001; QM(df = 1) = 2.5040, p-val = 0.1136
model_scale_inv_local  <- rma.mv(y1, v1, subset = (scale == "local"), random = list(~ 1 | taxon, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = es_invasive)
summary(model_scale_inv_local)#k = 414; estimate      se     zval    pval    ci.lb    ci.ub  -0.7592  0.2823  -2.6891  0.0072  -1.3126  -0.2059  ** 
model_scale_inv_region  <- rma.mv(y1, v1, subset = (scale == "region"), random = list(~ 1 | taxon, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = es_invasive)
summary(model_scale_inv_region)#k = 126; estimate      se     zval    pval    ci.lb    ci.ub  -0.9224  0.4593  -2.0080  0.0446  -1.8227  -0.0221  * 

##Phylogeny related variables

#family

es_endangered$family<-as.factor(es_endangered$family)
model_family_end <- rma.mv(y1, v1, mods= ~ family, random = list(~ 1 | taxon, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = es_endangered)
summary(model_family_end)#QE(df = 972) = 18222.3901, p-val < .0001; QM(df = 123) = 189.1016, p-val = 0.0001 ***

es_invasive$family<-as.factor(es_invasive$family)
model_family_inv <- rma.mv(y1, v1, mods= ~ family, random = list(~ 1 | taxon, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = es_invasive)
summary(model_family_inv)#QE(df = 496) = 14074.3361, p-val < .0001; QM(df = 43) = 52.2585, p-val = 0.1574

#order

es_endangered$order<-as.factor(es_endangered$order)
model_order_end <- rma.mv(y1, v1, mods= ~ order, random = list(~ 1 | taxon, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = es_endangered)
summary(model_order_end)#QE(df = 1048) = 25346.1920, p-val < .0001; QM(df = 47) = 78.8737, p-val = 0.0025 **

es_invasive$order<-as.factor(es_invasive$order)
model_order_inv <- rma.mv(y1, v1, mods= ~ order, random = list(~ 1 | taxon, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = es_invasive)
summary(model_order_inv)#QE(df = 513) = 14646.3981, p-val < .0001; QM(df = 26) = 33.1863, p-val = 0.1568

#class

es_endangered$class<-as.factor(es_endangered$class)
model_class_end <- rma.mv(y1, v1, mods= ~ class, random = list(~ 1 | taxon, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = es_endangered)
summary(model_class_end)#QE(df = 1088) = 30580.0574, p-val < .0001; QM(df = 7) = 36.0215, p-val < .0001 ***

es_invasive$class<-as.factor(es_invasive$class)
model_class_inv <- rma.mv(y1, v1, mods= ~ class, random = list(~ 1 | taxon, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = es_invasive)
summary(model_class_inv)#QE(df = 535) = 17540.6751, p-val < .0001; QM(df = 4) = 7.7452, p-val = 0.1014

#division

es_endangered$division<-as.factor(es_endangered$division)
model_division_end <- rma.mv(y1, v1, mods= ~ division, random = list(~ 1 | taxon, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = es_endangered)
summary(model_division_end)#QE(df = 1091) = 31068.5159, p-val < .0001; QM(df = 4) = 31.7449, p-val < .0001 ***

es_invasive$division<-as.factor(es_invasive$division)
model_division_inv <- rma.mv(y1, v1, mods= ~ division, random = list(~ 1 | taxon, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = es_invasive)
summary(model_division_inv)#QE(df = 536) = 18134.4754, p-val < .0001; QM(df = 3) = 7.7420, p-val = 0.0517 .


##Species characteristic related variables

#Life form

es_endangered$life_form<-as.factor(es_endangered$life_form)
model_life_form_end <- rma.mv(y1, v1, mods= ~ life_form, random = list(~ 1 | taxon, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = es_endangered)
summary(model_life_form_end)#QE(df = 1093) = 32659.8155, p-val < .0001; QM(df = 2) = 7.0788, p-val = 0.0290 *
model_life_form_end_shortlived <- rma.mv(y1, v1, subset = (life_form == "shortlived"), random = list(~ 1 | taxon, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = es_endangered)
summary(model_life_form_end_shortlived)#k = 66; estimate      se     zval    pval    ci.lb   ci.ub  -0.0895  0.4911  -0.1821  0.8555  -1.0520  0.8731 
model_life_form_end_longlived <- rma.mv(y1, v1, subset = (life_form == "longlived"), random = list(~ 1 | taxon, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = es_endangered)
summary(model_life_form_end_longlived)#k = 646; estimate      se     zval    pval    ci.lb   ci.ub  -0.6329  0.3734  -1.6949  0.0901  -1.3648  0.0990  .
model_life_form_end_woody <- rma.mv(y1, v1, subset = (life_form == "woody"), random = list(~ 1 | taxon, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = es_endangered)
summary(model_life_form_end_woody)#k = 384; estimate      se     zval    pval    ci.lb   ci.ub  -0.3674  0.2466  -1.4900  0.1362  -0.8506  0.1159 

es_invasive$life_form<-as.factor(es_invasive$life_form)
model_life_form_inv <- rma.mv(y1, v1, mods= ~ life_form, random = list(~ 1 | taxon, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = es_invasive)
summary(model_life_form_inv)#QE(df = 537) = 18595.0963, p-val < .0001; QM(df = 2) = 1.8434, p-val = 0.3978
model_life_form_inv_shortlived <- rma.mv(y1, v1, subset = (life_form == "shortlived"), random = list(~ 1 | taxon, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = es_invasive)
summary(model_life_form_inv_shortlived)#k = 207; estimate      se     zval    pval    ci.lb    ci.ub  -0.9329  0.5087  -1.8339  0.0667  -1.9299  0.0641  . 
model_life_form_inv_longlived <- rma.mv(y1, v1, subset = (life_form == "longlived"), random = list(~ 1 | taxon, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = es_invasive)
summary(model_life_form_inv_longlived)#k = 254; estimate      se     zval    pval    ci.lb    ci.ub  -0.6134  0.2171  -2.8258  0.0047  -1.0388  -0.1879  ** 
model_life_form_inv_woody <- rma.mv(y1, v1, subset = (life_form == "woody"), random = list(~ 1 | taxon, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = es_invasive)
summary(model_life_form_inv_woody)#k = 79; estimate      se     zval    pval    ci.lb   ci.ub  -0.4731  0.2651  -1.7848  0.0743  -0.9927  0.0464  .

#Mating system

es_endangered$mat_sys<-as.factor(es_endangered$mat_sys)
model_mat_sys_end <- rma.mv(y1, v1, mods= ~ mat_sys, random = list(~ 1 | taxon, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = es_endangered)
summary(model_mat_sys_end)#QE(df = 1092) = 31299.3452, p-val < .0001; QM(df = 3) = 43.3006, p-val < .0001 ***
model_mat_sys_end_inbreeding <- rma.mv(y1, v1, subset = (mat_sys == "inbreeding"), random = list(~ 1 | taxon, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = es_endangered)
summary(model_mat_sys_end_inbreeding)#k = 44; estimate      se     zval    pval    ci.lb   ci.ub  0.1102  1.1752  0.0938  0.9253  -2.1931  2.4135  
model_mat_sys_end_mixing <- rma.mv(y1, v1, subset = (mat_sys == "mixing"), random = list(~ 1 | taxon, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = es_endangered)
summary(model_mat_sys_end_mixing)#k = 152; estimate      se     zval    pval    ci.lb   ci.ub  -0.7291  0.5626  -1.2961  0.1950  -1.8317  0.3735 
model_mat_sys_end_outcrossing <- rma.mv(y1, v1, subset = (mat_sys == "outcrossing"), random = list(~ 1 | taxon, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = es_endangered)
summary(model_mat_sys_end_outcrossing)#k = 345; estimate      se     zval    pval    ci.lb   ci.ub  -0.5030  0.2557  -1.9675  0.0491  -1.0041  -0.0019  *  

es_invasive$mat_sys<-as.factor(es_invasive$mat_sys)
model_mat_sys_inv <- rma.mv(y1, v1, mods= ~ mat_sys, random = list(~ 1 | taxon, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = es_invasive)
summary(model_mat_sys_inv)#QE(df = 536) = 17164.6867, p-val < .0001; QM(df = 3) = 7.8151, p-val = 0.0500 *
model_mat_sys_inv_inbreeding <- rma.mv(y1, v1, subset = (mat_sys == "inbreeding"), random = list(~ 1 | taxon, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = es_invasive)
summary(model_mat_sys_inv_inbreeding)#k = 102; estimate      se     zval    pval    ci.lb    ci.ub  -1.3237  0.6341  -2.0875  0.0368  -2.5665  -0.0809  * 
model_mat_sys_inv_mixing <- rma.mv(y1, v1, subset = (mat_sys == "mixing"), random = list(~ 1 | taxon, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = es_invasive)
summary(model_mat_sys_inv_mixing)#k = 70; estimate      se     zval    pval    ci.lb    ci.ub -0.4654  0.4079  -1.1410  0.2539  -1.2648  0.3341
model_mat_sys_inv_outcrossing <- rma.mv(y1, v1, subset = (mat_sys == "outcrossing"), random = list(~ 1 | taxon, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = es_invasive)
summary(model_mat_sys_inv_outcrossing)#k = 306; estimate      se     zval    pval    ci.lb    ci.ub  -0.3973  0.2799  -1.4195  0.1557  -0.9459  0.1513

#Reproductive system

es_endangered$rep_sys<-as.factor(es_endangered$rep_sys)
model_rep_sys_end <- rma.mv(y1, v1, mods= ~ rep_sys, random = list(~ 1 | taxon, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = es_endangered)
summary(model_rep_sys_end)#QE(df = 1092) = 32689.8033, p-val < .0001; QM(df = 3) = 0.8092, p-val = 0.8473
model_rep_sys_end_sexual <- rma.mv(y1, v1, subset = (rep_sys == "sexual"), random = list(~ 1 | taxon, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = es_endangered)
summary(model_rep_sys_end_sexual)#k = 64; estimate      se     zval    pval    ci.lb   ci.ub  -0.2776  0.2539  -1.0933  0.2743  -0.7752  0.2200  
model_rep_sys_end_facultative <- rma.mv(y1, v1, subset = (rep_sys == "facultative"), random = list(~ 1 | taxon, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = es_endangered)
summary(model_rep_sys_end_facultative)#k = 167; estimate      se     zval    pval    ci.lb    ci.ub  -0.4969  0.3474  -1.4303  0.1526  -1.1778  0.1840 
model_rep_sys_end_clonal <- rma.mv(y1, v1, subset = (rep_sys == "clonal"), random = list(~ 1 | taxon, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = es_endangered)
summary(model_rep_sys_end_clonal)#k = 12; estimate      se     zval    pval    ci.lb   ci.ub  -0.1344  0.5830  -0.2306  0.8176  -1.2771  1.0082

es_invasive$rep_sys<-as.factor(es_invasive$rep_sys)
model_rep_sys_inv <- rma.mv(y1, v1, mods= ~ rep_sys, random = list(~ 1 | taxon, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = es_invasive)
summary(model_rep_sys_inv)#QE(df = 536) = 17622.8978, p-val < .0001; QM(df = 3) = 3.1692, p-val = 0.3663
model_rep_sys_inv_sexual <- rma.mv(y1, v1, subset = (rep_sys == "sexual"), random = list(~ 1 | taxon, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = es_invasive)
summary(model_rep_sys_inv_sexual)#k = 235; estimate      se     zval    pval    ci.lb   ci.ub  -0.8635  0.5567  -1.5510  0.1209  -1.9547  0.2277 
model_rep_sys_inv_facultative <- rma.mv(y1, v1, subset = (rep_sys == "facultative"), random = list(~ 1 | taxon, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = es_invasive)
summary(model_rep_sys_inv_facultative)#k = 235; estimate      se     zval    pval    ci.lb    ci.ub  -0.6355  0.2340  -2.7157  0.0066  -1.0941  -0.1768  ** 
model_rep_sys_inv_clonal <- rma.mv(y1, v1, subset = (rep_sys == "clonal"), random = list(~ 1 | taxon, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = es_invasive)
summary(model_rep_sys_inv_clonal)#k = 14; estimate      se     zval    pval    ci.lb    ci.ub  -0.9396  0.3598  -2.6119  0.0090  -1.6447  -0.2345  **

#Pollination

es_endangered$pollination<-as.factor(es_endangered$pollination)
model_pollination_end <- rma.mv(y1, v1, mods= ~ pollination, random = list(~ 1 | taxon, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = es_endangered)
summary(model_pollination_end)#QE(df = 1093) = 31777.6216, p-val < .0001; QM(df = 2) = 1.7937, p-val = 0.4079
model_pollination_end_long <- rma.mv(y1, v1, subset = (pollination == "long"), random = list(~ 1 | taxon, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = es_endangered)
summary(model_pollination_end_long)#k = 97; estimate      se     zval    pval    ci.lb   ci.ub  -0.1214  0.2323  -0.5228  0.6011  -0.5767  0.3338 
model_pollination_end_short <- rma.mv(y1, v1, subset = (pollination == "short"), random = list(~ 1 | taxon, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = es_endangered)
summary(model_pollination_end_short)#k = 412; estimate      se     zval    pval    ci.lb   ci.ub  -0.3518  0.2923  -1.2036  0.2288  -0.9247  0.2211

es_invasive$pollination<-as.factor(es_invasive$pollination)
model_pollination_inv <- rma.mv(y1, v1, mods= ~ pollination, random = list(~ 1 | taxon, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = es_invasive)
summary(model_pollination_inv)#QE(df = 537) = 18730.7335, p-val < .0001; QM(df = 2) = 1.5731, p-val = 0.4554
model_pollination_inv_long <- rma.mv(y1, v1, subset = (pollination == "long"), random = list(~ 1 | taxon, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = es_invasive)
summary(model_pollination_inv_long)#k = 68; estimate      se     zval    pval    ci.lb    ci.ub   -0.5492  0.4295  -1.2787  0.2010  -1.3911  0.2926 
model_pollination_inv_short <- rma.mv(y1, v1, subset = (pollination == "short"), random = list(~ 1 | taxon, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = es_invasive)
summary(model_pollination_inv_short)#k = 384; estimate      se     zval    pval    ci.lb    ci.ub -0.9543  0.4562  -2.0919  0.0364  -1.8484  -0.0602  * 

#Propagule dispersal

es_endangered$propagule_dis<-as.factor(es_endangered$propagule_dis)
model_propagule_dis_end <- rma.mv(y1, v1, mods= ~ propagule_dis, random = list(~ 1 | taxon, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = es_endangered)
summary(model_propagule_dis_end)#QE(df = 1093) = 32764.8582, p-val < .0001; QM(df = 2) = 11.6581, p-val = 0.0029 **
model_propagule_dis_end_lon_dis <- rma.mv(y1, v1, subset = (propagule_dis == "lon_dis"), random = list(~ 1 | taxon, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = es_endangered)
summary(model_propagule_dis_end_lon_dis)#k = 316; estimate      se     zval    pval    ci.lb   ci.ub  -0.4421  0.4103  -1.0776  0.2812  -1.2463  0.3620
model_propagule_dis_end_sho_dis <- rma.mv(y1, v1, subset = (propagule_dis == "sho_dis"), random = list(~ 1 | taxon, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = es_endangered)
summary(model_propagule_dis_end_sho_dis)#k = 115; estimate      se     zval    pval    ci.lb   ci.ub  -0.0327  0.3517  -0.0931  0.9258  -0.7221  0.6566

es_invasive$propagule_dis<-as.factor(es_invasive$propagule_dis)
model_propagule_dis_inv <- rma.mv(y1, v1, mods= ~ propagule_dis, random = list(~ 1 | taxon, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = es_invasive)
summary(model_propagule_dis_inv)#QE(df = 537) = 18085.0788, p-val < .0001; QM(df = 2) = 1.4584, p-val = 0.4823
model_propagule_dis_inv_lon_dis <- rma.mv(y1, v1, subset = (propagule_dis == "lon_dis"), random = list(~ 1 | taxon, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = es_invasive)
summary(model_propagule_dis_inv_lon_dis)#k = 437; estimate      se     zval    pval    ci.lb    ci.ub   -0.9003  0.4438  -2.0286  0.0425  -1.7701  -0.0305  *  
model_propagule_dis_inv_sho_dis <- rma.mv(y1, v1, subset = (propagule_dis == "sho_dis"), random = list(~ 1 | taxon, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = es_invasive)
summary(model_propagule_dis_inv_sho_dis)#k = 59; estimate      se     zval    pval    ci.lb   ci.ub  -0.1595  0.3816  -0.4180  0.6759  -0.9075  0.5885  

#Distribution

es_endangered$distribution<-as.factor(es_endangered$distribution)
model_distribution_end <- rma.mv(y1, v1, mods= ~ distribution, random = list(~ 1 | taxon, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = es_endangered)
summary(model_distribution_end)#QE(df = 1093) = 32335.0357, p-val < .0001; QM(df = 2) = 1.4334, p-val = 0.4884
model_distribution_end_island <- rma.mv(y1, v1, subset = (distribution == "island endemic"), random = list(~ 1 | taxon, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = es_endangered)
summary(model_distribution_end_island)#k = 214; estimate      se     zval    pval    ci.lb    ci.ub  -0.2240  0.3912  -0.5724  0.5670  -0.9907  0.5428 
model_distribution_end_continent <- rma.mv(y1, v1, subset = (distribution == "continent endemic"), random = list(~ 1 | taxon, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = es_endangered)
summary(model_distribution_end_continent)#k = 751; estimate      se     zval    pval    ci.lb   ci.ub  -0.4291  0.2499  -1.7169  0.0860  -0.9189  0.0607  . 
model_distribution_end_widespread <- rma.mv(y1, v1, subset = (distribution == "widespread"), random = list(~ 1 | taxon, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = es_endangered)
summary(model_distribution_end_widespread)#k = 131; estimate      se     zval    pval    ci.lb   ci.ub  -0.5337  0.4024  -1.3263  0.1848  -1.3223  0.2550 

#Propagule

es_invasive$propagule<-as.factor(es_invasive$propagule)
model_propagule_inv <- rma.mv(y1, v1, mods= ~ propagule, random = list(~ 1 | taxon, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = es_invasive)
summary(model_propagule_inv)#QE(df = 536) = 17908.4835, p-val < .0001; QM(df = 3) = 3.3747, p-val = 0.3374
model_propagule_inv_seed <- rma.mv(y1, v1, subset = (propagule == "seed"), random = list(~ 1 | taxon, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = es_invasive)
summary(model_propagule_inv_seed)#k = 286; estimate      se     zval    pval    ci.lb   ci.ub  -0.9524  0.5523  -1.7243  0.0847  -2.0349  0.1302  .
model_propagule_inv_rhizome <- rma.mv(y1, v1, subset = (propagule == "rhizome"), random = list(~ 1 | taxon, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = es_invasive)
summary(model_propagule_inv_rhizome)#k = 13; estimate      se     zval    pval    ci.lb   ci.ub  -0.9156  0.5439  -1.6833  0.0923  -1.9816  0.1505  . 
model_propagule_inv_multiple <- rma.mv(y1, v1, subset = (propagule == "multiple"), random = list(~ 1 | taxon, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = es_invasive)
summary(model_propagule_inv_multiple)#k = 225;estimate      se     zval    pval    ci.lb    ci.ub  -0.6535  0.2538  -2.5751  0.0100  -1.1510  -0.1561  * 

####none <- NA####
es_endangered[es_endangered == "none"] <- NA
es_invasive[es_invasive == "none"] <- NA

##Species characteristic related variables

#Life form
es_endangered$life_form<-as.factor(es_endangered$life_form)
model_life_form_end <- rma.mv(y1, v1, mods= ~ life_form, random = list(~ 1 | taxon, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = es_endangered)
summary(model_life_form_end)#QE(df = 1093) = 32659.8155, p-val < .0001; QM(df = 2) = 7.0788, p-val = 0.0290 *
es_invasive$life_form<-as.factor(es_invasive$life_form)
model_life_form_inv <- rma.mv(y1, v1, mods= ~ life_form, random = list(~ 1 | taxon, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = es_invasive)
summary(model_life_form_inv)#QE(df = 537) = 18595.0963, p-val < .0001; QM(df = 2) = 1.8434, p-val = 0.3978

#Mating system
es_endangered$mat_sys<-as.factor(es_endangered$mat_sys)
model_mat_sys_end <- rma.mv(y1, v1, mods= ~ mat_sys, random = list(~ 1 | taxon, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = es_endangered)
summary(model_mat_sys_end)#QE(df = 538) = 15610.9280, p-val < .0001; QM(df = 2) = 10.1876, p-val = 0.0061 **
es_invasive$mat_sys<-as.factor(es_invasive$mat_sys)
model_mat_sys_inv <- rma.mv(y1, v1, mods= ~ mat_sys, random = list(~ 1 | taxon, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = es_invasive)
summary(model_mat_sys_inv)#QE(df = 475) = 16412.3740, p-val < .0001; QM(df = 2) = 3.6463, p-val = 0.1615

#Reproductive system

es_endangered$rep_sys<-as.factor(es_endangered$rep_sys)
model_rep_sys_end <- rma.mv(y1, v1, mods= ~ rep_sys, random = list(~ 1 | taxon, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = es_endangered)
summary(model_rep_sys_end)#QE(df = 240) = 4081.5291, p-val < .0001; QM(df = 2) = 0.3546, p-val = 0.8375
es_invasive$rep_sys<-as.factor(es_invasive$rep_sys)
model_rep_sys_inv <- rma.mv(y1, v1, mods= ~ rep_sys, random = list(~ 1 | taxon, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = es_invasive)
summary(model_rep_sys_inv)#QE(df = 481) = 17299.0962, p-val < .0001; QM(df = 2) = 2.6854, p-val = 0.2611

#Pollination
es_endangered$pollination<-as.factor(es_endangered$pollination)
model_pollination_end <- rma.mv(y1, v1, mods= ~ pollination, random = list(~ 1 | taxon, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = es_endangered)
summary(model_pollination_end)#QE(df = 507) = 14902.2079, p-val < .0001; QM(df = 1) = 0.6067, p-val = 0.4360
es_invasive$pollination<-as.factor(es_invasive$pollination)
model_pollination_inv <- rma.mv(y1, v1, mods= ~ pollination, random = list(~ 1 | taxon, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = es_invasive)
summary(model_pollination_inv)#QE(df = 450) = 17231.3932, p-val < .0001; QM(df = 1) = 0.0022, p-val = 0.9628

#Propagule dispersal
es_endangered$propagule_dis<-as.factor(es_endangered$propagule_dis)
model_propagule_dis_end <- rma.mv(y1, v1, mods= ~ propagule_dis, random = list(~ 1 | taxon, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = es_endangered)
summary(model_propagule_dis_end)#QE(df = 429) = 11604.8000, p-val < .0001; QM(df = 1) = 0.0904, p-val = 0.7636
es_invasive$propagule_dis<-as.factor(es_invasive$propagule_dis)
model_propagule_dis_inv <- rma.mv(y1, v1, mods= ~ propagule_dis, random = list(~ 1 | taxon, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = es_invasive)
summary(model_propagule_dis_inv)#QE(df = 494) = 17385.3673, p-val < .0001; QM(df = 1) = 0.2539, p-val = 0.6143

#Distribution
es_endangered$distribution<-as.factor(es_endangered$distribution)
model_distribution_end <- rma.mv(y1, v1, mods= ~ distribution, random = list(~ 1 | taxon, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = es_endangered)
summary(model_distribution_end)#QE(df = 1093) = 32335.0357, p-val < .0001; QM(df = 2) = 1.4334, p-val = 0.4884

#Propagule
es_invasive$propagule<-as.factor(es_invasive$propagule)
model_propagule_inv <- rma.mv(y1, v1, mods= ~ propagule, random = list(~ 1 | taxon, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = es_invasive)
summary(model_propagule_inv)#QE(df = 521) = 17725.5118, p-val < .0001; QM(df = 2) = 1.8880, p-val = 0.3891
