library(metafor)
library(MuMIn)
library(readxl)

##Large dataset
es_endangered <- read_excel("your_path/Appendix_S1.xlsx", sheet = 1)

#Set the random factors
es_endangered$taxon<-as.factor(es_endangered$taxon)
es_endangered$gene_meth<-as.factor(es_endangered$gene_meth)
es_endangered$DNA_sou<-as.factor(es_endangered$DNA_sou)

#Habitat

es_endangered$habitat<-as.factor(es_endangered$habitat)
model_habitat_end <- rma.mv(y1, v1, mods= ~ habitat, random = list(~ 1 | taxon, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = es_endangered)
summary(model_habitat_end)#QE(df = 356) = 8476.1059, p-val < .0001; QM(df = 1) = 0.1088, p-val = 0.7415

model_habitat_end_specific <- rma.mv(y1, v1, subset = (habitat == "specific"), random = list(~ 1 | taxon, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = es_endangered)
summary(model_habitat_end_specific)#k = 235; estimate      se     zval    pval    ci.lb   ci.ub  -0.2439  0.4049  -0.6023  0.5470  -1.0375  0.5497   

model_habitat_end_unspecific <- rma.mv(y1, v1, subset = (habitat == "unspecific"), random = list(~ 1 | taxon, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = es_endangered)
summary(model_habitat_end_unspecific)#k = 123; estimate      se     zval    pval    ci.lb   ci.ub  -0.1293  0.3557  -0.3634  0.7163  -0.8264  0.5679

#Rarity

es_endangered$rarity<-as.factor(es_endangered$rarity)
model_rarity_end <- rma.mv(y1, v1, mods= ~ rarity, random = list(~ 1 | taxon, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = es_endangered)
summary(model_rarity_end)#QE(df = 351) = 7520.0295, p-val < .0001; QM(df = 6) = 7.2713, p-val = 0.2965

model_rarity_end_WSU <- rma.mv(y1, v1, subset = (rarity == "WSU"), random = list(~ 1 | taxon, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = es_endangered)
summary(model_rarity_end_WSU)#k = 6; estimate      se     zval    pval    ci.lb   ci.ub  0.2909  0.3515  0.8278  0.4078  -0.3979  0.9798 

model_rarity_end_WLS <- rma.mv(y1, v1, subset = (rarity == "WLS"), random = list(~ 1 | taxon, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = es_endangered)#Optimizer (nlminb) did not achieve convergence
model_rarity_end_WLS <- rma.mv(y1, v1, subset = (rarity == "WLS"), random = list(~ 1 | taxon, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = es_endangered, verbose=TRUE, control=list(rel.tol=1e-8))
summary(model_rarity_end_WLS)#k = 15; estimate      se     zval    pval    ci.lb   ci.ub  -0.1934  0.2765  -0.6996  0.4842  -0.7354  0.3485

model_rarity_end_WSS <- rma.mv(y1, v1, subset = (rarity == "WSS"), random = list(~ 1 | taxon, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = es_endangered)
summary(model_rarity_end_WSS)#k = 13; estimate      se     zval    pval    ci.lb   ci.ub  0.2635  0.0722  3.6480  0.0003  0.1219  0.4051  *** and Test for Heterogeneity:Q(df = 12) = 4.7526, p-val = 0.9657

model_rarity_end_NLU <- rma.mv(y1, v1, subset = (rarity == "NLU"), random = list(~ 1 | taxon, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = es_endangered)
summary(model_rarity_end_NLU)#k = 51; estimate      se     zval    pval    ci.lb   ci.ub  -0.0193  0.3745  -0.0515  0.9589  -0.7534  0.7148 

model_rarity_end_NSU <- rma.mv(y1, v1, subset = (rarity == "NSU"), random = list(~ 1 | taxon, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = es_endangered)
summary(model_rarity_end_NSU)#k = 66; estimate      se     zval    pval    ci.lb   ci.ub  0.1333  0.2688  0.4958  0.6200  -0.3936  0.6601  

model_rarity_end_NLS <- rma.mv(y1, v1, subset = (rarity == "NLS"), random = list(~ 1 | taxon, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = es_endangered)
summary(model_rarity_end_NLS)#k = 61; estimate      se     zval    pval    ci.lb   ci.ub  -0.1005  0.3852  -0.2610  0.7941  -0.8554  0.6544 

model_rarity_end_NSS <- rma.mv(y1, v1, subset = (rarity == "NSS"), random = list(~ 1 | taxon, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = es_endangered)
summary(model_rarity_end_NSS)#k = 146; estimate      se     zval    pval    ci.lb   ci.ub  -0.7455  0.3166  -2.3546  0.0185  -1.3660  -0.1250  *  


##Strict
es_endangered_strict <- read_excel("your_path/Appendix_S4.xlsx", sheet = 1)

#Set the random factor
es_endangered_strict$taxon_exp<-as.factor(es_endangered_strict$taxon_exp)
es_endangered_strict$taxon_ctrl<-as.factor(es_endangered_strict$taxon_ctrl)
es_endangered_strict$gene_meth<-as.factor(es_endangered_strict$gene_meth)
es_endangered_strict$DNA_sou<-as.factor(es_endangered_strict$DNA_sou)

es_endangered_strict[es_endangered_strict == "none"] <- NA

#Habitat

es_endangered_strict$habitat<-as.factor(es_endangered_strict$habitat)
model_habitat_end <- rma.mv(yi, vi, mods= ~ habitat, random = list(~ 1 | taxon_exp,~ 1 | taxon_ctrl, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = es_endangered_strict)
summary(model_habitat_end)#QE(df = 5) = 318.3850, p-val < .0001; QM(df = 1) = 2.3205, p-val = 0.1277

model_habitat_end_specific <- rma.mv(yi, vi, subset = (habitat == "specific"), random = list(~ 1 | taxon_exp,~ 1 | taxon_ctrl, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = es_endangered_strict)
summary(model_habitat_end_specific)#k = 6; estimate      se     zval    pval    ci.lb   ci.ub  -0.8517  0.3701  -2.3011  0.0214  -1.5771  -0.1263  *    

model_habitat_end_unspecific <- rma.mv(yi, vi, subset = (habitat == "unspecific"), random = list(~ 1 | taxon_exp,~ 1 | taxon_ctrl, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = es_endangered_strict)
#Processing terminated since k <= 1.

#Rarity

es_endangered_strict$rarity<-as.factor(es_endangered_strict$rarity)
model_rarity_end <- rma.mv(yi, vi, mods= ~ rarity, random = list(~ 1 | taxon_exp,~ 1 | taxon_ctrl, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = es_endangered_strict)
summary(model_rarity_end)#QE(df = 4) = 150.3229, p-val < .0001; QM(df = 2) = 22.2638, p-val < .0001

model_rarity_end_NLS <- rma.mv(yi, vi, subset = (rarity == "NLS"), random = list(~ 1 | taxon_exp,~ 1 | taxon_ctrl, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = es_endangered_strict)
summary(model_rarity_end_NLS)#k = 3; estimate      se     zval    pval    ci.lb   ci.ub  -0.4235  0.3684  -1.1495  0.2503  -1.1455  0.2985 

model_rarity_end_NSS <- rma.mv(yi, vi, subset = (rarity == "NSS"), random = list(~ 1 | taxon_exp,~ 1 | taxon_ctrl, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = es_endangered_strict)
summary(model_rarity_end_NSS)#k = 3; estimate      se     zval    pval    ci.lb   ci.ub  -1.0435  0.4095  -2.5484  0.0108  -1.8461  -0.2409  *  

##forest plot
library(forestplot)
# Be sure to set the header to FALSE when reading the data to ensure that the first row is not used as the column name.
subforest_end <- read.csv("subgroup_rarity_20231023.csv", header = FALSE)
tiff('subgroup_rarity_20231023.tiff',height = 6000,width = 7000,res= 600)
#Please enter the following code twice to ensure that the image is drawn on the drawing
forestplot(labeltext = as.matrix(subforest_end[,1:2]),
           #Set the columns for text display, where we use the first four columns of the data as text to display in the graph
           mean = subforest_end$V5, #set mean
           lower = subforest_end$V6, #Set lowlimits for the mean
           upper = subforest_end$V7, #Set uplimits for the mean
           is.summary=c(T,T,F,F,T,F,F,F,F,F,F,F,T,T,T,F,F,T,F,F,F),
           #Defines whether each row in the data is a summary value, if so, set it to TRUE and the row appears in bold, if not, set it to FALSE
           align = "c",
           zero = 0, #Set the reference value. Here we show the lnRR value, so the reference value is 0
           boxsize = 0.5, #Sets the square size of the point estimate
           txt_gp = fpTxtGp(label = gpar(cex = 1.3),xlab = gpar(cex = 1.3),ticks = gpar(cex = 1.3)),
           #label represents the general text, xlab represents the X-axis title, ticks represents the x scale, and cex represents the scale multiple relative to the default size
           lineheight = unit(8,'mm'),#Sets the line spacing in the graph
           colgap = unit(5,'mm'),#Sets column spacing in the graph
           lwd.zero = 2,#Set the thickness of the guide line
           lwd.ci = 2,#Sets the thickness of the interval estimator line
           col=fpColors(box='gray',summary = 'gray',lines = 'gray',zero = 'gray',axes = 'gray'),
           #Use the fpColors() function to define the colors of graphic elements
           xlab="LnRR",#Set the X-axis label
           lwd.xaxis=2,#Set the thickness of the X axis
           lty.ci = "solid",
           graph.pos = 2)#Set the position of the forest map, where 2 appears in the second column
dev.off()#Exit the tiff device and save the image

# Be sure to set the header to FALSE when reading the data to ensure that the first row is not used as the column name.
subforest_end <- read.csv("C:/OneDrive/Desktop/Wangdao/subgroup_rarity_20240111.csv", header = FALSE)
tiff('subgroup_rarity_20240111.tiff',height = 6000,width = 7000,res= 600)
#Please enter the following code twice to ensure that the image is drawn on the drawing
forestplot(labeltext = as.matrix(subforest_end[,1:2]),
           #Set the columns for text display, where we use the first four columns of the data as text to display in the graph
           mean = subforest_end$V5, #set mean
           lower = subforest_end$V6, #Set lowlimits for the mean
           upper = subforest_end$V7, #Set uplimits for the mean
           is.summary=c(T,T,F,F,T,F,F,F,F,F,F,F,T,T,T,F,F,T,F,F,F),
           #Defines whether each row in the data is a summary value, if so, set it to TRUE and the row appears in bold, if not, set it to FALSE
           align = "c",
           zero = 0, #Set the reference value. Here we show the lnRR value, so the reference value is 0
           boxsize = 0.5, #Sets the square size of the point estimate
           txt_gp = fpTxtGp(label = gpar(cex = 1.3),xlab = gpar(cex = 1.3),ticks = gpar(cex = 1.3)),
           #label represents the general text, xlab represents the X-axis title, ticks represents the x scale, and cex represents the scale multiple relative to the default size
           lineheight = unit(8,'mm'),#Sets the line spacing in the graph
           colgap = unit(5,'mm'),#Sets column spacing in the graph
           lwd.zero = 2,#Set the thickness of the guide line
           lwd.ci = 2,#Sets the thickness of the interval estimator line
           col=fpColors(box='gray',summary = 'gray',lines = 'gray',zero = 'gray',axes = 'gray'),
           #Use the fpColors() function to define the colors of graphic elements
           xlab="LnRR",#Set the X-axis label
           lwd.xaxis=2,#Set the thickness of the X axis
           lty.ci = "solid",
           graph.pos = 2)#Set the position of the forest map, where 2 appears in the second column
dev.off()#Exit the tiff device and save the image

##Publish bias
es_endangered_WSS <- es_endangered[es_endangered$rarity == "WSS", ]
es_endangered_NSS <- es_endangered[es_endangered$rarity == "NSS", ]
es_endangered_NSS_strict <- es_endangered_strict[es_endangered_strict$rarity == "NSS", ]

#Rosenthal fail safe number
fsn(y1, v1, data=es_endangered_WSS,type="Rosenthal",alpha=.05, digits=4)#Observed Significance Level: 0.0002; Target Significance Level:   0.05; Fail-safe N: 50 < 5*13+10=75
fsn(y1, v1, data=es_endangered_NSS,type="Rosenthal",alpha=.05, digits=4)#Observed Significance Level: <.0001; Target Significance Level:   0.05; Fail-safe N: 183328 > 5*146+10=740
fsn(yi, vi, data=es_endangered_NSS_strict,type="Rosenthal",alpha=.05, digits=4)#Observed Significance Level: <.0001; Target Significance Level:   0.05; Fail-safe N: 402 > 5*3+10=25

#funnel plot
tiff('funnel_WSS_20231025.tiff',height = 3000,width = 4000,res= 400)
funnel(model_rarity_end_WSS, xlab = "Risk Ratio (log scale)",level=c(90, 95, 99), shade=c("white","gray", "darkgray"), refline=0, atransf=exp,at=log(c(.10, .25, .5, 1, 2, 4, 10)))
legend(1, 0.02, c("0.1 > p > 0.05", "0.05 > p >0.01", "< 0.01"), fill=c("white", "gray", "darkgray"))#super funnel!
dev.off()#Exit the tiff device and save the image
tiff('funnel_NSS_20231025.tiff',height = 3000,width = 4000,res= 400)
funnel(model_rarity_end_NSS, xlab = "Risk Ratio (log scale)",level=c(90, 95, 99), shade=c("white","gray", "darkgray"), refline=0, atransf=exp,at=log(c(.10, .25, .5, 1, 2, 4, 10)))
legend(-5, 0.02, c("0.1 > p > 0.05", "0.05 > p >0.01", "< 0.01"), fill=c("white", "gray", "darkgray"))#super funnel!
dev.off()#Exit the tiff device and save the image

###Select NSS to analysis

library(dplyr)
es_endangered_NSS <- es_endangered %>% 
  filter(rarity == "NSS")

#Set the random factors
es_endangered_NSS$taxon<-as.factor(es_endangered_NSS$taxon)
es_endangered_NSS$gene_meth<-as.factor(es_endangered_NSS$gene_meth)
es_endangered_NSS$DNA_sou<-as.factor(es_endangered_NSS$DNA_sou)

#none <- NA
es_endangered_NSS[es_endangered_NSS == "none"] <- NA

##Population genetics related variables

#Na

es_endangered_NSS$Na<-as.numeric(es_endangered_NSS$Na)
model_Na_end <- rma.mv(y1, v1, mods= ~ Na, random = list(~ 1 | taxon, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = es_endangered_NSS)
summary(model_Na_end)#QE(df = 137) = 3345.9795, p-val < .0001; QM(df = 1) = 1.2946, p-val = 0.2552; ns+

#Ne

es_endangered_NSS$Ne<-as.numeric(es_endangered_NSS$Ne)
model_Ne_end <- rma.mv(y1, v1, mods= ~ Ne, random = list(~ 1 | taxon, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = es_endangered_NSS)
summary(model_Ne_end)#QE(df = 7) = 48.5380, p-val < .0001; QM(df = 1) = 12.7553, p-val = 0.0004; ***-

#FIS

es_endangered_NSS$FIS<-as.numeric(es_endangered_NSS$FIS)
model_FIS_end <- rma.mv(y1, v1, mods= ~ FIS, random = list(~ 1 | taxon, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = es_endangered_NSS)
summary(model_FIS_end)#QE(df = 40) = 1461.7022, p-val < .0001; QM(df = 1) = 117.7284, p-val < .0001; ***-

#Fst

es_endangered_NSS$Fst<-as.numeric(es_endangered_NSS$Fst)
model_Fst_end <- rma.mv(y1, v1, mods= ~ Fst, random = list(~ 1 | taxon, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = es_endangered_NSS)
summary(model_Fst_end)#QE(df = 64) = 1474.2277, p-val < .0001; QM(df = 1) = 2.0872, p-val = 0.1485; ns-

#Nm

es_endangered_NSS$Nm<-as.numeric(es_endangered_NSS$Nm)
model_Nm_end <- rma.mv(y1, v1, mods= ~ Nm, random = list(~ 1 | taxon, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = es_endangered_NSS)
summary(model_Nm_end)#QE(df = 64) = 1465.0253, p-val < .0001; QM(df = 1) = 2.6919, p-val = 0.1009; ns+

##Methods related variables

#pri_num

es_endangered_NSS$pri_num<-as.numeric(es_endangered_NSS$pri_num)
model_pri_num_end <- rma.mv(y1, v1, mods= ~ pri_num, random = list(~ 1 | taxon, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = es_endangered_NSS)
summary(model_pri_num_end)#QE(df = 144) = 3733.1869, p-val < .0001;QM(df = 1) = 0.0019, p-val = 0.9654;ns+

#scale

es_endangered_NSS$scale<-as.factor(es_endangered_NSS$scale)
model_scale_end <- rma.mv(y1, v1, mods= ~ scale, random = list(~ 1 | taxon, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = es_endangered_NSS)
summary(model_scale_end)#QE(df = 144) = 3393.1397, p-val < .0001; QM(df = 1) = 4.8080, p-val = 0.0283 *
model_scale_end_local  <- rma.mv(y1, v1, subset = (scale == "local"), random = list(~ 1 | taxon, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = es_endangered_NSS)
summary(model_scale_end_local)#k = 92; estimate      se     zval    pval    ci.lb   ci.ub  -1.1027  0.1637  -6.7378  <.0001  -1.4235  -0.7820  ***
model_scale_end_region  <- rma.mv(y1, v1, subset = (scale == "region"), random = list(~ 1 | taxon, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = es_endangered_NSS)
summary(model_scale_end_region)#k = 54; estimate      se     zval    pval    ci.lb   ci.ub  -0.4755  0.2849  -1.6687  0.0952  -1.0339  0.0830  . 

##Phylogeny related variables

#family

es_endangered_NSS$family<-as.factor(es_endangered_NSS$family)
model_family_end <- rma.mv(y1, v1, mods= ~ family, random = list(~ 1 | taxon, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = es_endangered_NSS)
summary(model_family_end)#QE(df = 105) = 1482.3680, p-val < .0001; QM(df = 40) = 135.8118, p-val < .0001 ****

#order

es_endangered_NSS$order<-as.factor(es_endangered_NSS$order)
model_order_end <- rma.mv(y1, v1, mods= ~ order, random = list(~ 1 | taxon, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = es_endangered_NSS)
summary(model_order_end)#QE(df = 121) = 2085.9722, p-val < .0001; QM(df = 24) = 60.9725, p-val < .0001 ****

#class

es_endangered_NSS$class<-as.factor(es_endangered_NSS$class)
model_class_end <- rma.mv(y1, v1, mods= ~ class, random = list(~ 1 | taxon, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = es_endangered_NSS)
summary(model_class_end)#QE(df = 140) = 3103.1896, p-val < .0001; QM(df = 5) = 9.9419, p-val = 0.0769 .

#division

es_endangered_NSS$division<-as.factor(es_endangered_NSS$division)
model_division_end <- rma.mv(y1, v1, mods= ~ division, random = list(~ 1 | taxon, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = es_endangered_NSS)
summary(model_division_end)#QE(df = 142) = 3572.8268, p-val < .0001; QM(df = 3) = 3.6081, p-val = 0.3070 ns

##Species characteristic related variables

#Life form

es_endangered_NSS$life_form<-as.factor(es_endangered_NSS$life_form)
model_life_form_end <- rma.mv(y1, v1, mods= ~ life_form, random = list(~ 1 | taxon, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = es_endangered_NSS)
summary(model_life_form_end)#QE(df = 143) = 3720.2256, p-val < .0001; QM(df = 2) = 2.2659, p-val = 0.3221 ns
model_life_form_end_shortlived <- rma.mv(y1, v1, subset = (life_form == "shortlived"), random = list(~ 1 | taxon, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = es_endangered_NSS)
summary(model_life_form_end_shortlived)#k = 17; estimate      se     zval    pval    ci.lb   ci.ub  -0.9334  0.2575  -3.6245  0.0003  -1.4381  -0.4287  ***  
model_life_form_end_longlived <- rma.mv(y1, v1, subset = (life_form == "longlived"), random = list(~ 1 | taxon, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = es_endangered_NSS)
summary(model_life_form_end_longlived)#k = 75; estimate      se     zval    pval    ci.lb   ci.ub  -0.7902  0.2581  -3.0619  0.0022  -1.2959  -0.2844  ** 
model_life_form_end_woody <- rma.mv(y1, v1, subset = (life_form == "woody"), random = list(~ 1 | taxon, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = es_endangered_NSS)
summary(model_life_form_end_woody)#k = 54; estimate      se     zval    pval    ci.lb   ci.ub  -0.7811  0.5565  -1.4036  0.1604  -1.8719  0.3097  

#Mating system

es_endangered_NSS$mat_sys<-as.factor(es_endangered_NSS$mat_sys)
model_mat_sys_end <- rma.mv(y1, v1, mods= ~ mat_sys, random = list(~ 1 | taxon, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = es_endangered_NSS)
summary(model_mat_sys_end)#QE(df = 82) = 2464.1330, p-val < .0001; QM(df = 2) = 0.8323, p-val = 0.6596 ns
model_mat_sys_end_inbreeding <- rma.mv(y1, v1, subset = (mat_sys == "inbreeding"), random = list(~ 1 | taxon, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = es_endangered_NSS)
summary(model_mat_sys_end_inbreeding)#k = 15; estimate      se     zval    pval    ci.lb   ci.ub  -0.6236  0.3220  -1.9367  0.0528  -1.2548  0.0075  .  
model_mat_sys_end_mixing <- rma.mv(y1, v1, subset = (mat_sys == "mixing"), random = list(~ 1 | taxon, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = es_endangered_NSS)
summary(model_mat_sys_end_mixing)#k = 35; estimate      se     zval    pval    ci.lb   ci.ub  -0.7499  0.2266  -3.3094  0.0009  -1.1941  -0.3058  ***  
model_mat_sys_end_outcrossing <- rma.mv(y1, v1, subset = (mat_sys == "outcrossing"), random = list(~ 1 | taxon, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = es_endangered_NSS)
summary(model_mat_sys_end_outcrossing)#k = 35; estimate      se     zval    pval    ci.lb   ci.ub  -0.8131  0.4405  -1.8458  0.0649  -1.6764  0.0503  .  

#Reproductive system

es_endangered_NSS$rep_sys<-as.factor(es_endangered_NSS$rep_sys)
model_rep_sys_end <- rma.mv(y1, v1, mods= ~ rep_sys, random = list(~ 1 | taxon, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = es_endangered_NSS)
summary(model_rep_sys_end)#QE(df = 17) = 633.0567, p-val < .0001; QM(df = 1) = 0.0875, p-val = 0.7674 ns
model_rep_sys_end_sexual <- rma.mv(y1, v1, subset = (rep_sys == "sexual"), random = list(~ 1 | taxon, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = es_endangered_NSS)
summary(model_rep_sys_end_sexual)#k = 6; estimate      se     zval    pval    ci.lb   ci.ub  -0.4680  0.3343  -1.4000  0.1615  -1.1232  0.1872  
model_rep_sys_end_facultative <- rma.mv(y1, v1, subset = (rep_sys == "facultative"), random = list(~ 1 | taxon, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = es_endangered_NSS)
summary(model_rep_sys_end_facultative)#k = 13; estimate      se     zval    pval    ci.lb    ci.ub  -0.6300  0.2386  -2.6407  0.0083  -1.0976  -0.1624  ** 
model_rep_sys_end_clonal <- rma.mv(y1, v1, subset = (rep_sys == "clonal"), random = list(~ 1 | taxon, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = es_endangered_NSS)
summary(model_rep_sys_end_clonal)#k = 0

#Pollination

es_endangered_NSS$pollination<-as.factor(es_endangered_NSS$pollination)
model_pollination_end <- rma.mv(y1, v1, mods= ~ pollination, random = list(~ 1 | taxon, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = es_endangered_NSS)
summary(model_pollination_end)#QE(df = 67) = 2457.7498, p-val < .0001; QM(df = 1) = 1.1146, p-val = 0.2911 ns
model_pollination_end_long <- rma.mv(y1, v1, subset = (pollination == "long"), random = list(~ 1 | taxon, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = es_endangered_NSS)
summary(model_pollination_end_long)#k = 14; estimate      se     zval    pval    ci.lb   ci.ub   -0.4034  0.3226  -1.2504  0.2111  -1.0356  0.2289 
model_pollination_end_short <- rma.mv(y1, v1, subset = (pollination == "short"), random = list(~ 1 | taxon, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = es_endangered_NSS)
summary(model_pollination_end_short)#k = 55; estimate      se     zval    pval    ci.lb   ci.ub  -0.9283  0.2103  -4.4144  <.0001  -1.3404  -0.5161  ***

#Propagule dispersal

es_endangered_NSS$propagule_dis<-as.factor(es_endangered_NSS$propagule_dis)
model_propagule_dis_end <- rma.mv(y1, v1, mods= ~ propagule_dis, random = list(~ 1 | taxon, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = es_endangered_NSS)
summary(model_propagule_dis_end)#QE(df = 67) = 1312.4775, p-val < .0001; QM(df = 1) = 0.0507, p-val = 0.8219 ns
model_propagule_dis_end_lon_dis <- rma.mv(y1, v1, subset = (propagule_dis == "lon_dis"), random = list(~ 1 | taxon, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = es_endangered_NSS)
summary(model_propagule_dis_end_lon_dis)#k = 51; estimate      se     zval    pval    ci.lb   ci.ub  -0.5503  0.4725  -1.1647  0.2441  -1.4763  0.3757
model_propagule_dis_end_sho_dis <- rma.mv(y1, v1, subset = (propagule_dis == "sho_dis"), random = list(~ 1 | taxon, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = es_endangered_NSS)
summary(model_propagule_dis_end_sho_dis)#k = 18; estimate      se     zval    pval    ci.lb   ci.ub  -0.1376  0.4286  -0.3210  0.7482  -0.9776  0.7024

#Distribution

es_endangered_NSS$distribution<-as.factor(es_endangered_NSS$distribution)
model_distribution_end <- rma.mv(y1, v1, mods= ~ distribution, random = list(~ 1 | taxon, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = es_endangered_NSS)
summary(model_distribution_end)#QE(df = 144) = 3732.6703, p-val < .0001; QM(df = 1) = 2.3290, p-val = 0.1270
model_distribution_end_island <- rma.mv(y1, v1, subset = (distribution == "island endemic"), random = list(~ 1 | taxon, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = es_endangered_NSS)
summary(model_distribution_end_island)#k = 45; estimate      se     zval    pval    ci.lb    ci.ub  -0.7172  0.4496  -1.5955  0.1106  -1.5984  0.1639 
model_distribution_end_continent <- rma.mv(y1, v1, subset = (distribution == "continent endemic"), random = list(~ 1 | taxon, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = es_endangered_NSS)
summary(model_distribution_end_continent)#k = 101; estimate      se     zval    pval    ci.lb   ci.ub  -0.6182  0.1837  -3.3645  0.0008  -0.9783  -0.2581  *** 

##WLR plot
options(na.action = "na.exclude")

#Endangered plants
w1 <- 1/es_endangered_NSS$v1
size <- 0.5 + 3 * (w1 - min(w1))/(max(w1) - min(w1))
w2 <- 1/es_endangered$v1
size2 <- 0.5 + 3 * (w2 - min(w2))/(max(w2) - min(w2))

#Fst
#par(mar=c(2, 2, 2, 2) + 0.1)
plot(es_endangered_NSS$Fst,es_endangered_NSS$y1, pch = 19, col='#808080', cex = size,xlim=c(0,1),ylim = c(-6,2), xlab="", ylab="",axes=FALSE)
axis(1, col="black", col.ticks="black", col.axis="black", cex.axis=1.5, lwd=3, font=2)
axis(2, col="black", col.ticks="black", col.axis="black", cex.axis=1.5, lwd=3, font=2)
mtext("Population differentiation", side=1, line=3, col="black", cex=1.5, font=2)
mtext("Genetic diversity (lnRR)", side=2, line=3, col="black", cex=1.5, font=2)
Fst_end_lm <- lm(es_endangered_NSS$y1~es_endangered_NSS$Fst,data=es_endangered_NSS,weights=(1/v1))
summary(Fst_end_lm)
abline(Fst_end_lm, col='#808080', lwd=3, lty=2)#The ones that are not significant are indicated by dotted lines, lty=2
legend("bottomright",c("P > 0.05, R^2 = -0.0156"),bty="n",cex=1.5, text.col='#808080', text.font=2)

#FIS
plot(es_endangered_NSS$FIS,es_endangered_NSS$y1, pch = 19, col='#808080', cex = size,xlim=c(-1,1),ylim = c(-6,2), xlab="", ylab="",axes=FALSE)
axis(1, col="black", col.ticks="black", col.axis="black", cex.axis=1.5, lwd=3, font=2)
axis(2, col="black", col.ticks="black", col.axis="black", cex.axis=1.5, lwd=3, font=2)
mtext("Coefficient of inbreeding", side=1, line=3, col="black", cex=1.5, font=2)
mtext("Genetic diversity (lnRR)", side=2, line=3, col="black", cex=1.5, font=2)
FIS_end_lm <- lm(es_endangered_NSS$y1~es_endangered_NSS$FIS,data=es_endangered_NSS,weights=(1/v1))
summary(FIS_end_lm)
abline(FIS_end_lm, col='#808080', lwd=3, lty=2)
legend("bottomright",c("P > 0.05, R^2 = -0.0220"),bty="n",cex=1.5, text.col='#808080', text.font=2)

#Nm
plot(es_endangered_NSS$Nm,es_endangered_NSS$y1, pch = 19, col='#808080', cex = size, xlim=c(0,30), ylim = c(-6,2), xlab="", ylab="",axes=FALSE)
axis(1, col="black", col.ticks="black", col.axis="black", cex.axis=1.5, lwd=3, font=2)
axis(2, col="black", col.ticks="black", col.axis="black", cex.axis=1.5, lwd=3, font=2)
mtext("Gene Flow", side=1, line=3, col="black", cex=1.5, font=2)
mtext("Genetic diversity (lnRR)", side=2, line=3, col="black", cex=1.5, font=2)
Nm_end_lm <- lm(es_endangered_NSS$y1~es_endangered_NSS$Nm,data=es_endangered_NSS,weights=(1/v1))
summary(Nm_end_lm)
abline(Nm_end_lm, col='#808080', lwd=3, lty=2)
legend("bottomright",c("P > 0.05, R^2 = -0.0093"),bty="n",cex=1.5, text.col='#808080', text.font=2)

es_endangered_NSS <- es_endangered_NSS[es_endangered_NSS$Nm != 0, ]
plot(log(es_endangered_NSS$Nm),es_endangered_NSS$y1, pch = 19, col='#808080', cex = size,xlim=c(-6,4),ylim = c(-6,2), xlab="", ylab="",axes=FALSE)
axis(1, col="black", col.ticks="black", col.axis="black", cex.axis=1.5, lwd=3, font=2)
axis(2, col="black", col.ticks="black", col.axis="black", cex.axis=1.5, lwd=3, font=2)
mtext("Gene Flow (lnNm)", side=1, line=3, col="black", cex=1.5, font=2)
mtext("Genetic diversity (lnRR)", side=2, line=3, col="black", cex=1.5, font=2)
Nm_end_lm <- lm(es_endangered_NSS$y1~log(es_endangered_NSS$Nm),data=es_endangered_NSS,weights=(1/v1))
summary(Nm_end_lm)
abline(Nm_end_lm, col='#808080', lwd=3, lty=2)
legend("bottomright",c("P > 0.05, R^2 = -0.0042"),bty="n",cex=1.5, text.col='#808080', text.font=2)

#Na(i.e., Nc)
plot(es_endangered_NSS$Na,es_endangered_NSS$y1, pch = 19, col='#808080', cex = size, ylim = c(-6,2), xlab="", ylab="",axes=FALSE)
axis(1, col="black", col.ticks="black", col.axis="black", cex.axis=1.5, lwd=3, font=2)
axis(2, col="black", col.ticks="black", col.axis="black", cex.axis=1.5, lwd=3, font=2)
mtext("Census Population Size", side=1, line=3, col="black", cex=1.5, font=2)
mtext("Genetic diversity (lnRR)", side=2, line=3, col="black", cex=1.5, font=2)
Na_end_lm <- lm(es_endangered_NSS$y1~es_endangered_NSS$Na,data=es_endangered_NSS,weights=(1/v1))
summary(Na_end_lm)
abline(Na_end_lm, col='#808080', lwd=3, lty=2)
legend("bottomright",c("P > 0.05, R^2 = 0.0268"),bty="n",cex=1.5, text.col='#808080', text.font=2)

plot(log(es_endangered_NSS$Na),es_endangered_NSS$y1, pch = 19, col='#808080', cex = size, xlim=c(2,8), ylim = c(-6,2), xlab="", ylab="",axes=FALSE)
axis(1, col="black", col.ticks="black", col.axis="black", cex.axis=1.5, lwd=3, font=2)
axis(2, col="black", col.ticks="black", col.axis="black", cex.axis=1.5, lwd=3, font=2)
mtext("Census Population Size (lnNc)", side=1, line=3, col="black", cex=1.5, font=2)
mtext("Genetic diversity (lnRR)", side=2, line=3, col="black", cex=1.5, font=2)
Na_end_lm <- lm(es_endangered_NSS$y1~log(es_endangered_NSS$Na),data=es_endangered_NSS,weights=(1/v1))
summary(Na_end_lm)
abline(Na_end_lm, col='#808080', lwd=3, lty=2)
legend("bottomright",c("P > 0.05, R^2 = 0.0452"),bty="n",cex=1.5, text.col='#808080', text.font=2)

#Ne
plot(log(es_endangered$Ne),es_endangered$y1, pch = 19, col='gray', cex = size2, xlim=c(0,14), ylim = c(-2,2), xlab="", ylab="",axes=FALSE)
axis(1, col="black", col.ticks="black", col.axis="black", cex.axis=1.5, lwd=3, font=2)
axis(2, col="black", col.ticks="black", col.axis="black", cex.axis=1.5, lwd=3, font=2)
mtext("Effective Population Size (lnNe)", side=1, line=3, col="black", cex=1.5, font=2)
mtext("Genetic diversity (lnRR)", side=2, line=3, col="black", cex=1.5, font=2)
Ne_end_lm_log <- lm(es_endangered$y1~log(es_endangered$Ne),data=es_endangered,weights=(1/v1))
summary(Ne_end_lm_log)
abline(Ne_end_lm_log, col='gray', lwd=3, lty=2)
legend("bottomleft",c("P > 0.05, R^2 = -0.0009"),bty="n",cex=1.5, text.col='gray', text.font=2)

points(log(es_endangered_NSS$Ne), es_endangered_NSS$y1,pch = 19, col='#808080', cex = size)
Ne_NSS_lm_log <- lm(es_endangered_NSS$y1~log(es_endangered_NSS$Ne),data=es_endangered_NSS,weights=(1/v1))
summary(Ne_NSS_lm_log)
abline(Ne_NSS_lm_log, col='#808080', lwd=3)
legend("bottomright",c("P < 0.05, R^2 = 0.6055"),bty="n",cex=1.5, text.col='#808080', text.font=2)

plot(es_endangered$Ne,es_endangered$y1, pch = 19, col='gray', cex = size2, ylim = c(-2,2), xlab="", ylab="",axes=FALSE)
axis(1, col="black", col.ticks="black", col.axis="black", cex.axis=1.5, lwd=3, font=2)
axis(2, col="black", col.ticks="black", col.axis="black", cex.axis=1.5, lwd=3, font=2)
mtext("Effective Population Size", side=1, line=3, col="black", cex=1.5, font=2)
mtext("Genetic diversity (lnRR)", side=2, line=3, col="black", cex=1.5, font=2)
Ne_end_lm <- lm(es_endangered$y1~es_endangered$Ne,data=es_endangered,weights=(1/v1))
summary(Ne_end_lm)
abline(Ne_end_lm, col='gray', lwd=3, lty=2)
legend("bottomleft",c("P > 0.05, R^2 = 0.0495"),bty="n",cex=1.5, text.col='gray', text.font=2)

points(es_endangered_NSS$Ne, es_endangered_NSS$y1,pch = 19, col='#808080', cex = size)
Ne_NSS_lm <- lm(es_endangered_NSS$y1~es_endangered_NSS$Ne,data=es_endangered_NSS,weights=(1/v1))
summary(Ne_NSS_lm)
abline(Ne_NSS_lm, col='#808080', lwd=3)
legend("bottomright",c("P < 0.05, R^2 = 0.5967"),bty="n",cex=1.5, text.col='#808080', text.font=2)

#Ne - Outlier removal
es_endangered_Ne_noout <- es_endangered[order(-es_endangered$Ne), ]
View(es_endangered_Ne_noout)
es_endangered_Ne_noout <- es_endangered_Ne_noout[es_endangered_Ne_noout$Ne <= 6000, , drop = FALSE]
es_endangered_Ne_noout <- es_endangered_Ne_noout[rowSums(is.na(es_endangered_Ne_noout)) != ncol(es_endangered_Ne_noout), ]
w1_Ne_noout <- 1/es_endangered_Ne_noout$v1
size_Ne_noout <- 0.5 + 3 * (w1_Ne_noout - min(w1_Ne_noout))/(max(w1_Ne_noout) - min(w1_Ne_noout))

plot(log(es_endangered_Ne_noout$Ne),es_endangered_Ne_noout$y1, pch = 19, col='gray', cex = size_Ne_noout, xlim=c(0,9), ylim = c(-3,2), xlab="", ylab="",axes=FALSE)
axis(1, col="black", col.ticks="black", col.axis="black", cex.axis=1.5, lwd=3, font=2)
axis(2, col="black", col.ticks="black", col.axis="black", cex.axis=1.5, lwd=3, font=2)
mtext("Effective Population Size (lnNe)", side=1, line=3, col="black", cex=1.5, font=2)
mtext("Genetic diversity (lnRR)", side=2, line=3, col="black", cex=1.5, font=2)
Ne_end_lm_log <- lm(es_endangered_Ne_noout$y1~log(es_endangered_Ne_noout$Ne),data=es_endangered_Ne_noout,weights=(1/v1))
summary(Ne_end_lm_log)#Adjusted R-squared:  0.08663 ,  p-value: 0.1114
abline(Ne_end_lm_log, col='gray', lwd=3, lty=2)
legend("bottomleft",c("P > 0.05, R^2 = 0.0866"),bty="n",cex=1.5, text.col='gray', text.font=2)

points(log(es_endangered_NSS$Ne), es_endangered_NSS$y1,pch = 19, col='#808080', cex = size)
Ne_NSS_lm_log <- lm(es_endangered_NSS$y1~log(es_endangered_NSS$Ne),data=es_endangered_NSS,weights=(1/v1))
summary(Ne_NSS_lm_log)#Adjusted R-squared:  0.6908,  p-value: 0.003377
abline(Ne_NSS_lm_log, col='#808080', lwd=3)
legend("bottomright",c("P < 0.01, R^2 = 0.6908"),bty="n",cex=1.5, text.col='#808080', text.font=2)

plot(es_endangered_Ne_noout$Ne,es_endangered_Ne_noout$y1, pch = 19, col='gray', cex = size_Ne_noout, xlim = c(0,3000), ylim = c(-3,2), xlab="", ylab="",axes=FALSE)
axis(1, col="black", col.ticks="black", col.axis="black", cex.axis=1.5, lwd=3, font=2)
axis(2, col="black", col.ticks="black", col.axis="black", cex.axis=1.5, lwd=3, font=2)
mtext("Effective Population Size", side=1, line=3, col="black", cex=1.5, font=2)
mtext("Genetic diversity (lnRR)", side=2, line=3, col="black", cex=1.5, font=2)
Ne_end_lm <- lm(es_endangered_Ne_noout$y1~es_endangered_Ne_noout$Ne,data=es_endangered_Ne_noout,weights=(1/v1))
summary(Ne_end_lm)#Adjusted R-squared:  -0.05454,  p-value: 0.8966
abline(Ne_end_lm, col='gray', lwd=3, lty=2)
legend("bottomleft",c("P > 0.05, R^2 = -0.0545"),bty="n",cex=1.5, text.col='gray', text.font=2)

points(es_endangered_NSS$Ne, es_endangered_NSS$y1,pch = 19, col='#808080', cex = size)
Ne_NSS_lm <- lm(es_endangered_NSS$y1~es_endangered_NSS$Ne,data=es_endangered_NSS,weights=(1/v1))
summary(Ne_NSS_lm)#Adjusted R-squared:  0.6929,  p-value: 0.003294
abline(Ne_NSS_lm, col='#808080', lwd=3)
legend("bottomright",c("P < 0.01, R^2 = 0.6929"),bty="n",cex=1.5, text.col='#808080', text.font=2)

#pri_num
plot(log(es_endangered_NSS$pri_num),es_endangered_NSS$y1, pch = 19, col='#808080', cex = size, ylim = c(-6,2), xlab="", ylab="",axes=FALSE)
axis(1, col="black", col.ticks="black", col.axis="black", cex.axis=1.5, lwd=3, font=2)
axis(2, col="black", col.ticks="black", col.axis="black", cex.axis=1.5, lwd=3, font=2)
mtext("Number of loci (lnNL)", side=1, line=3, col="black", cex=1.5, font=2)
mtext("Genetic diversity (lnRR)", side=2, line=3, col="black", cex=1.5, font=2)
Pn_end_lm <- lm(es_endangered_NSS$y1~log(es_endangered_NSS$pri_num),data=es_endangered_NSS,weights=(1/v1))
summary(Pn_end_lm)
abline(Pn_end_lm, col='#808080', lwd=3, lty=2)
legend("bottomright",c("P > 0.05, R^2 = -0.0159"),bty="n",cex=1.5, text.col='#808080', text.font=2)

plot(es_endangered_NSS$pri_num,es_endangered_NSS$y1, pch = 19, col='#808080', cex = size, xlim = c(0,20), ylim = c(-6,2), xlab="", ylab="",axes=FALSE)
axis(1, col="black", col.ticks="black", col.axis="black", cex.axis=1.5, lwd=3, font=2)
axis(2, col="black", col.ticks="black", col.axis="black", cex.axis=1.5, lwd=3, font=2)
mtext("Number of loci", side=1, line=3, col="black", cex=1.5, font=2)
mtext("Genetic diversity (lnRR)", side=2, line=3, col="black", cex=1.5, font=2)
Pn_end_lm <- lm(es_endangered_NSS$y1~es_endangered_NSS$pri_num,data=es_endangered_NSS,weights=(1/v1))
summary(Pn_end_lm)
abline(Pn_end_lm, col='#808080', lwd=3, lty=2)
legend("bottomright",c("P > 0.05, R^2 = -0.0104"),bty="n",cex=1.5, text.col='#808080', text.font=2)

##Forrest plot
#Large dataset
# Be sure to set the header to FALSE when reading the data to ensure that the first row is not used as the column name.
subforest_NSS <- read.csv("C:/OneDrive/Desktop/Wangdao/subgroup_NSS_trait_20231107.csv", header = FALSE)
tiff('subgroup_NSS_trait_20231107.tiff',height = 6000,width = 7000,res= 600)
#Please enter the following code twice to ensure that the image is drawn on the drawing
forestplot(labeltext = as.matrix(subforest_NSS[,1:2]),
           #Set the columns for text display, where we use the first four columns of the data as text to display in the graph
           mean = subforest_NSS$V5, #set mean
           lower = subforest_NSS$V6, #Set lowlimits for the mean
           upper = subforest_NSS$V7, #Set uplimits for the mean
           is.summary=c(T,T,F,F,F,T,F,F,F,T,F,F,T,F,F,T,F,F,T,F,F),
           #Defines whether each row in the data is a summary value, if so, set it to TRUE and the row appears in bold, if not, set it to FALSE
           align = "c",
           zero = 0, #Set the reference value. Here we show the lnRR value, so the reference value is 0
           boxsize = 0.5, #Sets the square size of the point estimate
           txt_gp = fpTxtGp(label = gpar(cex = 1.3),xlab = gpar(cex = 1.3),ticks = gpar(cex = 1.3)),
           #label represents the general text, xlab represents the X-axis title, ticks represents the x scale, and cex represents the scale multiple relative to the default size
           lineheight = unit(8,'mm'),#Sets the line spacing in the graph
           colgap = unit(5,'mm'),#Sets column spacing in the graph
           lwd.zero = 2,#Set the thickness of the guide line
           lwd.ci = 2,#Sets the thickness of the interval estimator line
           col=fpColors(box='#808080',summary = '#808080',lines = '#808080',zero = '#808080',axes = '#808080'),
           #Use the fpColors() function to define the colors of graphic elements
           xlab="LnRR",#Set the X-axis label
           lwd.xaxis=2,#Set the thickness of the X axis
           lty.ci = "solid",
           graph.pos = 2)#Set the position of the forest map, where 2 appears in the second column
dev.off()#Exit the tiff device and save the image
