library(metafor)
library(MuMIn)
library(readxl)

es_endangered <- read_excel("your_path/Appendix_S4.xlsx", sheet = 1)
es_invasive <- read_excel("your_path/Appendix_S5.xlsx", sheet = 1)

#Set the random factor
es_endangered$taxon_exp<-as.factor(es_endangered$taxon_exp)
es_endangered$taxon_ctrl<-as.factor(es_endangered$taxon_ctrl)
es_endangered$gene_meth<-as.factor(es_endangered$gene_meth)
es_endangered$DNA_sou<-as.factor(es_endangered$DNA_sou)

es_invasive$taxon_exp<-as.factor(es_invasive$taxon_exp)
es_invasive$taxon_ctrl<-as.factor(es_invasive$taxon_ctrl)
es_invasive$gene_meth<-as.factor(es_invasive$gene_meth)
es_invasive$DNA_sou<-as.factor(es_invasive$DNA_sou)

es_endangered[es_endangered == "none"] <- NA
es_invasive[es_invasive == "none"] <- NA


##Calculate the cumulative effect size
ces_end <- rma.mv(yi, vi, mods= ~ 1, random = list(~ 1 | taxon_exp, ~ 1 | taxon_ctrl, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = es_endangered)
summary(ces_end)#k = 34; estimate      se     zval    pval    ci.lb   ci.ub    -0.1140  0.1021  -1.1163  0.2643  -0.3141  0.0861  
forest(ces_end)
ces_inv <- rma.mv(yi, vi, mods= ~ 1, random = list(~ 1 | taxon_exp, ~ 1 | taxon_ctrl, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = es_invasive)
summary(ces_inv)#k = 29; estimate      se     zval    pval    ci.lb    ci.ub  -0.8855  0.3882  -2.2812  0.0225  -1.6463  -0.1247  *
forest(ces_inv)

##Publish bias
#Rosenthal fail safe number
fsn(yi, vi, data=es_endangered,type="Rosenthal",alpha=.05, digits=4)#Observed Significance Level: 0.1768; Target Significance Level:   0.05; Fail-safe N: 0 < 5*34+10=180
fsn(yi, vi, data=es_invasive,type="Rosenthal",alpha=.05, digits=4)#Observed Significance Level: <.0001; Target Significance Level:   0.05; Fail-safe N: 2511 > 5*29+10=155
#funnel plot
funnel(ces_end)
funnel(ces_end, xlab = "Risk Ratio (log scale)",level=c(90, 95, 99), shade=c("white","gray", "darkgray"), refline=0, atransf=exp,at=log(c(.10, .25, .5, 1, 2, 4, 10)))
legend(5, -0.18, c("0.1 > p > 0.05", "0.05 > p >0.01", "< 0.01"), fill=c("white", "gray", "darkgray"))#super funnel!
funnel(ces_inv)
funnel(ces_inv, xlab = "Risk Ratio (log scale)",level=c(90, 95, 99), shade=c("white","gray", "darkgray"), refline=0, atransf=exp,at=log(c(.10, .25, .5, 1, 2, 4, 10)))
legend(1, -0.05, c("0.1 > p > 0.05", "0.05 > p >0.01", "< 0.01"), fill=c("white", "gray", "darkgray"))#super funnel!

##Population genetics related variables

#FIS
es_endangered$FIS<-as.numeric(es_endangered$FIS)
model_FIS_end <- rma.mv(yi, vi, mods= ~ FIS, random = list(~ 1 | taxon_exp, ~ 1 | taxon_ctrl, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = es_endangered)
summary(model_FIS_end)#QE(df = 18) = 897.5828, p-val < .0001; QM(df = 1) = 20.9024, p-val < .0001 ***
es_invasive$FIS<-as.numeric(es_invasive$FIS)
model_FIS_inv <- rma.mv(yi, vi, mods= ~ FIS, random = list(~ 1 | taxon_exp, ~ 1 | taxon_ctrl, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = es_invasive)
summary(model_FIS_inv)#QE(df = 10) = 72.2147, p-val < .0001; QM(df = 1) = 5.4486, p-val = 0.0196 *

#Nc(Na)
es_endangered$Na<-as.numeric(es_endangered$Na)
model_Na_end <- rma.mv(yi, vi, mods= ~ Na, random = list(~ 1 | taxon_exp, ~ 1 | taxon_ctrl, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = es_endangered)
summary(model_Na_end)#QE(df = 5) = 350.2621, p-val < .0001; QM(df = 1) = 0.0440, p-val = 0.8339 ns
es_invasive$Na<-as.numeric(es_invasive$Na)
model_Na_inv <- rma.mv(yi, vi, mods= ~ Na, random = list(~ 1 | taxon_exp, ~ 1 | taxon_ctrl, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = es_invasive)
summary(model_Na_inv)#Processing terminated since k <= 1.

#FST
es_endangered$Fst<-as.numeric(es_endangered$Fst)
model_Fst_end <- rma.mv(yi, vi, mods= ~ Fst, random = list(~ 1 | taxon_exp, ~ 1 | taxon_ctrl, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = es_endangered)
summary(model_Fst_end)#QE(df = 15) = 455.5087, p-val < .0001, QM(df = 1) = 7.7354, p-val = 0.0054,**
es_invasive$Fst<-as.numeric(es_invasive$Fst)
model_Fst_inv <- rma.mv(yi, vi, mods= ~ Fst, random = list(~ 1 | taxon_exp, ~ 1 | taxon_ctrl, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = es_invasive)
summary(model_Fst_inv)#QE(df = 13) = 203.2259, p-val < .0001, QM(df = 1) = 20.6544, p-val < .0001, ****

#Nm
es_endangered$Nm<-as.numeric(es_endangered$Nm)
model_Nm_end <- rma.mv(yi, vi, mods= ~ Nm, random = list(~ 1 | taxon_exp, ~ 1 | taxon_ctrl, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = es_endangered, control=list(optimizer="optim", optmethod="Nelder-Mead"))
summary(model_Nm_end)#QE(df = 15) = 1108.0525, p-val < .0001, QM(df = 1) = 2.4138, p-val = 0.1203,ns
es_invasive$Nm<-as.numeric(es_invasive$Nm)
model_Nm_inv <- rma.mv(yi, vi, mods= ~ Nm, random = list(~ 1 | taxon_exp, ~ 1 | taxon_ctrl, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = es_invasive)
summary(model_Nm_inv)#QE(df = 13) = 345.1527, p-val < .0001, QM(df = 1) = 3.7296, p-val = 0.0535, .

##Methods related variables

#pri_num
es_endangered$pri_num<-as.numeric(es_endangered$pri_num)
model_pri_num_end <- rma.mv(yi, vi, mods= ~ pri_num, random = list(~ 1 | taxon_exp, ~ 1 | taxon_ctrl, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = es_endangered)
summary(model_pri_num_end)#QE(df = 32) = 906.2633, p-val < .0001; QM(df = 1) = 0.0032, p-val = 0.9546
es_invasive$pri_num<-as.numeric(es_invasive$pri_num)
model_pri_num_inv <- rma.mv(yi, vi, mods= ~ pri_num, random = list(~ 1 | taxon_exp, ~ 1 | taxon_ctrl, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = es_invasive)
summary(model_pri_num_inv)#QE(df = 27) = 367.7752, p-val < .0001; QM(df = 1) = 11.3961, p-val = 0.0007 ***

#scale
es_endangered$scale<-as.factor(es_endangered$scale)
model_scale_end <- rma.mv(yi, vi, mods= ~ scale, random = list(~ 1 | taxon_exp, ~ 1 | taxon_ctrl, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = es_endangered)
summary(model_scale_end)#QE(df = 32) = 1313.0955, p-val < .0001; QM(df = 1) = 0.1903, p-val = 0.6626
es_invasive$scale<-as.factor(es_invasive$scale)
model_scale_inv <- rma.mv(yi, vi, mods= ~ scale, random = list(~ 1 | taxon_exp, ~ 1 | taxon_ctrl, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = es_invasive)
summary(model_scale_inv)#QE(df = 27) = 712.3979, p-val < .0001; QM(df = 1) = 1.6439, p-val = 0.1998

##Phylogeny related variables

#family
es_endangered$family<-as.factor(es_endangered$family)
model_family_end <- rma.mv(yi, vi, mods= ~ family, random = list(~ 1 | taxon_exp, ~ 1 | taxon_ctrl, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = es_endangered, verbose=TRUE, control=list(rel.tol=1e-8))#ref:http://metafor-project.org/doku.php/tips:convergence_problems_rma_mv
summary(model_family_end)#QE(df = 13) = 155.7061, p-val < .0001; QM(df = 20) = 37.8627, p-val = 0.0092 **
es_invasive$family<-as.factor(es_invasive$family)
model_family_inv <- rma.mv(yi, vi, mods= ~ family, random = list(~ 1 | taxon_exp, ~ 1 | taxon_ctrl, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = es_invasive)
summary(model_family_inv)#QE(df = 10) = 27.4833, p-val = 0.0022; QM(df = 18) = 726.0652, p-val < .0001 ***

#order
es_endangered$order<-as.factor(es_endangered$order)
model_order_end <- rma.mv(yi, vi, mods= ~ order, random = list(~ 1 | taxon_exp, ~ 1 | taxon_ctrl, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = es_endangered, verbose=TRUE, control=list(rel.tol=1e-8))#ref:http://metafor-project.org/doku.php/tips:convergence_problems_rma_mv
summary(model_order_end)#QE(df = 20) = 189.4912, p-val < .0001; QM(df = 13) = 24.8481, p-val = 0.0242 *
es_invasive$order<-as.factor(es_invasive$order)
model_order_inv <- rma.mv(yi, vi, mods= ~ order, random = list(~ 1 | taxon_exp, ~ 1 | taxon_ctrl, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = es_invasive)
summary(model_order_inv)#QE(df = 14) = 37.3222, p-val = 0.0007; QM(df = 14) = 684.4157, p-val < .0001 ***

#class
es_endangered$class<-as.factor(es_endangered$class)
model_class_end <- rma.mv(yi, vi, mods= ~ class, random = list(~ 1 | taxon_exp, ~ 1 | taxon_ctrl, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = es_endangered)
summary(model_class_end)#QE(df = 31) = 2418.8431, p-val < .0001; QM(df = 2) = 0.4324, p-val = 0.8056
es_invasive$class<-as.factor(es_invasive$class)
model_class_inv <- rma.mv(yi, vi, mods= ~ class, random = list(~ 1 | taxon_exp, ~ 1 | taxon_ctrl, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = es_invasive)
summary(model_class_inv)#QE(df = 26) = 328.7178, p-val < .0001; QM(df = 2) = 26.9936, p-val < .0001 ***

#division
es_endangered$division<-as.factor(es_endangered$division)
model_division_end <- rma.mv(yi, vi, mods= ~ division, random = list(~ 1 | taxon_exp, ~ 1 | taxon_ctrl, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = es_endangered)
summary(model_division_end)#QE(df = 32) = 2418.8766, p-val < .0001; QM(df = 1) = 0.0025, p-val = 0.9603
es_invasive$division<-as.factor(es_invasive$division)
model_division_inv <- rma.mv(yi, vi, mods= ~ division, random = list(~ 1 | taxon_exp, ~ 1 | taxon_ctrl, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = es_invasive)
summary(model_division_inv)#QE(df = 27) = 351.9972, p-val < .0001; QM(df = 1) = 23.7034, p-val < .0001 ***

##Species characteristic related variables

#Life form
es_endangered$life_form<-as.factor(es_endangered$life_form)
model_life_form_end <- rma.mv(yi, vi, mods= ~ life_form, random = list(~ 1 | taxon_exp, ~ 1 | taxon_ctrl, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = es_endangered)
summary(model_life_form_end)#QE(df = 31) = 2417.1532, p-val < .0001; QM(df = 2) = 0.5471, p-val = 0.7607
model_life_form_end_longlived <- rma.mv(yi, vi, subset = (life_form == "longlived"), random = list(~ 1 | taxon_exp, ~ 1 | taxon_ctrl, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = es_endangered, verbose=TRUE, control=list(rel.tol=1e-8))
summary(model_life_form_end_longlived)#k = 19; estimate      se     zval    pval    ci.lb   ci.ub  -0.1734  0.1657  -1.0467  0.2952  -0.4981  0.1513 
model_life_form_end_woody <- rma.mv(yi, vi, subset = (life_form == "woody"), random = list(~ 1 | taxon_exp, ~ 1 | taxon_ctrl, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = es_endangered)
summary(model_life_form_end_woody)#k = 14; estimate      se     zval    pval    ci.lb   ci.ub  -0.0326  0.0705  -0.4624  0.6438  -0.1707  0.1055 
#model_life_form_end_shortlived k = 1

es_invasive$life_form<-as.factor(es_invasive$life_form)
model_life_form_inv <- rma.mv(yi, vi, mods= ~ life_form, random = list(~ 1 | taxon_exp, ~ 1 | taxon_ctrl, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = es_invasive)
summary(model_life_form_inv)#QE(df = 26) = 646.9922, p-val < .0001; QM(df = 2) = 3.1885, p-val = 0.2031
model_life_form_inv_shortlived <- rma.mv(yi, vi, subset = (life_form == "shortlived"), random = list(~ 1 | taxon_exp, ~ 1 | taxon_ctrl, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = es_invasive)
summary(model_life_form_inv_shortlived)#k = 7; estimate      se     zval    pval    ci.lb    ci.ub  -0.3130  0.1479  -2.1165  0.0343  -0.6029  -0.0232  *  
model_life_form_inv_longlived <- rma.mv(yi, vi, subset = (life_form == "longlived"), random = list(~ 1 | taxon_exp, ~ 1 | taxon_ctrl, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = es_invasive)
summary(model_life_form_inv_longlived)#k = 12; estimate      se     zval    pval    ci.lb    ci.ub  -1.2330  0.4880  -2.5267  0.0115  -2.1894  -0.2765  * 
model_life_form_inv_woody <- rma.mv(yi, vi, subset = (life_form == "woody"), random = list(~ 1 | taxon_exp, ~ 1 | taxon_ctrl, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = es_invasive)
summary(model_life_form_inv_woody)#k = 10; estimate      se     zval    pval    ci.lb   ci.ub  -0.0510  0.0980  -0.5205  0.6027  -0.2431  0.1411
#Since the control is the same species, let's see if the results are the same for only taxon in the experimental group as a random factor
es_invasive$life_form<-as.factor(es_invasive$life_form)
model_life_form_inv2 <- rma.mv(yi, vi, mods= ~ life_form, random = list(~ 1 | taxon_exp, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = es_invasive)
summary(model_life_form_inv2)#QE(df = 26) = 646.9922, p-val < .0001; QM(df = 2) = 3.1885, p-val = 0.2031
model_life_form_inv_shortlived2 <- rma.mv(yi, vi, subset = (life_form == "shortlived"), random = list(~ 1 | taxon_exp, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = es_invasive)
summary(model_life_form_inv_shortlived2)#k = 7; estimate      se     zval    pval    ci.lb    ci.ub  -0.3130  0.1479  -2.1165  0.0343  -0.6029  -0.0232  *  
model_life_form_inv_longlived2 <- rma.mv(yi, vi, subset = (life_form == "longlived"), random = list(~ 1 | taxon_exp, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = es_invasive)
summary(model_life_form_inv_longlived2)#k = 12; estimate      se     zval    pval    ci.lb    ci.ub  -1.2330  0.4880  -2.5267  0.0115  -2.1894  -0.2765  * 
model_life_form_inv_woody2 <- rma.mv(yi, vi, subset = (life_form == "woody"), random = list(~ 1 | taxon_exp, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = es_invasive)
summary(model_life_form_inv_woody2)#k = 10; estimate      se     zval    pval    ci.lb   ci.ub  -0.0510  0.0980  -0.5205  0.6027  -0.2431  0.1411
#The same as the former

#Mating system
es_endangered$mat_sys<-as.factor(es_endangered$mat_sys)
model_mat_sys_end <- rma.mv(yi, vi, mods= ~ mat_sys, random = list(~ 1 | taxon_exp, ~ 1 | taxon_ctrl, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = es_endangered)
summary(model_mat_sys_end)#QE(df = 6) = 1211.7753, p-val < .0001; QM(df = 1) = 0.0803, p-val = 0.7769
model_mat_sys_end_mixing <- rma.mv(yi, vi, subset = (mat_sys == "mixing"), random = list(~ 1 | taxon_exp, ~ 1 | taxon_ctrl, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = es_endangered)
summary(model_mat_sys_end_mixing)#k = 3; estimate      se     zval    pval    ci.lb    ci.ub -0.2914  0.2888  -1.0091  0.3129  -0.8575  0.2746 
model_mat_sys_end_outcrossing <- rma.mv(yi, vi, subset = (mat_sys == "outcrossing"), random = list(~ 1 | taxon_exp, ~ 1 | taxon_ctrl, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = es_endangered)
summary(model_mat_sys_end_outcrossing)#k = 5; estimate      se     zval    pval    ci.lb    ci.ub -0.4241  0.3348  -1.2666  0.2053  -1.0802  0.2321

es_invasive$mat_sys<-as.factor(es_invasive$mat_sys)
model_mat_sys_inv <- rma.mv(yi, vi, mods= ~ mat_sys, random = list(~ 1 | taxon_exp, ~ 1 | taxon_ctrl, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = es_invasive)
summary(model_mat_sys_inv)#QE(df = 21) = 276.5555, p-val < .0001; QM(df = 2) = 37.5823, p-val < .0001 ***
model_mat_sys_inv_inbreeding <- rma.mv(yi, vi, subset = (mat_sys == "inbreeding"), random = list(~ 1 | taxon_exp, ~ 1 | taxon_ctrl, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = es_invasive)
summary(model_mat_sys_inv_inbreeding)#k = 7; estimate      se     zval    pval    ci.lb    ci.ub -1.2533  0.3447  -3.6362  0.0003  -1.9288  -0.5778  ***
model_mat_sys_inv_mixing <- rma.mv(yi, vi, subset = (mat_sys == "mixing"), random = list(~ 1 | taxon_exp, ~ 1 | taxon_ctrl, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = es_invasive)
summary(model_mat_sys_inv_mixing)#k = 7; estimate      se     zval    pval    ci.lb    ci.ub -0.2580  0.0915  -2.8186  0.0048  -0.4374  -0.0786  **  
model_mat_sys_inv_outcrossing <- rma.mv(yi, vi, subset = (mat_sys == "outcrossing"), random = list(~ 1 | taxon_exp, ~ 1 | taxon_ctrl, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = es_invasive)
summary(model_mat_sys_inv_outcrossing)#k = 10; estimate      se     zval    pval    ci.lb    ci.ub 0.0015  0.0388  0.0396  0.9684  -0.0746  0.0776  


#Reproductive system
es_endangered$rep_sys<-as.factor(es_endangered$rep_sys)
model_rep_sys_end <- rma.mv(yi, vi, mods= ~ rep_sys, random = list(~ 1 | taxon_exp, ~ 1 | taxon_ctrl, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = es_endangered)
summary(model_rep_sys_end)#QE(df = 2) = 14.7754, p-val = 0.0006; QM(df = 1) = 0.2545, p-val = 0.6139
#model_rep_sys_end_sexual,k = 0  
#model_rep_sys_end_facultative, k = 1
model_rep_sys_end_clonal <- rma.mv(yi, vi, subset = (rep_sys == "clonal"), random = list(~ 1 | taxon_exp, ~ 1 | taxon_ctrl, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = es_endangered)
summary(model_rep_sys_end_clonal)#k = 3; estimate      se     zval    pval    ci.lb   ci.ub -0.2033  0.5652  -0.3597  0.7191  -1.3112  0.9046

es_invasive$rep_sys<-as.factor(es_invasive$rep_sys)
model_rep_sys_inv <- rma.mv(yi, vi, mods= ~ rep_sys, random = list(~ 1 | taxon_exp, ~ 1 | taxon_ctrl, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = es_invasive)
summary(model_rep_sys_inv)#QE(df = 25) = 637.9992, p-val < .0001; QM(df = 2) = 1.2276, p-val = 0.5413
model_rep_sys_inv_sexual <- rma.mv(yi, vi, subset = (rep_sys == "sexual"), random = list(~ 1 | taxon_exp, ~ 1 | taxon_ctrl, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = es_invasive)
summary(model_rep_sys_inv_sexual)#k = 15; estimate      se     zval    pval    ci.lb   ci.ub  -0.1422  0.1086  -1.3092  0.1905  -0.3551  0.0707 
model_rep_sys_inv_facultative <- rma.mv(yi, vi, subset = (rep_sys == "facultative"), random = list(~ 1 | taxon_exp, ~ 1 | taxon_ctrl, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = es_invasive)
summary(model_rep_sys_inv_facultative)#k = 11; estimate      se     zval    pval    ci.lb    ci.ub   -1.4700  0.5911  -2.4870  0.0129  -2.6284  -0.3115  *  
model_rep_sys_inv_clonal <- rma.mv(yi, vi, subset = (rep_sys == "clonal"), random = list(~ 1 | taxon_exp, ~ 1 | taxon_ctrl, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = es_invasive)
summary(model_rep_sys_inv_clonal)#k = 2; estimate      se     zval    pval    ci.lb    ci.ub  -0.4781  0.0848  -5.6354  <.0001  -0.6443  -0.3118  ***

#Pollination
es_endangered$pollination<-as.factor(es_endangered$pollination)
model_pollination_end <- rma.mv(yi, vi, mods= ~ pollination, random = list(~ 1 | taxon_exp, ~ 1 | taxon_ctrl, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = es_endangered)
summary(model_pollination_end)#QE(df = 14) = 2374.2432, p-val < .0001; QM(df = 1) = 0.0477, p-val = 0.8271
model_pollination_end_long <- rma.mv(yi, vi, subset = (pollination == "long"), random = list(~ 1 | taxon_exp, ~ 1 | taxon_ctrl, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = es_endangered)
summary(model_pollination_end_long)#k = 3; estimate      se     zval    pval    ci.lb   ci.ub  -0.0980  0.1512  -0.6479  0.5170  -0.3944  0.1984
model_pollination_end_short <- rma.mv(yi, vi, subset = (pollination == "short"), random = list(~ 1 | taxon_exp, ~ 1 | taxon_ctrl, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = es_endangered)
summary(model_pollination_end_short)#k = 13; estimate      se     zval    pval    ci.lb   ci.ub  -0.2144  0.2107  -1.0176  0.3089  -0.6273  0.1986 

es_invasive$pollination<-as.factor(es_invasive$pollination)
model_pollination_inv <- rma.mv(yi, vi, mods= ~ pollination, random = list(~ 1 | taxon_exp, ~ 1 | taxon_ctrl, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = es_invasive)
summary(model_pollination_inv)#QE(df = 23) = 335.2834, p-val < .0001; QM(df = 1) = 0.9677, p-val = 0.3252
model_pollination_inv_long <- rma.mv(yi, vi, subset = (pollination == "long"), random = list(~ 1 | taxon_exp, ~ 1 | taxon_ctrl, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = es_invasive)
summary(model_pollination_inv_long)#k = 7; estimate      se     zval    pval    ci.lb    ci.ub   -0.0591  0.0539  -1.0958  0.2732  -0.1648  0.0466 
model_pollination_inv_short <- rma.mv(yi, vi, subset = (pollination == "short"), random = list(~ 1 | taxon_exp, ~ 1 | taxon_ctrl, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = es_invasive)
summary(model_pollination_inv_short)#k = 18; estimate      se     zval    pval    ci.lb    ci.ub  -0.3391  0.1286  -2.6370  0.0084  -0.5912  -0.0871  ** 

#Propagule dispersal
es_endangered$propagule_dis<-as.factor(es_endangered$propagule_dis)
model_propagule_dis_end <- rma.mv(yi, vi, mods= ~ propagule_dis, random = list(~ 1 | taxon_exp, ~ 1 | taxon_ctrl, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = es_endangered)
summary(model_propagule_dis_end)#QE(df = 10) = 101.6083, p-val < .0001; QM(df = 1) = 1.5953, p-val = 0.2066
model_propagule_dis_end_lon_dis <- rma.mv(yi, vi, subset = (propagule_dis == "lon_dis"), random = list(~ 1 | taxon_exp, ~ 1 | taxon_ctrl, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = es_endangered)
summary(model_propagule_dis_end_lon_dis)#k = 4; estimate      se     zval    pval    ci.lb   ci.ub  -0.0320  0.1331  -0.2403  0.8101  -0.2929  0.2289
model_propagule_dis_end_sho_dis <- rma.mv(yi, vi, subset = (propagule_dis == "sho_dis"), random = list(~ 1 | taxon_exp, ~ 1 | taxon_ctrl, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = es_endangered)
summary(model_propagule_dis_end_sho_dis)#k = 8; estimate      se     zval    pval    ci.lb   ci.ub  -0.4495  0.2768  -1.6242  0.1043  -0.9919  0.0929 

es_invasive$propagule_dis<-as.factor(es_invasive$propagule_dis)
model_propagule_dis_inv <- rma.mv(yi, vi, mods= ~ propagule_dis, random = list(~ 1 | taxon_exp, ~ 1 | taxon_ctrl, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = es_invasive)
summary(model_propagule_dis_inv)#QE(df = 24) = 716.2826, p-val < .0001; QM(df = 1) = 0.1945, p-val = 0.6592
model_propagule_dis_inv_lon_dis <- rma.mv(yi, vi, subset = (propagule_dis == "lon_dis"), random = list(~ 1 | taxon_exp, ~ 1 | taxon_ctrl, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = es_invasive)
summary(model_propagule_dis_inv_lon_dis)#k = 23; estimate      se     zval    pval    ci.lb    ci.ub   -1.0895  0.4241  -2.5688  0.0102  -1.9209  -0.2582  *  
model_propagule_dis_inv_sho_dis <- rma.mv(yi, vi, subset = (propagule_dis == "sho_dis"), random = list(~ 1 | taxon_exp, ~ 1 | taxon_ctrl, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = es_invasive)
summary(model_propagule_dis_inv_sho_dis)#k = 3; estimate      se     zval    pval    ci.lb   ci.ub  -0.1725  0.1196  -1.4418  0.1494  -0.4069  0.0620  

#Distribution
es_endangered$distribution<-as.factor(es_endangered$distribution)
model_distribution_end <- rma.mv(yi, vi, mods= ~ distribution, random = list(~ 1 | taxon_exp, ~ 1 | taxon_ctrl, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = es_endangered)
summary(model_distribution_end)#QE(df = 32) = 1601.9694, p-val < .0001; QM(df = 1) = 3.8906, p-val = 0.0486 *
model_distribution_end_island <- rma.mv(yi, vi, subset = (distribution == "island endemic"), random = list(~ 1 | taxon_exp, ~ 1 | taxon_ctrl, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = es_endangered)
summary(model_distribution_end_island)#k = 8; estimate      se     zval    pval    ci.lb    ci.ub  -0.5018  0.4793  -1.0470  0.2951  -1.4413  0.4376 
model_distribution_end_continent <- rma.mv(yi, vi, subset = (distribution == "continent endemic"), random = list(~ 1 | taxon_exp, ~ 1 | taxon_ctrl, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = es_endangered, verbose=TRUE, control=list(rel.tol=1e-8))
summary(model_distribution_end_continent)#k = 26; estimate      se     zval    pval    ci.lb   ci.ub  -0.0273  0.0736  -0.3708  0.7108  -0.1715  0.1169 
#model_distribution_end_widespread, k = 0

#Propagule
es_invasive$propagule<-as.factor(es_invasive$propagule)
model_propagule_inv <- rma.mv(yi, vi, mods= ~ propagule, random = list(~ 1 | taxon_exp, ~ 1 | taxon_ctrl, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = es_invasive)
summary(model_propagule_inv)#QE(df = 25) = 637.9992, p-val < .0001; QM(df = 2) = 1.2276, p-val = 0.5413
model_propagule_inv_seed <- rma.mv(yi, vi, subset = (propagule == "seed"), random = list(~ 1 | taxon_exp, ~ 1 | taxon_ctrl, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = es_invasive)
summary(model_propagule_inv_seed)#k = 15; estimate      se     zval    pval    ci.lb   ci.ub  -0.1422  0.1086  -1.3092  0.1905  -0.3551  0.0707 
model_propagule_inv_rhizome <- rma.mv(yi, vi, subset = (propagule == "rhizome"), random = list(~ 1 | taxon_exp, ~ 1 | taxon_ctrl, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = es_invasive)
summary(model_propagule_inv_rhizome)#k = 2; estimate      se     zval    pval    ci.lb   ci.ub  -0.4781  0.0848  -5.6354  <.0001  -0.6443  -0.3118  ***  
model_propagule_inv_multiple <- rma.mv(yi, vi, subset = (propagule == "multiple"), random = list(~ 1 | taxon_exp, ~ 1 | taxon_ctrl, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = es_invasive)
summary(model_propagule_inv_multiple)#k = 11; estimate      se     zval    pval    ci.lb    ci.ub  -1.4700  0.5911  -2.4870  0.0129  -2.6284  -0.3115  *  
