##Preparation

#Load the required R packages
library(metafor)#install.packages("metafor")
#MuMIn <- "https://cran.r-project.org/src/contrib/Archive/MuMIn/MuMIn_1.43.17.tar.gz"
#install.packages(MuMIn, repos=NULL, type="source")
library(MuMIn)
library(readxl)

#Read data
forAIC_end <- read_excel("your_path/Appendix_S1.xlsx", sheet = 1)
forAIC_inv <- read_excel("your_path/Appendix_S2.xlsx", sheet = 1)

##MuMIn package was used to calculate the AIC value of meta-analysis for model selection
eval(metafor:::.MuMIn) #!!!

#Endangered plants
forAIC_end$pri_num<-as.numeric(forAIC_end$pri_num)
forAIC_end$Ne<-as.numeric(forAIC_end$Ne)
forAIC_end$Na<-as.numeric(forAIC_end$Na)
forAIC_end$Nm<-as.numeric(forAIC_end$Nm)
forAIC_end$Fst<-as.numeric(forAIC_end$Fst)
forAIC_end$FIS<-as.numeric(forAIC_end$FIS)
forAIC_end$scale<-as.factor(forAIC_end$scale)
forAIC_end$rep_sys<-as.factor(forAIC_end$rep_sys)
forAIC_end$mat_sys<-as.factor(forAIC_end$mat_sys)
forAIC_end$pollination<-as.factor(forAIC_end$pollination)
forAIC_end$propagule_dis<-as.factor(forAIC_end$propagule_dis)
forAIC_end$distribution<-as.factor(forAIC_end$distribution)
forAIC_end$life_form<-as.factor(forAIC_end$life_form)
forAIC_end$DNA_sou<-as.factor(forAIC_end$DNA_sou)
forAIC_end$sam_sou<-as.factor(forAIC_end$sam_sou)
forAIC_end$taxon<-as.factor(forAIC_end$taxon)
forAIC_end$gene_meth<-as.factor(forAIC_end$gene_meth)
forAIC_end[forAIC_end == "none"] <- NA

#classified factors
full_end <- rma.mv(y1, v1, mods = ~ distribution+rep_sys+mat_sys+pollination+propagule_dis+life_form, random = list(~ 1 | taxon, ~ 1 | gene_meth, ~ 1 | DNA_sou), data=forAIC_end, method="ML")#Build full models
anova(full_end)#Test of Moderators
res_end <- dredge(full_end, trace=2)#Fit the full models, need a long time
summary(model.avg(res_end, revised.var=FALSE))#Multimodel inference
write.csv(res_end,"Appendix_S8_Model_selection_result_of_classified_factors_for_endangered_plants_in_the_larger_dataset.csv")
par(mar = c(3,5,6,4))#Set graphic parameters. The "mar" is a numeric vector of the form c(down, left, up, right) that gives the number of margin rows to specify on the four sides of the drawing.
plot(res_end, labAsExpr = TRUE)#visualize the model selection table
importance(res_end)#the relative importance values for the predictors
subset(res_end, delta < 2, recalc.weights=FALSE)#Check the models with delta AIC less than 2
mod.ave_end <- model.avg(res_end, subset = delta < 2)#report results: conditional average. 'object' consists of only one model so that no average model.

#continuous factors
full_end <- rma.mv(y1, v1, mods = ~ Na+Nm+FIS, random = list(~ 1 | taxon, ~ 1 | gene_meth, ~ 1 | DNA_sou), data=forAIC_end, method="ML")#Build full models
anova(full_end)#Test of Moderators
res_end <- dredge(full_end, trace=2)#Fit the full models, need a long time
summary(model.avg(res_end, revised.var=FALSE))#Multimodel inference
write.csv(res_end,"Appendix_S9_Model_selection_result_of_continuous_factors_for_endangered_plants_in_the_larger_dataset.csv")
par(mar = c(3,5,6,4))#Set graphic parameters. The "mar" is a numeric vector of the form c(down, left, up, right) that gives the number of margin rows to specify on the four sides of the drawing.
plot(res_end, labAsExpr = TRUE)#visualize the model selection table
importance(res_end)#the relative importance values for the predictors
subset(res_end, delta < 2, recalc.weights=FALSE)#Check the models with delta AIC less than 2
mod.ave_end <- model.avg(res_end, subset = delta < 2)#report results: conditional average. 'object' consists of only one model so that no average model.

#Invasive plants
forAIC_inv$pri_num<-as.numeric(forAIC_inv$pri_num)
forAIC_inv$Ne<-as.numeric(forAIC_inv$Ne)
forAIC_inv$Na<-as.numeric(forAIC_inv$Na)
forAIC_inv$Nm<-as.numeric(forAIC_inv$Nm)
forAIC_inv$Fst<-as.numeric(forAIC_inv$Fst)
forAIC_inv$FIS<-as.numeric(forAIC_inv$FIS)
forAIC_inv$scale<-as.factor(forAIC_inv$scale)
forAIC_inv$rep_sys<-as.factor(forAIC_inv$rep_sys)
forAIC_inv$mat_sys<-as.factor(forAIC_inv$mat_sys)
forAIC_inv$pollination<-as.factor(forAIC_inv$pollination)
forAIC_inv$propagule_dis<-as.factor(forAIC_inv$propagule_dis)
forAIC_inv$propagule<-as.factor(forAIC_inv$propagule)
forAIC_inv$life_form<-as.factor(forAIC_inv$life_form)
forAIC_inv$DNA_sou<-as.factor(forAIC_inv$DNA_sou)
forAIC_inv$sam_sou<-as.factor(forAIC_inv$sam_sou)
forAIC_inv$taxon<-as.factor(forAIC_inv$taxon)
forAIC_inv$gene_meth<-as.factor(forAIC_inv$gene_meth)
forAIC_inv[forAIC_inv == "none"] <- NA

#classified factors
full_inv <- rma.mv(y1, v1, mods = ~ rep_sys+mat_sys+pollination+propagule_dis+propagule+life_form, random = list(~ 1 | taxon, ~ 1 | gene_meth, ~ 1 | DNA_sou), data=forAIC_inv, method="ML")
anova(full_inv)#Test of Moderators 
res_inv <- dredge(full_inv, trace=2)#Fit the full models, need a long time
summary(model.avg(res_inv, revised.var=FALSE))
write.csv(res_inv,"Appendix_S10_Model_selection_result_of_classified_factors_for_invasive_plants_in_the_larger_dataset.csv")
par(mar = c(3,5,6,4))#Set graphic parameters. The "mar" is a numeric vector of the form c(down, left, up, right) that gives the number of margin rows to specify on the four sides of the drawing.
plot(res_inv, labAsExpr = TRUE)#visualize the model selection table
importance(res_inv)#the relative importance values for the predictors
subset(res_inv, delta < 2, recalc.weights=FALSE)#Check the models with delta AIC less than 2
mod.ave_inv <- model.avg(res_inv, subset = delta < 2)#report results: conditional average,  'object' consists of only one model

#continuous factors
full_inv <- rma.mv(y1, v1, mods = ~ Na+Nm+FIS, random = list(~ 1 | taxon, ~ 1 | gene_meth, ~ 1 | DNA_sou), data=forAIC_inv, method="ML")
anova(full_inv)#Test of Moderators
res_inv <- dredge(full_inv, trace=2)#Fit the full models, need a long time
summary(model.avg(res_inv, revised.var=FALSE))
write.csv(res_inv,"Appendix_S11_Model_selection_result_of_continuous_factors_for_invasive_plants_in_the_larger_dataset.csv")
par(mar = c(3,5,6,4))#Set graphic parameters. The "mar" is a numeric vector of the form c(down, left, up, right) that gives the number of margin rows to specify on the four sides of the drawing.
plot(res_inv, labAsExpr = TRUE)#visualize the model selection table
importance(res_inv)#the relative importance values for the predictors
subset(res_inv, delta < 2, recalc.weights=FALSE)#Check the models with delta AIC less than 2
mod.ave_inv <- model.avg(res_inv, subset = delta < 2)#report results: conditional average,  'object' consists of only one model


##Combine Endangered & Invasive
forAIC_end$pro_stu <- "end"
forAIC_inv$pro_stu <- "inv"
library(dplyr)
forAIC_all <- bind_rows(forAIC_end, forAIC_inv)#Concatenate the two data sets
str(forAIC_all)
forAIC_all$pro_stu<-as.factor(forAIC_all$pro_stu)
forAIC_all[forAIC_all == "none"] <- NA

#classified factors
forAIC_all$rep_sys<-as.factor(forAIC_all$rep_sys)
forAIC_all$mat_sys<-as.factor(forAIC_all$mat_sys)
forAIC_all$pollination<-as.factor(forAIC_all$pollination)
forAIC_all$propagule_dis<-as.factor(forAIC_all$propagule_dis)
forAIC_all$life_form<-as.factor(forAIC_all$life_form)
full_all <- rma.mv(y1, v1, mods = ~ rep_sys+mat_sys+pollination+propagule_dis+life_form+pro_stu, random = list(~ 1 | taxon, ~ 1 | gene_meth, ~ 1 | DNA_sou), data=forAIC_all, method="ML")
anova(full_all)#Test of Moderators
res_all <- dredge(full_all, trace=2)#Fit the full models, need a long time
summary(model.avg(res_all, revised.var=FALSE))
write.csv(res_all,"Appendix_S15_Model_selection_result_of_classified_factors_for_two_kinds_of_plants_in_the_larger_dataset.csv")
par(mar = c(3,5,6,4))#Set graphic parameters. The "mar" is a numeric vector of the form c(down, left, up, right) that gives the number of margin rows to specify on the four sides of the drawing.
plot(res_all, labAsExpr = TRUE)#visualize the model selection table
importance(res_all)#the relative importance values for the predictors
subset(res_all, delta < 2, recalc.weights=FALSE)#Check the models with delta AIC less than 2
mod.ave_all <- model.avg(res_all, subset = delta < 2)#report results: conditional average,'object' consists of only one model

#continuous factors
full_all <- rma.mv(y1, v1, mods = ~ Na+Nm+FIS+pro_stu+pro_stu*Na+pro_stu*Nm+pro_stu*FIS, random = list(~ 1 | taxon, ~ 1 | gene_meth, ~ 1 | DNA_sou), data=forAIC_all, method="ML")
anova(full_all)#Test of Moderators
res_all <- dredge(full_all, trace=2)#Fit the full models, need a long time
summary(model.avg(res_all, revised.var=FALSE))
write.csv(res_all,"Appendix_S16_Model_selection_result_of_continuous_factors_for_two_kinds_of_plants_in_the_larger_dataset.csv")
par(mar = c(3,5,6,4))#Set graphic parameters. The "mar" is a numeric vector of the form c(down, left, up, right) that gives the number of margin rows to specify on the four sides of the drawing.
plot(res_all, labAsExpr = TRUE)#visualize the model selection table
importance(res_all)#the relative importance values for the predictors
subset(res_all, delta < 2, recalc.weights=FALSE)#Check the models with delta AIC less than 2
mod.ave_all <- model.avg(res_all, subset = delta < 2)#report results: conditional average,'object' consists of only one model

#all factors
full_all_all <- rma.mv(y1, v1, mods = ~ rep_sys+mat_sys+pollination+propagule_dis+life_form+Na+Nm+FIS+pro_stu+pro_stu*Na+pro_stu*Nm+pro_stu*FIS+pro_stu*rep_sys+pro_stu*mat_sys+pro_stu*pollination+pro_stu*propagule_dis+pro_stu*life_form, random = list(~ 1 | taxon, ~ 1 | gene_meth, ~ 1 | DNA_sou), data=forAIC_all, method="ML")
anova(full_all_all)#Test of Moderators
res_all_all <- dredge(full_all_all, trace=2)#Fit the full models, need a long time
summary(model.avg(res_all_all, revised.var=FALSE))
write.csv(res_all_all,"Appendix_S17_Model_selection_result_of_all_factors_for_two_kinds_of_plants_in_the_larger_dataset.csv")
par(mar = c(3,5,6,4))#Set graphic parameters. The "mar" is a numeric vector of the form c(down, left, up, right) that gives the number of margin rows to specify on the four sides of the drawing.
plot(res_all_all, labAsExpr = TRUE)#visualize the model selection table
importance(res_all_all)#the relative importance values for the predictors
subset(res_all_all, delta < 2, recalc.weights=FALSE)#Check the models with delta AIC less than 2
mod.ave_all <- model.avg(res_all_all, subset = delta < 2)#report results: conditional average,'object' consists of only one model

##The interaction of different variables individually with the state of the population in all plants

#classification variable
forAIC_all$life_form_pro_stu <- interaction(forAIC_all$life_form, forAIC_all$pro_stu)
model_life_form_pro_stu <- rma.mv(y1, v1, mods= ~ life_form_pro_stu, random = list(~ 1 | taxon, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = forAIC_all)
summary(model_life_form_pro_stu)#QM(df = 5) = 25.4710, p-val = 0.0001***

forAIC_all$mat_sys_pro_stu <- interaction(forAIC_all$mat_sys, forAIC_all$pro_stu)
model_mat_sys_pro_stu <- rma.mv(y1, v1, mods= ~ mat_sys_pro_stu, random = list(~ 1 | taxon, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = forAIC_all)
summary(model_mat_sys_pro_stu)#Optimizer (nlminb) did not achieve convergence (convergence = 1).

forAIC_all$rep_sys_pro_stu <- interaction(forAIC_all$rep_sys, forAIC_all$pro_stu)
model_rep_sys_pro_stu <- rma.mv(y1, v1, mods= ~ rep_sys_pro_stu, random = list(~ 1 | taxon, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = forAIC_all)
summary(model_rep_sys_pro_stu)#QM(df = 5) = 14.7144, p-val = 0.0117*

forAIC_all$pollination_pro_stu <- interaction(forAIC_all$pollination, forAIC_all$pro_stu)
model_pollination_pro_stu <- rma.mv(y1, v1, mods= ~ pollination_pro_stu, random = list(~ 1 | taxon, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = forAIC_all)
summary(model_pollination_pro_stu)#QM(df = 3) = 25.0491, p-val < .0001***

forAIC_all$propagule_dis_pro_stu <- interaction(forAIC_all$propagule_dis, forAIC_all$pro_stu)
model_propagule_dis_pro_stu <- rma.mv(y1, v1, mods= ~ propagule_dis_pro_stu, random = list(~ 1 | taxon, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = forAIC_all)
summary(model_propagule_dis_pro_stu)#QM(df = 3) = 22.5021, p-val < .0001***

#continuals variable
#forAIC_all$Nm_pro_stu <- forAIC_all$Nm * as.numeric(forAIC_all$pro_stu)
#model_Nm_pro_stu <- rma.mv(y1, v1, mods= ~ Nm_pro_stu, random = list(~ 1 | taxon, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = forAIC_all)
#summary(model_Nm_pro_stu)#
#model_Nm_pro_stu2 <- rma.mv(y1, v1, mods= ~ Nm * pro_stu, random = list(~ 1 | taxon, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = forAIC_all)
#summary(model_Nm_pro_stu2)#
forAIC_all$pro_stuend <- as.numeric(forAIC_all$pro_stu == "end")
forAIC_all$pro_stuinv <- as.numeric(forAIC_all$pro_stu == "inv")
model_Nm_pro_stu_end <- rma.mv(y1, v1, mods = ~ Nm * pro_stuend, random = list(~ 1 | taxon, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = forAIC_all)
summary(model_Nm_pro_stu_end)#Nm:pro_stuend   -0.0509  0.0193  -2.6369  0.0084  -0.0888  -0.0131   ** 
model_Nm_pro_stu_inv <- rma.mv(y1, v1, mods = ~ Nm * pro_stuinv, random = list(~ 1 | taxon, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = forAIC_all)
summary(model_Nm_pro_stu_inv)#Nm:pro_stuinv    0.0509  0.0193   2.6369  0.0084   0.0131   0.0888  ** 

model_FIS_pro_stu_end <- rma.mv(y1, v1, mods = ~ FIS * pro_stuend, random = list(~ 1 | taxon, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = forAIC_all)
summary(model_FIS_pro_stu_end)#FIS:pro_stuend   -0.6618  0.1281  -5.1667  <.0001  -0.9129  -0.4108  ***  
model_FIS_pro_stu_inv <- rma.mv(y1, v1, mods = ~ FIS * pro_stuinv, random = list(~ 1 | taxon, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = forAIC_all)
summary(model_FIS_pro_stu_inv)#FIS:pro_stuinv    0.6618  0.1281   5.1667  <.0001   0.4108   0.9129  *** 

model_Na_pro_stu_end <- rma.mv(y1, v1, mods = ~ Na * pro_stuend, random = list(~ 1 | taxon, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = forAIC_all)
summary(model_Na_pro_stu_end)#Na:pro_stuend   -0.0000  0.0000  -1.8884  0.0590  -0.0000  0.0000  . 
model_Na_pro_stu_inv <- rma.mv(y1, v1, mods = ~ Na * pro_stuinv, random = list(~ 1 | taxon, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = forAIC_all)
summary(model_Na_pro_stu_inv)#Na:pro_stuinv    0.0000  0.0000   1.8884  0.0590  -0.0000  0.0000  . 

model_Ne_pro_stu_end <- rma.mv(y1, v1, mods = ~ Ne * pro_stuend, random = list(~ 1 | taxon, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = forAIC_all)
summary(model_Ne_pro_stu_end)#Ne:pro_stuend    0.0002  0.0001   1.9306  0.0535  -0.0000  0.0005  . 
model_Ne_pro_stu_inv <- rma.mv(y1, v1, mods = ~ Ne * pro_stuinv, random = list(~ 1 | taxon, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = forAIC_all)
summary(model_Ne_pro_stu_inv)#Ne:pro_stuinv   -0.0002  0.0001  -1.9306  0.0535  -0.0005  0.0000  . 

model_Fst_pro_stu_end <- rma.mv(y1, v1, mods = ~ Fst * pro_stuend, random = list(~ 1 | taxon, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = forAIC_all)
summary(model_Fst_pro_stu_end)#Fst:pro_stuend    0.5040  0.2460   2.0484  0.0405   0.0218   0.9861    * 
model_Fst_pro_stu_inv <- rma.mv(y1, v1, mods = ~ Fst * pro_stuinv, random = list(~ 1 | taxon, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = forAIC_all)
summary(model_Fst_pro_stu_inv)#Fst:pro_stuinv   -0.5040  0.2460  -2.0484  0.0405  -0.9861  -0.0218    * 

##The interaction of different variables with each other in endangered plants

#Classification variables

#habitat with others
forAIC_end$habitat_life_form <- interaction(forAIC_end$habitat, forAIC_end$life_form)
table(forAIC_end$habitat_life_form)
model_end_habitat_life_form <- rma.mv(y1, v1, mods= ~ habitat_life_form, random = list(~ 1 | taxon, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = forAIC_end)
summary(model_end_habitat_life_form)#QE(df = 3) = 44.2609, p-val < .0001; QM(df = 3) = 29.5875, p-val < .0001***

forAIC_end$habitat_mat_sys <- interaction(forAIC_end$habitat, forAIC_end$mat_sys)
table(forAIC_end$habitat_mat_sys)
model_end_habitat_mat_sys <- rma.mv(y1, v1, mods= ~ habitat_mat_sys, random = list(~ 1 | taxon, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = forAIC_end)
summary(model_end_habitat_mat_sys)#QE(df = 0) = 0.0000, p-val = 1.0000; QM(df = 1) = 27.4420, p-val < .0001 ***

forAIC_end$habitat_rep_sys <- interaction(forAIC_end$habitat, forAIC_end$rep_sys)
table(forAIC_end$habitat_rep_sys)
model_end_habitat_rep_sys <- rma.mv(y1, v1, mods= ~ habitat_rep_sys, random = list(~ 1 | taxon, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = forAIC_end)
summary(model_end_habitat_rep_sys)#Processing terminated since k <= 1.

forAIC_end$habitat_pollination <- interaction(forAIC_end$habitat, forAIC_end$pollination)
table(forAIC_end$habitat_pollination)
model_end_habitat_pollination <- rma.mv(y1, v1, mods= ~ habitat_pollination, random = list(~ 1 | taxon, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = forAIC_end)
summary(model_end_habitat_pollination)#QE(df = 3) = 44.2609, p-val < .0001; QM(df = 2) = 29.5639, p-val < .0001 ***

forAIC_end$habitat_propagule_dis <- interaction(forAIC_end$habitat, forAIC_end$propagule_dis)
table(forAIC_end$habitat_propagule_dis)
model_end_habitat_propagule_dis <- rma.mv(y1, v1, mods= ~ habitat_propagule_dis, random = list(~ 1 | taxon, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = forAIC_end)
summary(model_end_habitat_propagule_dis)#QE(df = 2) = 16.8189, p-val = 0.0002; QM(df = 2) = 15.7431, p-val = 0.0004 ***

forAIC_end$habitat_distribution <- interaction(forAIC_end$habitat, forAIC_end$distribution)
table(forAIC_end$habitat_distribution)
model_end_habitat_distribution <- rma.mv(y1, v1, mods= ~ habitat_distribution, random = list(~ 1 | taxon, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = forAIC_end)
summary(model_end_habitat_distribution)#QE(df = 4) = 55.7207, p-val < .0001; QM(df = 2) = 14.2966, p-val = 0.0008 ***

#rarity with others
forAIC_end$rarity_life_form <- interaction(forAIC_end$rarity, forAIC_end$life_form)
table(forAIC_end$rarity_life_form)
model_end_rarity_life_form <- rma.mv(y1, v1, mods= ~ rarity_life_form, random = list(~ 1 | taxon, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = forAIC_end)
summary(model_end_rarity_life_form)#QE(df = 1) = 0.0205, p-val = 0.8862; QM(df = 5) = 360.9849, p-val < .0001 ***

forAIC_end$rarity_mat_sys <- interaction(forAIC_end$rarity, forAIC_end$mat_sys)
table(forAIC_end$rarity_mat_sys)
model_end_rarity_mat_sys <- rma.mv(y1, v1, mods= ~ rarity_mat_sys, random = list(~ 1 | taxon, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = forAIC_end)
summary(model_end_rarity_mat_sys)#QE(df = 0) = 0.0000, p-val = 1.0000; QM(df = 1) = 27.4420, p-val < .0001 ***

forAIC_end$rarity_rep_sys <- interaction(forAIC_end$rarity, forAIC_end$rep_sys)
table(forAIC_end$rarity_rep_sys)
model_end_rarity_rep_sys <- rma.mv(y1, v1, mods= ~ rarity_rep_sys, random = list(~ 1 | taxon, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = forAIC_end)
summary(model_end_rarity_rep_sys)#Processing terminated since k <= 1.

forAIC_end$rarity_pollination <- interaction(forAIC_end$rarity, forAIC_end$pollination)
table(forAIC_end$rarity_pollination)
model_end_rarity_pollination <- rma.mv(y1, v1, mods= ~ rarity_pollination, random = list(~ 1 | taxon, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = forAIC_end)
summary(model_end_rarity_pollination)#QE(df = 1) = 0.0205, p-val = 0.8862; QM(df = 4) = 360.9800, p-val < .0001 ***

forAIC_end$rarity_propagule_dis <- interaction(forAIC_end$rarity, forAIC_end$propagule_dis)
table(forAIC_end$rarity_propagule_dis)
model_end_rarity_propagule_dis <- rma.mv(y1, v1, mods= ~ rarity_propagule_dis, random = list(~ 1 | taxon, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = forAIC_end)
summary(model_end_rarity_propagule_dis)#QE(df = 1) = 0.0205, p-val = 0.8862; QM(df = 3) = 63.8901, p-val < .0001 ***

forAIC_end$rarity_distribution <- interaction(forAIC_end$rarity, forAIC_end$distribution)
table(forAIC_end$rarity_distribution)
model_end_rarity_distribution <- rma.mv(y1, v1, mods= ~ rarity_distribution, random = list(~ 1 | taxon, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = forAIC_end)
summary(model_end_rarity_distribution)#QE(df = 3) = 53.3741, p-val < .0001; QM(df = 3) = 27.5500, p-val < .0001 ***

# List all variables to be analyzed for interaction
vars_end <- c("life_form", "mat_sys", "rep_sys", "pollination", "propagule_dis", "distribution", "habitat", "rarity")

# Create an empty list to hold the model results
models_end_class_inter <- list()

# Create an empty list to hold the frequency table of interaction items
tables_end <- list()

# Use nested loops to iterate over all combinations of variables
for (i in 1:(length(vars_end))) {
  for (j in 1:length(vars_end)) {
    # Skip the same variable
    if (i == j) next
    # Create interactive items
    interaction_var_end <- interaction(forAIC_end[[vars_end[i]]], forAIC_end[[vars_end[j]]])
    # Adds the interaction item to the data box
    interaction_name_end <- paste(sort(c(vars_end[i], vars_end[j])), collapse="_")
    forAIC_end[interaction_name_end] <- interaction_var_end
    # Saves a frequency table of interaction items
    tables_end[[interaction_name_end]] <- table(interaction_var_end)
    # Try to run the model and catch possible errors
    tryCatch({
      model_end <- rma.mv(y1, v1, mods = as.formula(paste("~", interaction_name_end)), random = list(~ 1 | taxon, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = forAIC_end)
      # Save the model results to the list
      models_end_class_inter[[interaction_name_end]] <- model_end
    }, error = function(e) {
      message(paste("Failed to fit model for", interaction_name_end, ":"))
      message(e)
    })
  }
}

# Iterate over all the elements in the models list
for (model_name_end in names(models_end_class_inter)) {
  # print model name
  print(model_name_end)
  # Get a summary of the model results and print it
  print(summary(models_end_class_inter[[model_name_end]]))
}

# Iterate over all the elements in the tables list
for (table_name_end in names(tables_end)) {
  # print table name
  print(table_name_end)
  # Print a frequency table of interaction items
  print(tables_end[[table_name_end]])
}

#Separate print
print(summary(models_end_class_inter[["life_form_mat_sys"]]))
print(summary(models_end_class_inter[["life_form_rep_sys"]]))
print(summary(models_end_class_inter[["life_form_pollination"]]))
print(summary(models_end_class_inter[["life_form_propagule_dis"]]))
print(summary(models_end_class_inter[["distribution_life_form"]]))
print(summary(models_end_class_inter[["habitat_life_form"]]))
print(summary(models_end_class_inter[["life_form_rarity"]]))
print(summary(models_end_class_inter[["mat_sys_rep_sys"]]))

##Continuous variable
model_end_Na_FIS <- rma.mv(y1, v1, mods = ~ Na * FIS, random = list(~ 1 | taxon, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = forAIC_end)
summary(model_end_Na_FIS)#QM(df = 3) = 23.9253, p-val < .0001***;  Na:FIS     0.0001  0.0001   1.9366  0.0528  -0.0000   0.0003    .

model_end_Na_Nm <- rma.mv(y1, v1, mods = ~ Na * Nm, random = list(~ 1 | taxon, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = forAIC_end)
summary(model_end_Na_Nm)#QM(df = 3) = 6.8149, p-val = 0.0780;   Na:Nm      0.0000  0.0000   1.4645  0.1431  -0.0000  0.0000

model_end_Na_Fst <- rma.mv(y1, v1, mods = ~ Na * Fst, random = list(~ 1 | taxon, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = forAIC_end)
summary(model_end_Na_Fst)#QM(df = 3) = 7.4482, p-val = 0.0589;      Na:Fst    -0.0000  0.0000  -1.4863  0.1372  -0.0000   0.0000 

model_end_Nm_FIS <- rma.mv(y1, v1, mods = ~ Nm * FIS, random = list(~ 1 | taxon, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = forAIC_end)
summary(model_end_Nm_FIS)#QM(df = 3) = 10.5543, p-val = 0.0144*;  Nm:FIS     0.1516  0.0633   2.3938  0.0167   0.0275   0.2757  *

model_end_Fst_FIS <- rma.mv(y1, v1, mods = ~ Fst * FIS, random = list(~ 1 | taxon, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = forAIC_end)
summary(model_end_Fst_FIS)#QM(df = 3) = 16.1446, p-val = 0.0011**; Fst:FIS   -2.2468  0.8267  -2.7178  0.0066  -3.8672  -0.6265  ** 

model_end_Ne_FIS <- rma.mv(y1, v1, mods = ~ Ne * FIS, random = list(~ 1 | taxon, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = forAIC_end)
summary(model_end_Ne_FIS)#QM(df = 3) = 4.0304, p-val = 0.2582;   Ne:FIS     0.0000  0.0003   0.0625  0.9502  -0.0006  0.0007

model_end_Ne_Nm <- rma.mv(y1, v1, mods = ~ Ne * Nm, random = list(~ 1 | taxon, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = forAIC_end)
summary(model_end_Ne_Nm)#QM(df = 3) = 1.1744, p-val = 0.7592;  Ne:Nm      0.0000  0.0000   0.6429  0.5203  -0.0000  0.0000

model_end_Ne_Fst <- rma.mv(y1, v1, mods = ~ Ne * Fst, random = list(~ 1 | taxon, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = forAIC_end)
summary(model_end_Ne_Fst)#QM(df = 3) = 2.1541, p-val = 0.5410;   Ne:Fst     0.0000  0.0000   0.4796  0.6315  -0.0001  0.0001

#Continuous * Classification variable
#Nm
model_end_Nm_life_form <- rma.mv(y1, v1, mods = ~ Nm * life_form, random = list(~ 1 | taxon, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = forAIC_end)
summary(model_end_Nm_life_form)#QE(df = 362) = 10557.0392, p-val < .0001; QM(df = 5) = 16.5518, p-val = 0.0054**; Nm:life_formshortlived    0.1164  0.0646   1.8022  0.0715  -0.0102  0.2430  .;Nm:life_formwoody         0.0061  0.0229   0.2661  0.7902  -0.0387  0.0509
model_end_Nm_life_formshortlived <- rma.mv(y1, v1, mods = ~ Nm * (life_form == "shortlived"), random = list(~ 1 | taxon, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = forAIC_end)
summary(model_end_Nm_life_formshortlived)#Nm:life_form == "shortlived"TRUE    0.1134  0.0644   1.7595  0.0785  -0.0129  0.2396  .
model_end_Nm_life_formlonglived <- rma.mv(y1, v1, mods = ~ Nm * (life_form == "longlived"), random = list(~ 1 | taxon, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = forAIC_end)
summary(model_end_Nm_life_formlonglived)#Nm:life_form == "longlived"TRUE   -0.0162  0.0220  -0.7360  0.4617  -0.0594  0.0270
model_end_Nm_life_formwoody <- rma.mv(y1, v1, mods = ~ Nm * (life_form == "woody"), random = list(~ 1 | taxon, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = forAIC_end)
summary(model_end_Nm_life_formwoody)#Nm:life_form == "woody"TRUE    0.0033  0.0229   0.1437  0.8857  -0.0415  0.0481

model_end_Nm_mat_sys <- rma.mv(y1, v1, mods = ~ Nm * mat_sys, random = list(~ 1 | taxon, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = forAIC_end)
summary(model_end_Nm_mat_sys)#QE(df = 144) = 4833.5934, p-val < .0001; QM(df = 5) = 24.3347, p-val = 0.0002***; Nm:mat_sysmixing        -0.4793  0.1782  -2.6896  0.0072  -0.8287  -0.1300   ** ; Nm:mat_sysoutcrossing   -0.4938  0.1620  -3.0491  0.0023  -0.8113  -0.1764   **
model_end_Nm_mat_sysoutcrossing <- rma.mv(y1, v1, mods = ~ Nm * (mat_sys == "outcrossing"), random = list(~ 1 | taxon, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = forAIC_end)
summary(model_end_Nm_mat_sysoutcrossing)#Nm:mat_sys == "outcrossing"TRUE   -0.1379  0.0690  -1.9987  0.0456  -0.2732  -0.0027  *
model_end_Nm_mat_sysmixing <- rma.mv(y1, v1, mods = ~ Nm * (mat_sys == "mixing"), random = list(~ 1 | taxon, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = forAIC_end)
summary(model_end_Nm_mat_sysmixing)#Nm:mat_sys == "mixing"TRUE    0.0172  0.0770   0.2228  0.8237  -0.1337  0.1680
model_end_Nm_mat_sysinbreeding <- rma.mv(y1, v1, mods = ~ Nm * (mat_sys == "inbreeding"), random = list(~ 1 | taxon, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = forAIC_end)
summary(model_end_Nm_mat_sysinbreeding)#Nm:mat_sys == "inbreeding"TRUE    0.4963  0.1633   3.0391  0.0024   0.1762   0.8164   **

model_end_Nm_rep_sys <- rma.mv(y1, v1, mods = ~ Nm * rep_sys, random = list(~ 1 | taxon, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = forAIC_end)
summary(model_end_Nm_rep_sys)#QE(df = 94) = 1771.5500, p-val < .0001; QM(df = 5) = 6.3673, p-val = 0.2721; Nm:rep_sysfacultative    0.0838  0.0496   1.6911  0.0908  -0.0133  0.1809  . ; Nm:rep_syssexual         0.1468  0.0906   1.6195  0.1053  -0.0309  0.3244
model_end_Nm_rep_sysclonal <- rma.mv(y1, v1, mods = ~ Nm * (rep_sys == "clonal"), random = list(~ 1 | taxon, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = forAIC_end)
summary(model_end_Nm_rep_sysclonal)#Nm:rep_sys == "clonal"TRUE   -0.0961  0.0458  -2.0971  0.0360  -0.1859  -0.0063  *
model_end_Nm_rep_sysfacultative <- rma.mv(y1, v1, mods = ~ Nm * (rep_sys == "facultative"), random = list(~ 1 | taxon, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = forAIC_end)
summary(model_end_Nm_rep_sysfacultative)#Nm:rep_sys == "facultative"TRUE    0.0743  0.0491   1.5147  0.1299  -0.0219  0.1706
model_end_Nm_rep_syssexual <- rma.mv(y1, v1, mods = ~ Nm * (rep_sys == "sexual"), random = list(~ 1 | taxon, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = forAIC_end)
summary(model_end_Nm_rep_syssexual)#Nm:rep_sys == "sexual"TRUE    0.1290  0.0901   1.4315  0.1523  -0.0476  0.3056

model_end_Nm_pollination <- rma.mv(y1, v1, mods = ~ Nm * pollination, random = list(~ 1 | taxon, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = forAIC_end)
summary(model_end_Nm_pollination)#QE(df = 155) = 5195.7433, p-val < .0001; QM(df = 3) = 8.8620, p-val = 0.0312*; Nm:pollinationshort    0.0359  0.0368   0.9769  0.3286  -0.0361  0.1080
model_end_Nm_pollinationshort <- rma.mv(y1, v1, mods = ~ Nm * (pollination == "short"), random = list(~ 1 | taxon, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = forAIC_end)
summary(model_end_Nm_pollinationshort)#Nm:pollination == "short"TRUE    0.0359  0.0368   0.9769  0.3286  -0.0361  0.1080
model_end_Nm_pollinationlong <- rma.mv(y1, v1, mods = ~ Nm * (pollination == "long"), random = list(~ 1 | taxon, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = forAIC_end)
summary(model_end_Nm_pollinationlong)#Nm:pollination == "long"TRUE   -0.0359  0.0368  -0.9769  0.3286  -0.1080  0.0361

model_end_Nm_propagule_dis <- rma.mv(y1, v1, mods = ~ Nm * propagule_dis, random = list(~ 1 | taxon, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = forAIC_end)
summary(model_end_Nm_propagule_dis)#QE(df = 132) = 3803.1121, p-val < .0001; QM(df = 3) = 10.9521, p-val = 0.0120*; Nm:propagule_dissho_dis    0.1456  0.0628   2.3198  0.0203   0.0226  0.2687  *
model_end_Nm_propagule_dislon_dis <- rma.mv(y1, v1, mods = ~ Nm * (propagule_dis == "lon_dis"), random = list(~ 1 | taxon, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = forAIC_end)
summary(model_end_Nm_propagule_dislon_dis)#Nm:propagule_dis == "lon_dis"TRUE   -0.1456  0.0628  -2.3198  0.0203  -0.2687  -0.0226   *
model_end_Nm_propagule_dissho_dis <- rma.mv(y1, v1, mods = ~ Nm * (propagule_dis == "sho_dis"), random = list(~ 1 | taxon, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = forAIC_end)
summary(model_end_Nm_propagule_dissho_dis)#Nm:propagule_dis == "sho_dis"TRUE    0.1456  0.0628   2.3198  0.0203   0.0226  0.2687  *

model_end_Nm_distribution <- rma.mv(y1, v1, mods = ~ Nm * distribution, random = list(~ 1 | taxon, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = forAIC_end)
summary(model_end_Nm_distribution)#QE(df = 362) = 10536.3828, p-val < .0001; QM(df = 5) = 19.4695, p-val = 0.0016**; Nm:distributionisland endemic    0.1963  0.0650   3.0186  0.0025   0.0689   0.3238  **;  Nm:distributionwidespread       -0.0156  0.0211  -0.7399  0.4593  -0.0570   0.0258
model_end_Nm_distributionisland_endemic <- rma.mv(y1, v1, mods = ~ Nm * (distribution == "island endemic"), random = list(~ 1 | taxon, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = forAIC_end)
summary(model_end_Nm_distributionisland_endemic)#Nm:distribution == "island endemic"TRUE    0.2012  0.0647   3.1089  0.0019   0.0744  0.3280  **
model_end_Nm_distributioncontinent_endemic <- rma.mv(y1, v1, mods = ~ Nm * (distribution == "continent  endemic"), random = list(~ 1 | taxon, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = forAIC_end)
summary(model_end_Nm_distributioncontinent_endemic)#NO INTERACTION
model_end_Nm_distributionwidespread <- rma.mv(y1, v1, mods = ~ Nm * (distribution == "widespread"), random = list(~ 1 | taxon, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = forAIC_end)
summary(model_end_Nm_distributionwidespread)#Nm:distribution == "widespread"TRUE   -0.0226  0.0214  -1.0560  0.2910  -0.0644  0.0193

model_end_Nm_habitat <- rma.mv(y1, v1, mods = ~ Nm * habitat, random = list(~ 1 | taxon, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = forAIC_end)
summary(model_end_Nm_habitat)#QE(df = 133) = 2797.7802, p-val < .0001; QM(df = 3) = 8.7409, p-val = 0.0329*; Nm:habitatunspecific    0.0380  0.0684   0.5565  0.5779  -0.0960  0.1720
model_end_Nm_habitatspecific <- rma.mv(y1, v1, mods = ~ Nm * (habitat == "specific"), random = list(~ 1 | taxon, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = forAIC_end)
summary(model_end_Nm_habitatspecific)#Nm:habitat == "specific"TRUE   -0.0380  0.0684  -0.5565  0.5779  -0.1720  0.0960
model_end_Nm_habitatunspecific <- rma.mv(y1, v1, mods = ~ Nm * (habitat == "unspecific"), random = list(~ 1 | taxon, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = forAIC_end)
summary(model_end_Nm_habitatunspecific)#Nm:habitat == "unspecific"TRUE    0.0380  0.0684   0.5565  0.5779  -0.0960  0.1720

model_end_Nm_rarity <- rma.mv(y1, v1, mods = ~ Nm * rarity, random = list(~ 1 | taxon, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = forAIC_end)
summary(model_end_Nm_rarity)#QE(df = 123) = 2655.5183, p-val < .0001; QM(df = 13) = 24.1034, p-val = 0.0302 *; Nm:rarityNLU   -0.1557  0.1167  -1.3347  0.1820  -0.3844   0.0729      ;Nm:rarityNSS   -0.2317  0.0836  -2.7713  0.0056  -0.3955  -0.0678   ** ;  Nm:rarityNSU   -0.3616  0.1391  -2.5996  0.0093  -0.6343  -0.0890   ** ;  Nm:rarityWLS   -0.2626  0.1933  -1.3580  0.1745  -0.6415   0.1164      ;Nm:rarityWSS   -0.2665  0.0851  -3.1338  0.0017  -0.4332  -0.0998   ** ;  Nm:rarityWSU   -0.7242  0.6629  -1.0925  0.2746  -2.0234   0.5750 
model_end_Nm_rarityNSS <- rma.mv(y1, v1, mods = ~ Nm * (rarity == "NSS"), random = list(~ 1 | taxon, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = forAIC_end)
summary(model_end_Nm_rarityNSS)#Nm:rarity == "NSS"TRUE    0.0079  0.0327   0.2405  0.8099  -0.0562  0.0719 
model_end_Nm_rarityNSU <- rma.mv(y1, v1, mods = ~ Nm * (rarity == "NSU"), random = list(~ 1 | taxon, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = forAIC_end)
summary(model_end_Nm_rarityNSU)#Nm:rarity == "NSU"TRUE   -0.1224  0.1168  -1.0479  0.2947  -0.3513  0.1065
model_end_Nm_rarityNLS <- rma.mv(y1, v1, mods = ~ Nm * (rarity == "NLS"), random = list(~ 1 | taxon, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = forAIC_end)
summary(model_end_Nm_rarityNLS)#Nm:rarity == "NLS"TRUE    0.2448  0.0830   2.9489  0.0032   0.0821   0.4076  **
model_end_Nm_rarityNLU <- rma.mv(y1, v1, mods = ~ Nm * (rarity == "NLU"), random = list(~ 1 | taxon, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = forAIC_end)
summary(model_end_Nm_rarityNLU)#Nm:rarity == "NLU"TRUE    0.0975  0.0884   1.1028  0.2701  -0.0758  0.2708
model_end_Nm_rarityWLS <- rma.mv(y1, v1, mods = ~ Nm * (rarity == "WLS"), random = list(~ 1 | taxon, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = forAIC_end)
summary(model_end_Nm_rarityWLS)#Nm:rarity == "WLS"TRUE   -0.0625  0.1895  -0.3298  0.7415  -0.4339  0.3089 
model_end_Nm_rarityWSU <- rma.mv(y1, v1, mods = ~ Nm * (rarity == "WSU"), random = list(~ 1 | taxon, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = forAIC_end)
summary(model_end_Nm_rarityWSU)#Nm:rarity == "WSU"TRUE   -0.3794  0.7109  -0.5337  0.5936  -1.7728  1.0140
model_end_Nm_rarityWSS <- rma.mv(y1, v1, mods = ~ Nm * (rarity == "WSS"), random = list(~ 1 | taxon, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = forAIC_end)
summary(model_end_Nm_rarityWSS)#Nm:rarity == "WSS"TRUE   -0.0526  0.0383  -1.3760  0.1688  -0.1276  0.0223

#FIS
model_end_FIS_life_form <- rma.mv(y1, v1, mods = ~ FIS * life_form, random = list(~ 1 | taxon, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = forAIC_end)
summary(model_end_FIS_life_form)#QE(df = 437) = 13047.3987, p-val < .0001; QM(df = 5) = 9.2529, p-val = 0.0994; FIS:life_formshortlived    0.7467  0.4420   1.6895  0.0911  -0.1195  1.6130  .; FIS:life_formwoody         0.2062  0.1763   1.1697  0.2421  -0.1393  0.5517
model_end_FIS_life_formshortlived <- rma.mv(y1, v1, mods = ~ FIS * (life_form == "shortlived"), random = list(~ 1 | taxon, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = forAIC_end)
summary(model_end_FIS_life_formshortlived)#FIS:life_form == "shortlived"TRUE    0.6723  0.4411   1.5240  0.1275  -0.1923  1.5369 
model_end_FIS_life_formlonglived <- rma.mv(y1, v1, mods = ~ FIS * (life_form == "longlived"), random = list(~ 1 | taxon, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = forAIC_end)
summary(model_end_FIS_life_formlonglived)#FIS:life_form == "longlived"TRUE   -0.2568  0.1701  -1.5096  0.1311  -0.5902  0.0766
model_end_FIS_life_formwoody <- rma.mv(y1, v1, mods = ~ FIS * (life_form == "woody"), random = list(~ 1 | taxon, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = forAIC_end)
summary(model_end_FIS_life_formwoody)#FIS:life_form == "woody"TRUE    0.1673  0.1748   0.9572  0.3385  -0.1753  0.5100

model_end_FIS_mat_sys <- rma.mv(y1, v1, mods = ~ FIS * mat_sys, random = list(~ 1 | taxon, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = forAIC_end)
summary(model_end_FIS_mat_sys)#QE(df = 262) = 8913.2386, p-val < .0001; QM(df = 5) = 26.6275, p-val < .0001***; FIS:mat_sysmixing         1.9611  0.8977   2.1847  0.0289   0.2018   3.7205   * ; FIS:mat_sysoutcrossing    2.4603  0.8997   2.7347  0.0062   0.6970   4.2235  ** 
model_end_FIS_mat_sysoutcrossing <- rma.mv(y1, v1, mods = ~ FIS * (mat_sys == "outcrossing"), random = list(~ 1 | taxon, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = forAIC_end)
summary(model_end_FIS_mat_sysoutcrossing)#FIS:mat_sys == "outcrossing"TRUE    0.6359  0.2228   2.8539  0.0043   0.1992   1.0725  **
model_end_FIS_mat_sysmixing <- rma.mv(y1, v1, mods = ~ FIS * (mat_sys == "mixing"), random = list(~ 1 | taxon, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = forAIC_end)
summary(model_end_FIS_mat_sysmixing)#FIS:mat_sys == "mixing"TRUE   -0.2145  0.2111  -1.0162  0.3095  -0.6282  0.1992
model_end_FIS_mat_sysinbreeding <- rma.mv(y1, v1, mods = ~ FIS * (mat_sys == "inbreeding"), random = list(~ 1 | taxon, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = forAIC_end)
summary(model_end_FIS_mat_sysinbreeding)#FIS:mat_sys == "inbreeding"TRUE   -2.2381  0.9011  -2.4838  0.0130  -4.0041  -0.4720  *

model_end_FIS_rep_sys <- rma.mv(y1, v1, mods = ~ FIS * rep_sys, random = list(~ 1 | taxon, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = forAIC_end)
summary(model_end_FIS_rep_sys)#QE(df = 96) = 988.2780, p-val < .0001; QM(df = 5) = 158.5244, p-val < .0001***; FIS:rep_sysfacultative    0.3388  0.8108   0.4179  0.6760  -1.2502   1.9279  ; FIS:rep_syssexual        -3.8843  0.8456  -4.5933  <.0001  -5.5417  -2.2269  ***
model_end_FIS_rep_sysclonal <- rma.mv(y1, v1, mods = ~ FIS * (rep_sys == "clonal"), random = list(~ 1 | taxon, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = forAIC_end)
summary(model_end_FIS_rep_sysclonal)#FIS:rep_sys == "clonal"TRUE    0.7244  0.8435   0.8588  0.3905  -0.9289   2.3776
model_end_FIS_rep_sysfacultative <- rma.mv(y1, v1, mods = ~ FIS * (rep_sys == "facultative"), random = list(~ 1 | taxon, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = forAIC_end)
summary(model_end_FIS_rep_sysfacultative)#FIS:rep_sys == "facultative"TRUE    4.0621  0.3701   10.9771  <.0001   3.3368   4.7874  ***
model_end_FIS_rep_syssexual <- rma.mv(y1, v1, mods = ~ FIS * (rep_sys == "sexual"), random = list(~ 1 | taxon, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = forAIC_end)
summary(model_end_FIS_rep_syssexual)#FIS:rep_sys == "sexual"TRUE   -4.2131  0.3587  -11.7458  <.0001  -4.9162  -3.5101  ***

model_end_FIS_pollination <- rma.mv(y1, v1, mods = ~ FIS * pollination, random = list(~ 1 | taxon, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = forAIC_end)
summary(model_end_FIS_pollination)#QE(df = 200) = 7027.7679, p-val < .0001; QM(df = 3) = 19.8589, p-val = 0.0002***; FIS:pollinationshort   -0.7113  0.2332  -3.0496  0.0023  -1.1684  -0.2541  **
model_end_FIS_pollinationshort <- rma.mv(y1, v1, mods = ~ FIS * (pollination == "short"), random = list(~ 1 | taxon, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = forAIC_end)
summary(model_end_FIS_pollinationshort)#FIS:pollination == "short"TRUE    -0.7113  0.2332  -3.0496  0.0023  -1.1684  -0.2541  **
model_end_FIS_pollinationlong <- rma.mv(y1, v1, mods = ~ FIS * (pollination == "long"), random = list(~ 1 | taxon, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = forAIC_end)
summary(model_end_FIS_pollinationlong)#FIS:pollination == "long"TRUE    0.7113  0.2332   3.0496  0.0023   0.2541   1.1684   **

model_end_FIS_propagule_dis <- rma.mv(y1, v1, mods = ~ FIS * propagule_dis, random = list(~ 1 | taxon, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = forAIC_end)
summary(model_end_FIS_propagule_dis)#QE(df = 201) = 5099.6276, p-val < .0001; QM(df = 3) = 2.9441, p-val = 0.4003; FIS:propagule_dissho_dis   -0.7546  0.4539  -1.6623  0.0964  -1.6443  0.1351  .
model_end_FIS_propagule_dislon_dis <- rma.mv(y1, v1, mods = ~ FIS * (propagule_dis == "lon_dis"), random = list(~ 1 | taxon, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = forAIC_end)
summary(model_end_FIS_propagule_dislon_dis)#FIS:propagule_dis == "lon_dis"TRUE    0.7546  0.4539   1.6623  0.0964  -0.1351  1.6443  .
model_end_FIS_propagule_dissho_dis <- rma.mv(y1, v1, mods = ~ FIS * (propagule_dis == "sho_dis"), random = list(~ 1 | taxon, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = forAIC_end)
summary(model_end_FIS_propagule_dissho_dis)#FIS:propagule_dis == "sho_dis"TRUE   -0.7546  0.4539  -1.6623  0.0964  -1.6443  0.1351  . 

model_end_FIS_distribution <- rma.mv(y1, v1, mods = ~ FIS * distribution, random = list(~ 1 | taxon, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = forAIC_end)
summary(model_end_FIS_distribution)#QE(df = 437) = 13654.1350, p-val < .0001; QM(df = 5) = 19.5027, p-val = 0.0015 **; FIS:distributionisland endemic    0.2949  0.2554   1.1543  0.2484  -0.2058   0.7955  ; FIS:distributionwidespread        0.9898  0.2496   3.9658  <.0001   0.5006   1.4790  ***  
model_end_FIS_distributionisland_endemic <- rma.mv(y1, v1, mods = ~ FIS * (distribution == "island endemic"), random = list(~ 1 | taxon, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = forAIC_end)
summary(model_end_FIS_distributionisland_endemic)#FIS:distribution == "island endemic"TRUE    0.1516  0.2520   0.6019  0.5473  -0.3422  0.6455
model_end_FIS_distributioncontinent_endemic <- rma.mv(y1, v1, mods = ~ FIS * (distribution == "continent  endemic"), random = list(~ 1 | taxon, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = forAIC_end)
summary(model_end_FIS_distributioncontinent_endemic)#NO INTERACTION
model_end_FIS_distributionwidespread <- rma.mv(y1, v1, mods = ~ FIS * (distribution == "widespread"), random = list(~ 1 | taxon, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = forAIC_end)
summary(model_end_FIS_distributionwidespread)#FIS:distribution == "widespread"TRUE    0.9443  0.2475   3.8150  0.0001   0.4592  1.4294  ***

model_end_FIS_habitat <- rma.mv(y1, v1, mods = ~ FIS * habitat, random = list(~ 1 | taxon, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = forAIC_end)
summary(model_end_FIS_habitat)#QE(df = 137) = 2982.2436, p-val < .0001; QM(df = 3) = 35.2009, p-val < .0001***; FIS:habitatunspecific    1.2633  0.3036   4.1613  <.0001   0.6683   1.8582  *** 
model_end_FIS_habitatspecific <- rma.mv(y1, v1, mods = ~ FIS * (habitat == "specific"), random = list(~ 1 | taxon, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = forAIC_end)
summary(model_end_FIS_habitatspecific)#FIS:habitat == "specific"TRUE   -1.2633  0.3036  -4.1613  <.0001  -1.8582  -0.6683  ***
model_end_FIS_habitatunspecific <- rma.mv(y1, v1, mods = ~ FIS * (habitat == "unspecific"), random = list(~ 1 | taxon, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = forAIC_end)
summary(model_end_FIS_habitatunspecific)#FIS:habitat == "unspecific"TRUE    1.2633  0.3036   4.1613  <.0001   0.6683   1.8582  ***

model_end_FIS_rarity <- rma.mv(y1, v1, mods = ~ FIS * rarity, random = list(~ 1 | taxon, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = forAIC_end)
summary(model_end_FIS_rarity)#QE(df = 128) = 2793.4888, p-val < .0001; QM(df = 12) = 56.0633, p-val < .0001 ***; FIS:rarityNLU    0.6002  0.4836   1.2411  0.2146  -0.3477   1.5480     ;FIS:rarityNSS   -1.1412  0.3933  -2.9016  0.0037  -1.9120  -0.3703  ** ;  FIS:rarityNSU    0.7124  0.4678   1.5230  0.1278  -0.2044   1.6292     ;FIS:rarityWLS    1.0286  0.9240   1.1132  0.2656  -0.7823   2.8395     ;FIS:rarityWSU    1.9614  5.0694   0.3869  0.6988  -7.9744  11.8972
model_end_FIS_rarityNSS <- rma.mv(y1, v1, mods = ~ FIS * (rarity == "NSS"), random = list(~ 1 | taxon, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = forAIC_end)
summary(model_end_FIS_rarityNSS)#FIS:rarity == "NSS"TRUE   -1.5493  0.2800  -5.5332  <.0001  -2.0981  -1.0005  ***
model_end_FIS_rarityNSU <- rma.mv(y1, v1, mods = ~ FIS * (rarity == "NSU"), random = list(~ 1 | taxon, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = forAIC_end)
summary(model_end_FIS_rarityNSU)#FIS:rarity == "NSU"TRUE    0.7090  0.2909   2.4373  0.0148   0.1389   1.2792    *
model_end_FIS_rarityNLS <- rma.mv(y1, v1, mods = ~ FIS * (rarity == "NLS"), random = list(~ 1 | taxon, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = forAIC_end)
summary(model_end_FIS_rarityNLS)#FIS:rarity == "NLS"TRUE    0.5591  0.3727   1.5002  0.1336  -0.1713   1.2894
model_end_FIS_rarityNLU <- rma.mv(y1, v1, mods = ~ FIS * (rarity == "NLU"), random = list(~ 1 | taxon, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = forAIC_end)
summary(model_end_FIS_rarityNLU)#FIS:rarity == "NLU"TRUE    0.4491  0.3123   1.4381  0.1504  -0.1630   1.0613
model_end_FIS_rarityWLS <- rma.mv(y1, v1, mods = ~ FIS * (rarity == "WLS"), random = list(~ 1 | taxon, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = forAIC_end)
summary(model_end_FIS_rarityWLS)#FIS:rarity == "WLS"TRUE    0.8416  0.7613   1.1055  0.2689  -0.6505   2.3338
model_end_FIS_rarityWSU <- rma.mv(y1, v1, mods = ~ FIS * (rarity == "WSU"), random = list(~ 1 | taxon, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = forAIC_end)
summary(model_end_FIS_rarityWSU)#FIS:rarity == "WSU"TRUE    1.7432  4.5641   0.3819  0.7025  -7.2023  10.6886
model_end_FIS_rarityWSS <- rma.mv(y1, v1, mods = ~ FIS * (rarity == "WSS"), random = list(~ 1 | taxon, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = forAIC_end)
summary(model_end_FIS_rarityWSS)#NO

#Na
model_end_Na_life_form <- rma.mv(y1, v1, mods = ~ Na * life_form, random = list(~ 1 | taxon, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = forAIC_end)
summary(model_end_Na_life_form)#QE(df = 333) = 8408.8269, p-val < .0001; QM(df = 5) = 9.9603, p-val = 0.0764; Na:life_formshortlived    0.0000  0.0000   2.0810  0.0374   0.0000  0.0000  * ; Na:life_formwoody         0.0000  0.0000   1.1449  0.2523  -0.0000  0.0000
model_end_Na_life_formshortlived <- rma.mv(y1, v1, mods = ~ Na * (life_form == "shortlived"), random = list(~ 1 | taxon, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = forAIC_end)
summary(model_end_Na_life_formshortlived)#Na:life_form == "shortlived"TRUE    0.0000  0.0000   2.0231  0.0431   0.0000   0.0000  *
model_end_Na_life_formlonglived <- rma.mv(y1, v1, mods = ~ Na * (life_form == "longlived"), random = list(~ 1 | taxon, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = forAIC_end)
summary(model_end_Na_life_formlonglived)#Na:life_form == "longlived"TRUE   -0.0000  0.0000  -1.5852  0.1129  -0.0000  0.0000
model_end_Na_life_formwoody <- rma.mv(y1, v1, mods = ~ Na * (life_form == "woody"), random = list(~ 1 | taxon, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = forAIC_end)
summary(model_end_Na_life_formwoody)#Na:life_form == "woody"TRUE    0.0000  0.0000   1.0922  0.2748  -0.0000  0.0000

model_end_Na_mat_sys <- rma.mv(y1, v1, mods = ~ Na * mat_sys, random = list(~ 1 | taxon, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = forAIC_end)
summary(model_end_Na_mat_sys)#QE(df = 193) = 5384.7204, p-val < .0001; QM(df = 5) = 5.0444, p-val = 0.4105; Na:mat_sysmixing         0.0002  0.0002   0.8417  0.4000  -0.0003   0.0006    ; Na:mat_sysoutcrossing    0.0002  0.0002   0.8507  0.3949  -0.0003   0.0006
model_end_Na_mat_sysoutcrossing <- rma.mv(y1, v1, mods = ~ Na * (mat_sys == "outcrossing"), random = list(~ 1 | taxon, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = forAIC_end)
summary(model_end_Na_mat_sysoutcrossing)#Na:mat_sys == "outcrossing"TRUE    0.0000  0.0000   0.5801  0.5619  -0.0000   0.0000
model_end_Na_mat_sysmixing <- rma.mv(y1, v1, mods = ~ Na * (mat_sys == "mixing"), random = list(~ 1 | taxon, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = forAIC_end)
summary(model_end_Na_mat_sysmixing)#Na:mat_sys == "mixing"TRUE   -0.0000  0.0000  -0.6285  0.5297  -0.0000  0.0000
model_end_Na_mat_sysinbreeding <- rma.mv(y1, v1, mods = ~ Na * (mat_sys == "inbreeding"), random = list(~ 1 | taxon, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = forAIC_end)
summary(model_end_Na_mat_sysinbreeding)#Na:mat_sys == "inbreeding"TRUE   -0.0002  0.0002  -0.8460  0.3976  -0.0006  0.0003

model_end_Na_rep_sys <- rma.mv(y1, v1, mods = ~ Na * rep_sys, random = list(~ 1 | taxon, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = forAIC_end)
summary(model_end_Na_rep_sys)#QE(df = 34) = 887.6145, p-val < .0001; QM(df = 3) = 1.8403, p-val = 0.6062; Na:rep_sysfacultative   -0.0001  0.0001  -1.1388  0.2548  -0.0003  0.0001
model_end_Na_rep_sysclonal <- rma.mv(y1, v1, mods = ~ Na * (rep_sys == "clonal"), random = list(~ 1 | taxon, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = forAIC_end)
summary(model_end_Na_rep_sysclonal)#NO INTERACTION
model_end_Na_rep_sysfacultative <- rma.mv(y1, v1, mods = ~ Na * (rep_sys == "facultative"), random = list(~ 1 | taxon, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = forAIC_end)
summary(model_end_Na_rep_sysfacultative)#Na:rep_sys == "facultative"TRUE   -0.0001  0.0001  -1.1388  0.2548  -0.0003  0.0001
model_end_Na_rep_syssexual <- rma.mv(y1, v1, mods = ~ Na * (rep_sys == "sexual"), random = list(~ 1 | taxon, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = forAIC_end)
summary(model_end_Na_rep_syssexual)#Na:rep_sys == "sexual"TRUE    0.0001  0.0001   1.1388  0.2548  -0.0001  0.0003

model_end_Na_pollination <- rma.mv(y1, v1, mods = ~ Na * pollination, random = list(~ 1 | taxon, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = forAIC_end)
summary(model_end_Na_pollination)#QE(df = 204) = 6141.8075, p-val < .0001; QM(df = 3) = 2.5830, p-val = 0.4605; Na:pollinationshort    0.0000  0.0000   0.2635  0.7922  -0.0000  0.0000
model_end_Na_pollinationshort <- rma.mv(y1, v1, mods = ~ Na * (pollination == "short"), random = list(~ 1 | taxon, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = forAIC_end)
summary(model_end_Na_pollinationshort)#Na:pollination == "short"TRUE    0.0000  0.0000   0.2635  0.7922  -0.0000  0.0000
model_end_Na_pollinationlong <- rma.mv(y1, v1, mods = ~ Na * (pollination == "long"), random = list(~ 1 | taxon, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = forAIC_end)
summary(model_end_Na_pollinationlong)#Na:pollination == "long"TRUE   -0.0000  0.0000  -0.2635  0.7922  -0.0000  0.0000

model_end_Na_propagule_dis <- rma.mv(y1, v1, mods = ~ Na * propagule_dis, random = list(~ 1 | taxon, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = forAIC_end)
summary(model_end_Na_propagule_dis)#QE(df = 191) = 4002.2640, p-val < .0001; QM(df = 3) = 0.9852, p-val = 0.8048; Na:propagule_dissho_dis    0.0000  0.0000   0.0160  0.9872  -0.0000  0.0000
model_end_Na_propagule_dislon_dis <- rma.mv(y1, v1, mods = ~ Na * (propagule_dis == "lon_dis"), random = list(~ 1 | taxon, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = forAIC_end)
summary(model_end_Na_propagule_dislon_dis)#Na:propagule_dis == "lon_dis"TRUE   -0.0000  0.0000  -0.0160  0.9872  -0.0000  0.0000
model_end_Na_propagule_dissho_dis <- rma.mv(y1, v1, mods = ~ Na * (propagule_dis == "sho_dis"), random = list(~ 1 | taxon, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = forAIC_end)
summary(model_end_Na_propagule_dissho_dis)#Na:propagule_dis == "sho_dis"TRUE    0.0000  0.0000   0.0160  0.9872  -0.0000  0.0000 

model_end_Na_distribution <- rma.mv(y1, v1, mods = ~ Na * distribution, random = list(~ 1 | taxon, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = forAIC_end)
summary(model_end_Na_distribution)#QE(df = 333) = 8704.9620, p-val < .0001; QM(df = 5) = 17.2078, p-val = 0.0041 **; Na:distributionisland endemic    0.0001  0.0000   2.6958  0.0070   0.0000   0.0002  ** ; Na:distributionwidespread       -0.0000  0.0000  -1.9173  0.0552  -0.0000   0.0000   . 
model_end_Na_distributionisland_endemic <- rma.mv(y1, v1, mods = ~ Na * (distribution == "island endemic"), random = list(~ 1 | taxon, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = forAIC_end)
summary(model_end_Na_distributionisland_endemic)#Na:distribution == "island endemic"TRUE    0.0001  0.0000   2.7536  0.0059   0.0000  0.0002  **
model_end_Na_distributioncontinent_endemic <- rma.mv(y1, v1, mods = ~ Na * (distribution == "continent  endemic"), random = list(~ 1 | taxon, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = forAIC_end)
summary(model_end_Na_distributioncontinent_endemic)#NO INTERACTION
model_end_Na_distributionwidespread <- rma.mv(y1, v1, mods = ~ Na * (distribution == "widespread"), random = list(~ 1 | taxon, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = forAIC_end)
summary(model_end_Na_distributionwidespread)#Na:distribution == "widespread"TRUE   -0.0000  0.0000  -2.1143  0.0345  -0.0000  -0.0000  *

model_end_Na_habitat <- rma.mv(y1, v1, mods = ~ Na * habitat, random = list(~ 1 | taxon, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = forAIC_end)
summary(model_end_Na_habitat)#QE(df = 335) = 7554.9940, p-val < .0001; QM(df = 3) = 2.4214, p-val = 0.4897; Na:habitatunspecific    0.0000  0.0000   1.3537  0.1758  -0.0000  0.0000
model_end_Na_habitatspecific <- rma.mv(y1, v1, mods = ~ Na * (habitat == "specific"), random = list(~ 1 | taxon, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = forAIC_end)
summary(model_end_Na_habitatspecific)#Na:habitat == "specific"TRUE   -0.0000  0.0000  -1.3537  0.1758  -0.0000  0.0000
model_end_Na_habitatunspecific <- rma.mv(y1, v1, mods = ~ Na * (habitat == "unspecific"), random = list(~ 1 | taxon, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = forAIC_end)
summary(model_end_Na_habitatunspecific)#Na:habitat == "unspecific"TRUE    0.0000  0.0000   1.3537  0.1758  -0.0000  0.0000

model_end_Na_rarity <- rma.mv(y1, v1, mods = ~ Na * rarity, random = list(~ 1 | taxon, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = forAIC_end)
summary(model_end_Na_rarity)#QE(df = 0) = 0.0000, p-val = 1.0000; QM(df = 4) = 360.8861, p-val < .0001 ***; Na:rarityNSS    5.1956  1.8003   2.8860  0.0039   1.6672   8.7241  **
model_end_Na_rarityNSS <- rma.mv(y1, v1, mods = ~ Na * (rarity == "NSS"), random = list(~ 1 | taxon, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = forAIC_end)
summary(model_end_Na_rarityNSS)#Na:rarity == "NSS"TRUE    0.0005  0.0002   2.3446  0.0190   0.0001   0.0009   *
model_end_Na_rarityNSU <- rma.mv(y1, v1, mods = ~ Na * (rarity == "NSU"), random = list(~ 1 | taxon, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = forAIC_end)
summary(model_end_Na_rarityNSU)#Na:rarity == "NSU"TRUE   -0.0000  0.0002  -0.0778  0.9380  -0.0005  0.0004
model_end_Na_rarityNLS <- rma.mv(y1, v1, mods = ~ Na * (rarity == "NLS"), random = list(~ 1 | taxon, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = forAIC_end)
summary(model_end_Na_rarityNLS)#Na:rarity == "NLS"TRUE    0.0000  0.0000   0.9717  0.3312  -0.0000  0.0000
model_end_Na_rarityNLU <- rma.mv(y1, v1, mods = ~ Na * (rarity == "NLU"), random = list(~ 1 | taxon, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = forAIC_end)
summary(model_end_Na_rarityNLU)#Na:rarity == "NLU"TRUE    0.0000  0.0000   1.5262  0.1270  -0.0000  0.0000
model_end_Na_rarityWLS <- rma.mv(y1, v1, mods = ~ Na * (rarity == "WLS"), random = list(~ 1 | taxon, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = forAIC_end)
summary(model_end_Na_rarityWLS)#Na:rarity == "WLS"TRUE   -0.0000  0.0000  -2.0152  0.0439  -0.0000  -0.0000  *
model_end_Na_rarityWSU <- rma.mv(y1, v1, mods = ~ Na * (rarity == "WSU"), random = list(~ 1 | taxon, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = forAIC_end)
summary(model_end_Na_rarityWSU)#Na:rarity == "WSU"TRUE   -0.0010  0.0009  -1.0800  0.2801  -0.0027  0.0008
model_end_Na_rarityWSS <- rma.mv(y1, v1, mods = ~ Na * (rarity == "WSS"), random = list(~ 1 | taxon, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = forAIC_end)
summary(model_end_Na_rarityWSS)#Na:rarity == "WSS"TRUE    0.0001  0.0008   0.1030  0.9180  -0.0014  0.0016

#Ne
model_end_Ne_life_form <- rma.mv(y1, v1, mods = ~ Ne * life_form, random = list(~ 1 | taxon, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = forAIC_end)
summary(model_end_Ne_life_form)#QE(df = 19) = 340.4428, p-val < .0001; QM(df = 5) = 99.1468, p-val < .0001 ***; Ne:life_formshortlived   -0.0026  0.0003  -9.1179  <.0001  -0.0032  -0.0020  *** ; Ne:life_formwoody         0.0000  0.0000   2.3256  0.0200   0.0000   0.0001    *
model_end_Ne_life_formshortlived <- rma.mv(y1, v1, mods = ~ Ne * (life_form == "shortlived"), random = list(~ 1 | taxon, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = forAIC_end)
summary(model_end_Ne_life_formshortlived)#Ne:life_form == "shortlived"TRUE   -0.0026  0.0003  -8.3760  <.0001  -0.0032  -0.0020  ***
model_end_Ne_life_formlonglived <- rma.mv(y1, v1, mods = ~ Ne * (life_form == "longlived"), random = list(~ 1 | taxon, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = forAIC_end)
summary(model_end_Ne_life_formlonglived)#Ne:life_form == "longlived"TRUE   -0.0000  0.0000  -1.9186  0.0550  -0.0001  0.0000  .
model_end_Ne_life_formwoody <- rma.mv(y1, v1, mods = ~ Ne * (life_form == "woody"), random = list(~ 1 | taxon, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = forAIC_end)
summary(model_end_Ne_life_formwoody)#Ne:life_form == "woody"TRUE    0.0000  0.0000   1.9722  0.0486   0.0000  0.0001  *

model_end_Ne_mat_sys <- rma.mv(y1, v1, mods = ~ Ne * mat_sys, random = list(~ 1 | taxon, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = forAIC_end)
summary(model_end_Ne_mat_sys)#QE(df = 5) = 21.7914, p-val = 0.0006; QM(df = 5) = 17.9187, p-val = 0.0031**; Ne:mat_sysmixing        -0.0661  0.1728  -0.3826  0.7021  -0.4047  0.2725   ; Ne:mat_sysoutcrossing   -0.0714  0.1728  -0.4130  0.6796  -0.4100  0.2673
model_end_Ne_mat_sysoutcrossing <- rma.mv(y1, v1, mods = ~ Ne * (mat_sys == "outcrossing"), random = list(~ 1 | taxon, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = forAIC_end)
summary(model_end_Ne_mat_sysoutcrossing)#Ne:mat_sys == "outcrossing"TRUE   -0.0058  0.0015  -3.9113  <.0001  -0.0087  -0.0029  ***
model_end_Ne_mat_sysmixing <- rma.mv(y1, v1, mods = ~ Ne * (mat_sys == "mixing"), random = list(~ 1 | taxon, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = forAIC_end)
summary(model_end_Ne_mat_sysmixing)#Ne:mat_sys == "mixing"TRUE    0.0052  0.0015   3.3502  0.0008   0.0021   0.0082  ***
model_end_Ne_mat_sysinbreeding <- rma.mv(y1, v1, mods = ~ Ne * (mat_sys == "inbreeding"), random = list(~ 1 | taxon, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = forAIC_end)
summary(model_end_Ne_mat_sysinbreeding)#Ne:mat_sys == "inbreeding"TRUE    0.0662  0.1728   0.3833  0.7015  -0.2724  0.4049

model_end_Ne_rep_sys <- rma.mv(y1, v1, mods = ~ Ne * rep_sys, random = list(~ 1 | taxon, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = forAIC_end)
summary(model_end_Ne_rep_sys)#NO INTERACTION
model_end_Ne_rep_sysclonal <- rma.mv(y1, v1, mods = ~ Ne * (rep_sys == "clonal"), random = list(~ 1 | taxon, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = forAIC_end)
summary(model_end_Ne_rep_sysclonal)#NO INTERACTION
model_end_Ne_rep_sysfacultative <- rma.mv(y1, v1, mods = ~ Ne * (rep_sys == "facultative"), random = list(~ 1 | taxon, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = forAIC_end)
summary(model_end_Ne_rep_sysfacultative)#NO INTERACTION
model_end_Ne_rep_syssexual <- rma.mv(y1, v1, mods = ~ Ne * (rep_sys == "sexual"), random = list(~ 1 | taxon, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = forAIC_end)
summary(model_end_Ne_rep_syssexual)#NO INTERACTION

model_end_Ne_pollination <- rma.mv(y1, v1, mods = ~ Ne * pollination, random = list(~ 1 | taxon, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = forAIC_end)
summary(model_end_Ne_pollination)#QE(df = 11) = 298.1387, p-val < .0001; QM(df = 3) = 1.2603, p-val = 0.7386; Ne:pollinationshort   -0.0661  0.1728  -0.3823  0.7023  -0.4047  0.2726
model_end_Ne_pollinationshort <- rma.mv(y1, v1, mods = ~ Ne * (pollination == "short"), random = list(~ 1 | taxon, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = forAIC_end)
summary(model_end_Ne_pollinationshort)#Ne:pollination == "short"TRUE   -0.0661  0.1728  -0.3823  0.7023  -0.4047  0.2726
model_end_Ne_pollinationlong <- rma.mv(y1, v1, mods = ~ Ne * (pollination == "long"), random = list(~ 1 | taxon, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = forAIC_end)
summary(model_end_Ne_pollinationlong)#Ne:pollination == "long"TRUE    0.0661  0.1728   0.3823  0.7023  -0.2726  0.4047

model_end_Ne_propagule_dis <- rma.mv(y1, v1, mods = ~ Ne * propagule_dis, random = list(~ 1 | taxon, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = forAIC_end)
summary(model_end_Ne_propagule_dis)#QE(df = 14) = 152.0744, p-val < .0001; QM(df = 3) = 7.9467, p-val = 0.0471*; Ne:propagule_dissho_dis   -0.0000  0.0000  -0.5346  0.5929  -0.0001  0.0001
model_end_Ne_propagule_dislon_dis <- rma.mv(y1, v1, mods = ~ Ne * (propagule_dis == "lon_dis"), random = list(~ 1 | taxon, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = forAIC_end)
summary(model_end_Ne_propagule_dislon_dis)#Ne:propagule_dis == "lon_dis"TRUE    0.0000  0.0000   0.5346  0.5929  -0.0001  0.0001
model_end_Ne_propagule_dissho_dis <- rma.mv(y1, v1, mods = ~ Ne * (propagule_dis == "sho_dis"), random = list(~ 1 | taxon, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = forAIC_end)
summary(model_end_Ne_propagule_dissho_dis)#Ne:propagule_dis == "sho_dis"TRUE   -0.0000  0.0000  -0.5346  0.5929  -0.0001  0.0001 

model_end_Ne_distribution <- rma.mv(y1, v1, mods = ~ Ne * distribution, random = list(~ 1 | taxon, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = forAIC_end)
summary(model_end_Ne_distribution)#QE(df = 20) = 525.2294, p-val < .0001; QM(df = 4) = 22.2810, p-val = 0.0002 ***; Ne:distributionwidespread     0.0036  0.0107   0.3384  0.7351  -0.0174  0.0247  
model_end_Ne_distributionisland_endemic <- rma.mv(y1, v1, mods = ~ Ne * (distribution == "island endemic"), random = list(~ 1 | taxon, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = forAIC_end)
summary(model_end_Ne_distributionisland_endemic)#NO INTERACTION
model_end_Ne_distributioncontinent_endemic <- rma.mv(y1, v1, mods = ~ Ne * (distribution == "continent  endemic"), random = list(~ 1 | taxon, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = forAIC_end)
summary(model_end_Ne_distributioncontinent_endemic)#NO INTERACTION
model_end_Ne_distributionwidespread <- rma.mv(y1, v1, mods = ~ Ne * (distribution == "widespread"), random = list(~ 1 | taxon, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = forAIC_end)
summary(model_end_Ne_distributionwidespread)#Ne:distribution == "widespread"TRUE    0.0036  0.0151   0.2405  0.8099  -0.0260  0.0332

model_end_Ne_habitat <- rma.mv(y1, v1, mods = ~ Ne * habitat, random = list(~ 1 | taxon, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = forAIC_end)
summary(model_end_Ne_habitat)#QE(df = 21) = 420.1152, p-val < .0001; QM(df = 3) = 1.5098, p-val = 0.6800; Ne:habitatunspecific    0.0000  0.0000  1.0725  0.2835  -0.0000  0.0001
model_end_Ne_habitatspecific <- rma.mv(y1, v1, mods = ~ Ne * (habitat == "specific"), random = list(~ 1 | taxon, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = forAIC_end)
summary(model_end_Ne_habitatspecific)#Ne:habitat == "specific"TRUE   -0.0000  0.0000  -1.0725  0.2835  -0.0001  0.0000
model_end_Ne_habitatunspecific <- rma.mv(y1, v1, mods = ~ Ne * (habitat == "unspecific"), random = list(~ 1 | taxon, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = forAIC_end)
summary(model_end_Ne_habitatunspecific)#Ne:habitat == "unspecific"TRUE    0.0000  0.0000  1.0725  0.2835  -0.0000  0.0001 

model_end_Ne_rarity <- rma.mv(y1, v1, mods = ~ Ne * rarity, random = list(~ 1 | taxon, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = forAIC_end)
summary(model_end_Ne_rarity)#QE(df = 15) = 275.5273, p-val < .0001; QM(df = 9) = 7.4992, p-val = 0.5853; Ne:rarityNLU    0.0000  0.0000   1.0297  0.3032  -0.0000   0.0001    ;Ne:rarityNSS   -0.0042  0.0019  -2.1666  0.0303  -0.0079  -0.0004  * ;  Ne:rarityNSU   -0.0015  0.0024  -0.6154  0.5383  -0.0061   0.0032 
model_end_Ne_rarityNSS <- rma.mv(y1, v1, mods = ~ Ne * (rarity == "NSS"), random = list(~ 1 | taxon, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = forAIC_end)
summary(model_end_Ne_rarityNSS)#Ne:rarity == "NSS"TRUE   -0.0038  0.0021  -1.8470  0.0648  -0.0078  0.0002  .
model_end_Ne_rarityNSU <- rma.mv(y1, v1, mods = ~ Ne * (rarity == "NSU"), random = list(~ 1 | taxon, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = forAIC_end)
summary(model_end_Ne_rarityNSU)#Ne:rarity == "NSU"TRUE   -0.0014  0.0027  -0.5235  0.6006  -0.0068  0.0039
model_end_Ne_rarityNLS <- rma.mv(y1, v1, mods = ~ Ne * (rarity == "NLS"), random = list(~ 1 | taxon, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = forAIC_end)
summary(model_end_Ne_rarityNLS)#Ne:rarity == "NLS"TRUE   -0.0000  0.0000  -1.0667  0.2861  -0.0001  0.0000 
model_end_Ne_rarityNLU <- rma.mv(y1, v1, mods = ~ Ne * (rarity == "NLU"), random = list(~ 1 | taxon, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = forAIC_end)
summary(model_end_Ne_rarityNLU)#Ne:rarity == "NLU"TRUE    0.0000  0.0000  1.0166  0.3093  -0.0000  0.0001
model_end_Ne_rarityWLS <- rma.mv(y1, v1, mods = ~ Ne * (rarity == "WLS"), random = list(~ 1 | taxon, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = forAIC_end)
summary(model_end_Ne_rarityWLS)#NO INTERACTION
model_end_Ne_rarityWSU <- rma.mv(y1, v1, mods = ~ Ne * (rarity == "WSU"), random = list(~ 1 | taxon, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = forAIC_end)
summary(model_end_Ne_rarityWSU)#NO INTERACTION
model_end_Ne_rarityWSS <- rma.mv(y1, v1, mods = ~ Ne * (rarity == "WSS"), random = list(~ 1 | taxon, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = forAIC_end)
summary(model_end_Ne_rarityWSS)#NO INTERACTION

##The interaction of different variables with each other in invasive plants

#Classification variables

# List all variables to be analyzed for interaction
vars_inv <- c("life_form", "mat_sys", "rep_sys", "pollination", "propagule_dis", "propagule")

# Create an empty list to hold the model results
models_inv_class_inter <- list()

# Create an empty list to hold the frequency table of interaction items
tables_inv <- list()

# Use nested loops to iterate over all combinations of variables
for (i in 1:(length(vars_inv))) {
  for (j in 1:length(vars_inv)) {
    # Skip the same variable
    if (i == j) next
    # Create interactive items
    interaction_var_inv <- interaction(forAIC_inv[[vars_inv[i]]], forAIC_inv[[vars_inv[j]]])
    # Adds the interaction item to the data box
    interaction_name_inv <- paste(sort(c(vars_inv[i], vars_inv[j])), collapse="_")
    forAIC_inv[interaction_name_inv] <- interaction_var_inv
    # Saves a frequency table of interaction items
    tables_inv[[interaction_name_inv]] <- table(interaction_var_inv)
    # Try to run the model and catch possible errors
    tryCatch({
      model_inv <- rma.mv(y1, v1, mods = as.formula(paste("~", interaction_name_inv)), random = list(~ 1 | taxon, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = forAIC_inv)
      # Save the model results to the list
      models_inv_class_inter[[interaction_name_inv]] <- model_inv
    }, error = function(e) {
      message(paste("Failed to fit model for", interaction_name_inv, ":"))
      message(e)
    })
  }
}

# Iterate over all the elements in the models list
for (model_name_inv in names(models_inv_class_inter)) {
  # print model name
  print(model_name_inv)
  # Get a summary of the model results and print it
  print(summary(models_inv_class_inter[[model_name_inv]]))
}

# Iterate over all the elements in the tables list
for (table_name_inv in names(tables_inv)) {
  # print table name
  print(table_name_inv)
  # Print a frequency table of interaction items
  print(tables_inv[[table_name_inv]])
}

##Continuous variable

forAIC_inv$invasion_time<-as.numeric(forAIC_inv$invasion_time)
model_inv_Nm_invasion_time <- rma.mv(y1, v1, mods = ~ Nm * invasion_time, random = list(~ 1 | taxon, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = forAIC_inv)
summary(model_inv_Nm_invasion_time)#Nm:invasion_time   -0.0007  0.0003  -2.3304  0.0198  -0.0013  -0.0001    * 
model_inv_Na_invasion_time <- rma.mv(y1, v1, mods = ~ Na * invasion_time, random = list(~ 1 | taxon, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = forAIC_inv)
summary(model_inv_Na_invasion_time)#Na:invasion_time    0.0000  0.0000   1.2070  0.2274  -0.0000  0.0000
model_inv_FIS_invasion_time <- rma.mv(y1, v1, mods = ~ FIS * invasion_time, random = list(~ 1 | taxon, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = forAIC_inv)
summary(model_inv_FIS_invasion_time)#FIS:invasion_time    0.0012  0.0045   0.2604  0.7946  -0.0076  0.0099
model_inv_Fst_invasion_time <- rma.mv(y1, v1, mods = ~ Fst * invasion_time, random = list(~ 1 | taxon, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = forAIC_inv)
summary(model_inv_Fst_invasion_time)#Fst:invasion_time    0.0067  0.0048   1.3768  0.1686  -0.0028   0.0162

model_inv_Na_FIS <- rma.mv(y1, v1, mods = ~ Na * FIS, random = list(~ 1 | taxon, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = forAIC_inv)
summary(model_inv_Na_FIS)#NO

model_inv_Na_Nm <- rma.mv(y1, v1, mods = ~ Na * Nm, random = list(~ 1 | taxon, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = forAIC_inv)
summary(model_inv_Na_Nm)#Na:Nm     -0.0001  0.0001  -0.7456  0.4559  -0.0002  0.0001 

model_inv_Na_Fst <- rma.mv(y1, v1, mods = ~ Na * Fst, random = list(~ 1 | taxon, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = forAIC_inv)
summary(model_inv_Na_Fst)#Na:Fst     0.0017  0.0025   0.6558  0.5119  -0.0033  0.0066

model_inv_Nm_Fst <- rma.mv(y1, v1, mods = ~ Fst * Nm, random = list(~ 1 | taxon, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = forAIC_inv)
summary(model_inv_Nm_Fst)#Fst:Nm    -0.3181  0.9074  -0.3506  0.7259  -2.0967  1.4604

model_inv_Nm_FIS <- rma.mv(y1, v1, mods = ~ Nm * FIS, random = list(~ 1 | taxon, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = forAIC_inv)
summary(model_inv_Nm_FIS)#Nm:FIS     0.0920  0.0811   1.1341  0.2567  -0.0670  0.2509

model_inv_Fst_FIS <- rma.mv(y1, v1, mods = ~ Fst * FIS, random = list(~ 1 | taxon, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = forAIC_inv)
summary(model_inv_Fst_FIS)#Fst:FIS   -1.5672  0.4897  -3.2001  0.0014  -2.5271  -0.6074  **

#Continuous * Classification variable
#Nm
model_inv_Nm_life_form <- rma.mv(y1, v1, mods = ~ Nm * life_form, random = list(~ 1 | taxon, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = forAIC_inv)
summary(model_inv_Nm_life_form)#QE(df = 143) = 3820.4328, p-val < .0001; QM(df = 5) = 45.5500, p-val < .0001 ***; Nm:life_formshortlived    0.2074  0.0455   4.5595  <.0001   0.1182   0.2965  *** ;Nm:life_formwoody        -0.0210  0.0413  -0.5089  0.6108  -0.1019   0.0599
model_inv_Nm_life_formshortlived <- rma.mv(y1, v1, mods = ~ Nm * (life_form == "shortlived"), random = list(~ 1 | taxon, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = forAIC_inv)
summary(model_inv_Nm_life_formshortlived)#Nm:life_form == "shortlived"TRUE    0.2122  0.0443   4.7903  <.0001   0.1254   0.2990  ***  
model_inv_Nm_life_formlonglived <- rma.mv(y1, v1, mods = ~ Nm * (life_form == "longlived"), random = list(~ 1 | taxon, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = forAIC_inv)
summary(model_inv_Nm_life_formlonglived)#Nm:life_form == "longlived"TRUE   -0.0750  0.0337  -2.2261  0.0260  -0.1411  -0.0090    *
model_inv_Nm_life_formwoody <- rma.mv(y1, v1, mods = ~ Nm * (life_form == "woody"), random = list(~ 1 | taxon, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = forAIC_inv)
summary(model_inv_Nm_life_formwoody)#Nm:life_form == "woody"TRUE   -0.0615  0.0408  -1.5079  0.1316  -0.1414   0.0184

model_inv_Nm_mat_sys <- rma.mv(y1, v1, mods = ~ Nm * mat_sys, random = list(~ 1 | taxon, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = forAIC_inv)
summary(model_inv_Nm_mat_sys)#QE(df = 127) = 3799.4880, p-val < .0001; QM(df = 5) = 25.0993, p-val = 0.0001***; Nm:mat_sysmixing        -0.1586  0.1039  -1.5266  0.1269  -0.3622   0.0450      ;Nm:mat_sysoutcrossing   -0.0993  0.0948  -1.0466  0.2953  -0.2851   0.0866
model_inv_Nm_mat_sysoutcrossing <- rma.mv(y1, v1, mods = ~ Nm * (mat_sys == "outcrossing"), random = list(~ 1 | taxon, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = forAIC_inv)
summary(model_inv_Nm_mat_sysoutcrossing)#Nm:mat_sys == "outcrossing"TRUE    0.0168  0.0460   0.3662  0.7142  -0.0733   0.1070
model_inv_Nm_mat_sysmixing <- rma.mv(y1, v1, mods = ~ Nm * (mat_sys == "mixing"), random = list(~ 1 | taxon, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = forAIC_inv)
summary(model_inv_Nm_mat_sysmixing)#Nm:mat_sys == "mixing"TRUE   -0.0660  0.0516  -1.2790  0.2009  -0.1672   0.0352
model_inv_Nm_mat_sysselfing <- rma.mv(y1, v1, mods = ~ Nm * (mat_sys == "inbreeding"), random = list(~ 1 | taxon, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = forAIC_inv)
summary(model_inv_Nm_mat_sysselfing)#Nm:mat_sys == "inbreeding"TRUE    0.1090  0.0944   1.1536  0.2487  -0.0762   0.2941

model_inv_Nm_rep_sys <- rma.mv(y1, v1, mods = ~ Nm * rep_sys, random = list(~ 1 | taxon, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = forAIC_inv)
summary(model_inv_Nm_rep_sys)#QE(df = 131) = 4527.0842, p-val < .0001; QM(df = 5) = 21.5989, p-val = 0.0006***; Nm:rep_sysfacultative    0.0099  0.6360   0.0156  0.9876  -1.2367  1.2565    ;Nm:rep_syssexual         0.0447  0.6353   0.0703  0.9440  -1.2006  1.2899
model_inv_Nm_rep_sysclonal <- rma.mv(y1, v1, mods = ~ Nm * (rep_sys == "clonal"), random = list(~ 1 | taxon, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = forAIC_inv)
summary(model_inv_Nm_rep_sysclonal)#Nm:rep_sys == "clonal"TRUE   -0.0415  0.6310  -0.0658  0.9476  -1.2782   1.1953
model_inv_Nm_rep_sysfacultative <- rma.mv(y1, v1, mods = ~ Nm * (rep_sys == "facultative"), random = list(~ 1 | taxon, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = forAIC_inv)
summary(model_inv_Nm_rep_sysfacultative)#Nm:rep_sys == "facultative"TRUE   -0.0353  0.0339  -1.0401  0.2983  -0.1017   0.0312 
model_inv_Nm_rep_syssexual <- rma.mv(y1, v1, mods = ~ Nm * (rep_sys == "sexual"), random = list(~ 1 | taxon, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = forAIC_inv)
summary(model_inv_Nm_rep_syssexual)#Nm:rep_sys == "sexual"TRUE    0.0344  0.0339   1.0148  0.3102  -0.0321   0.1009

model_inv_Nm_pollination <- rma.mv(y1, v1, mods = ~ Nm * pollination, random = list(~ 1 | taxon, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = forAIC_inv)
summary(model_inv_Nm_pollination)#QE(df = 119) = 3810.7524, p-val < .0001; QM(df = 3) = 42.6046, p-val < .0001 ***; Nm:pollinationshort   -0.2069  0.0456  -4.5356  <.0001  -0.2963  -0.1175  ***
model_inv_Nm_pollinationshort <- rma.mv(y1, v1, mods = ~ Nm * (pollination == "short"), random = list(~ 1 | taxon, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = forAIC_inv)
summary(model_inv_Nm_pollinationshort)#Nm:pollination == "short"TRUE   -0.2069  0.0456  -4.5356  <.0001  -0.2963  -0.1175  ***
model_inv_Nm_pollinationlong <- rma.mv(y1, v1, mods = ~ Nm * (pollination == "long"), random = list(~ 1 | taxon, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = forAIC_inv)
summary(model_inv_Nm_pollinationlong)#Nm:pollination == "long"TRUE    0.2069  0.0456   4.5356  <.0001   0.1175   0.2963  ***

model_inv_Nm_propagule_dis <- rma.mv(y1, v1, mods = ~ Nm * propagule_dis, random = list(~ 1 | taxon, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = forAIC_inv)
summary(model_inv_Nm_propagule_dis)#QE(df = 126) = 4408.4850, p-val < .0001; QM(df = 3) = 21.9929, p-val < .0001***; Nm:propagule_dissho_dis   -0.0740  0.0578  -1.2818  0.1999  -0.1872   0.0392
model_inv_Nm_propagule_dislon_dis <- rma.mv(y1, v1, mods = ~ Nm * (propagule_dis == "lon_dis"), random = list(~ 1 | taxon, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = forAIC_inv)
summary(model_inv_Nm_propagule_dislon_dis)#Nm:propagule_dis == "lon_dis"TRUE    0.0740  0.0578   1.2818  0.1999  -0.0392  0.1872
model_inv_Nm_propagule_dissho_dis <- rma.mv(y1, v1, mods = ~ Nm * (propagule_dis == "sho_dis"), random = list(~ 1 | taxon, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = forAIC_inv)
summary(model_inv_Nm_propagule_dissho_dis)#Nm:propagule_dis == "sho_dis"TRUE   -0.0740  0.0578  -1.2818  0.1999  -0.1872   0.0392 

model_inv_Nm_propagule <- rma.mv(y1, v1, mods = ~ Nm * propagule, random = list(~ 1 | taxon, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = forAIC_inv)
summary(model_inv_Nm_propagule)#QE(df = 133) = 4558.0873, p-val < .0001; QM(df = 5) = 22.4933, p-val = 0.0004 ***; Nm:propagulerhizome   -1.1952  1.5134  -0.7897  0.4297  -4.1615   1.7710     ; Nm:propaguleseed       0.0347  0.0338   1.0266  0.3046  -0.0315   0.1009
model_inv_Nm_propagulerhizome <- rma.mv(y1, v1, mods = ~ Nm * (propagule == "rhizome"), random = list(~ 1 | taxon, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = forAIC_inv)
summary(model_inv_Nm_propagulerhizome)#Nm:propagule == "rhizome"TRUE   -1.2179  1.5037  -0.8099  0.4180  -4.1651   1.7293 
model_inv_Nm_propagulemultiple <- rma.mv(y1, v1, mods = ~ Nm * (propagule == "multiple"), random = list(~ 1 | taxon, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = forAIC_inv)
summary(model_inv_Nm_propagulemultiple)#Nm:propagule == "multiple"TRUE   -0.0345  0.0338  -1.0224  0.3066  -0.1007   0.0317 
model_inv_Nm_propaguleseed <- rma.mv(y1, v1, mods = ~ Nm * (propagule == "seed"), random = list(~ 1 | taxon, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = forAIC_inv)
summary(model_inv_Nm_propaguleseed)#Nm:propagule == "seed"TRUE    0.0352  0.0338   1.0419  0.2975  -0.0310   0.1015

#FIS
model_inv_FIS_life_form <- rma.mv(y1, v1, mods = ~ FIS * life_form, random = list(~ 1 | taxon, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = forAIC_inv)
summary(model_inv_FIS_life_form)#QE(df = 119) = 2467.0006, p-val < .0001; QM(df = 5) = 45.6709, p-val < .0001 *** 
model_inv_FIS_life_formshortlived <- rma.mv(y1, v1, mods = ~ FIS * (life_form == "shortlived"), random = list(~ 1 | taxon, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = forAIC_inv)
summary(model_inv_FIS_life_formshortlived)#FIS:life_form == "shortlived"TRUE    0.3420  0.2364   1.4466  0.1480  -0.1214  0.8054
model_inv_FIS_life_formlonglived <- rma.mv(y1, v1, mods = ~ FIS * (life_form == "longlived"), random = list(~ 1 | taxon, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = forAIC_inv)
summary(model_inv_FIS_life_formlonglived)#FIS:life_form == "longlived"TRUE   -0.2295  0.2428  -0.9454  0.3444  -0.7054  0.2463 
model_inv_FIS_life_formwoody <- rma.mv(y1, v1, mods = ~ FIS * (life_form == "woody"), random = list(~ 1 | taxon, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = forAIC_inv)
summary(model_inv_FIS_life_formwoody)#FIS:life_form == "woody"TRUE   -1.2978  0.7561  -1.7163  0.0861  -2.7797  0.1842    .

model_inv_FIS_mat_sys <- rma.mv(y1, v1, mods = ~ FIS * mat_sys, random = list(~ 1 | taxon, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = forAIC_inv)
summary(model_inv_FIS_mat_sys)#QE(df = 5) = 12.1227, p-val = 0.0331; QM(df = 4) = 71.5172, p-val < .0001 ***; FIS:mat_sysmixing    -1.4602  0.6617  -2.2069  0.0273  -2.7571  -0.1634    *
model_inv_FIS_mat_sysoutcrossing <- rma.mv(y1, v1, mods = ~ FIS * (mat_sys == "outcrossing"), random = list(~ 1 | taxon, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = forAIC_inv)
summary(model_inv_FIS_mat_sysoutcrossing)#Optimizer (nlminb) did not achieve convergence (convergence = 1).
model_inv_FIS_mat_sysinbreeding <- rma.mv(y1, v1, mods = ~ FIS * (mat_sys == "inbreeding"), random = list(~ 1 | taxon, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = forAIC_inv)
summary(model_inv_FIS_mat_sysinbreeding)#FIS:mat_sys == "inbreeding"TRUE   -1.0755  0.6052  -1.7770  0.0756  -2.2618  0.1107    .
model_inv_FIS_mat_sysmixing <- rma.mv(y1, v1, mods = ~ FIS * (mat_sys == "mixing"), random = list(~ 1 | taxon, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = forAIC_inv)
summary(model_inv_FIS_mat_sysmixing)#Optimizer (nlminb) did not achieve convergence (convergence = 1).

model_inv_FIS_rep_sys <- rma.mv(y1, v1, mods = ~ FIS * rep_sys, random = list(~ 1 | taxon, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = forAIC_inv)
summary(model_inv_FIS_rep_sys)#QE(df = 112) = 1291.9286, p-val < .0001; QM(df = 4) = 48.3321, p-val < .0001 ***
model_inv_FIS_rep_sysclonal <- rma.mv(y1, v1, mods = ~ FIS * (rep_sys == "clonal"), random = list(~ 1 | taxon, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = forAIC_inv)
summary(model_inv_FIS_rep_sysclonal)#NO INTERACTION
model_inv_FIS_rep_sysfacultative <- rma.mv(y1, v1, mods = ~ FIS * (rep_sys == "facultative"), random = list(~ 1 | taxon, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = forAIC_inv)
summary(model_inv_FIS_rep_sysfacultative)#FIS:rep_sys == "facultative"TRUE   -0.6515  0.2861  -2.2773  0.0228  -1.2123  -0.0908    *
model_inv_FIS_rep_syssexual <- rma.mv(y1, v1, mods = ~ FIS * (rep_sys == "sexual"), random = list(~ 1 | taxon, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = forAIC_inv)
summary(model_inv_FIS_rep_syssexual)#FIS:rep_sys == "sexual"TRUE    0.6895  0.2830   2.4367  0.0148   0.1349  1.2441  *

model_inv_FIS_pollination <- rma.mv(y1, v1, mods = ~ FIS * pollination, random = list(~ 1 | taxon, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = forAIC_inv)
summary(model_inv_FIS_pollination)#QE(df = 109) = 2035.9197, p-val < .0001; QM(df = 3) = 53.5963, p-val < .0001***
model_inv_FIS_pollinationshort <- rma.mv(y1, v1, mods = ~ FIS * (pollination == "short"), random = list(~ 1 | taxon, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = forAIC_inv)
summary(model_inv_FIS_pollinationshort)#FIS:pollination == "short"TRUE    0.7195  0.2219   3.2430  0.0012   0.2847  1.1544  **
model_inv_FIS_pollinationlong <- rma.mv(y1, v1, mods = ~ FIS * (pollination == "long"), random = list(~ 1 | taxon, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = forAIC_inv)
summary(model_inv_FIS_pollinationlong)#FIS:pollination == "long"TRUE   -0.7195  0.2219  -3.2430  0.0012  -1.1544  -0.2847   **

model_inv_FIS_propagule_dis <- rma.mv(y1, v1, mods = ~ FIS * propagule_dis, random = list(~ 1 | taxon, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = forAIC_inv)
summary(model_inv_FIS_propagule_dis)#Optimizer (nlminb) did not achieve convergence (convergence = 1).

model_inv_FIS_propagule <- rma.mv(y1, v1, mods = ~ FIS * propagule, random = list(~ 1 | taxon, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = forAIC_inv)
summary(model_inv_FIS_propagule)#QE(df = 113) = 1322.2948, p-val < .0001; QM(df = 4) = 47.6363, p-val < .0001***
model_inv_FIS_propagulerhizome <- rma.mv(y1, v1, mods = ~ FIS * (propagule == "rhizome"), random = list(~ 1 | taxon, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = forAIC_inv)
summary(model_inv_FIS_propagulerhizome)#NO INTERACTION
model_inv_FIS_propagulemultiple <- rma.mv(y1, v1, mods = ~ FIS * (propagule == "multiple"), random = list(~ 1 | taxon, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = forAIC_inv)
summary(model_inv_FIS_propagulemultiple)#FIS:propagule == "multiple"TRUE   -0.6399  0.2874  -2.2262  0.0260  -1.2032  -0.0765    *
model_inv_FIS_propaguleseed <- rma.mv(y1, v1, mods = ~ FIS * (propagule == "seed"), random = list(~ 1 | taxon, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = forAIC_inv)
summary(model_inv_FIS_propaguleseed)#FIS:propagule == "seed"TRUE    0.6773  0.2845   2.3809  0.0173   0.1197  1.2348  *

#invasion_time
model_inv_invasion_time_life_form <- rma.mv(y1, v1, mods = ~ invasion_time * life_form, random = list(~ 1 | taxon, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = forAIC_inv)
summary(model_inv_invasion_time_life_form)#QE(df = 409) = 13452.0880, p-val < .0001; QM(df = 5) = 83.8718, p-val < .0001***
model_inv_invasion_time_life_formshortlived <- rma.mv(y1, v1, mods = ~ invasion_time * (life_form == "shortlived"), random = list(~ 1 | taxon, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = forAIC_inv)
summary(model_inv_invasion_time_life_formshortlived)#invasion_time:life_form == "shortlived"TRUE   -0.0049  0.0008  -6.2622  <.0001  -0.0064  -0.0034  ***
model_inv_invasion_time_life_formlonglived <- rma.mv(y1, v1, mods = ~ invasion_time * (life_form == "longlived"), random = list(~ 1 | taxon, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = forAIC_inv)
summary(model_inv_invasion_time_life_formlonglived)#invasion_time:life_form == "longlived"TRUE    0.0051  0.0008   6.5819  <.0001   0.0036 0.0066  ***
model_inv_invasion_time_life_formwoody <- rma.mv(y1, v1, mods = ~ invasion_time * (life_form == "woody"), random = list(~ 1 | taxon, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = forAIC_inv)
summary(model_inv_invasion_time_life_formwoody)#invasion_time:life_form == "woody"TRUE   -0.0103  0.0044  -2.3425  0.0192  -0.0188  -0.0017 *

model_inv_invasion_time_mat_sys <- rma.mv(y1, v1, mods = ~ invasion_time * mat_sys, random = list(~ 1 | taxon, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = forAIC_inv)
summary(model_inv_invasion_time_mat_sys)#QE(df = 364) = 12781.0159, p-val < .0001; QM(df = 5) = 334.6853, p-val < .0001***
model_inv_invasion_time_mat_sysoutcrossing <- rma.mv(y1, v1, mods = ~ invasion_time * (mat_sys == "outcrossing"), random = list(~ 1 | taxon, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = forAIC_inv)
summary(model_inv_invasion_time_mat_sysoutcrossing)#invasion_time:mat_sys == "outcrossing"TRUE    0.0216  0.0014   14.8891  <.0001   0.0187 0.0244  ***
model_inv_invasion_time_mat_sysmixing <- rma.mv(y1, v1, mods = ~ invasion_time * (mat_sys == "mixing"), random = list(~ 1 | taxon, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = forAIC_inv)
summary(model_inv_invasion_time_mat_sysmixing)#invasion_time:mat_sys == "mixing"TRUE    0.0079  0.0035   2.2514  0.0244   0.0010   0.0147 *
model_inv_invasion_time_mat_sysinbreeding <- rma.mv(y1, v1, mods = ~ invasion_time * (mat_sys == "inbreeding"), random = list(~ 1 | taxon, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = forAIC_inv)
summary(model_inv_invasion_time_mat_sysinbreeding)#invasion_time:mat_sys == "inbreeding"TRUE   -0.0265  0.0016  -16.9999  <.0001  -0.0295 -0.0234  ***

model_inv_invasion_time_rep_sys <- rma.mv(y1, v1, mods = ~ invasion_time * rep_sys, random = list(~ 1 | taxon, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = forAIC_inv)
summary(model_inv_invasion_time_rep_sys)#QE(df = 364) = 13152.3388, p-val < .0001; QM(df = 5) = 62.1140, p-val < .0001***
model_inv_invasion_time_rep_sysclonal <- rma.mv(y1, v1, mods = ~ invasion_time * (rep_sys == "clonal"), random = list(~ 1 | taxon, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = forAIC_inv)
summary(model_inv_invasion_time_rep_sysclonal)#invasion_time:rep_sys == "clonal"TRUE    0.0051  0.0082   0.6266  0.5309  -0.0109   0.0211
model_inv_invasion_time_rep_sysfacultative <- rma.mv(y1, v1, mods = ~ invasion_time * (rep_sys == "facultative"), random = list(~ 1 | taxon, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = forAIC_inv)
summary(model_inv_invasion_time_rep_sysfacultative)#invasion_time:rep_sys == "facultative"TRUE    0.0033  0.0007   4.4804  <.0001   0.0019  0.0048  ***
model_inv_invasion_time_rep_syssexual <- rma.mv(y1, v1, mods = ~ invasion_time * (rep_sys == "sexual"), random = list(~ 1 | taxon, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = forAIC_inv)
summary(model_inv_invasion_time_rep_syssexual)#invasion_time:rep_sys == "sexual"TRUE   -0.0035  0.0007  -4.6841  <.0001  -0.0050  -0.0020 ***

model_inv_invasion_time_pollination <- rma.mv(y1, v1, mods = ~ invasion_time * pollination, random = list(~ 1 | taxon, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = forAIC_inv)
summary(model_inv_invasion_time_pollination)#QE(df = 344) = 14571.1301, p-val < .0001; QM(df = 3) = 52.5474, p-val < .0001***
model_inv_invasion_time_pollinationshort <- rma.mv(y1, v1, mods = ~ invasion_time * (pollination == "short"), random = list(~ 1 | taxon, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = forAIC_inv)
summary(model_inv_invasion_time_pollinationshort)#invasion_time:pollination == "short"TRUE   -0.0034  0.0008  -4.2888  <.0001  -0.0049  -0.0018  ***
model_inv_invasion_time_pollinationlong <- rma.mv(y1, v1, mods = ~ invasion_time * (pollination == "long"), random = list(~ 1 | taxon, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = forAIC_inv)
summary(model_inv_invasion_time_pollinationlong)#invasion_time:pollination == "long"TRUE    0.0034  0.0008   4.2888  <.0001   0.0018 0.0049  ***

model_inv_invasion_time_propagule_dis <- rma.mv(y1, v1, mods = ~ invasion_time * propagule_dis, random = list(~ 1 | taxon, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = forAIC_inv)
summary(model_inv_invasion_time_propagule_dis)#QE(df = 388) = 14243.3530, p-val < .0001; QM(df = 3) = 19.1194, p-val = 0.0003***
model_inv_invasion_time_propagule_dislon_dis <- rma.mv(y1, v1, mods = ~ invasion_time * (propagule_dis == "lon_dis"), random = list(~ 1 | taxon, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = forAIC_inv)
summary(model_inv_invasion_time_propagule_dislon_dis)#invasion_time:propagule_dis == "lon_dis"TRUE    0.0021  0.0128   0.1606  0.8724  -0.0231  0.0272
model_inv_invasion_time_propagule_dissho_dis <- rma.mv(y1, v1, mods = ~ invasion_time * (propagule_dis == "sho_dis"), random = list(~ 1 | taxon, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = forAIC_inv)
summary(model_inv_invasion_time_propagule_dissho_dis)#invasion_time:propagule_dis == "sho_dis"TRUE   -0.0021  0.0128  -0.1606  0.8724  -0.0272   0.0231

model_inv_invasion_time_propagule <- rma.mv(y1, v1, mods = ~ invasion_time * propagule, random = list(~ 1 | taxon, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = forAIC_inv)
summary(model_inv_invasion_time_propagule)#QE(df = 404) = 13284.3842, p-val < .0001; QM(df = 5) = 61.0467, p-val < .0001***
model_inv_invasion_time_propagulerhizome <- rma.mv(y1, v1, mods = ~ invasion_time * (propagule == "rhizome"), random = list(~ 1 | taxon, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = forAIC_inv)
summary(model_inv_invasion_time_propagulerhizome)#invasion_time:propagule == "rhizome"TRUE    0.0043  0.0071   0.6068  0.5440  -0.0097 0.0183
model_inv_invasion_time_propagulemultiple <- rma.mv(y1, v1, mods = ~ invasion_time * (propagule == "multiple"), random = list(~ 1 | taxon, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = forAIC_inv)
summary(model_inv_invasion_time_propagulemultiple)#invasion_time:propagule == "multiple"TRUE    0.0034  0.0007   4.5626  <.0001   0.0019  0.0048  ***     
model_inv_invasion_time_propaguleseed <- rma.mv(y1, v1, mods = ~ invasion_time * (propagule == "seed"), random = list(~ 1 | taxon, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = forAIC_inv)
summary(model_inv_invasion_time_propaguleseed)#invasion_time:propagule == "seed"TRUE   -0.0035  0.0007  -4.6503  <.0001  -0.0049  -0.0020 ***

##Separate influence of species status
model_all_pro_stu <- rma.mv(y1, v1, mods = ~ pro_stu, random = list(~ 1 | taxon, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = forAIC_all)
summary(model_all_pro_stu)#QE(df = 1634) = 51562.2496, p-val < .0001; QM(df = 1) = 22.2237, p-val < .0001***
model_all_pro_stu_end <- rma.mv(y1, v1, subset =  (pro_stu == "end"), random = list(~ 1 | taxon, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = forAIC_all)
summary(model_all_pro_stu_end)#-0.4350  0.2265  -1.9205  0.0548  -0.8789  0.0089  .
model_all_pro_stu_inv <- rma.mv(y1, v1, subset =  (pro_stu == "inv"), random = list(~ 1 | taxon, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = forAIC_all)
summary(model_all_pro_stu_inv)#-0.8087  0.3727  -2.1700  0.0300  -1.5391  -0.0783  * 