##Preparation

#Load the required R packages
library(metafor)#install.packages("metafor")
#MuMIn <- "https://cran.r-project.org/src/contrib/Archive/MuMIn/MuMIn_1.43.17.tar.gz"
#install.packages(MuMIn, repos=NULL, type="source")
library(MuMIn)
library(readxl)

#Read data
forAIC_end <- read_excel("your_path/Appendix_S4.xlsx", sheet = 1)
forAIC_inv <- read_excel("your_path/Appendix_S5.xlsx", sheet = 1)

##MuMIn package was used to calculate the AIC value of meta-analysis for model selection
eval(metafor:::.MuMIn) #!!!

#Endangered plants
forAIC_end$pri_num<-as.numeric(forAIC_end$pri_num)
forAIC_end$Na<-as.numeric(forAIC_end$Na)
forAIC_end$Nm<-as.numeric(forAIC_end$Nm)
forAIC_end$Fst<-as.numeric(forAIC_end$Fst)
forAIC_end$FIS<-as.numeric(forAIC_end$FIS)
forAIC_end$DNA_sou<-as.factor(forAIC_end$DNA_sou)
forAIC_end$sam_sou<-as.factor(forAIC_end$sam_sou)
forAIC_end$taxon_exp<-as.factor(forAIC_end$taxon_exp)
forAIC_end$taxon_ctrl<-as.factor(forAIC_end$taxon_ctrl)
forAIC_end$gene_meth<-as.factor(forAIC_end$gene_meth)
forAIC_end[forAIC_end == "none"] <- NA

full_end <- rma.mv(yi, vi, mods = ~ rep_sys+mat_sys+pollination+propagule_dis+life_form+distribution, random = list(~ 1 | taxon_exp, ~ 1 | taxon_ctrl, ~ 1 | gene_meth, ~ 1 | DNA_sou), data=forAIC_end, method="ML")#Build full models
#Processing terminated since k <= 1.

full_end <- rma.mv(yi, vi, mods = ~ Na+Nm+FIS, random = list(~ 1 | taxon_exp, ~ 1 | taxon_ctrl, ~ 1 | gene_meth, ~ 1 | DNA_sou), data=forAIC_end, method="ML")#Build full models
anova(full_end)#Test of Moderators
res_end <- dredge(full_end, trace=2)#Fit the full models, need a long time
summary(model.avg(res_end, revised.var=FALSE))#Multimodel inference
write.csv(res_end,"Appendix_S12_Model_selection_result_of_continuous_factors_for_endangered_plants_in_the_stricter_dataset.csv")
par(mar = c(3,5,6,4))#Set graphic parameters. The "mar" is a numeric vector of the form c(down, left, up, right) that gives the number of margin rows to specify on the four sides of the drawing.
plot(res_end, labAsExpr = TRUE)#Visualize the model selection table
importance(res_end)#the relative importance values for the predictors
subset(res_end, delta < 2, recalc.weights=FALSE)#Check the models with delta AIC less than 2
mod.ave_end <- model.avg(res_end, subset = delta < 2)#report results: conditional average. 'object' consists of only one model so that no average model.

#Invasive plants
forAIC_inv$pri_num<-as.numeric(forAIC_inv$pri_num)
forAIC_inv$Nm<-as.numeric(forAIC_inv$Nm)
forAIC_inv$FIS<-as.numeric(forAIC_inv$FIS)
forAIC_inv$DNA_sou<-as.factor(forAIC_inv$DNA_sou)
forAIC_inv$sam_sou<-as.factor(forAIC_inv$sam_sou)
forAIC_inv$taxon_exp<-as.factor(forAIC_inv$taxon_exp)
forAIC_inv$taxon_ctrl<-as.factor(forAIC_inv$taxon_ctrl)
forAIC_inv$gene_meth<-as.factor(forAIC_inv$gene_meth)
forAIC_inv[forAIC_inv == "none"] <- NA

full_inv <- rma.mv(yi, vi, mods = ~ rep_sys+mat_sys+pollination+propagule_dis+life_form+propagule, random = list(~ 1 | taxon_exp, ~ 1 | taxon_ctrl, ~ 1 | gene_meth, ~ 1 | DNA_sou), data=forAIC_inv, method="ML")#Build full models
anova(full_inv)#Test of Moderators
res_inv <- dredge(full_inv, trace=2)#Fit the full models, need a long time
summary(model.avg(res_inv, revised.var=FALSE))
write.csv(res_inv,"Appendix_S13_Model_selection_result_of_classified_factors_for_invasive_plants_in_the_stricter_dataset.csv")
par(mar = c(3,5,6,4))#Set graphic parameters. The "mar" is a numeric vector of the form c(down, left, up, right) that gives the number of margin rows to specify on the four sides of the drawing.
plot(res_inv, labAsExpr = TRUE)#Visualize the model selection table
importance(res_inv)#the relative importance values for the predictors
subset(res_inv, delta < 2, recalc.weights=FALSE)#Check the models with delta AIC less than 2
mod.ave_inv <- model.avg(res_inv, subset = delta < 2)#report results: conditional average,  'object' consists of only one model


full_inv <- rma.mv(yi, vi, mods = ~ Nm+FIS, random = list(~ 1 | taxon_exp, ~ 1 | taxon_ctrl, ~ 1 | gene_meth, ~ 1 | DNA_sou), data=forAIC_inv, method="ML")
anova(full_inv)#Test of Moderators
res_inv <- dredge(full_inv, trace=2)#Fit the full models, need a long time
summary(model.avg(res_inv, revised.var=FALSE))
write.csv(res_inv,"Appendix_S14_Model_selection_result_of_continuous_factors_for_invasive_plants_in_the_stricter_dataset.csv")
par(mar = c(3,5,6,4))#Set graphic parameters. The "mar" is a numeric vector of the form c(down, left, up, right) that gives the number of margin rows to specify on the four sides of the drawing.
plot(res_inv, labAsExpr = TRUE)#Visualize the model selection table
importance(res_inv)#the relative importance values for the predictors
subset(res_inv, delta < 2, recalc.weights=FALSE)#Check the models with delta AIC less than 2
mod.ave_inv <- model.avg(res_inv, subset = delta < 2)#report results: conditional average,  'object' consists of only one model

##Combine Endangered & Invasive
forAIC_end$pro_stu <- "end"
forAIC_inv$pro_stu <- "inv"
library(dplyr)
forAIC_all <- bind_rows(forAIC_end, forAIC_inv)#Concatenate the two data sets
str(forAIC_all)
forAIC_all$pro_stu<-as.factor(forAIC_all$pro_stu)
full_all <- rma.mv(yi, vi, mods = ~ Na+Nm+FIS+pro_stu+pro_stu*Na+pro_stu*Nm+pro_stu*FIS, random = list(~ 1 | taxon_exp, ~ 1 | taxon_ctrl, ~ 1 | gene_meth, ~ 1 | DNA_sou), data=forAIC_all, method="ML")
anova(full_all)#Test of Moderators
res_all <- dredge(full_all, trace=2)#Fit the full models, need a long time
summary(model.avg(res_all, revised.var=FALSE))
write.csv(res_all,"Appendix_S18_Model_selection_result_of_continuous_factors_for_two_kinds_of_plants_in_the_stricter_dataset.csv")
par(mar = c(3,5,6,4))#Set graphic parameters. The "mar" is a numeric vector of the form c(down, left, up, right) that gives the number of margin rows to specify on the four sides of the drawing.
plot(res_all, labAsExpr = TRUE)#Visualize the model selection table
importance(res_all)#the relative importance values for the predictors
subset(res_all, delta < 2, recalc.weights=FALSE)#Check the models with delta AIC less than 2
mod.ave_all <- model.avg(res_all, subset = delta < 2)#report results: conditional average,'object' consists of only one model

forAIC_all$rep_sys<-as.factor(forAIC_all$rep_sys)
forAIC_all$mat_sys<-as.factor(forAIC_all$mat_sys)
forAIC_all$pollination<-as.factor(forAIC_all$pollination)
forAIC_all$propagule_dis<-as.factor(forAIC_all$propagule_dis)
forAIC_all$life_form<-as.factor(forAIC_all$life_form)
full_all_all <- rma.mv(yi, vi, mods = ~ rep_sys+mat_sys+pollination+propagule_dis+life_form+Nm+FIS+pro_stu+pro_stu*Nm+pro_stu*FIS+pro_stu*rep_sys+pro_stu*mat_sys+pro_stu*pollination+pro_stu*propagule_dis+pro_stu*life_form, random = list(~ 1 | taxon_exp, ~ 1 | taxon_ctrl, ~ 1 | gene_meth, ~ 1 | DNA_sou), data=forAIC_all, method="ML")
anova(full_all_all)#Test of Moderators
res_all_all <- dredge(full_all_all, trace=2)#Fit the full models, need a long time
summary(model.avg(res_all_all, revised.var=FALSE))
write.csv(res_all_all,"Appendix_S19_Model_selection_result_of_all_factors_for_two_kinds_of_plants_in_the_stricter_dataset.csv")
par(mar = c(3,5,6,4))#Set graphic parameters. The "mar" is a numeric vector of the form c(down, left, up, right) that gives the number of margin rows to specify on the four sides of the drawing.
plot(res_all_all, labAsExpr = TRUE)#Visualize the model selection table
importance(res_all_all)#the relative importance values for the predictors
subset(res_all_all, delta < 2, recalc.weights=FALSE)#Check the models with delta AIC less than 2
mod.ave_all <- model.avg(res_all_all, subset = delta < 2)#report results: conditional average,'object' consists of only one model

##The interaction of different variables individually with the state of the population in all plants

#classification variable
forAIC_all$life_form_pro_stu <- interaction(forAIC_all$life_form, forAIC_all$pro_stu)
model_life_form_pro_stu <- rma.mv(yi, vi, mods= ~ life_form_pro_stu, random = list(~ 1 | taxon_exp, ~ 1 | taxon_ctrl, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = forAIC_all)
summary(model_life_form_pro_stu)

forAIC_all$mat_sys_pro_stu <- interaction(forAIC_all$mat_sys, forAIC_all$pro_stu)
model_mat_sys_pro_stu <- rma.mv(yi, vi, mods= ~ mat_sys_pro_stu, random = list(~ 1 | taxon_exp, ~ 1 | taxon_ctrl, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = forAIC_all)
summary(model_mat_sys_pro_stu)

forAIC_all$rep_sys_pro_stu <- interaction(forAIC_all$rep_sys, forAIC_all$pro_stu)
model_rep_sys_pro_stu <- rma.mv(yi, vi, mods= ~ rep_sys_pro_stu, random = list(~ 1 | taxon_exp, ~ 1 | taxon_ctrl, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = forAIC_all)
summary(model_rep_sys_pro_stu)

forAIC_all$pollination_pro_stu <- interaction(forAIC_all$pollination, forAIC_all$pro_stu)
model_pollination_pro_stu <- rma.mv(yi, vi, mods= ~ pollination_pro_stu, random = list(~ 1 | taxon_exp, ~ 1 | taxon_ctrl, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = forAIC_all)
summary(model_pollination_pro_stu)

forAIC_all$propagule_dis_pro_stu <- interaction(forAIC_all$propagule_dis, forAIC_all$pro_stu)
model_propagule_dis_pro_stu <- rma.mv(yi, vi, mods= ~ propagule_dis_pro_stu, random = list(~ 1 | taxon_exp, ~ 1 | taxon_ctrl, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = forAIC_all)
summary(model_propagule_dis_pro_stu)

#continuals variable
forAIC_all$Nm_pro_stu <- forAIC_all$Nm * as.numeric(forAIC_all$pro_stu)
model_Nm_pro_stu <- rma.mv(yi, vi, mods= ~ Nm_pro_stu, random = list(~ 1 | taxon_exp, ~ 1 | taxon_ctrl, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = forAIC_all)
summary(model_Nm_pro_stu)#estimate      se     zval    pval    ci.lb   ci.ub Nm_pro_stu    0.0485  0.0205   2.3608  0.0182   0.0082  0.0887  *
model_Nm_pro_stu2 <- rma.mv(yi, vi, mods= ~ Nm * pro_stu, random = list(~ 1 | taxon_exp, ~ 1 | taxon_ctrl, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = forAIC_all)
summary(model_Nm_pro_stu2)#estimate      se     zval    pval    ci.lb    ci.ub    0.1782  0.0847   2.1034  0.0354   0.0121   0.3442  *
model_Nm_pro_stu3 <- rma.mv(yi, vi, mods = ~ Nm * pro_stuend, random = list(~ 1 | taxon_exp, ~ 1 | taxon_ctrl, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = forAIC_all)
summary(model_Nm_pro_stu3)#estimate      se     zval    pval    ci.lb    ci.ub -0.1782  0.0847  -2.1034  0.0354  -0.3442  -0.0121   *
model_Nm_pro_stu4 <- rma.mv(yi, vi, mods = ~ Nm * pro_stuinv, random = list(~ 1 | taxon_exp, ~ 1 | taxon_ctrl, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = forAIC_all)
summary(model_Nm_pro_stu4)#estimate      se     zval    pval    ci.lb    ci.ub    0.1782  0.0847   2.1034  0.0354   0.0121   0.3442  *

model_FIS_pro_stu_end <- rma.mv(yi, vi, mods = ~ FIS * pro_stuend, random = list(~ 1 | taxon_exp, ~ 1 | taxon_ctrl, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = forAIC_all)
summary(model_FIS_pro_stu_end)#estimate      se     zval    pval    ci.lb    ci.ub    2.4686  0.5653   4.3671  <.0001   1.3607   3.5765  *** 
model_FIS_pro_stu_inv <- rma.mv(yi, vi, mods = ~ FIS * pro_stuinv, random = list(~ 1 | taxon_exp, ~ 1 | taxon_ctrl, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = forAIC_all)
summary(model_FIS_pro_stu_inv)#estimate      se     zval    pval    ci.lb    ci.ub   -2.4686  0.5653  -4.3671  <.0001  -3.5765  -1.3607  *** 

model_Na_pro_stu_end <- rma.mv(yi, vi, mods = ~ Na * pro_stuend, random = list(~ 1 | taxon_exp, ~ 1 | taxon_ctrl, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = forAIC_all)
summary(model_Na_pro_stu_end)#NO INTERACTION
model_Na_pro_stu_inv <- rma.mv(yi, vi, mods = ~ Na * pro_stuinv, random = list(~ 1 | taxon_exp, ~ 1 | taxon_ctrl, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = forAIC_all)
summary(model_Na_pro_stu_inv)#NO INTERACTION

model_Fst_pro_stu_end <- rma.mv(yi, vi, mods = ~ Fst * pro_stuend, random = list(~ 1 | taxon_exp, ~ 1 | taxon_ctrl, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = forAIC_all)
summary(model_Fst_pro_stu_end)#estimate      se     zval    pval    ci.lb    ci.ub 1.2144  0.5924   2.0500  0.0404   0.0533   2.3754    *
model_Fst_pro_stu_inv <- rma.mv(yi, vi, mods = ~ Fst * pro_stuinv, random = list(~ 1 | taxon_exp, ~ 1 | taxon_ctrl, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = forAIC_all)
summary(model_Fst_pro_stu_inv)#estimate      se     zval    pval    ci.lb    ci.ub -1.2144  0.5924  -2.0500  0.0404  -2.3754  -0.0533   *

##The interaction of different variables with each other in endangered plants

#Classification variables

#habitat with others
forAIC_end$habitat_life_form <- interaction(forAIC_end$habitat, forAIC_end$life_form)
table(forAIC_end$habitat_life_form)
model_end_habitat_life_form <- rma.mv(yi, vi, mods= ~ habitat_life_form, random = list(~ 1 | taxon_exp, ~ 1 | taxon_ctrl, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = forAIC_end)
summary(model_end_habitat_life_form)#QE(df = 3) = 44.2609, p-val < .0001; QM(df = 3) = 29.5875, p-val < .0001***

forAIC_end$habitat_mat_sys <- interaction(forAIC_end$habitat, forAIC_end$mat_sys)
table(forAIC_end$habitat_mat_sys)
model_end_habitat_mat_sys <- rma.mv(yi, vi, mods= ~ habitat_mat_sys, random = list(~ 1 | taxon_exp, ~ 1 | taxon_ctrl, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = forAIC_end)
summary(model_end_habitat_mat_sys)#QE(df = 0) = 0.0000, p-val = 1.0000; QM(df = 1) = 27.4420, p-val < .0001 ***

forAIC_end$habitat_rep_sys <- interaction(forAIC_end$habitat, forAIC_end$rep_sys)
table(forAIC_end$habitat_rep_sys)
model_end_habitat_rep_sys <- rma.mv(yi, vi, mods= ~ habitat_rep_sys, random = list(~ 1 | taxon_exp, ~ 1 | taxon_ctrl, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = forAIC_end)
summary(model_end_habitat_rep_sys)#Processing terminated since k <= 1.

forAIC_end$habitat_pollination <- interaction(forAIC_end$habitat, forAIC_end$pollination)
table(forAIC_end$habitat_pollination)
model_end_habitat_pollination <- rma.mv(yi, vi, mods= ~ habitat_pollination, random = list(~ 1 | taxon_exp, ~ 1 | taxon_ctrl, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = forAIC_end)
summary(model_end_habitat_pollination)#QE(df = 3) = 44.2609, p-val < .0001; QM(df = 2) = 29.5639, p-val < .0001 ***

forAIC_end$habitat_propagule_dis <- interaction(forAIC_end$habitat, forAIC_end$propagule_dis)
table(forAIC_end$habitat_propagule_dis)
model_end_habitat_propagule_dis <- rma.mv(yi, vi, mods= ~ habitat_propagule_dis, random = list(~ 1 | taxon_exp, ~ 1 | taxon_ctrl, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = forAIC_end)
summary(model_end_habitat_propagule_dis)#QE(df = 2) = 16.8189, p-val = 0.0002; QM(df = 2) = 15.7431, p-val = 0.0004 ***

forAIC_end$habitat_distribution <- interaction(forAIC_end$habitat, forAIC_end$distribution)
table(forAIC_end$habitat_distribution)
model_end_habitat_distribution <- rma.mv(yi, vi, mods= ~ habitat_distribution, random = list(~ 1 | taxon_exp, ~ 1 | taxon_ctrl, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = forAIC_end)
summary(model_end_habitat_distribution)#QE(df = 4) = 55.7207, p-val < .0001; QM(df = 2) = 14.2966, p-val = 0.0008 ***

#rarity with others
forAIC_end$rarity_life_form <- interaction(forAIC_end$rarity, forAIC_end$life_form)
table(forAIC_end$rarity_life_form)
model_end_rarity_life_form <- rma.mv(yi, vi, mods= ~ rarity_life_form, random = list(~ 1 | taxon_exp, ~ 1 | taxon_ctrl, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = forAIC_end)
summary(model_end_rarity_life_form)#QE(df = 1) = 0.0205, p-val = 0.8862; QM(df = 5) = 360.9849, p-val < .0001 ***

forAIC_end$rarity_mat_sys <- interaction(forAIC_end$rarity, forAIC_end$mat_sys)
table(forAIC_end$rarity_mat_sys)
model_end_rarity_mat_sys <- rma.mv(yi, vi, mods= ~ rarity_mat_sys, random = list(~ 1 | taxon_exp, ~ 1 | taxon_ctrl, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = forAIC_end)
summary(model_end_rarity_mat_sys)#QE(df = 0) = 0.0000, p-val = 1.0000; QM(df = 1) = 27.4420, p-val < .0001 ***

forAIC_end$rarity_rep_sys <- interaction(forAIC_end$rarity, forAIC_end$rep_sys)
table(forAIC_end$rarity_rep_sys)
model_end_rarity_rep_sys <- rma.mv(yi, vi, mods= ~ rarity_rep_sys, random = list(~ 1 | taxon_exp, ~ 1 | taxon_ctrl, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = forAIC_end)
summary(model_end_rarity_rep_sys)#Processing terminated since k <= 1.

forAIC_end$rarity_pollination <- interaction(forAIC_end$rarity, forAIC_end$pollination)
table(forAIC_end$rarity_pollination)
model_end_rarity_pollination <- rma.mv(yi, vi, mods= ~ rarity_pollination, random = list(~ 1 | taxon_exp, ~ 1 | taxon_ctrl, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = forAIC_end)
summary(model_end_rarity_pollination)#QE(df = 1) = 0.0205, p-val = 0.8862; QM(df = 4) = 360.9800, p-val < .0001 ***

forAIC_end$rarity_propagule_dis <- interaction(forAIC_end$rarity, forAIC_end$propagule_dis)
table(forAIC_end$rarity_propagule_dis)
model_end_rarity_propagule_dis <- rma.mv(yi, vi, mods= ~ rarity_propagule_dis, random = list(~ 1 | taxon_exp, ~ 1 | taxon_ctrl, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = forAIC_end)
summary(model_end_rarity_propagule_dis)#QE(df = 1) = 0.0205, p-val = 0.8862; QM(df = 3) = 63.8901, p-val < .0001 ***

forAIC_end$rarity_distribution <- interaction(forAIC_end$rarity, forAIC_end$distribution)
table(forAIC_end$rarity_distribution)
model_end_rarity_distribution <- rma.mv(yi, vi, mods= ~ rarity_distribution, random = list(~ 1 | taxon_exp, ~ 1 | taxon_ctrl, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = forAIC_end)
summary(model_end_rarity_distribution)#QE(df = 3) = 53.3741, p-val < .0001; QM(df = 3) = 27.5500, p-val < .0001 ***

# List all variables to be analyzed for interaction
vars_end <- c("life_form", "mat_sys", "rep_sys", "pollination", "propagule_dis", "distribution")

# Create an empty list to hold the model results
models_end_class_inter <- list()

# Create an empty list to hold the frequency table of interaction items
tables_end <- list()

# Use nested loops to iterate over all combinations of variables
for (i in 1:(length(vars_end))) {
  for (j in 1:length(vars_end)) {
    # Skip the same variable
    if (i == j) next
    # Create interactive items
    interaction_var_end <- interaction(forAIC_end[[vars_end[i]]], forAIC_end[[vars_end[j]]])
    # Adds the interaction item to the data box
    interaction_name_end <- paste(sort(c(vars_end[i], vars_end[j])), collapse="_")
    forAIC_end[interaction_name_end] <- interaction_var_end
    # Saves a frequency table of interaction items
    tables_end[[interaction_name_end]] <- table(interaction_var_end)
    # Try to run the model and catch possible errors
    tryCatch({
      model_end <- rma.mv(yi, vi, mods = as.formula(paste("~", interaction_name_end)), random = list(~ 1 | taxon_exp, ~ 1 | taxon_ctrl, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = forAIC_end)
      # Save the model results to the list
      models_end_class_inter[[interaction_name_end]] <- model_end
    }, error = function(e) {
      message(paste("Failed to fit model for", interaction_name_end, ":"))
      message(e)
    })
  }
}

# Iterate over all the elements in the models list
for (model_name_end in names(models_end_class_inter)) {
  # print model name
  print(model_name_end)
  # Get a summary of the model results and print it
  print(summary(models_end_class_inter[[model_name_end]]))
}

# Iterate over all the elements in the tables list
for (table_name_end in names(tables_end)) {
  # print table name
  print(table_name_end)
  # Print a frequency table of interaction items
  print(tables_end[[table_name_end]])
}

##Continuous variable
model_end_Na_FIS <- rma.mv(yi, vi, mods = ~ Na * FIS, random = list(~ 1 | taxon_exp, ~ 1 | taxon_ctrl, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = forAIC_end)
summary(model_end_Na_FIS)#estimate      se     zval    pval    ci.lb    ci.ub  0.0009  0.0023   0.3812  0.7030  -0.0036   0.0054

model_end_Na_Nm <- rma.mv(yi, vi, mods = ~ Na * Nm, random = list(~ 1 | taxon_exp, ~ 1 | taxon_ctrl, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = forAIC_end)
summary(model_end_Na_Nm)#estimate      se     zval    pval    ci.lb    ci.ub   -0.0016  0.0006  -2.7989  0.0051  -0.0027  -0.0005   **

model_end_Na_Fst <- rma.mv(yi, vi, mods = ~ Na * Fst, random = list(~ 1 | taxon_exp, ~ 1 | taxon_ctrl, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = forAIC_end)
summary(model_end_Na_Fst)#estimate      se     zval    pval    ci.lb    ci.ub      0.0012  0.0005   2.5073  0.0122   0.0003  0.0022  * 

model_end_Nm_FIS <- rma.mv(yi, vi, mods = ~ Nm * FIS, random = list(~ 1 | taxon_exp, ~ 1 | taxon_ctrl, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = forAIC_end)
summary(model_end_Nm_FIS)#Optimizer (nlminb) did not achieve convergence (convergence = 1). 

model_end_Fst_FIS <- rma.mv(yi, vi, mods = ~ Fst * FIS, random = list(~ 1 | taxon_exp, ~ 1 | taxon_ctrl, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = forAIC_end)
summary(model_end_Fst_FIS)#Fst:FIS    6.0408  1.1685   5.1699  <.0001   3.7507   8.3310  ***

#Continuous * Classification variable
#Nm
model_end_Nm_life_form <- rma.mv(yi, vi, mods = ~ Nm * life_form, random = list(~ 1 | taxon_exp, ~ 1 | taxon_ctrl, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = forAIC_end)
summary(model_end_Nm_life_form)#QE(df = 12) = 1086.7650, p-val < .0001; QM(df = 4) = 4.2156, p-val = 0.3776; Nm:life_formwoody     -0.0316  0.1470  -0.2146  0.8301  -0.3197   0.2566
model_end_Nm_life_formshortlived <- rma.mv(yi, vi, mods = ~ Nm * (life_form == "shortlived"), random = list(~ 1 | taxon_exp, ~ 1 | taxon_ctrl, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = forAIC_end)
summary(model_end_Nm_life_formshortlived)#Optimizer (nlminb) did not achieve convergence (convergence = 1).
model_end_Nm_life_formlonglived <- rma.mv(yi, vi, mods = ~ Nm * (life_form == "longlived"), random = list(~ 1 | taxon_exp, ~ 1 | taxon_ctrl, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = forAIC_end)
summary(model_end_Nm_life_formlonglived)#estimate      se     zval    pval    ci.lb   ci.ub 0.0348  0.1455   0.2390  0.8111  -0.2505  0.3200
model_end_Nm_life_formwoody <- rma.mv(yi, vi, mods = ~ Nm * (life_form == "woody"), random = list(~ 1 | taxon_exp, ~ 1 | taxon_ctrl, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = forAIC_end)
summary(model_end_Nm_life_formwoody)#Optimizer (nlminb) did not achieve convergence (convergence = 1).

model_end_Nm_mat_sys <- rma.mv(yi, vi, mods = ~ Nm * mat_sys, random = list(~ 1 | taxon_exp, ~ 1 | taxon_ctrl, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = forAIC_end)
summary(model_end_Nm_mat_sys)#NO INTERACTION
model_end_Nm_mat_sysoutcrossing <- rma.mv(yi, vi, mods = ~ Nm * (mat_sys == "outcrossing"), random = list(~ 1 | taxon_exp, ~ 1 | taxon_ctrl, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = forAIC_end)
summary(model_end_Nm_mat_sysoutcrossing)#NO INTERACTION

model_end_Nm_rep_sys <- rma.mv(yi, vi, mods = ~ Nm * rep_sys, random = list(~ 1 | taxon_exp, ~ 1 | taxon_ctrl, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = forAIC_end)
summary(model_end_Nm_rep_sys)#NO INTERACTION

model_end_Nm_pollination <- rma.mv(yi, vi, mods = ~ Nm * pollination, random = list(~ 1 | taxon_exp, ~ 1 | taxon_ctrl, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = forAIC_end)
summary(model_end_Nm_pollination)#Optimizer (nlminb) did not achieve convergence (convergence = 1).
model_end_Nm_pollinationshort <- rma.mv(yi, vi, mods = ~ Nm * (pollination == "short"), random = list(~ 1 | taxon_exp, ~ 1 | taxon_ctrl, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = forAIC_end)
summary(model_end_Nm_pollinationshort)#Optimizer (nlminb) did not achieve convergence (convergence = 1).
model_end_Nm_pollinationlong <- rma.mv(yi, vi, mods = ~ Nm * (pollination == "long"), random = list(~ 1 | taxon_exp, ~ 1 | taxon_ctrl, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = forAIC_end)
summary(model_end_Nm_pollinationlong)#Nm:pollination == "long"TRUE 0.2009  1.3835   0.1452  0.8846  -2.5108   2.9125

model_end_Nm_propagule_dis <- rma.mv(yi, vi, mods = ~ Nm * propagule_dis, random = list(~ 1 | taxon_exp, ~ 1 | taxon_ctrl, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = forAIC_end)
summary(model_end_Nm_propagule_dis)#QE(df = 1) = 10.4826, p-val = 0.0012; QM(df = 3) = 6.6261, p-val = 0.0848; Nm:propagule_dissho_dis   -0.4369  0.6847  -0.6381  0.5234  -1.7788  0.9050
model_end_Nm_propagule_dislon_dis <- rma.mv(yi, vi, mods = ~ Nm * (propagule_dis == "lon_dis"), random = list(~ 1 | taxon_exp, ~ 1 | taxon_ctrl, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = forAIC_end)
summary(model_end_Nm_propagule_dislon_dis)#Nm:propagule_dis == "lon_dis"TRUE    0.4369  0.6847   0.6381  0.5234  -0.9050   1.7788
model_end_Nm_propagule_dissho_dis <- rma.mv(yi, vi, mods = ~ Nm * (propagule_dis == "sho_dis"), random = list(~ 1 | taxon_exp, ~ 1 | taxon_ctrl, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = forAIC_end)
summary(model_end_Nm_propagule_dissho_dis)#Nm:propagule_dis == "sho_dis"TRUE   -0.4369  0.6847  -0.6381  0.5234  -1.7788  0.9050

model_end_Nm_distribution <- rma.mv(yi, vi, mods = ~ Nm * distribution, random = list(~ 1 | taxon_exp, ~ 1 | taxon_ctrl, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = forAIC_end)
summary(model_end_Nm_distribution)#QE(df = 13) = 116.3668, p-val < .0001; QM(df = 3) = 70.2684, p-val < .0001 ***; Nm:distributionisland endemic    0.9652  0.2334   4.1357  <.0001   0.5078   1.4226  *** 
model_end_Nm_distributionisland_endemic <- rma.mv(yi, vi, mods = ~ Nm * (distribution == "island endemic"), random = list(~ 1 | taxon_exp, ~ 1 | taxon_ctrl, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = forAIC_end)
summary(model_end_Nm_distributionisland_endemic)#Nm:propagule_dis == "lon_dis"TRUE    Nm:distribution == "island endemic"TRUE    0.9652  0.2334   4.1357  <.0001   0.5078 1.4226  ***
model_end_Nm_distributioncontinent_endemic <- rma.mv(yi, vi, mods = ~ Nm * (distribution == "continent  endemic"), random = list(~ 1 | taxon_exp, ~ 1 | taxon_ctrl, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = forAIC_end)
summary(model_end_Nm_distributioncontinent_endemic)#Optimizer (nlminb) did not achieve convergence (convergence = 1).

model_end_Nm_habitat <- rma.mv(yi, vi, mods = ~ Nm * habitat, random = list(~ 1 | taxon_exp, ~ 1 | taxon_ctrl, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = forAIC_end)
summary(model_end_Nm_habitat)#NO INTERACTION
model_end_Nm_habitatspecific <- rma.mv(yi, vi, mods = ~ Nm * (habitat == "specific"), random = list(~ 1 | taxon_exp, ~ 1 | taxon_ctrl, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = forAIC_end)
summary(model_end_Nm_habitatspecific)#NO INTERACTION
model_end_Nm_habitatunspecific <- rma.mv(yi, vi, mods = ~ Nm * (habitat == "unspecific"), random = list(~ 1 | taxon_exp, ~ 1 | taxon_ctrl, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = forAIC_end)
summary(model_end_Nm_habitatunspecific)#NO INTERACTION

model_end_Nm_rarity <- rma.mv(yi, vi, mods = ~ Nm * rarity, random = list(~ 1 | taxon_exp, ~ 1 | taxon_ctrl, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = forAIC_end)
summary(model_end_Nm_rarity)#QE(df = 1) = 85.9911, p-val < .0001; QM(df = 4) = 21.9748, p-val = 0.0002 ***; Nm:rarityNSS   -0.0793  0.9207  -0.0862  0.9313  -1.8839   1.7252 
model_end_Nm_rarityNSS <- rma.mv(yi, vi, mods = ~ Nm * (rarity == "NSS"), random = list(~ 1 | taxon_exp, ~ 1 | taxon_ctrl, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = forAIC_end)
summary(model_end_Nm_rarityNSS)#Nm:rarity == "NSS"TRUE   -0.3173  0.8179  -0.3880  0.6980  -1.9203   1.2857
model_end_Nm_rarityNSU <- rma.mv(yi, vi, mods = ~ Nm * (rarity == "NSU"), random = list(~ 1 | taxon_exp, ~ 1 | taxon_ctrl, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = forAIC_end)
summary(model_end_Nm_rarityNSU)#NO INTERACTION
model_end_Nm_rarityNLS <- rma.mv(yi, vi, mods = ~ Nm * (rarity == "NLS"), random = list(~ 1 | taxon_exp, ~ 1 | taxon_ctrl, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = forAIC_end)
summary(model_end_Nm_rarityNLS)#Nm:rarity == "NLS"TRUE   -0.5257  0.5968  -0.8808  0.3784  -1.6955   0.6441

#FIS
model_end_FIS_life_form <- rma.mv(yi, vi, mods = ~ FIS * life_form, random = list(~ 1 | taxon_exp, ~ 1 | taxon_ctrl, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = forAIC_end)
summary(model_end_FIS_life_form)#QE(df = 16) = 619.0929, p-val < .0001; QM(df = 3) = 29.6286, p-val < .0001; FIS:life_formwoody   -0.6794  0.6131  -1.1081  0.2678  -1.8811   0.5223
model_end_FIS_life_formshortlived <- rma.mv(yi, vi, mods = ~ FIS * (life_form == "shortlived"), random = list(~ 1 | taxon_exp, ~ 1 | taxon_ctrl, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = forAIC_end)
summary(model_end_FIS_life_formshortlived)#NO INTERACTION
model_end_FIS_life_formlonglived <- rma.mv(yi, vi, mods = ~ FIS * (life_form == "longlived"), random = list(~ 1 | taxon_exp, ~ 1 | taxon_ctrl, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = forAIC_end)
summary(model_end_FIS_life_formlonglived)#estimate      se     zval    pval    ci.lb   ci.ub FIS:life_form == "longlived"TRUE    0.6794  0.6131   1.1081  0.2678  -0.5223   1.8811
model_end_FIS_life_formwoody <- rma.mv(yi, vi, mods = ~ FIS * (life_form == "woody"), random = list(~ 1 | taxon_exp, ~ 1 | taxon_ctrl, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = forAIC_end)
summary(model_end_FIS_life_formwoody)#FIS:life_form == "woody"TRUE   -0.6794  0.6131  -1.1081  0.2678  -1.8811   0.5223

model_end_FIS_mat_sys <- rma.mv(yi, vi, mods = ~ FIS * mat_sys, random = list(~ 1 | taxon_exp, ~ 1 | taxon_ctrl, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = forAIC_end)
summary(model_end_FIS_mat_sys)#NO INTERACTION
model_end_FIS_mat_sysoutcrossing <- rma.mv(yi, vi, mods = ~ FIS * (mat_sys == "outcrossing"), random = list(~ 1 | taxon_exp, ~ 1 | taxon_ctrl, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = forAIC_end)
summary(model_end_FIS_mat_sysoutcrossing)#NO INTERACTION

model_end_FIS_rep_sys <- rma.mv(yi, vi, mods = ~ FIS * rep_sys, random = list(~ 1 | taxon_exp, ~ 1 | taxon_ctrl, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = forAIC_end)
summary(model_end_FIS_rep_sys)#NO INTERACTION

model_end_FIS_pollination <- rma.mv(yi, vi, mods = ~ FIS * pollination, random = list(~ 1 | taxon_exp, ~ 1 | taxon_ctrl, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = forAIC_end)
summary(model_end_FIS_pollination)#QE(df = 8) = 702.1030, p-val < .0001; QM(df = 3) = 1629.9561, p-val < .0001; FIS:pollinationshort    0.3948  0.5993   0.6588  0.5100  -0.7797   1.5694
model_end_FIS_pollinationshort <- rma.mv(yi, vi, mods = ~ FIS * (pollination == "short"), random = list(~ 1 | taxon_exp, ~ 1 | taxon_ctrl, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = forAIC_end)
summary(model_end_FIS_pollinationshort)#FIS:pollination == "short"TRUE    0.3948  0.5993   0.6588  0.5100  -0.7797   1.5694
model_end_FIS_pollinationlong <- rma.mv(yi, vi, mods = ~ FIS * (pollination == "long"), random = list(~ 1 | taxon_exp, ~ 1 | taxon_ctrl, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = forAIC_end)
summary(model_end_FIS_pollinationlong)#FIS:pollination == "long"TRUE   -0.3948  0.5993  -0.6588  0.5100  -1.5694   0.7797

model_end_FIS_propagule_dis <- rma.mv(yi, vi, mods = ~ FIS * propagule_dis, random = list(~ 1 | taxon_exp, ~ 1 | taxon_ctrl, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = forAIC_end)
summary(model_end_FIS_propagule_dis)#QE(df = 5) = 12.5737, p-val = 0.0277; QM(df = 3) = 29.2354, p-val < .0001; FIS:propagule_dissho_dis   -0.4511  0.7757  -0.5816  0.5609  -1.9716   1.0693
model_end_FIS_propagule_dislon_dis <- rma.mv(yi, vi, mods = ~ FIS * (propagule_dis == "lon_dis"), random = list(~ 1 | taxon_exp, ~ 1 | taxon_ctrl, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = forAIC_end)
summary(model_end_FIS_propagule_dislon_dis)#FIS:propagule_dis == "lon_dis"TRUE    0.4511  0.7757   0.5816  0.5609  -1.0693   1.9716
model_end_FIS_propagule_dissho_dis <- rma.mv(yi, vi, mods = ~ FIS * (propagule_dis == "sho_dis"), random = list(~ 1 | taxon_exp, ~ 1 | taxon_ctrl, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = forAIC_end)
summary(model_end_FIS_propagule_dissho_dis)#FIS:propagule_dis == "sho_dis"TRUE   -0.4511  0.7757  -0.5816  0.5609  -1.9716   1.0693 

model_end_FIS_distribution <- rma.mv(yi, vi, mods = ~ FIS * distribution, random = list(~ 1 | taxon_exp, ~ 1 | taxon_ctrl, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = forAIC_end)
summary(model_end_FIS_distribution)#QE(df = 16) = 328.4006, p-val < .0001; QM(df = 3) = 37.6943, p-val < .0001 ***; FIS:distributionisland endemic   -1.2335  0.8086  -1.5254  0.1272  -2.8183   0.3514  
model_end_FIS_distributionisland_endemic <- rma.mv(yi, vi, mods = ~ FIS * (distribution == "island endemic"), random = list(~ 1 | taxon_exp, ~ 1 | taxon_ctrl, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = forAIC_end)
summary(model_end_FIS_distributionisland_endemic)#FIS:distribution == "island endemic"TRUE   -1.2335  0.8086  -1.5254  0.1272  -2.8183 0.3514
model_end_FIS_distributioncontinent_endemic <- rma.mv(yi, vi, mods = ~ FIS * (distribution == "continent  endemic"), random = list(~ 1 | taxon_exp, ~ 1 | taxon_ctrl, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = forAIC_end)
summary(model_end_FIS_distributioncontinent_endemic)#NO INTERACTION

model_end_FIS_habitat <- rma.mv(yi, vi, mods = ~ FIS * habitat, random = list(~ 1 | taxon_exp, ~ 1 | taxon_ctrl, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = forAIC_end)
summary(model_end_FIS_habitat)#NO INTERACTION
model_end_FIS_habitatspecific <- rma.mv(yi, vi, mods = ~ FIS * (habitat == "specific"), random = list(~ 1 | taxon_exp, ~ 1 | taxon_ctrl, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = forAIC_end)
summary(model_end_FIS_habitatspecific)#NO INTERACTION
model_end_FIS_habitatunspecific <- rma.mv(yi, vi, mods = ~ FIS * (habitat == "unspecific"), random = list(~ 1 | taxon_exp, ~ 1 | taxon_ctrl, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = forAIC_end)
summary(model_end_FIS_habitatunspecific)#NO INTERACTION

model_end_FIS_rarity <- rma.mv(yi, vi, mods = ~ FIS * rarity, random = list(~ 1 | taxon_exp, ~ 1 | taxon_ctrl, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = forAIC_end)
summary(model_end_FIS_rarity)#QE(df = 0) = 0.0000, p-val = 1.0000; QM(df = 4) = 360.8861, p-val < .0001 ***; FIS:rarityNSS    5.1956  1.8003   2.8860  0.0039   1.6672   8.7241  **
model_end_FIS_rarityNSS <- rma.mv(yi, vi, mods = ~ FIS * (rarity == "NSS"), random = list(~ 1 | taxon_exp, ~ 1 | taxon_ctrl, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = forAIC_end)
summary(model_end_FIS_rarityNSS)#FIS:rarity == "NSS"TRUE    5.7448  0.8142   7.0556  <.0001   4.1490   7.3406  ***
model_end_FIS_rarityNSU <- rma.mv(yi, vi, mods = ~ FIS * (rarity == "NSU"), random = list(~ 1 | taxon_exp, ~ 1 | taxon_ctrl, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = forAIC_end)
summary(model_end_FIS_rarityNSU)#NO INTERACTION
model_end_FIS_rarityNLS <- rma.mv(yi, vi, mods = ~ FIS * (rarity == "NLS"), random = list(~ 1 | taxon_exp, ~ 1 | taxon_ctrl, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = forAIC_end)
summary(model_end_FIS_rarityNLS)#FIS:rarity == "NLS"TRUE   -5.2324  1.8001  -2.9067  0.0037  -8.7605  -1.7042   ** 

#Na
model_end_Na_life_form <- rma.mv(yi, vi, mods = ~ Na * life_form, random = list(~ 1 | taxon_exp, ~ 1 | taxon_ctrl, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = forAIC_end)
summary(model_end_Na_life_form)#QE(df = 2) = 13.2592, p-val = 0.0013; QM(df = 4) = 104.8286, p-val < .0001; Na:life_formwoody      0.0000  0.0001    0.5400  0.5892  -0.0001   0.0002
model_end_Na_life_formshortlived <- rma.mv(yi, vi, mods = ~ Na * (life_form == "shortlived"), random = list(~ 1 | taxon_exp, ~ 1 | taxon_ctrl, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = forAIC_end)
summary(model_end_Na_life_formshortlived)#NO INTERACTION
model_end_Na_life_formlonglived <- rma.mv(yi, vi, mods = ~ Na * (life_form == "longlived"), random = list(~ 1 | taxon_exp, ~ 1 | taxon_ctrl, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = forAIC_end)
summary(model_end_Na_life_formlonglived)#Na:life_form == "longlived"TRUE   -0.0000  0.0001  -0.5427  0.5874  -0.0002   0.0001
model_end_Na_life_formwoody <- rma.mv(yi, vi, mods = ~ Na * (life_form == "woody"), random = list(~ 1 | taxon_exp, ~ 1 | taxon_ctrl, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = forAIC_end)
summary(model_end_Na_life_formwoody)#Na:life_form == "woody"TRUE    0.0000  0.0001    0.5414  0.5882  -0.0001   0.0002

model_end_Na_mat_sys <- rma.mv(yi, vi, mods = ~ Na * mat_sys, random = list(~ 1 | taxon_exp, ~ 1 | taxon_ctrl, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = forAIC_end)
summary(model_end_Na_mat_sys)#NO INTERACTION
model_end_Na_mat_sysoutcrossing <- rma.mv(yi, vi, mods = ~ Na * (mat_sys == "outcrossing"), random = list(~ 1 | taxon_exp, ~ 1 | taxon_ctrl, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = forAIC_end)
summary(model_end_Na_mat_sysoutcrossing)#NO INTERACTION

model_end_Na_rep_sys <- rma.mv(yi, vi, mods = ~ Na * rep_sys, random = list(~ 1 | taxon_exp, ~ 1 | taxon_ctrl, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = forAIC_end)
summary(model_end_Na_rep_sys)#NO INTERACTION

model_end_Na_pollination <- rma.mv(yi, vi, mods = ~ Na * pollination, random = list(~ 1 | taxon_exp, ~ 1 | taxon_ctrl, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = forAIC_end)
summary(model_end_Na_pollination)#QE(df = 2) = 103.7776, p-val < .0001; QM(df = 3) = 280.4460, p-val < .0001; Na:pollinationshort   -0.0001  0.0001   -1.8693  0.0616  -0.0002   0.0000    .
model_end_Na_pollinationshort <- rma.mv(yi, vi, mods = ~ Na * (pollination == "short"), random = list(~ 1 | taxon_exp, ~ 1 | taxon_ctrl, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = forAIC_end)
summary(model_end_Na_pollinationshort)#Na:pollination == "short"TRUE   -0.0001  0.0001   -1.8693  0.0616  -0.0002   0.0000    .
model_end_Na_pollinationlong <- rma.mv(yi, vi, mods = ~ Na * (pollination == "long"), random = list(~ 1 | taxon_exp, ~ 1 | taxon_ctrl, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = forAIC_end)
summary(model_end_Na_pollinationlong)#Na:pollination == "long"TRUE    0.0001  0.0001   1.8693  0.0616  -0.0000  0.0002    .

model_end_Na_propagule_dis <- rma.mv(yi, vi, mods = ~ Na * propagule_dis, random = list(~ 1 | taxon_exp, ~ 1 | taxon_ctrl, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = forAIC_end)
summary(model_end_Na_propagule_dis)#QE(df = 1) = 6.1334, p-val = 0.0133; QM(df = 3) = 45.7025, p-val < .0001; Na:propagule_dissho_dis   -0.0003  0.0001  -4.4338  <.0001  -0.0004  -0.0002  *** 
model_end_Na_propagule_dislon_dis <- rma.mv(yi, vi, mods = ~ Na * (propagule_dis == "lon_dis"), random = list(~ 1 | taxon_exp, ~ 1 | taxon_ctrl, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = forAIC_end)
summary(model_end_Na_propagule_dislon_dis)#Na:propagule_dis == "lon_dis"TRUE    0.0003  0.0001   4.4338  <.0001   0.0002   0.0004  ***
model_end_Na_propagule_dissho_dis <- rma.mv(yi, vi, mods = ~ Na * (propagule_dis == "sho_dis"), random = list(~ 1 | taxon_exp, ~ 1 | taxon_ctrl, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = forAIC_end)
summary(model_end_Na_propagule_dissho_dis)#Na:propagule_dis == "sho_dis"TRUE   -0.0003  0.0001  -4.4338  <.0001  -0.0004  -0.0002  ***

model_end_Na_distribution <- rma.mv(yi, vi, mods = ~ Na * distribution, random = list(~ 1 | taxon_exp, ~ 1 | taxon_ctrl, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = forAIC_end)
summary(model_end_Na_distribution)#NO INTERACTION
model_end_Na_distributionisland_endemic <- rma.mv(yi, vi, mods = ~ Na * (distribution == "island endemic"), random = list(~ 1 | taxon_exp, ~ 1 | taxon_ctrl, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = forAIC_end)
summary(model_end_Na_distributionisland_endemic)#NO INTERACTION
model_end_Na_distributioNaontinent_endemic <- rma.mv(yi, vi, mods = ~ Na * (distribution == "continent  endemic"), random = list(~ 1 | taxon_exp, ~ 1 | taxon_ctrl, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = forAIC_end)
summary(model_end_Na_distributioNaontinent_endemic)#NO INTERACTION

model_end_Na_habitat <- rma.mv(yi, vi, mods = ~ Na * habitat, random = list(~ 1 | taxon_exp, ~ 1 | taxon_ctrl, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = forAIC_end)
summary(model_end_Na_habitat)#NO INTERACTION
model_end_Na_habitatspecific <- rma.mv(yi, vi, mods = ~ Na * (habitat == "specific"), random = list(~ 1 | taxon_exp, ~ 1 | taxon_ctrl, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = forAIC_end)
summary(model_end_Na_habitatspecific)#NO INTERACTION
model_end_Na_habitatunspecific <- rma.mv(yi, vi, mods = ~ Na * (habitat == "unspecific"), random = list(~ 1 | taxon_exp, ~ 1 | taxon_ctrl, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = forAIC_end)
summary(model_end_Na_habitatunspecific)#NO INTERACTION

model_end_Na_rarity <- rma.mv(yi, vi, mods = ~ Na * rarity, random = list(~ 1 | taxon_exp, ~ 1 | taxon_ctrl, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = forAIC_end)
summary(model_end_Na_rarity)#QE(df = 2) = 6.2185, p-val = 0.0446; QM(df = 4) = 354.7868, p-val < .0001 ***; Na:rarityNSS    0.0756  0.0078    9.6878  <.0001    0.0603    0.0909  ***  
model_end_Na_rarityNSS <- rma.mv(yi, vi, mods = ~ Na * (rarity == "NSS"), random = list(~ 1 | taxon_exp, ~ 1 | taxon_ctrl, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = forAIC_end)
summary(model_end_Na_rarityNSS)#Na:rarity == "NSS"TRUE    0.0756  0.0078    9.6873  <.0001    0.0603    0.0909  ***
model_end_Na_rarityNSU <- rma.mv(yi, vi, mods = ~ Na * (rarity == "NSU"), random = list(~ 1 | taxon_exp, ~ 1 | taxon_ctrl, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = forAIC_end)
summary(model_end_Na_rarityNSU)#NO INTERACTION
model_end_Na_rarityNLS <- rma.mv(yi, vi, mods = ~ Na * (rarity == "NLS"), random = list(~ 1 | taxon_exp, ~ 1 | taxon_ctrl, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = forAIC_end)
summary(model_end_Na_rarityNLS)#Na:rarity == "NLS"TRUE   -0.0217  0.0062  -3.5119  0.0004  -0.0338  -0.0096  ***

##The interaction of different variables with each other in invasive plants

#Classification variables

# List all variables to be analyzed for interaction
vars_inv <- c("life_form", "mat_sys", "rep_sys", "pollination", "propagule_dis", "propagule")

# Create an empty list to hold the model results
models_inv_class_inter <- list()

# Create an empty list to hold the frequency table of interaction items
tables_inv <- list()

# Use nested loops to iterate over all combinations of variables
for (i in 1:(length(vars_inv))) {
  for (j in 1:length(vars_inv)) {
    # Skip the same variable
    if (i == j) next
    # Create interactive items
    interaction_var_inv <- interaction(forAIC_inv[[vars_inv[i]]], forAIC_inv[[vars_inv[j]]])
    # Adds the interaction item to the data box
    interaction_name_inv <- paste(sort(c(vars_inv[i], vars_inv[j])), collapse="_")
    forAIC_inv[interaction_name_inv] <- interaction_var_inv
    # Saves a frequency table of interaction items
    tables_inv[[interaction_name_inv]] <- table(interaction_var_inv)
    # Try to run the model and catch possible errors
    tryCatch({
      model_inv <- rma.mv(yi, vi, mods = as.formula(paste("~", interaction_name_inv)), random = list(~ 1 | taxon_exp, ~ 1 | taxon_ctrl, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = forAIC_inv)
      # Save the model results to the list
      models_inv_class_inter[[interaction_name_inv]] <- model_inv
    }, error = function(e) {
      message(paste("Failed to fit model for", interaction_name_inv, ":"))
      message(e)
    })
  }
}

# Iterate over all the elements in the models list
for (model_name_inv in names(models_inv_class_inter)) {
  # print model name
  print(model_name_inv)
  # Get a summary of the model results and print it
  print(summary(models_inv_class_inter[[model_name_inv]]))
}

# Iterate over all the elements in the tables list
for (table_name_inv in names(tables_inv)) {
  # print table name
  print(table_name_inv)
  # Print a frequency table of interaction items
  print(tables_inv[[table_name_inv]])
}

##Continuous variable

forAIC_inv$invasion_time<-as.numeric(forAIC_inv$invasion_time)
model_inv_Nm_invasion_time <- rma.mv(yi, vi, mods = ~ Nm * invasion_time, random = list(~ 1 | taxon_exp, ~ 1 | taxon_ctrl, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = forAIC_inv)
summary(model_inv_Nm_invasion_time)#Nm:invasion_time 0.0006  0.0022   0.2560  0.7980  -0.0038  0.0049
model_inv_Na_invasion_time <- rma.mv(yi, vi, mods = ~ Na * invasion_time, random = list(~ 1 | taxon_exp, ~ 1 | taxon_ctrl, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = forAIC_inv)
summary(model_inv_Na_invasion_time)#Processing terminated since k <= 1.
model_inv_FIS_invasion_time <- rma.mv(yi, vi, mods = ~ FIS * invasion_time, random = list(~ 1 | taxon_exp, ~ 1 | taxon_ctrl, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = forAIC_inv)
summary(model_inv_FIS_invasion_time)#FIS:invasion_time    0.0012  0.0080   0.1503  0.8805  -0.0144  0.0168
model_inv_Fst_invasion_time <- rma.mv(yi, vi, mods = ~ Fst * invasion_time, random = list(~ 1 | taxon_exp, ~ 1 | taxon_ctrl, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = forAIC_inv)
summary(model_inv_Fst_invasion_time)#Fst:invasion_time    0.0064  0.0147   0.4385  0.6610  -0.0223   0.0352

model_inv_Na_FIS <- rma.mv(yi, vi, mods = ~ Na * FIS, random = list(~ 1 | taxon_exp, ~ 1 | taxon_ctrl, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = forAIC_inv)
summary(model_inv_Na_FIS)#Processing terminated since k <= 1.

model_inv_Na_Nm <- rma.mv(yi, vi, mods = ~ Na * Nm, random = list(~ 1 | taxon_exp, ~ 1 | taxon_ctrl, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = forAIC_inv)
summary(model_inv_Na_Nm)#Processing terminated since k <= 1.

model_inv_Na_Fst <- rma.mv(yi, vi, mods = ~ Na * Fst, random = list(~ 1 | taxon_exp, ~ 1 | taxon_ctrl, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = forAIC_inv)
summary(model_inv_Na_Fst)#Processing terminated since k <= 1.

model_inv_Nm_Fst <- rma.mv(yi, vi, mods = ~ Fst * Nm, random = list(~ 1 | taxon_exp, ~ 1 | taxon_ctrl, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = forAIC_inv)
summary(model_inv_Nm_Fst)#NO INTERACTION

model_inv_Nm_FIS <- rma.mv(yi, vi, mods = ~ Nm * FIS, random = list(~ 1 | taxon_exp, ~ 1 | taxon_ctrl, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = forAIC_inv)
summary(model_inv_Nm_FIS)#Nm:FIS     0.3225  0.0953   3.3852  0.0007   0.1358   0.5092  ***

model_inv_Fst_FIS <- rma.mv(yi, vi, mods = ~ Fst * FIS, random = list(~ 1 | taxon_exp, ~ 1 | taxon_ctrl, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = forAIC_inv)
summary(model_inv_Fst_FIS)#Fst:FIS   -0.7839  0.6652  -1.1785  0.2386  -2.0876   0.5198

#Continuous * Classification variable
#Nm
model_inv_Nm_life_form <- rma.mv(yi, vi, mods = ~ Nm * life_form, random = list(~ 1 | taxon_exp, ~ 1 | taxon_ctrl, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = forAIC_inv)
summary(model_inv_Nm_life_form)#QE(df = 9) = 143.5733, p-val < .0001; QM(df = 5) = 28.9693, p-val < .0001 ***; Nm:life_formshortlived    0.0783  0.1149   0.6817  0.4955  -0.1469   0.3036   0.2566; Nm:life_formwoody        -0.0360  0.1156  -0.3116  0.7554  -0.2626   0.1906
model_inv_Nm_life_formshortlived <- rma.mv(yi, vi, mods = ~ Nm * (life_form == "shortlived"), random = list(~ 1 | taxon_exp, ~ 1 | taxon_ctrl, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = forAIC_inv)
summary(model_inv_Nm_life_formshortlived)#Nm:life_form == "shortlived"TRUE    0.1116  0.0460   2.4246  0.0153   0.0214   0.2019    *
model_inv_Nm_life_formlonglived <- rma.mv(yi, vi, mods = ~ Nm * (life_form == "longlived"), random = list(~ 1 | taxon_exp, ~ 1 | taxon_ctrl, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = forAIC_inv)
summary(model_inv_Nm_life_formlonglived)#Nm:life_form == "longlived"TRUE    0.4487  0.1832   2.4497  0.0143   0.0897   0.8077  *
model_inv_Nm_life_formwoody <- rma.mv(yi, vi, mods = ~ Nm * (life_form == "woody"), random = list(~ 1 | taxon_exp, ~ 1 | taxon_ctrl, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = forAIC_inv)
summary(model_inv_Nm_life_formwoody)#Nm:life_form == "woody"TRUE   -0.0646  0.0889  -0.7271  0.4672  -0.2389   0.1096

model_inv_Nm_mat_sys <- rma.mv(yi, vi, mods = ~ Nm * mat_sys, random = list(~ 1 | taxon_exp, ~ 1 | taxon_ctrl, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = forAIC_inv)
summary(model_inv_Nm_mat_sys)#QE(df = 8) = 61.3736, p-val < .0001; QM(df = 5) = 86.0102, p-val < .0001***; Nm:mat_sysmixing         2.8441  4.6947   0.6058  0.5446   -6.3573  12.0455;Nm:mat_sysoutcrossing    2.5326  4.6942   0.5395  0.5895   -6.6680  11.7331
model_inv_Nm_mat_sysoutcrossing <- rma.mv(yi, vi, mods = ~ Nm * (mat_sys == "outcrossing"), random = list(~ 1 | taxon_exp, ~ 1 | taxon_ctrl, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = forAIC_inv)
summary(model_inv_Nm_mat_sysoutcrossing)#Nm:mat_sys == "outcrossing"TRUE   -0.5700  0.1209  -4.7143  <.0001  -0.8070  -0.3330  ***
model_inv_Nm_mat_sysmixing <- rma.mv(yi, vi, mods = ~ Nm * (mat_sys == "mixing"), random = list(~ 1 | taxon_exp, ~ 1 | taxon_ctrl, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = forAIC_inv)
summary(model_inv_Nm_mat_sysmixing)#Nm:mat_sys == "mixing"TRUE    0.2843  0.1540   1.8460  0.0649  -0.0176   0.5861  .
model_inv_Nm_mat_sysselfing <- rma.mv(yi, vi, mods = ~ Nm * (mat_sys == "inbreeding"), random = list(~ 1 | taxon_exp, ~ 1 | taxon_ctrl, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = forAIC_inv)
summary(model_inv_Nm_mat_sysselfing)#Nm:mat_sys == "inbreeding"TRUE    4.7474  5.4859   0.8654  0.3868  -6.0048  15.4995

model_inv_Nm_rep_sys <- rma.mv(yi, vi, mods = ~ Nm * rep_sys, random = list(~ 1 | taxon_exp, ~ 1 | taxon_ctrl, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = forAIC_inv)
summary(model_inv_Nm_rep_sys)#QE(df = 10) = 106.3979, p-val < .0001; QM(df = 3) = 26.7105, p-val < .0001***; Nm:rep_sysfacultative    0.6393  0.2007   3.1851  0.0014   0.2459   1.0327  **
model_inv_Nm_rep_sysclonal <- rma.mv(yi, vi, mods = ~ Nm * (rep_sys == "clonal"), random = list(~ 1 | taxon_exp, ~ 1 | taxon_ctrl, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = forAIC_inv)
summary(model_inv_Nm_rep_sysclonal)#NO INTERACTION
model_inv_Nm_rep_sysfacultative <- rma.mv(yi, vi, mods = ~ Nm * (rep_sys == "facultative"), random = list(~ 1 | taxon_exp, ~ 1 | taxon_ctrl, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = forAIC_inv)
summary(model_inv_Nm_rep_sysfacultative)#Nm:rep_sys == "facultative"TRUE    0.6393  0.2007   3.1851  0.0014   0.2459   1.0327  **
model_inv_Nm_rep_syssexual <- rma.mv(yi, vi, mods = ~ Nm * (rep_sys == "sexual"), random = list(~ 1 | taxon_exp, ~ 1 | taxon_ctrl, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = forAIC_inv)
summary(model_inv_Nm_rep_syssexual)#Nm:rep_sys == "sexual"TRUE   -0.6393  0.2007  -3.1851  0.0014  -1.0327  -0.2459   **

model_inv_Nm_pollination <- rma.mv(yi, vi, mods = ~ Nm * pollination, random = list(~ 1 | taxon_exp, ~ 1 | taxon_ctrl, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = forAIC_inv)
summary(model_inv_Nm_pollination)#QE(df = 8) = 43.7270, p-val < .0001; QM(df = 3) = 9.3534, p-val = 0.0249 *; Nm:pollinationshort    0.1351  0.0967   1.3967  0.1625  -0.0545  0.3246
model_inv_Nm_pollinationshort <- rma.mv(yi, vi, mods = ~ Nm * (pollination == "short"), random = list(~ 1 | taxon_exp, ~ 1 | taxon_ctrl, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = forAIC_inv)
summary(model_inv_Nm_pollinationshort)#Nm:pollination == "short"TRUE    0.1351  0.0967   1.3967  0.1625  -0.0545  0.3246
model_inv_Nm_pollinationlong <- rma.mv(yi, vi, mods = ~ Nm * (pollination == "long"), random = list(~ 1 | taxon_exp, ~ 1 | taxon_ctrl, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = forAIC_inv)
summary(model_inv_Nm_pollinationlong)#Nm:pollination == "long"TRUE   -0.1351  0.0967  -1.3967  0.1625  -0.3246   0.0545

model_inv_Nm_propagule_dis <- rma.mv(yi, vi, mods = ~ Nm * propagule_dis, random = list(~ 1 | taxon_exp, ~ 1 | taxon_ctrl, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = forAIC_inv)
summary(model_inv_Nm_propagule_dis)#QE(df = 10) = 244.0755, p-val < .0001; QM(df = 3) = 5.9279, p-val = 0.1152; Nm:propagule_dissho_dis   -0.0240  0.1118  -0.2148  0.8299  -0.2431   0.1951
model_inv_Nm_propagule_dislon_dis <- rma.mv(yi, vi, mods = ~ Nm * (propagule_dis == "lon_dis"), random = list(~ 1 | taxon_exp, ~ 1 | taxon_ctrl, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = forAIC_inv)
summary(model_inv_Nm_propagule_dislon_dis)#Nm:propagule_dis == "lon_dis"TRUE    0.0240  0.1118   0.2148  0.8299  -0.1951   0.2431
model_inv_Nm_propagule_dissho_dis <- rma.mv(yi, vi, mods = ~ Nm * (propagule_dis == "sho_dis"), random = list(~ 1 | taxon_exp, ~ 1 | taxon_ctrl, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = forAIC_inv)
summary(model_inv_Nm_propagule_dissho_dis)#Nm:propagule_dis == "sho_dis"TRUE   -0.0240  0.1118  -0.2148  0.8299  -0.2431   0.1951 

model_inv_Nm_propagule <- rma.mv(yi, vi, mods = ~ Nm * propagule, random = list(~ 1 | taxon_exp, ~ 1 | taxon_ctrl, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = forAIC_inv)
summary(model_inv_Nm_propagule)#QE(df = 10) = 106.3979, p-val < .0001; QM(df = 3) = 26.7105, p-val < .0001 ***; Nm:propaguleseed   -0.6393  0.2007  -3.1851  0.0014  -1.0327  -0.2459   **
model_inv_Nm_propagulerhizome <- rma.mv(yi, vi, mods = ~ Nm * (propagule == "rhizome"), random = list(~ 1 | taxon_exp, ~ 1 | taxon_ctrl, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = forAIC_inv)
summary(model_inv_Nm_propagulerhizome)#NO INTERACTION
model_inv_Nm_propagulemultiple <- rma.mv(yi, vi, mods = ~ Nm * (propagule == "multiple"), random = list(~ 1 | taxon_exp, ~ 1 | taxon_ctrl, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = forAIC_inv)
summary(model_inv_Nm_propagulemultiple)#Nm:propagule == "multiple"TRUE    0.6393  0.2007   3.1851  0.0014   0.2459   1.0327  ** 
model_inv_Nm_propaguleseed <- rma.mv(yi, vi, mods = ~ Nm * (propagule == "seed"), random = list(~ 1 | taxon_exp, ~ 1 | taxon_ctrl, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = forAIC_inv)
summary(model_inv_Nm_propaguleseed)#Nm:propagule == "seed"TRUE   -0.6393  0.2007  -3.1851  0.0014  -1.0327  -0.2459   **

#FIS
model_inv_FIS_life_form <- rma.mv(yi, vi, mods = ~ FIS * life_form, random = list(~ 1 | taxon_exp, ~ 1 | taxon_ctrl, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = forAIC_inv)
summary(model_inv_FIS_life_form)#QE(df = 6) = 37.0289, p-val < .0001; QM(df = 5) = 32.3472, p-val < .0001***; FIS:life_formshortlived   -1.3960  1.4513  -0.9619  0.3361  -4.2404   1.4484;   FIS:life_formwoody         2.6417  0.7186   3.6764  0.0002   1.2334   4.0501  *** 
model_inv_FIS_life_formshortlived <- rma.mv(yi, vi, mods = ~ FIS * (life_form == "shortlived"), random = list(~ 1 | taxon_exp, ~ 1 | taxon_ctrl, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = forAIC_inv)
summary(model_inv_FIS_life_formshortlived)#FIS:life_form == "shortlived"TRUE   -1.7007  2.1768  -0.7813  0.4346  -5.9671   2.5657
model_inv_FIS_life_formlonglived <- rma.mv(yi, vi, mods = ~ FIS * (life_form == "longlived"), random = list(~ 1 | taxon_exp, ~ 1 | taxon_ctrl, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = forAIC_inv)
summary(model_inv_FIS_life_formlonglived)#FIS:life_form == "longlived"TRUE   -1.4014  0.7980  -1.7562  0.0791  -2.9653  0.1626  .
model_inv_FIS_life_formwoody <- rma.mv(yi, vi, mods = ~ FIS * (life_form == "woody"), random = list(~ 1 | taxon_exp, ~ 1 | taxon_ctrl, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = forAIC_inv)
summary(model_inv_FIS_life_formwoody)#FIS:life_form == "woody"TRUE    2.7353  0.7543   3.6263  0.0003   1.2569   4.2136  ***

model_inv_FIS_mat_sys <- rma.mv(yi, vi, mods = ~ FIS * mat_sys, random = list(~ 1 | taxon_exp, ~ 1 | taxon_ctrl, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = forAIC_inv)
summary(model_inv_FIS_mat_sys)#QE(df = 5) = 12.1227, p-val = 0.0331; QM(df = 4) = 71.5172, p-val < .0001 ***; FIS:mat_sysmixing    -1.4602  0.6617  -2.2069  0.0273  -2.7571  -0.1634    *
model_inv_FIS_mat_sysoutcrossing <- rma.mv(yi, vi, mods = ~ FIS * (mat_sys == "outcrossing"), random = list(~ 1 | taxon_exp, ~ 1 | taxon_ctrl, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = forAIC_inv)
summary(model_inv_FIS_mat_sysoutcrossing)#FIS:mat_sys == "outcrossing"TRUE    1.7150  0.4944   3.4690  0.0005   0.7460   2.6840  ***
model_inv_FIS_mat_sysinbreeding <- rma.mv(yi, vi, mods = ~ FIS * (mat_sys == "inbreeding"), random = list(~ 1 | taxon_exp, ~ 1 | taxon_ctrl, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = forAIC_inv)
summary(model_inv_FIS_mat_sysinbreeding)#NO INTERACTION
model_inv_FIS_mat_sysmixing <- rma.mv(yi, vi, mods = ~ FIS * (mat_sys == "mixing"), random = list(~ 1 | taxon_exp, ~ 1 | taxon_ctrl, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = forAIC_inv)
summary(model_inv_FIS_mat_sysmixing)#FIS:mat_sys == "mixing"TRUE   -0.2270  0.8137  -0.2789  0.7803  -1.8217   1.3678 

model_inv_FIS_rep_sys <- rma.mv(yi, vi, mods = ~ FIS * rep_sys, random = list(~ 1 | taxon_exp, ~ 1 | taxon_ctrl, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = forAIC_inv)
summary(model_inv_FIS_rep_sys)#QE(df = 7) = 43.8438, p-val < .0001; QM(df = 3) = 14.4208, p-val = 0.0024 **; FIS:rep_sysfacultative   -1.2624  0.8234  -1.5332  0.1252  -2.8763  0.3514 
model_inv_FIS_rep_sysclonal <- rma.mv(yi, vi, mods = ~ FIS * (rep_sys == "clonal"), random = list(~ 1 | taxon_exp, ~ 1 | taxon_ctrl, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = forAIC_inv)
summary(model_inv_FIS_rep_sysclonal)#NO INTERACTION
model_inv_FIS_rep_sysfacultative <- rma.mv(yi, vi, mods = ~ FIS * (rep_sys == "facultative"), random = list(~ 1 | taxon_exp, ~ 1 | taxon_ctrl, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = forAIC_inv)
summary(model_inv_FIS_rep_sysfacultative)#FIS:rep_sys == "facultative"TRUE   -1.2624  0.8234  -1.5332  0.1252  -2.8763  0.3514
model_inv_FIS_rep_syssexual <- rma.mv(yi, vi, mods = ~ FIS * (rep_sys == "sexual"), random = list(~ 1 | taxon_exp, ~ 1 | taxon_ctrl, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = forAIC_inv)
summary(model_inv_FIS_rep_syssexual)#FIS:rep_sys == "sexual"TRUE    1.2624  0.8234   1.5332  0.1252  -0.3514   2.8763

model_inv_FIS_pollination <- rma.mv(yi, vi, mods = ~ FIS * pollination, random = list(~ 1 | taxon_exp, ~ 1 | taxon_ctrl, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = forAIC_inv)
summary(model_inv_FIS_pollination)#QE(df = 6) = 57.3940, p-val < .0001; QM(df = 3) = 5.2485, p-val = 0.1545; FIS:pollinationshort   -1.3350  1.9395  -0.6883  0.4913  -5.1365  2.4664
model_inv_FIS_pollinationshort <- rma.mv(yi, vi, mods = ~ FIS * (pollination == "short"), random = list(~ 1 | taxon_exp, ~ 1 | taxon_ctrl, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = forAIC_inv)
summary(model_inv_FIS_pollinationshort)#FIS:pollination == "short"TRUE   -1.3350  1.9395  -0.6883  0.4913  -5.1365  2.4664
model_inv_FIS_pollinationlong <- rma.mv(yi, vi, mods = ~ FIS * (pollination == "long"), random = list(~ 1 | taxon_exp, ~ 1 | taxon_ctrl, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = forAIC_inv)
summary(model_inv_FIS_pollinationlong)#FIS:pollination == "long"TRUE    1.3350  1.9395   0.6883  0.4913  -2.4664   5.1365

model_inv_FIS_propagule_dis <- rma.mv(yi, vi, mods = ~ FIS * propagule_dis, random = list(~ 1 | taxon_exp, ~ 1 | taxon_ctrl, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = forAIC_inv)
summary(model_inv_FIS_propagule_dis)#NO INTERACTION

model_inv_FIS_propagule <- rma.mv(yi, vi, mods = ~ FIS * propagule, random = list(~ 1 | taxon_exp, ~ 1 | taxon_ctrl, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = forAIC_inv)
summary(model_inv_FIS_propagule)#QE(df = 7) = 43.8438, p-val < .0001; QM(df = 3) = 14.4208, p-val = 0.0024**; FIS:propaguleseed    1.2624  0.8234   1.5332  0.1252  -0.3514   2.8763
model_inv_FIS_propagulerhizome <- rma.mv(yi, vi, mods = ~ FIS * (propagule == "rhizome"), random = list(~ 1 | taxon_exp, ~ 1 | taxon_ctrl, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = forAIC_inv)
summary(model_inv_FIS_propagulerhizome)#NO INTERACTION
model_inv_FIS_propagulemultiple <- rma.mv(yi, vi, mods = ~ FIS * (propagule == "multiple"), random = list(~ 1 | taxon_exp, ~ 1 | taxon_ctrl, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = forAIC_inv)
summary(model_inv_FIS_propagulemultiple)#FIS:propagule == "multiple"TRUE   -1.2624  0.8234  -1.5332  0.1252  -2.8763  0.3514
model_inv_FIS_propaguleseed <- rma.mv(yi, vi, mods = ~ FIS * (propagule == "seed"), random = list(~ 1 | taxon_exp, ~ 1 | taxon_ctrl, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = forAIC_inv)
summary(model_inv_FIS_propaguleseed)#FIS:propagule == "seed"TRUE    1.2624  0.8234   1.5332  0.1252  -0.3514   2.8763

#invasion_time
model_inv_invasion_time_life_form <- rma.mv(yi, vi, mods = ~ invasion_time * life_form, random = list(~ 1 | taxon_exp, ~ 1 | taxon_ctrl, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = forAIC_inv)
summary(model_inv_invasion_time_life_form)#QE(df = 14) = 521.7943, p-val < .0001; QM(df = 5) = 1.4609, p-val = 0.9175; invasion_time:life_formshortlived   -0.0030  0.0052  -0.5724  0.5670  -0.0132   0.0073 ; invasion_time:life_formwoody        -0.0077  0.0091  -0.8374  0.4024  -0.0256   0.0103
model_inv_invasion_time_life_formshortlived <- rma.mv(yi, vi, mods = ~ invasion_time * (life_form == "shortlived"), random = list(~ 1 | taxon_exp, ~ 1 | taxon_ctrl, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = forAIC_inv)
summary(model_inv_invasion_time_life_formshortlived)#invasion_time:life_form == "shortlived"TRUE   -0.0027  0.0051  -0.5263  0.5987  -0.0127  0.0073
model_inv_invasion_time_life_formlonglived <- rma.mv(yi, vi, mods = ~ invasion_time * (life_form == "longlived"), random = list(~ 1 | taxon_exp, ~ 1 | taxon_ctrl, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = forAIC_inv)
summary(model_inv_invasion_time_life_formlonglived)#invasion_time:life_form == "longlived"TRUE    0.0040  0.0046   0.8724  0.3830  -0.0050  0.0130
model_inv_invasion_time_life_formwoody <- rma.mv(yi, vi, mods = ~ invasion_time * (life_form == "woody"), random = list(~ 1 | taxon_exp, ~ 1 | taxon_ctrl, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = forAIC_inv)
summary(model_inv_invasion_time_life_formwoody)#invasion_time:life_form == "woody"TRUE   -0.0076  0.0094  -0.8092  0.4184  -0.0259   0.0108

model_inv_invasion_time_mat_sys <- rma.mv(yi, vi, mods = ~ invasion_time * mat_sys, random = list(~ 1 | taxon_exp, ~ 1 | taxon_ctrl, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = forAIC_inv)
summary(model_inv_invasion_time_mat_sys)#QE(df = 12) = 51.6247, p-val < .0001; QM(df = 5) = 195.8900, p-val < .0001***; invasion_time:mat_sysmixing        -0.0189  0.0059  -3.2149  0.0013  -0.0304  -0.0074   ** ; invasion_time:mat_sysoutcrossing   -0.0183  0.0060  -3.0424  0.0023  -0.0300  -0.0065   **
model_inv_invasion_time_mat_sysoutcrossing <- rma.mv(yi, vi, mods = ~ invasion_time * (mat_sys == "outcrossing"), random = list(~ 1 | taxon_exp, ~ 1 | taxon_ctrl, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = forAIC_inv)
summary(model_inv_invasion_time_mat_sysoutcrossing)#invasion_time:mat_sys == "outcrossing"TRUE   -0.0025  0.0042  -0.5836  0.5595  -0.0107  0.0058
model_inv_invasion_time_mat_sysmixing <- rma.mv(yi, vi, mods = ~ invasion_time * (mat_sys == "mixing"), random = list(~ 1 | taxon_exp, ~ 1 | taxon_ctrl, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = forAIC_inv)
summary(model_inv_invasion_time_mat_sysmixing)#invasion_time:mat_sys == "mixing"TRUE    0.0003  0.0047   0.0633  0.9495  -0.0089   0.0095
model_inv_invasion_time_mat_sysinbreeding <- rma.mv(yi, vi, mods = ~ invasion_time * (mat_sys == "inbreeding"), random = list(~ 1 | taxon_exp, ~ 1 | taxon_ctrl, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = forAIC_inv)
summary(model_inv_invasion_time_mat_sysinbreeding)#Optimizer (nlminb) did not achieve convergence (convergence = 1).

model_inv_invasion_time_rep_sys <- rma.mv(yi, vi, mods = ~ invasion_time * rep_sys, random = list(~ 1 | taxon_exp, ~ 1 | taxon_ctrl, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = forAIC_inv)
summary(model_inv_invasion_time_rep_sys)#QE(df = 16) = 494.1534, p-val < .0001; QM(df = 3) = 1.9944, p-val = 0.5736; invasion_time:rep_sysfacultative    0.0053  0.0044   1.2145  0.2245  -0.0033  0.0139 
model_inv_invasion_time_rep_sysclonal <- rma.mv(yi, vi, mods = ~ invasion_time * (rep_sys == "clonal"), random = list(~ 1 | taxon_exp, ~ 1 | taxon_ctrl, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = forAIC_inv)
summary(model_inv_invasion_time_rep_sysclonal)#NO INTERACTION
model_inv_invasion_time_rep_sysfacultative <- rma.mv(yi, vi, mods = ~ invasion_time * (rep_sys == "facultative"), random = list(~ 1 | taxon_exp, ~ 1 | taxon_ctrl, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = forAIC_inv)
summary(model_inv_invasion_time_rep_sysfacultative)#invasion_time:rep_sys == "facultative"TRUE    0.0053  0.0044   1.2145  0.2245  -0.0033  0.0139
model_inv_invasion_time_rep_syssexual <- rma.mv(yi, vi, mods = ~ invasion_time * (rep_sys == "sexual"), random = list(~ 1 | taxon_exp, ~ 1 | taxon_ctrl, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = forAIC_inv)
summary(model_inv_invasion_time_rep_syssexual)#invasion_time:rep_sys == "sexual"TRUE   -0.0053  0.0044  -1.2145  0.2245  -0.0139   0.0033

model_inv_invasion_time_pollination <- rma.mv(yi, vi, mods = ~ invasion_time * pollination, random = list(~ 1 | taxon_exp, ~ 1 | taxon_ctrl, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = forAIC_inv)
summary(model_inv_invasion_time_pollination)#QE(df = 13) = 244.1284, p-val < .0001; QM(df = 3) = 3.7224, p-val = 0.2930; invasion_time:pollinationshort   -0.0020  0.0043  -0.4539  0.6499  -0.0104  0.0065
model_inv_invasion_time_pollinationshort <- rma.mv(yi, vi, mods = ~ invasion_time * (pollination == "short"), random = list(~ 1 | taxon_exp, ~ 1 | taxon_ctrl, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = forAIC_inv)
summary(model_inv_invasion_time_pollinationshort)#invasion_time:pollination == "short"TRUE   -0.0020  0.0043  -0.4539  0.6499  -0.0104  0.0065
model_inv_invasion_time_pollinationlong <- rma.mv(yi, vi, mods = ~ invasion_time * (pollination == "long"), random = list(~ 1 | taxon_exp, ~ 1 | taxon_ctrl, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = forAIC_inv)
summary(model_inv_invasion_time_pollinationlong)#invasion_time:pollination == "long"TRUE    0.0020  0.0043   0.4539  0.6499  -0.0065  0.0104

model_inv_invasion_time_propagule_dis <- rma.mv(yi, vi, mods = ~ invasion_time * propagule_dis, random = list(~ 1 | taxon_exp, ~ 1 | taxon_ctrl, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = forAIC_inv)
summary(model_inv_invasion_time_propagule_dis)#QE(df = 16) = 614.5045, p-val < .0001; QM(df = 3) = 1.0586, p-val = 0.7871; invasion_time:propagule_dissho_dis    0.0060  0.0077   0.7818  0.4343  -0.0091   0.0212 
model_inv_invasion_time_propagule_dislon_dis <- rma.mv(yi, vi, mods = ~ invasion_time * (propagule_dis == "lon_dis"), random = list(~ 1 | taxon_exp, ~ 1 | taxon_ctrl, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = forAIC_inv)
summary(model_inv_invasion_time_propagule_dislon_dis)#invasion_time:propagule_dis == "lon_dis"TRUE   -0.0060  0.0077  -0.7818  0.4343  -0.0212  0.0091
model_inv_invasion_time_propagule_dissho_dis <- rma.mv(yi, vi, mods = ~ invasion_time * (propagule_dis == "sho_dis"), random = list(~ 1 | taxon_exp, ~ 1 | taxon_ctrl, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = forAIC_inv)
summary(model_inv_invasion_time_propagule_dissho_dis)#invasion_time:propagule_dis == "sho_dis"TRUE    0.0060  0.0077   0.7818  0.4343  -0.0091  0.0212    

model_inv_invasion_time_propagule <- rma.mv(yi, vi, mods = ~ invasion_time * propagule, random = list(~ 1 | taxon_exp, ~ 1 | taxon_ctrl, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = forAIC_inv)
summary(model_inv_invasion_time_propagule)#QE(df = 16) = 494.1534, p-val < .0001; QM(df = 3) = 1.9944, p-val = 0.5736; invasion_time:propaguleseed   -0.0053  0.0044  -1.2145  0.2245  -0.0139   0.0033
model_inv_invasion_time_propagulerhizome <- rma.mv(yi, vi, mods = ~ invasion_time * (propagule == "rhizome"), random = list(~ 1 | taxon_exp, ~ 1 | taxon_ctrl, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = forAIC_inv)
summary(model_inv_invasion_time_propagulerhizome)#NO INTERACTION
model_inv_invasion_time_propagulemultiple <- rma.mv(yi, vi, mods = ~ invasion_time * (propagule == "multiple"), random = list(~ 1 | taxon_exp, ~ 1 | taxon_ctrl, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = forAIC_inv)
summary(model_inv_invasion_time_propagulemultiple)#invasion_time:propagule == "multiple"TRUE    0.0053  0.0044   1.2145  0.2245  -0.0033  0.0139    
model_inv_invasion_time_propaguleseed <- rma.mv(yi, vi, mods = ~ invasion_time * (propagule == "seed"), random = list(~ 1 | taxon_exp, ~ 1 | taxon_ctrl, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = forAIC_inv)
summary(model_inv_invasion_time_propaguleseed)#invasion_time:propagule == "seed"TRUE   -0.0053  0.0044  -1.2145  0.2245  -0.0139   0.0033

##Separate influence of species status
model_all_pro_stu_strict <- rma.mv(yi, vi, mods = ~ pro_stu, random = list(~ 1 | taxon_exp, ~ 1 | taxon_ctrl, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = forAIC_all)
summary(model_all_pro_stu_strict)#QE(df = 61) = 3190.9748, p-val < .0001; QM(df = 1) = 1.7775, p-val = 0.1825
model_all_pro_stu_end_strict <- rma.mv(yi, vi, subset =  (pro_stu == "end"), random = list(~ 1 | taxon_exp, ~ 1 | taxon_ctrl, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = forAIC_all)
summary(model_all_pro_stu_end_strict)#-0.1140  0.1021  -1.1163  0.2643  -0.3141  0.0861
model_all_pro_stu_inv_strict <- rma.mv(yi, vi, subset =  (pro_stu == "inv"), random = list(~ 1 | taxon_exp, ~ 1 | taxon_ctrl, ~ 1 | gene_meth, ~ 1 | DNA_sou), method="ML", data = forAIC_all)
summary(model_all_pro_stu_inv_strict)#-0.8855  0.3882  -2.2812  0.0225  -1.6463  -0.1247  * 