##Preparation
library(tidyr)
library(dplyr)
library(readxl)
library(lme4)
library(lmerTest)
library(MuMIn)
options(na.action = "na.exclude")

#Endangered plants
es_endangered <- read_excel("your_path/Appendix_S1.xlsx", sheet = 1)
#Invasive plants
es_invasive <- read_excel("your_path/Appendix_S2.xlsx", sheet = 1)
#Common plants
es_common <- read_excel("your_path/Appendix_S3.xlsx", sheet = 1)
#NSS
es_NSS <- es_endangered[es_endangered$rarity == "NSS", ]


es_endangered$Na[is.na(es_endangered$Na)] <- es_endangered$Ne[is.na(es_endangered$Na)]
es_end <- es_endangered[, c("He", "FIS", "Nm", "Na")]
colnames(es_end)[colnames(es_end) == "Na"] <- "Nc"
head(es_end)
summary(es_end)

es_invasive$Na[is.na(es_invasive$Na)] <- es_invasive$Ne[is.na(es_invasive$Na)]
es_inv <- es_invasive[, c("He", "FIS", "Nm", "Na")]
colnames(es_inv)[colnames(es_inv) == "Na"] <- "Nc"
head(es_inv)
summary(es_inv)

es_common$Na[is.na(es_common$Na)] <- es_common$Ne[is.na(es_common$Na)]
es_com <- es_common[, c("He", "FIS", "Nm", "Na")]
colnames(es_com)[colnames(es_com) == "Na"] <- "Nc"
head(es_com)
summary(es_com)

es_NSS$Na[is.na(es_NSS$Na)] <- es_common$Ne[is.na(es_NSS$Na)]
es_NSS <- es_NSS[, c("He", "FIS", "Nm", "Na")]
colnames(es_NSS)[colnames(es_NSS) == "Na"] <- "Nc"
head(es_NSS)
summary(es_NSS)

###Correlation----

library(Hmisc)
es_end = as.matrix(es_end)
rcorr(es_end)
es_inv = as.matrix(es_inv)
rcorr(es_inv)
es_com = as.matrix(es_com)
rcorr(es_com)
es_NSS = as.matrix(es_NSS)
rcorr(es_NSS)

library(PerformanceAnalytics)
chart.Correlation(es_end)
chart.Correlation(es_inv)
chart.Correlation(es_com)
chart.Correlation(es_NSS)

#es_end <- as.data.frame(es_end)
#es_inv <- as.data.frame(es_inv)
#es_com <- as.data.frame(es_com)
#es_NSS <- as.data.frame(es_NSS)

#combine
es_endangered$Na[is.na(es_endangered$Na)] <- es_endangered$Ne[is.na(es_endangered$Na)]
es_end <- es_endangered[, c("He", "FIS", "Nm", "Na")]
colnames(es_end)[colnames(es_end) == "Na"] <- "Nc"
es_end_combine <- es_end
es_end_combine$type <- "endangered"
head(es_end_combine)

es_invasive$Na[is.na(es_invasive$Na)] <- es_invasive$Ne[is.na(es_invasive$Na)]
es_inv <- es_invasive[, c("He", "FIS", "Nm", "Na")]
colnames(es_inv)[colnames(es_inv) == "Na"] <- "Nc"
es_inv_combine <- es_inv
es_inv_combine$type <- "invasive"
head(es_inv_combine)

es_common$Na[is.na(es_common$Na)] <- es_common$Ne[is.na(es_common$Na)]
es_com <- es_common[, c("He", "FIS", "Nm", "Na")]
colnames(es_com)[colnames(es_com) == "Na"] <- "Nc"
es_com_combine <- es_com
es_com_combine$type <- "common"
head(es_com_combine)

combined <- rbind(es_end_combine, es_inv_combine, es_com_combine)
summary(combined)

library(GGally)
ggpairs(combined, columns = (1:4),ggplot2::aes(color = combined$type))

###Linear and quadratic regression plot----

##endangered
es_end <- as.data.frame(es_end)
#He~FIS
library(AICcmodavg)
library(smatr)
model1.1_end <- lm(He~FIS,data = es_end)
AIC(model1.1_end)#-51.2454
summary(model1.1_end)#Adjusted R-squared:  0.006827, p-value: 0.04509
model1.1_end_Nc <- lm(He~FIS+Nc,data = es_end)
AIC(model1.1_end_Nc)#-5.600609
summary(model1.1_end_Nc)#Adjusted R-squared:  0.01522,  p-value: 0.1286

model1.2_end <- lm(He~FIS+I(FIS^2),data = es_end)
AIC(model1.2_end)#-66.06028
summary(model1.2_end)#Adjusted R-squared:  0.04165,  p-value: 3.18e-05
model1.2_end_Nc <- lm(He~Nc+FIS+I(FIS^2),data = es_end)
AIC(model1.2_end_Nc)#-6.019132
summary(model1.2_end_Nc)#Adjusted R-squared:  0.0249, p-value: 0.09184

model2.1_end <- lm(FIS~He,data = es_end)
AIC(model2.1_end)#139.7908
summary(model2.1_end)#Adjusted R-squared:  0.006827, p-value: 0.04509
model2.1_end_Nc <- lm(FIS~He+Nc,data = es_end)
AIC(model2.1_end_Nc)#35.90227
summary(model2.1_end_Nc)#Adjusted R-squared:  0.01258,  p-value: 0.1547

model2.2_end <- lm(FIS~He+I(He^2),data = es_end)
AIC(model2.2_end)#141.6554
summary(model2.2_end)#Adjusted R-squared:  0.004874,  p-value: 0.1259
model2.2_end_Nc <- lm(FIS~Nc+He+I(He^2),data = es_end)
AIC(model2.2_end_Nc)#30.84767
summary(model2.2_end_Nc)#Adjusted R-squared:  0.05391, p-value: 0.01411

p1_end <- ggplot(aes(x = FIS, y = He), data = es_end) +
  geom_point(shape = 20, size = 5, alpha = 0.3, color = "gray") +
  geom_smooth(method = "lm", size = 0.7, linetype = 1, color = "#CE3D32FF", se = TRUE, fill = "#FFC0CB") +
  geom_smooth(method = "lm", size = 0.7, linetype = 1, color = "#466983FF", se = TRUE, formula = y ~ I(x^2) + x, fill = "#ADD8E6") +
  theme(panel.border = element_rect(fill = NA, color = "black", size = 1, linetype = "solid"),
        axis.text.x = element_text(size = 15, face = "bold"),
        axis.text.y = element_text(size = 15, face = "bold"),
        axis.title.x = element_text(size = 15, face = "bold"),
        axis.title.y = element_text(size = 15, face = "bold"),
        legend.position = "none") +
  xlab(label = "FIS") +
  ylab(label = "He") +
  theme(plot.margin = unit(c(0.5, 0.5, 0.5, 0.5), "cm")) +
  annotate(geom = "text", x = -Inf, y = Inf,
           label = "Quadratic: P < 0.0001, R^2 = 0.0417", hjust = -0.05, vjust = 4, size = 5, color = "#466983FF") +
  annotate(geom = "text", x = -Inf, y = Inf,
           label = "Linear: P < 0.05, R^2 = 0.0068", hjust = -0.05, vjust = 2, size = 5, color = "#CE3D32FF")
p1_end

# Compare models that include random effects with models that do not
model1.1_end_radom1 <- lmer(He ~ FIS + (1 | gene_meth), data = es_endangered)#random model
model1.1_end_radom1 <- lmer(He ~ FIS + (1 | gene_meth), data = es_endangered)#Run twice in a row to have a p value
AIC(model1.1_end_radom1)#-314.4288
summary(model1.1_end_radom1)#Estimate Std.Error  df   t.value Pr(>|t|)   -0.00839    0.02800 438.58906  -0.300   0.7646
model1.1_end_radom3 <- lmer(He ~ FIS + (1 | taxon) + (1 | gene_meth) + (1 | DNA_sou), data = es_endangered)
AIC(model1.1_end_radom3)#-688.6007
summary(model1.1_end_radom3)#Estimate Std.Error  df   t.value Pr(>|t|) 0.01444    0.02468 437.60459   0.585   0.5587
#library(MuMIn)
marginal_r2_model1.1_end_radom1 <- r.squaredGLMM(model1.1_end_radom1)
marginal_r2_model1.1_end_radom1# R2m 0.0001012223   R2c 0.5180203
marginal_r2_model1.1_end_radom3 <- r.squaredGLMM(model1.1_end_radom3)
marginal_r2_model1.1_end_radom3# R2m 0.0002961133   R2c 0.9140845

model1.2_end_radom1 <- lmer(He~FIS+I(FIS^2) + (1 | gene_meth),data = es_endangered)
AIC(model1.2_end_radom1)#-341.2202
summary(model1.2_end_radom1)#FIS 0.08261    0.03114 437.24346   2.653  0.00828 **; I(FIS^2) -0.27177    0.04640 437.27890  -5.858 9.24e-09 ***
model1.2_end_radom3 <- lmer(He ~ FIS+I(FIS^2) + (1 | taxon) + (1 | gene_meth) + (1 | DNA_sou), data = es_endangered)
AIC(model1.2_end_radom3)#-704.8349
summary(model1.2_end_radom3)#FIS 0.09036    0.02861 393.41532   3.159  0.00171 **; I(FIS^2) -0.21026    0.04300 370.59289  -4.890 1.51e-06 ***
marginal_r2_model1.2_end_radom1 <- r.squaredGLMM(model1.2_end_radom1)
marginal_r2_model1.2_end_radom1# R2m 0.03447146   R2c 0.5625354
marginal_r2_model1.2_end_radom3 <- r.squaredGLMM(model1.2_end_radom3)
marginal_r2_model1.2_end_radom3# R2m 0.02127635   R2c 0.9147777

anova(model1.1_end_radom1)#ns
anova(model1.1_end_radom3)#ns
anova(model1.2_end_radom1)#sig.**+***
anova(model1.2_end_radom3)#sig.**+***

p1_end_radom <- ggplot(aes(x = FIS, y = He), data = es_end) +
  geom_point(shape = 20, size = 5, alpha = 0.3, color = "gray") +
  geom_smooth(method = "lm", size = 0.7, linetype = 2, color = "#CE3D32FF", se = TRUE, fill = "#FFC0CB") +
  geom_smooth(method = "lm", size = 0.7, linetype = 1, color = "#466983FF", se = TRUE, formula = y ~ I(x^2) + x, fill = "#ADD8E6") +
  theme(panel.border = element_rect(fill = NA, color = "black", size = 1, linetype = "solid"),
        axis.text.x = element_text(size = 15, face = "bold"),
        axis.text.y = element_text(size = 15, face = "bold"),
        axis.title.x = element_text(size = 15, face = "bold"),
        axis.title.y = element_text(size = 15, face = "bold"),
        legend.position = "none") +
  xlab(label = "FIS") +
  ylab(label = "He") +
  theme(plot.margin = unit(c(0.5, 0.5, 0.5, 0.5), "cm")) +
  annotate(geom = "text", x = -Inf, y = Inf,
           label = "Quadratic: R^2m = 0.0213, R^2c = 0.9148, ***", hjust = -0.05, vjust = 4, size = 5, color = "#466983FF") +
  annotate(geom = "text", x = -Inf, y = Inf,
           label = "Linear: R^2m = 0.0003, R^2c = 0.9141, ns", hjust = -0.05, vjust = 2, size = 5, color = "#CE3D32FF")
p1_end_radom #Three random factors were used

#He~Nm
model3.1_end <- lm(He~Nm,data = es_end)
AIC(model3.1_end)#-136.076
summary(model3.1_end)#Adjusted R-squared:  0.01259 , p-value: 0.01767
model3.1_end_Nc <- lm(He~Nm+Nc,data = es_end)
AIC(model3.1_end_Nc)#-47.60863
summary(model3.1_end_Nc)#Adjusted R-squared:  -0.005486,  p-value: 0.5347

es_end.omit <- na.omit(es_end)
es_end.omit <- es_end.omit[es_end.omit$Nm != 0, ]
model3.1.1_end <- lm(He~log(Nm),data = es_end.omit)
AIC(model3.1.1_end)#-14.28636
summary(model3.1.1_end)#Adjusted R-squared:  0.0009225  , p-value: 0.3076
model3.1.1_end_Nc <- lm(He~log(Nm)+Nc,data = es_end.omit)
AIC(model3.1.1_end_Nc)#-17.85044
summary(model3.1.1_end_Nc)#Adjusted R-squared:  0.0691,  p-value: 0.0421

model3.2_end <- lm(He~Nm+I(Nm^2),data = es_end)
AIC(model3.2_end)#-157.6275
summary(model3.2_end)#Adjusted R-squared:  0.07127,  p-value: 5.093e-07
model3.2_end_Nc <- lm(He~Nc+Nm+I(Nm^2),data = es_end)
AIC(model3.2_end_Nc)#-52.56412
summary(model3.2_end_Nc)#Adjusted R-squared:  0.0371, p-value: 0.0455

model4.1_end <- lm(Nm~He,data = es_end)
AIC(model4.1_end)#1979.531
summary(model4.1_end)#Adjusted R-squared:  0.01259 , p-value: 0.01767
model4.1_end_Nc <- lm(Nm~He+Nc,data = es_end)
AIC(model4.1_end_Nc)#787.7825
summary(model4.1_end_Nc)#Adjusted R-squared:  -0.01097,  p-value: 0.7698

model4.2_end <- lm(Nm~He+I(He^2),data = es_end)
AIC(model4.2_end)# 1980.667
summary(model4.2_end)#Adjusted R-squared:  0.01221 ,  p-value: 0.0392
model4.2_end_Nc <- lm(Nm~Nc+He+I(He^2),data = es_end)
AIC(model4.2_end_Nc)#789.1535
summary(model4.2_end_Nc)#Adjusted R-squared:  -0.01391, p-value: 0.7688

p2_end <- ggplot(aes(x = Nm, y = He), data = es_end) +
  geom_point(shape = 20, size = 5, alpha = 0.3, color = "gray") +
  geom_smooth(method = "lm", size = 0.7, linetype = 1, color = "#CE3D32FF", se = TRUE, fill = "#FFC0CB") +
  geom_smooth(method = "lm", size = 0.7, linetype = 1, color = "#466983FF", se = TRUE, formula = y ~ I(x^2) + x, fill = "#ADD8E6") +
  theme(panel.border = element_rect(fill = NA, color = "black", size = 1, linetype = "solid"),
        axis.text.x = element_text(size = 15, face = "bold"),
        axis.text.y = element_text(size = 15, face = "bold"),
        axis.title.x = element_text(size = 15, face = "bold"),
        axis.title.y = element_text(size = 15, face = "bold"),
        legend.position = "none") +
  xlab(label = "Nm") +
  ylab(label = "He") +
  theme(plot.margin = unit(c(0.5, 0.5, 0.5, 0.5), "cm")) +
  annotate(geom = "text", x = -Inf, y = Inf,
           label = "Quadratic: P < 0.0001, R^2 = 0.0713", hjust = -0.05, vjust = 34, size = 5, color = "#466983FF") +
  annotate(geom = "text", x = -Inf, y = Inf,
           label = "Linear: P < 0.05, R^2 = 0.0126", hjust = -0.05, vjust = 32, size = 5, color = "#CE3D32FF")
p2_end

# Compare models that include random effects with models that do not
model3.1_end_radom1 <- lmer(He ~ Nm + (1 | gene_meth), data = es_endangered)#random model
model3.1_end_radom1 <- lmer(He ~ Nm + (1 | gene_meth), data = es_endangered)#Run twice in a row to have a p value
AIC(model3.1_end_radom1)#-320.7529
summary(model3.1_end_radom1)#Estimate Std.Error  df   t.value Pr(>|t|)   4.590e-03  2.208e-03 3.628e+02   2.079  0.03836 *
model3.1_end_radom3 <- lmer(He ~ Nm + (1 | taxon) + (1 | gene_meth) + (1 | DNA_sou), data = es_endangered)
AIC(model3.1_end_radom3)#-389.2563
summary(model3.1_end_radom3)#Estimate Std.Error  df   t.value Pr(>|t|) 5.126e-03  2.214e-03 3.294e+02   2.315  0.02120 *
marginal_r2_model3.1_end_radom1 <- r.squaredGLMM(model3.1_end_radom1)
marginal_r2_model3.1_end_radom1# R2m 0.007019846   R2c 0.4221466
marginal_r2_model3.1_end_radom3 <- r.squaredGLMM(model3.1_end_radom3)
marginal_r2_model3.1_end_radom3# R2m 0.008715446   R2c 0.8539576

model3.2_end_radom1 <- lmer(He~Nm+I(Nm^2) + (1 | gene_meth),data = es_endangered)
AIC(model3.2_end_radom1)#-320.3269
summary(model3.2_end_radom1)#Nm 2.540e-02  5.431e-03  3.620e+02   4.676 4.14e-06 ***; I(Nm^2) -7.176e-04  1.719e-04  3.618e+02  -4.175 3.73e-05 ***
model3.2_end_radom3 <- lmer(He ~ Nm+I(Nm^2) + (1 | taxon) + (1 | gene_meth) + (1 | DNA_sou), data = es_endangered)
AIC(model3.2_end_radom3)#-388.6149
summary(model3.2_end_radom3)#Nm 2.521e-02  5.302e-03  3.616e+02   4.755 2.87e-06 ***; I(Nm^2) -7.054e-04  1.699e-04  3.518e+02  -4.151 4.15e-05 ***
marginal_r2_model3.2_end_radom1 <- r.squaredGLMM(model3.2_end_radom1)
marginal_r2_model3.2_end_radom1# R2m 0.03545861   R2c 0.4344122
marginal_r2_model3.2_end_radom3 <- r.squaredGLMM(model3.2_end_radom3)
marginal_r2_model3.2_end_radom3# R2m 0.03490865   R2c 0.8560801

anova(model3.1_end_radom1)#sig.*
anova(model3.1_end_radom3)#sig.*
anova(model3.2_end_radom1)#sig.***+***
anova(model3.2_end_radom3)#sig.***+***

p2_end_radom <- ggplot(aes(x = Nm, y = He), data = es_end) +
  geom_point(shape = 20, size = 5, alpha = 0.3, color = "gray") +
  geom_smooth(method = "lm", size = 0.7, linetype = 1, color = "#CE3D32FF", se = TRUE, fill = "#FFC0CB") +
  geom_smooth(method = "lm", size = 0.7, linetype = 1, color = "#466983FF", se = TRUE, formula = y ~ I(x^2) + x, fill = "#ADD8E6") +
  theme(panel.border = element_rect(fill = NA, color = "black", size = 1, linetype = "solid"),
        axis.text.x = element_text(size = 15, face = "bold"),
        axis.text.y = element_text(size = 15, face = "bold"),
        axis.title.x = element_text(size = 15, face = "bold"),
        axis.title.y = element_text(size = 15, face = "bold"),
        legend.position = "none") +
  xlab(label = "Nm") +
  ylab(label = "He") +
  theme(plot.margin = unit(c(0.5, 0.5, 0.5, 0.5), "cm")) +
  annotate(geom = "text", x = -Inf, y = Inf,
           label = "Quadratic: R^2m = 0.0349, R^2c = 0.8561, ***", hjust = -0.05, vjust = 34, size = 5, color = "#466983FF") +
  annotate(geom = "text", x = -Inf, y = Inf,
           label = "Linear: R^2m = 0.0087, R^2c = 0.8540, *", hjust = -0.05, vjust = 32, size = 5, color = "#CE3D32FF")
p2_end_radom

p2_end_radom_A6 <- ggplot(aes(x = Nm, y = He), data = es_end) +
  geom_point(shape = 20, size = 5, alpha = 0.3, color = "gray") +
  geom_smooth(method = "lm", size = 0.7, linetype = 1, color = "#CE3D32FF", se = TRUE, fill = "#FFC0CB") +
  geom_smooth(method = "lm", size = 0.7, linetype = 1, color = "#466983FF", se = TRUE, formula = y ~ I(x^2) + x, fill = "#ADD8E6") +
  theme(panel.border = element_rect(fill = NA, color = "black", size = 1, linetype = "solid"),
        axis.text.x = element_text(size = 15, face = "bold"),
        axis.text.y = element_text(size = 15, face = "bold"),
        axis.title.x = element_text(size = 15, face = "bold"),
        axis.title.y = element_text(size = 15, face = "bold"),
        legend.position = "none") +
  xlab(label = "Nm") +
  ylab(label = "He") +
  theme(plot.margin = unit(c(0.5, 0.5, 0.5, 0.5), "cm")) +
  annotate(geom = "text", x = -Inf, y = Inf,
           label = "Quadratic: R^2m = 0.0349, R^2c = 0.8561, ***", hjust = -0.05, vjust = 21, size = 5, color = "#466983FF") +
  annotate(geom = "text", x = -Inf, y = Inf,
           label = "Linear: R^2m = 0.0087, R^2c = 0.8540, *", hjust = -0.05, vjust = 19, size = 5, color = "#CE3D32FF")
p2_end_radom_A6

#Outlier removal
es_endangered_Nm_noout <- es_endangered[order(-es_endangered$Nm), ]
View(es_endangered_Nm_noout)
es_endangered_Nm_noout <- es_endangered_Nm_noout[es_endangered_Nm_noout$Nm <= 20, , drop = FALSE]

model3.1_end_radom1_noout <- lmer(He ~ Nm + (1 | gene_meth), data = es_endangered_Nm_noout)#random model
model3.1_end_radom1_noout <- lmer(He ~ Nm + (1 | gene_meth), data = es_endangered_Nm_noout)#Run twice in a row to have a p value
AIC(model3.1_end_radom1_noout)#-333.9347
summary(model3.1_end_radom1_noout)#Estimate Std.Error  df   t.value Pr(>|t|)   2.610e-02  5.255e-03 3.580e+02   4.968 1.05e-06 ***
model3.1_end_radom3_noout <- lmer(He ~ Nm + (1 | taxon) + (1 | gene_meth) + (1 | DNA_sou), data = es_endangered_Nm_noout)
AIC(model3.1_end_radom3_noout)#-399.8116
summary(model3.1_end_radom3_noout)#Estimate Std.Error  df   t.value Pr(>|t|) 0.02326    0.00487 322.30940   4.776 2.72e-06 ***
marginal_r2_model3.1_end_radom1_noout <- r.squaredGLMM(model3.1_end_radom1_noout)
marginal_r2_model3.1_end_radom1_noout# R2m 0.04014872   R2c 0.4381922
marginal_r2_model3.1_end_radom3_noout <- r.squaredGLMM(model3.1_end_radom3_noout)
marginal_r2_model3.1_end_radom3_noout# R2m 0.03180915   R2c 0.8513042

model3.2_end_radom1_noout <- lmer(He~Nm+I(Nm^2) + (1 | gene_meth),data = es_endangered_Nm_noout)
AIC(model3.2_end_radom1_noout)#-325.2401
summary(model3.2_end_radom1_noout)#Nm 0.046367   0.010871 357.121040   4.265 2.56e-05 ***; I(Nm^2) -0.003139   0.001476 356.696278  -2.126   0.0342 *
model3.2_end_radom3_noout <- lmer(He ~ Nm+I(Nm^2) + (1 | taxon) + (1 | gene_meth) + (1 | DNA_sou), data = es_endangered_Nm_noout)
AIC(model3.2_end_radom3_noout)#-394.2379
summary(model3.2_end_radom3_noout)#Nm 0.045637   0.009063 313.117652   5.035 8.06e-07 ***; I(Nm^2) -0.002867   0.000979 143.636142  -2.928  0.00397 **
marginal_r2_model3.2_end_radom1_noout <- r.squaredGLMM(model3.2_end_radom1_noout)
marginal_r2_model3.2_end_radom1_noout# R2m 0.04778325    R2c 0.4446163
marginal_r2_model3.2_end_radom3_noout <- r.squaredGLMM(model3.2_end_radom3_noout)
marginal_r2_model3.2_end_radom3_noout# R2m 0.04960498    R2c 0.8592025

anova(model3.1_end_radom1_noout)#sig.***
anova(model3.1_end_radom3_noout)#sig.***
anova(model3.2_end_radom1_noout)#sig.***+*
anova(model3.2_end_radom3_noout)#sig.***+**

p2_end_radom_noout <- ggplot(aes(x = Nm, y = He), data = es_endangered_Nm_noout) +
  geom_point(shape = 20, size = 5, alpha = 0.3, color = "gray") +
  geom_smooth(method = "lm", size = 0.7, linetype = 1, color = "#CE3D32FF", se = TRUE, fill = "#FFC0CB") +
  geom_smooth(method = "lm", size = 0.7, linetype = 1, color = "#466983FF", se = TRUE, formula = y ~ I(x^2) + x, fill = "#ADD8E6") +
  theme(panel.border = element_rect(fill = NA, color = "black", size = 1, linetype = "solid"),
        axis.text.x = element_text(size = 15, face = "bold"),
        axis.text.y = element_text(size = 15, face = "bold"),
        axis.title.x = element_text(size = 15, face = "bold"),
        axis.title.y = element_text(size = 15, face = "bold"),
        legend.position = "none") +
  xlab(label = "Nm") +
  ylab(label = "He") +
  theme(plot.margin = unit(c(0.5, 0.5, 0.5, 0.5), "cm")) +
  annotate(geom = "text", x = -Inf, y = Inf,
           label = "Quadratic: R^2m = 0.0496, R^2c = 0.8592, **", hjust = -0.05, vjust = 34, size = 5, color = "#466983FF") +
  annotate(geom = "text", x = -Inf, y = Inf,
           label = "Linear: R^2m = 0.0318, R^2c = 0.8513, ***", hjust = -0.05, vjust = 32, size = 5, color = "#CE3D32FF")
p2_end_radom_noout

p2_end_radom_A6_noout <- ggplot(aes(x = Nm, y = He), data = es_endangered_Nm_noout) +
  geom_point(shape = 20, size = 5, alpha = 0.3, color = "gray") +
  geom_smooth(method = "lm", size = 0.7, linetype = 1, color = "#CE3D32FF", se = TRUE, fill = "#FFC0CB") +
  geom_smooth(method = "lm", size = 0.7, linetype = 1, color = "#466983FF", se = TRUE, formula = y ~ I(x^2) + x, fill = "#ADD8E6") +
  theme(panel.border = element_rect(fill = NA, color = "black", size = 1, linetype = "solid"),
        axis.text.x = element_text(size = 15, face = "bold"),
        axis.text.y = element_text(size = 15, face = "bold"),
        axis.title.x = element_text(size = 15, face = "bold"),
        axis.title.y = element_text(size = 15, face = "bold"),
        legend.position = "none") +
  xlab(label = "Nm") +
  ylab(label = "He") +
  theme(plot.margin = unit(c(0.5, 0.5, 0.5, 0.5), "cm")) +
  annotate(geom = "text", x = -Inf, y = Inf,
           label = "Quadratic: R^2m = 0.0496, R^2c = 0.8592, **", hjust = -0.2, vjust = 4, size = 5, color = "#466983FF") +
  annotate(geom = "text", x = -Inf, y = Inf,
           label = "Linear: R^2m = 0.0318, R^2c = 0.8513, ***", hjust = -0.25, vjust = 2, size = 5, color = "#CE3D32FF")
p2_end_radom_A6_noout

#Nm~FIS
model5.1_end <- lm(Nm~FIS,data = es_end)
AIC(model5.1_end)#896.0156
summary(model5.1_end)#Adjusted R-squared:  0.004285 , p-value: 0.201
model5.1_end_Nc <- lm(Nm~FIS+Nc,data = es_end)
AIC(model5.1_end_Nc)#414.6025
summary(model5.1_end_Nc)#Adjusted R-squared:  -0.0291,  p-value: 0.9353

model5.2_end <- lm(Nm~FIS+I(FIS^2),data = es_end)
AIC(model5.2_end)# 897.2533
summary(model5.2_end)#Adjusted R-squared:  0.002617,  p-value: 0.3047
model5.2_end_Nc <- lm(Nm~Nc+FIS+I(FIS^2),data = es_end)
AIC(model5.2_end_Nc)#415.8864
summary(model5.2_end_Nc)#Adjusted R-squared:  -0.03432, p-value: 0.8468

model6.1_end <- lm(FIS~Nm,data = es_end)
AIC(model6.1_end)#41.78017
summary(model6.1_end)#Adjusted R-squared:  0.004285 , p-value: 0.201
model6.1_end_Nc <- lm(FIS~Nm+Nc,data = es_end)
AIC(model6.1_end_Nc)#-3.854732
summary(model6.1_end_Nc)#Adjusted R-squared:  -0.01741,  p-value: 0.6489

model6.2_end <- lm(FIS~Nm+I(Nm^2),data = es_end)
AIC(model6.2_end)#39.18122
summary(model6.2_end)#Adjusted R-squared:  0.02748 ,  p-value: 0.04647
model6.2_end_Nc <- lm(FIS~Nc+Nm+I(Nm^2),data = es_end)
AIC(model6.2_end_Nc)#-6.083664
summary(model6.2_end_Nc)#Adjusted R-squared:  0.02966 , p-value: 0.1819

p3_end <- ggplot(aes(x = Nm, y = FIS), data = es_end) +
  geom_point(shape = 20, size = 5, alpha = 0.3, color = "gray") +
  geom_smooth(method = "lm", size = 0.7, linetype = 2, color = "#CE3D32FF", se = TRUE, fill = "#FFC0CB") +
  geom_smooth(method = "lm", size = 0.7, linetype = 1, color = "#466983FF", se = TRUE, formula = y ~ I(x^2) + x, fill = "#ADD8E6") +
  theme(panel.border = element_rect(fill = NA, color = "black", size = 1, linetype = "solid"),
        axis.text.x = element_text(size = 15, face = "bold"),
        axis.text.y = element_text(size = 15, face = "bold"),
        axis.title.x = element_text(size = 15, face = "bold"),
        axis.title.y = element_text(size = 15, face = "bold"),
        legend.position = "none") +
  xlab(label = "Nm") +
  ylab(label = "FIS") +
  theme(plot.margin = unit(c(0.5, 0.5, 0.5, 0.5), "cm")) +
  annotate(geom = "text", x = -Inf, y = Inf,
           label = "Quadratic: P < 0.05, R^2 = 0.0275", hjust = -0.05, vjust = 34, size = 5, color = "#466983FF") +
  annotate(geom = "text", x = -Inf, y = Inf,
           label = "Linear: P > 0.05, R^2 = 0.0043", hjust = -0.05, vjust = 32, size = 5, color = "#CE3D32FF")
p3_end

# Compare models that include random effects with models that do not
model6.1_end_radom1 <- lmer(FIS ~ Nm + (1 | gene_meth), data = es_endangered)#random model
model6.1_end_radom1 <- lmer(FIS ~ Nm + (1 | gene_meth), data = es_endangered)#Run twice in a row to have a p value
AIC(model6.1_end_radom1)#54.57811
summary(model6.1_end_radom1)#Estimate Std.Error  df   t.value Pr(>|t|)   -0.006368   0.004796 148.899150  -1.328    0.186
model6.1_end_radom3 <- lmer(FIS ~ Nm + (1 | taxon) + (1 | gene_meth) + (1 | DNA_sou), data = es_endangered)
AIC(model6.1_end_radom3)#10.71356
summary(model6.1_end_radom3)#Estimate Std.Error  df   t.value Pr(>|t|) -0.001685   0.004888 141.348073  -0.345    0.731
marginal_r2_model6.1_end_radom1 <- r.squaredGLMM(model6.1_end_radom1)
marginal_r2_model6.1_end_radom1# R2m 0.01083302   R2c 0.07228373
marginal_r2_model6.1_end_radom3 <- r.squaredGLMM(model6.1_end_radom3)
marginal_r2_model6.1_end_radom3# R2m 0.000692059   R2c 0.8722665

model6.2_end_radom1 <- lmer(FIS~Nm+I(Nm^2) + (1 | gene_meth),data = es_endangered)
AIC(model6.2_end_radom1)#66.70967
summary(model6.2_end_radom1)#Nm -3.102e-02  1.356e-02  1.486e+02  -2.288   0.0236 *; I(Nm^2) 7.565e-04  3.896e-04  1.487e+02   1.942   0.0541 .
model6.2_end_radom3 <- lmer(FIS ~ Nm+I(Nm^2) + (1 | taxon) + (1 | gene_meth) + (1 | DNA_sou), data = es_endangered)
AIC(model6.2_end_radom3)#26.66923
summary(model6.2_end_radom3)#Nm -3.146e-03  1.228e-02  1.225e+02  -0.256    0.798; I(Nm^2) 4.619e-05  3.701e-04  1.462e+02   0.125    0.901
marginal_r2_model6.2_end_radom1 <- r.squaredGLMM(model6.2_end_radom1)
marginal_r2_model6.2_end_radom1# R2m 0.03393712   R2c 0.08536447
marginal_r2_model6.2_end_radom3 <- r.squaredGLMM(model6.2_end_radom3)
marginal_r2_model6.2_end_radom3# R2m 0.0007320443   R2c 0.8704984

anova(model6.1_end_radom1)#ns
anova(model6.1_end_radom3)#ns
anova(model6.2_end_radom1)#sig.*+.
anova(model6.2_end_radom3)#ns

p3_end_radom <- ggplot(aes(x = Nm, y = FIS), data = es_end) +
  geom_point(shape = 20, size = 5, alpha = 0.3, color = "gray") +
  geom_smooth(method = "lm", size = 0.7, linetype = 2, color = "#CE3D32FF", se = TRUE, fill = "#FFC0CB") +
  geom_smooth(method = "lm", size = 0.7, linetype = 2, color = "#466983FF", se = TRUE, formula = y ~ I(x^2) + x, fill = "#ADD8E6") +
  theme(panel.border = element_rect(fill = NA, color = "black", size = 1, linetype = "solid"),
        axis.text.x = element_text(size = 15, face = "bold"),
        axis.text.y = element_text(size = 15, face = "bold"),
        axis.title.x = element_text(size = 15, face = "bold"),
        axis.title.y = element_text(size = 15, face = "bold"),
        legend.position = "none") +
  xlab(label = "Nm") +
  ylab(label = "FIS") +
  theme(plot.margin = unit(c(0.5, 0.5, 0.5, 0.5), "cm")) +
  annotate(geom = "text", x = -Inf, y = Inf,
           label = "Quadratic: R^2m = 0.0007, R^2c = 0.8705, ns", hjust = -0.05, vjust = 34, size = 5, color = "#466983FF") +
  annotate(geom = "text", x = -Inf, y = Inf,
           label = "Linear: R^2m = 0.0007, R^2c = 0.8723, ns", hjust = -0.05, vjust = 32, size = 5, color = "#CE3D32FF")
p3_end_radom

p3_end_radom_A6 <- ggplot(aes(x = Nm, y = FIS), data = es_end) +
  geom_point(shape = 20, size = 5, alpha = 0.3, color = "gray") +
  geom_smooth(method = "lm", size = 0.7, linetype = 2, color = "#CE3D32FF", se = TRUE, fill = "#FFC0CB") +
  geom_smooth(method = "lm", size = 0.7, linetype = 2, color = "#466983FF", se = TRUE, formula = y ~ I(x^2) + x, fill = "#ADD8E6") +
  theme(panel.border = element_rect(fill = NA, color = "black", size = 1, linetype = "solid"),
        axis.text.x = element_text(size = 15, face = "bold"),
        axis.text.y = element_text(size = 15, face = "bold"),
        axis.title.x = element_text(size = 15, face = "bold"),
        axis.title.y = element_text(size = 15, face = "bold"),
        legend.position = "none") +
  xlab(label = "Nm") +
  ylab(label = "FIS") +
  theme(plot.margin = unit(c(0.5, 0.5, 0.5, 0.5), "cm")) +
  annotate(geom = "text", x = -Inf, y = Inf,
           label = "Quadratic: R^2m = 0.0007, R^2c = 0.8705, ns", hjust = -0.05, vjust = 22, size = 5, color = "#466983FF") +
  annotate(geom = "text", x = -Inf, y = Inf,
           label = "Linear: R^2m = 0.0007, R^2c = 0.8723, ns", hjust = -0.05, vjust = 20, size = 5, color = "#CE3D32FF")
p3_end_radom_A6

#Outlier removal
model6.1_end_radom1_noout <- lmer(FIS ~ Nm + (1 | gene_meth), data = es_endangered_Nm_noout)#random model
model6.1_end_radom1_noout <- lmer(FIS ~ Nm + (1 | gene_meth), data = es_endangered_Nm_noout)#Run twice in a row to have a p value
AIC(model6.1_end_radom1_noout)#50.99035
summary(model6.1_end_radom1_noout)#Estimate Std.Error  df   t.value Pr(>|t|)   -0.02611    0.01322 146.32916  -1.974   0.0502 .
model6.1_end_radom3_noout <- lmer(FIS ~ Nm + (1 | taxon) + (1 | gene_meth) + (1 | DNA_sou), data = es_endangered_Nm_noout)
AIC(model6.1_end_radom3_noout)#9.333762
summary(model6.1_end_radom3_noout)#Estimate Std.Error  df   t.value Pr(>|t|) 0.002149   0.010006 71.568333   0.215    0.831
marginal_r2_model6.1_end_radom1_noout <- r.squaredGLMM(model6.1_end_radom1_noout)
marginal_r2_model6.1_end_radom1_noout# R2m 0.0244042    R2c 0.07593659
marginal_r2_model6.1_end_radom3_noout <- r.squaredGLMM(model6.1_end_radom3_noout)
marginal_r2_model6.1_end_radom3_noout# R2m 0.0001505175    R2c 0.8717114

model6.2_end_radom1_noout <- lmer(FIS~Nm+I(Nm^2) + (1 | gene_meth),data = es_endangered_Nm_noout)
AIC(model6.2_end_radom1_noout)#62.31069
summary(model6.2_end_radom1_noout)#Nm -0.039812   0.026435 145.649227  -1.506   0.1342; I(Nm^2) 0.001892   0.003158 145.444881   0.599   0.5500
model6.2_end_radom3_noout <- lmer(FIS ~ Nm+I(Nm^2) + (1 | taxon) + (1 | gene_meth) + (1 | DNA_sou), data = es_endangered_Nm_noout)
AIC(model6.2_end_radom3_noout)#22.11057
summary(model6.2_end_radom3_noout)#Nm 5.678e-03  2.137e-02  1.141e+02   0.266    0.791; I(Nm^2) -3.349e-04  1.795e-03  6.632e+01  -0.187    0.853
marginal_r2_model6.2_end_radom1_noout <- r.squaredGLMM(model6.2_end_radom1_noout)
marginal_r2_model6.2_end_radom1_noout# R2m 0.02648218   R2c 0.07849257
marginal_r2_model6.2_end_radom3_noout <- r.squaredGLMM(model6.2_end_radom3_noout)
marginal_r2_model6.2_end_radom3_noout# R2m 0.0004065718    R2c 0.8716441

anova(model6.1_end_radom1_noout)#ns
anova(model6.1_end_radom3_noout)#ns
anova(model6.2_end_radom1_noout)#ns
anova(model6.2_end_radom3_noout)#ns

p3_end_radom_noout <- ggplot(aes(x = Nm, y = FIS), data = es_endangered_Nm_noout) +
  geom_point(shape = 20, size = 5, alpha = 0.3, color = "gray") +
  geom_smooth(method = "lm", size = 0.7, linetype = 2, color = "#CE3D32FF", se = TRUE, fill = "#FFC0CB") +
  geom_smooth(method = "lm", size = 0.7, linetype = 2, color = "#466983FF", se = TRUE, formula = y ~ I(x^2) + x, fill = "#ADD8E6") +
  theme(panel.border = element_rect(fill = NA, color = "black", size = 1, linetype = "solid"),
        axis.text.x = element_text(size = 15, face = "bold"),
        axis.text.y = element_text(size = 15, face = "bold"),
        axis.title.x = element_text(size = 15, face = "bold"),
        axis.title.y = element_text(size = 15, face = "bold"),
        legend.position = "none") +
  xlab(label = "Nm") +
  ylab(label = "FIS") +
  theme(plot.margin = unit(c(0.5, 0.5, 0.5, 0.5), "cm")) +
  annotate(geom = "text", x = -Inf, y = Inf,
           label = "Quadratic: R^2m = 0.0004, R^2c = 0.8716, ns", hjust = -0.05, vjust = 34, size = 5, color = "#466983FF") +
  annotate(geom = "text", x = -Inf, y = Inf,
           label = "Linear: R^2m = 0.0002, R^2c = 0.8717, ns", hjust = -0.05, vjust = 32, size = 5, color = "#CE3D32FF")
p3_end_radom_noout

p3_end_radom_A6_noout <- ggplot(aes(x = Nm, y = FIS), data = es_endangered_Nm_noout) +
  geom_point(shape = 20, size = 5, alpha = 0.3, color = "gray") +
  geom_smooth(method = "lm", size = 0.7, linetype = 2, color = "#CE3D32FF", se = TRUE, fill = "#FFC0CB") +
  geom_smooth(method = "lm", size = 0.7, linetype = 2, color = "#466983FF", se = TRUE, formula = y ~ I(x^2) + x, fill = "#ADD8E6") +
  theme(panel.border = element_rect(fill = NA, color = "black", size = 1, linetype = "solid"),
        axis.text.x = element_text(size = 15, face = "bold"),
        axis.text.y = element_text(size = 15, face = "bold"),
        axis.title.x = element_text(size = 15, face = "bold"),
        axis.title.y = element_text(size = 15, face = "bold"),
        legend.position = "none") +
  xlab(label = "Nm") +
  ylab(label = "FIS") +
  theme(plot.margin = unit(c(0.5, 0.5, 0.5, 0.5), "cm")) +
  annotate(geom = "text", x = -Inf, y = Inf,
           label = "Quadratic: R^2m = 0.0004, R^2c = 0.8716, ns", hjust = -0.05, vjust = 22, size = 5, color = "#466983FF") +
  annotate(geom = "text", x = -Inf, y = Inf,
           label = "Linear: R^2m = 0.0002, R^2c = 0.8717, ns", hjust = -0.05, vjust = 20, size = 5, color = "#CE3D32FF")
p3_end_radom_A6_noout

##common
es_com <- as.data.frame(es_com)
#He~FIS
model1.1_com <- lm(He~FIS,data = es_com)
AIC(model1.1_com)#0.5506028
summary(model1.1_com)#Adjusted R-squared:  0.05224 , p-value: 0.0299
model1.1_com_Nc <- lm(He~FIS+Nc,data = es_com)
AIC(model1.1_com_Nc)#0.06337556
summary(model1.1_com_Nc)#Adjusted R-squared:  0.07668 ,  p-value: 0.3321

model1.2_com <- lm(He~FIS+I(FIS^2),data = es_com)
AIC(model1.2_com)#2.535273
summary(model1.2_com)#Adjusted R-squared:  0.03871 ,  p-value: 0.09559
model1.2_com_Nc <- lm(He~Nc+FIS+I(FIS^2),data = es_com)
AIC(model1.2_com_Nc)#0.5079733
summary(model1.2_com_Nc)#Adjusted R-squared:  0.06787 , p-value: 0.4011

model2.1_com <- lm(FIS~He,data = es_com)
AIC(model2.1_com)#25.0923
summary(model2.1_com)#Adjusted R-squared:  0.05224 , p-value: 0.0299
model2.1_com_Nc <- lm(FIS~He+Nc,data = es_com)
AIC(model2.1_com_Nc)#3.175269
summary(model2.1_com_Nc)#Adjusted R-squared:  0.03345 ,  p-value: 0.3809

model2.2_com <- lm(FIS~He+I(He^2),data = es_com)
AIC(model2.2_com)#26.18392
summary(model2.2_com)#Adjusted R-squared:  0.05056 ,  p-value: 0.06231
model2.2_com_Nc <- lm(FIS~Nc+He+I(He^2),data = es_com)
AIC(model2.2_com_Nc)#4.806504
summary(model2.2_com_Nc)#Adjusted R-squared:  -0.1133 , p-value: 0.5775

p1_com <- ggplot(aes(x = FIS, y = He), data = es_com) +
  geom_point(shape = 20, size = 5, alpha = 0.3, color = "#808080") +
  geom_smooth(method = "lm", size = 0.7, linetype = 1, color = "#CE3D32FF", se = TRUE, fill = "#FFC0CB") +
  geom_smooth(method = "lm", size = 0.7, linetype = 2, color = "#466983FF", se = TRUE, formula = y ~ I(x^2) + x, fill = "#ADD8E6") +
  theme(panel.border = element_rect(fill = NA, color = "black", size = 1, linetype = "solid"),
        axis.text.x = element_text(size = 15, face = "bold"),
        axis.text.y = element_text(size = 15, face = "bold"),
        axis.title.x = element_text(size = 15, face = "bold"),
        axis.title.y = element_text(size = 15, face = "bold"),
        legend.position = "none") +
  xlab(label = "FIS") +
  ylab(label = "He") +
  theme(plot.margin = unit(c(0.5, 0.5, 0.5, 0.5), "cm")) +
  annotate(geom = "text", x = -Inf, y = Inf,
           label = "Quadratic: P > 0.05, R^2 = 0.0387", hjust = -0.05, vjust = 4, size = 5, color = "#466983FF") +
  annotate(geom = "text", x = -Inf, y = Inf,
           label = "Linear: P < 0.05, R^2 = 0.0522", hjust = -0.05, vjust = 2, size = 5, color = "#CE3D32FF")
p1_com

# Compare models that include random effects with models that do not
es_com <- cbind(es_com, es_common[, c("taxon", "gene_meth", "DNA_sou")])

model1.1_com_radom3 <- lmer(He ~ FIS + (1 | taxon) + (1 | gene_meth) + (1 | DNA_sou), data = es_com)
AIC(model1.1_com_radom3)#-11.99697
summary(model1.1_com_radom3)#Estimate Std.Error  df   t.value Pr(>|t|) 0.18786    0.08875 53.18042   2.117   0.0390 *
marginal_r2_model1.1_com_radom3 <- r.squaredGLMM(model1.1_com_radom3)
marginal_r2_model1.1_com_radom3# R2m 0.03916509   R2c 0.6355164

model1.2_com_radom3 <- lmer(He ~ FIS +I(FIS^2) + (1 | taxon) + (1 | gene_meth) + (1 | DNA_sou), data = es_com)
AIC(model1.2_com_radom3)#-8.982795
summary(model1.2_com_radom3)#FIS 0.22498    0.09508 49.62136   2.366   0.0219 *; I(FIS^2) -0.14535    0.13421 48.87222  -1.083   0.2841
marginal_r2_model1.2_com_radom3 <- r.squaredGLMM(model1.2_com_radom3)
marginal_r2_model1.2_com_radom3# R2m 0.04951508   R2c 0.6539379

p1_com_radom <- ggplot(aes(x = FIS, y = He), data = es_com) +
  geom_point(shape = 20, size = 5, alpha = 0.3, color = "#808080") +
  geom_smooth(method = "lm", size = 0.7, linetype = 1, color = "#CE3D32FF", se = TRUE, fill = "#FFC0CB") +
  geom_smooth(method = "lm", size = 0.7, linetype = 2, color = "#466983FF", se = TRUE, formula = y ~ I(x^2) + x, fill = "#ADD8E6") +
  theme(panel.border = element_rect(fill = NA, color = "black", size = 1, linetype = "solid"),
        axis.text.x = element_text(size = 15, face = "bold"),
        axis.text.y = element_text(size = 15, face = "bold"),
        axis.title.x = element_text(size = 15, face = "bold"),
        axis.title.y = element_text(size = 15, face = "bold"),
        legend.position = "none") +
  xlab(label = "FIS") +
  ylab(label = "He") +
  theme(plot.margin = unit(c(0.5, 0.5, 0.5, 0.5), "cm")) +
  annotate(geom = "text", x = -Inf, y = Inf,
           label = "Quadratic: R^2m = 0.0495, R^2c = 0.6539, ns", hjust = -0.05, vjust = 4, size = 5, color = "#466983FF") +
  annotate(geom = "text", x = -Inf, y = Inf,
           label = "Linear: R^2m = 0.0392, R^2c = 0.6355, *", hjust = -0.05, vjust = 2, size = 5, color = "#CE3D32FF")
p1_com_radom

p1_com_radom_A6 <- ggplot(aes(x = FIS, y = He), data = es_com) +
  geom_point(shape = 20, size = 5, alpha = 0.3, color = "#808080") +
  geom_smooth(method = "lm", size = 0.7, linetype = 1, color = "#CE3D32FF", se = TRUE, fill = "#FFC0CB") +
  geom_smooth(method = "lm", size = 0.7, linetype = 2, color = "#466983FF", se = TRUE, formula = y ~ I(x^2) + x, fill = "#ADD8E6") +
  theme(panel.border = element_rect(fill = NA, color = "black", size = 1, linetype = "solid"),
        axis.text.x = element_text(size = 15, face = "bold"),
        axis.text.y = element_text(size = 15, face = "bold"),
        axis.title.x = element_text(size = 15, face = "bold"),
        axis.title.y = element_text(size = 15, face = "bold"),
        legend.position = "none") +
  xlab(label = "FIS") +
  ylab(label = "He") +
  theme(plot.margin = unit(c(0.5, 0.5, 0.5, 0.5), "cm")) +
  annotate(geom = "text", x = -Inf, y = Inf,
           label = "Quadratic: R^2m = 0.0495, R^2c = 0.6539, ns", hjust = -0.05, vjust = 22, size = 5, color = "#466983FF") +
  annotate(geom = "text", x = -Inf, y = Inf,
           label = "Linear: R^2m = 0.0392, R^2c = 0.6355, *", hjust = -0.05, vjust = 20, size = 5, color = "#CE3D32FF")
p1_com_radom_A6

#He~Nm
model3.1_com <- lm(He~Nm,data = es_com)
AIC(model3.1_com)#-9.63141
summary(model3.1_com)#Adjusted R-squared:  0.1037  , p-value: 0.05266
model3.1_com_Nc <- lm(He~Nm+Nc,data = es_com)
AIC(model3.1_com_Nc)#4.942326
summary(model3.1_com_Nc)#Adjusted R-squared: -0.4684,  p-value: 0.9583

es_com.omit <- na.omit(es_com)
es_com.omit <- es_com.omit[es_com.omit$Nm != 0, ]
model3.1.1_com <- lm(He~log(Nm),data = es_com.omit)
AIC(model3.1.1_com)#5.358434
summary(model3.1.1_com)#Adjusted R-squared:  -0.2889  , p-value: 0.7688
model3.1.1_com_Nc <- lm(He~log(Nm)+Nc,data = es_com.omit)
AIC(model3.1.1_com_Nc)#7.327659
summary(model3.1.1_com_Nc)#Adjusted R-squared:  -0.9214,  p-value: 0.9607

model3.2_com <- lm(He~Nm+I(Nm^2),data = es_com)
AIC(model3.2_com)#-7.662356
summary(model3.2_com)#Adjusted R-squared:  0.06884,  p-value: 0.1567
model3.2_com_Nc <- lm(He~Nc+Nm+I(Nm^2),data = es_com)
AIC(model3.2_com_Nc)#4.987618
summary(model3.2_com_Nc)#Adjusted R-squared:  -0.4808, p-value: 0.7939

model4.1_com <- lm(Nm~He,data = es_com)
AIC(model4.1_com)#125.4727
summary(model4.1_com)#Adjusted R-squared:  0.1037  , p-value: 0.05266
model4.1_com_Nc <- lm(Nm~He+Nc,data = es_com)
AIC(model4.1_com_Nc)#34.09074
summary(model4.1_com_Nc)#Adjusted R-squared:  -0.2926 ,  p-value: 0.7426

model4.2_com <- lm(Nm~He+I(He^2),data = es_com)
AIC(model4.2_com)# 126.9378
summary(model4.2_com)#Adjusted R-squared:  0.08545 ,  p-value: 0.1251
model4.2_com_Nc <- lm(Nm~Nc+He+I(He^2),data = es_com)
AIC(model4.2_com_Nc)#21.70955
summary(model4.2_com_Nc)#Adjusted R-squared:  0.7791 , p-value: 0.0602

p2_com <- ggplot(aes(x = Nm, y = He), data = es_com) +
  geom_point(shape = 20, size = 5, alpha = 0.3, color = "#808080") +
  geom_smooth(method = "lm", size = 0.7, linetype = 2, color = "#CE3D32FF", se = TRUE, fill = "#FFC0CB") +
  geom_smooth(method = "lm", size = 0.7, linetype = 2, color = "#466983FF", se = TRUE, formula = y ~ I(x^2) + x, fill = "#ADD8E6") +
  theme(panel.border = element_rect(fill = NA, color = "black", size = 1, linetype = "solid"),
        axis.text.x = element_text(size = 15, face = "bold"),
        axis.text.y = element_text(size = 15, face = "bold"),
        axis.title.x = element_text(size = 15, face = "bold"),
        axis.title.y = element_text(size = 15, face = "bold"),
        legend.position = "none") +
  xlab(label = "Nm") +
  ylab(label = "He") +
  theme(plot.margin = unit(c(0.5, 0.5, 0.5, 0.5), "cm")) +
  annotate(geom = "text", x = -Inf, y = Inf,
           label = "Quadratic: P > 0.05, R^2 = 0.0688", hjust = -0.05, vjust = 4, size = 5, color = "#466983FF") +
  annotate(geom = "text", x = -Inf, y = Inf,
           label = "Linear: P > 0.05, R^2 = 0.1037", hjust = -0.05, vjust = 2, size = 5, color = "#CE3D32FF")
p2_com

# Compare models that include random effects with models that do not
model3.1_com_radom3 <- lmer(He ~ Nm + (1 | taxon) + (1 | gene_meth) + (1 | DNA_sou), data = es_com)
AIC(model3.1_com_radom3)#-13.92722
summary(model3.1_com_radom3)#Estimate Std.Error  df   t.value Pr(>|t|) 0.02829    0.01561 23.31742   1.812   0.0829 .
marginal_r2_model3.1_com_radom3 <- r.squaredGLMM(model3.1_com_radom3)
marginal_r2_model3.1_com_radom3# R2m 0.05993592   R2c 0.9522152

model3.2_com_radom3 <- lmer(He ~ Nm +I(Nm^2) + (1 | taxon) + (1 | gene_meth) + (1 | DNA_sou), data = es_com)
AIC(model3.2_com_radom3)#-2.922405
summary(model3.2_com_radom3)#Nm 0.046833   0.038020 22.139339   1.232    0.231; I(Nm^2) -0.002065   0.003933 17.234405  -0.525    0.606
marginal_r2_model3.2_com_radom3 <- r.squaredGLMM(model3.2_com_radom3)
marginal_r2_model3.2_com_radom3# R2m 0.07491477   R2c 0.9504172

p2_com_radom <- ggplot(aes(x = Nm, y = He), data = es_com) +
  geom_point(shape = 20, size = 5, alpha = 0.3, color = "#808080") +
  geom_smooth(method = "lm", size = 0.7, linetype = 2, color = "#CE3D32FF", se = TRUE, fill = "#FFC0CB") +
  geom_smooth(method = "lm", size = 0.7, linetype = 2, color = "#466983FF", se = TRUE, formula = y ~ I(x^2) + x, fill = "#ADD8E6") +
  theme(panel.border = element_rect(fill = NA, color = "black", size = 1, linetype = "solid"),
        axis.text.x = element_text(size = 15, face = "bold"),
        axis.text.y = element_text(size = 15, face = "bold"),
        axis.title.x = element_text(size = 15, face = "bold"),
        axis.title.y = element_text(size = 15, face = "bold"),
        legend.position = "none") +
  xlab(label = "Nm") +
  ylab(label = "He") +
  theme(plot.margin = unit(c(0.5, 0.5, 0.5, 0.5), "cm")) +
  annotate(geom = "text", x = -Inf, y = Inf,
           label = "Quadratic: R^2m = 0.0749, R^2c = 0.9504, ns", hjust = -0.05, vjust = 4, size = 5, color = "#466983FF") +
  annotate(geom = "text", x = -Inf, y = Inf,
           label = "Linear: R^2m = 0.0599, R^2c = 0.9522, ns", hjust = -0.05, vjust = 2, size = 5, color = "#CE3D32FF")
p2_com_radom

p2_com_radom_A6 <- ggplot(aes(x = Nm, y = He), data = es_com) +
  geom_point(shape = 20, size = 5, alpha = 0.3, color = "#808080") +
  geom_smooth(method = "lm", size = 0.7, linetype = 2, color = "#CE3D32FF", se = TRUE, fill = "#FFC0CB") +
  geom_smooth(method = "lm", size = 0.7, linetype = 2, color = "#466983FF", se = TRUE, formula = y ~ I(x^2) + x, fill = "#ADD8E6") +
  theme(panel.border = element_rect(fill = NA, color = "black", size = 1, linetype = "solid"),
        axis.text.x = element_text(size = 15, face = "bold"),
        axis.text.y = element_text(size = 15, face = "bold"),
        axis.title.x = element_text(size = 15, face = "bold"),
        axis.title.y = element_text(size = 15, face = "bold"),
        legend.position = "none") +
  xlab(label = "Nm") +
  ylab(label = "He") +
  theme(plot.margin = unit(c(0.5, 0.5, 0.5, 0.5), "cm")) +
  annotate(geom = "text", x = -Inf, y = Inf,
           label = "Quadratic: R^2m = 0.0749, R^2c = 0.9504, ns", hjust = -0.05, vjust = 22, size = 5, color = "#466983FF") +
  annotate(geom = "text", x = -Inf, y = Inf,
           label = "Linear: R^2m = 0.0599, R^2c = 0.9522, ns", hjust = -0.05, vjust = 20, size = 5, color = "#CE3D32FF")
p2_com_radom_A6

#Nm~FIS
model5.1_com <- lm(Nm~FIS,data = es_com)
AIC(model5.1_com)#116.0523
summary(model5.1_com)#Adjusted R-squared:  -0.02599 , p-value: 0.5374
model5.1_com_Nc <- lm(Nm~FIS+Nc,data = es_com)
AIC(model5.1_com_Nc)#21.72405
summary(model5.1_com_Nc)#Adjusted R-squared:  0.1486 ,  p-value: 0.4257

model5.2_com <- lm(Nm~FIS+I(FIS^2),data = es_com)
AIC(model5.2_com)# 116.5625
summary(model5.2_com)#Adjusted R-squared:  -0.01057,  p-value: 0.4311
model5.2_com_Nc <- lm(Nm~Nc+FIS+I(FIS^2),data = es_com)
AIC(model5.2_com_Nc)#21.92485
summary(model5.2_com_Nc)#Adjusted R-squared:  -0.1882 , p-value: 0.6579

model6.1_com <- lm(FIS~Nm,data = es_com)
AIC(model6.1_com)#5.146017
summary(model6.1_com)#Adjusted R-squared:  -0.02599 , p-value: 0.5374
model6.1_com_Nc <- lm(FIS~Nm+Nc,data = es_com)
AIC(model6.1_com_Nc)#1.265666
summary(model6.1_com_Nc)#Adjusted R-squared:  0.3168 ,  p-value: 0.3416

model6.2_com <- lm(FIS~Nm+I(Nm^2),data = es_com)
AIC(model6.2_com)#6.950482
summary(model6.2_com)#Adjusted R-squared:  -0.06427 ,  p-value: 0.7619
model6.2_com_Nc <- lm(FIS~Nc+Nm+I(Nm^2),data = es_com)
AIC(model6.2_com_Nc)#1.837045
summary(model6.2_com_Nc)#Adjusted R-squared:  -0.02677 , p-value: 0.6163

p3_com <- ggplot(aes(x = Nm, y = FIS), data = es_com) +
  geom_point(shape = 20, size = 5, alpha = 0.3, color = "#808080") +
  geom_smooth(method = "lm", size = 0.7, linetype = 2, color = "#CE3D32FF", se = TRUE, fill = "#FFC0CB") +
  geom_smooth(method = "lm", size = 0.7, linetype = 2, color = "#466983FF", se = TRUE, formula = y ~ I(x^2) + x, fill = "#ADD8E6") +
  theme(panel.border = element_rect(fill = NA, color = "black", size = 1, linetype = "solid"),
        axis.text.x = element_text(size = 15, face = "bold"),
        axis.text.y = element_text(size = 15, face = "bold"),
        axis.title.x = element_text(size = 15, face = "bold"),
        axis.title.y = element_text(size = 15, face = "bold"),
        legend.position = "none") +
  xlab(label = "Nm") +
  ylab(label = "FIS") +
  theme(plot.margin = unit(c(0.5, 0.5, 0.5, 0.5), "cm")) +
  annotate(geom = "text", x = -Inf, y = Inf,
           label = "Quadratic: P > 0.05, R^2 = -0.0643", hjust = -0.05, vjust = 34, size = 5, color = "#466983FF") +
  annotate(geom = "text", x = -Inf, y = Inf,
           label = "Linear: P > 0.05, R^2 = -0.0260", hjust = -0.05, vjust = 32, size = 5, color = "#CE3D32FF")
p3_com

# Compare models that include random effects with models that do not
model6.1_com_radom3 <- lmer(FIS ~ Nm + (1 | taxon) + (1 | gene_meth) + (1 | DNA_sou), data = es_com)
AIC(model6.1_com_radom3)#3.479969
summary(model6.1_com_radom3)#Estimate Std.Error  df   t.value Pr(>|t|) 0.02658    0.02191 16.19185   1.213    0.242
marginal_r2_model6.1_com_radom3 <- r.squaredGLMM(model6.1_com_radom3)
marginal_r2_model6.1_com_radom3# R2m 0.04358122    R2c 0.9468642

model6.2_com_radom3 <- lmer(FIS ~ Nm+I(Nm^2) + (1 | taxon) + (1 | gene_meth) + (1 | DNA_sou), data = es_com)
AIC(model6.2_com_radom3)#13.84216
summary(model6.2_com_radom3)#Nm 0.047360   0.065701 21.870609   0.721    0.479; I(Nm^2) -0.001913   0.005875 18.693800  -0.326    0.748
marginal_r2_model6.2_com_radom3 <- r.squaredGLMM(model6.2_com_radom3)
marginal_r2_model6.2_com_radom3# R2m 0.06260702    R2c 0.9513029

p3_com_radom <- ggplot(aes(x = Nm, y = FIS), data = es_com) +
  geom_point(shape = 20, size = 5, alpha = 0.3, color = "#808080") +
  geom_smooth(method = "lm", size = 0.7, linetype = 2, color = "#CE3D32FF", se = TRUE, fill = "#FFC0CB") +
  geom_smooth(method = "lm", size = 0.7, linetype = 2, color = "#466983FF", se = TRUE, formula = y ~ I(x^2) + x, fill = "#ADD8E6") +
  theme(panel.border = element_rect(fill = NA, color = "black", size = 1, linetype = "solid"),
        axis.text.x = element_text(size = 15, face = "bold"),
        axis.text.y = element_text(size = 15, face = "bold"),
        axis.title.x = element_text(size = 15, face = "bold"),
        axis.title.y = element_text(size = 15, face = "bold"),
        legend.position = "none") +
  xlab(label = "Nm") +
  ylab(label = "FIS") +
  theme(plot.margin = unit(c(0.5, 0.5, 0.5, 0.5), "cm")) +
  annotate(geom = "text", x = -Inf, y = Inf,
           label = "Quadratic: R^2m = 0.0626, R^2c = 0.9513, ns", hjust = -0.05, vjust = 22, size = 5, color = "#466983FF") +
  annotate(geom = "text", x = -Inf, y = Inf,
           label = "Linear: R^2m = 0.0436, R^2c = 0.9469, ns", hjust = -0.05, vjust = 20, size = 5, color = "#CE3D32FF")
p3_com_radom

##invasive
es_inv <- as.data.frame(es_inv)
#He~FIS
model1.1_inv <- lm(He~FIS,data = es_inv)
AIC(model1.1_inv)#-55.2899
summary(model1.1_inv)#Adjusted R-squared:  0.01462 , p-value: 0.09451
model1.1_inv_Nc <- lm(He~FIS+Nc,data = es_inv)
AIC(model1.1_inv_Nc)#1.963935
summary(model1.1_inv_Nc)#Adjusted R-squared:  -0.346 ,  p-value: 0.8052

model1.2_inv <- lm(He~FIS+I(FIS^2),data = es_inv)
AIC(model1.2_inv)#-54.62203
summary(model1.2_inv)#Adjusted R-squared:  0.01707 ,  p-value: 0.1297
model1.2_inv_Nc <- lm(He~Nc+FIS+I(FIS^2),data = es_inv)
AIC(model1.2_inv_Nc)#3.769968
summary(model1.2_inv_Nc)#Adjusted R-squared:  -0.7456 , p-value: 0.926

model2.1_inv <- lm(FIS~He,data = es_inv)
AIC(model2.1_inv)#83.3608
summary(model2.1_inv)#Adjusted R-squared:  0.01462 , p-value: 0.09451
model2.1_inv_Nc <- lm(FIS~He+Nc,data = es_inv)
AIC(model2.1_inv_Nc)#5.802065
summary(model2.1_inv_Nc)#Adjusted R-squared:  0.07692 ,  p-value: 0.3787

model2.2_inv <- lm(FIS~He+I(He^2),data = es_inv)
AIC(model2.2_inv)#77.78908
summary(model2.2_inv)#Adjusted R-squared:  0.06493 ,  p-value: 0.006175
model2.2_inv_Nc <- lm(FIS~Nc+He+I(He^2),data = es_inv)
AIC(model2.2_inv_Nc)#-8.903216
summary(model2.2_inv_Nc)#Adjusted R-squared:  0.8868 , p-value: 0.02246

p1_inv <- ggplot(aes(x = He, y = FIS), data = es_inv) +
  geom_point(shape = 20, size = 5, alpha = 0.3, color = "black") +
  geom_smooth(method = "lm", size = 0.7, linetype = 2, color = "#CE3D32FF", se = TRUE, fill = "#FFC0CB") +
  geom_smooth(method = "lm", size = 0.7, linetype = 1, color = "#466983FF", se = TRUE, formula = y ~ I(x^2) + x, fill = "#ADD8E6") +
  theme(panel.border = element_rect(fill = NA, color = "black", size = 1, linetype = "solid"),
        axis.text.x = element_text(size = 15, face = "bold"),
        axis.text.y = element_text(size = 15, face = "bold"),
        axis.title.x = element_text(size = 15, face = "bold"),
        axis.title.y = element_text(size = 15, face = "bold"),
        legend.position = "none") +
  xlab(label = "He") +
  ylab(label = "FIS") +
  theme(plot.margin = unit(c(0.5, 0.5, 0.5, 0.5), "cm")) +
  annotate(geom = "text", x = -Inf, y = Inf,
           label = "Quadratic: P < 0.01, R^2 = 0.0649", hjust = -1.25, vjust = 32, size = 5, color = "#466983FF") +
  annotate(geom = "text", x = -Inf, y = Inf,
           label = "Linear: P > 0.05, R^2 = 0.0146", hjust = -1.5, vjust = 30, size = 5, color = "#CE3D32FF")
p1_inv

# Compare models that include random effects with models that do not
es_inv <- cbind(es_inv, es_invasive[, c("taxon", "gene_meth", "DNA_sou")])

model1.1_inv_radom3 <- lmer(He ~ FIS + (1 | taxon) + (1 | gene_meth) + (1 | DNA_sou), data = es_inv)
AIC(model1.1_inv_radom3)#-108.6
summary(model1.1_inv_radom3)#Estimate Std.Error  df   t.value Pr(>|t|) 0.12236    0.04877 122.48776   2.509   0.0134 *
marginal_r2_model1.1_inv_radom3 <- r.squaredGLMM(model1.1_inv_radom3)
marginal_r2_model1.1_inv_radom3# R2m 0.02159684    R2c 0.8430453

model1.2_inv_radom3 <- lmer(He ~ FIS +I(FIS^2) + (1 | taxon) + (1 | gene_meth) + (1 | DNA_sou), data = es_inv)
AIC(model1.2_inv_radom3)#-104.2915
summary(model1.2_inv_radom3)#FIS 0.12244    0.04887 121.48550   2.505   0.0136 *; I(FIS^2) -0.07778    0.07712 116.12616  -1.009   0.3153
marginal_r2_model1.2_inv_radom3 <- r.squaredGLMM(model1.2_inv_radom3)
marginal_r2_model1.2_inv_radom3# R2m 0.01886482    R2c 0.8269276

p1_inv_radom <- ggplot(aes(x = FIS, y = He), data = es_inv) +
  geom_point(shape = 20, size = 5, alpha = 0.3, color = "black") +
  geom_smooth(method = "lm", size = 0.7, linetype = 1, color = "#CE3D32FF", se = TRUE, fill = "#FFC0CB") +
  geom_smooth(method = "lm", size = 0.7, linetype = 2, color = "#466983FF", se = TRUE, formula = y ~ I(x^2) + x, fill = "#ADD8E6") +
  theme(panel.border = element_rect(fill = NA, color = "black", size = 1, linetype = "solid"),
        axis.text.x = element_text(size = 15, face = "bold"),
        axis.text.y = element_text(size = 15, face = "bold"),
        axis.title.x = element_text(size = 15, face = "bold"),
        axis.title.y = element_text(size = 15, face = "bold"),
        legend.position = "none") +
  xlab(label = "FIS") +
  ylab(label = "He") +
  theme(plot.margin = unit(c(0.5, 0.5, 0.5, 0.5), "cm")) +
  annotate(geom = "text", x = -Inf, y = Inf,
           label = "Quadratic: R^2m = 0.0189, R^2c = 0.8269, ns", hjust = -1.25, vjust = 32, size = 5, color = "#466983FF") +
  annotate(geom = "text", x = -Inf, y = Inf,
           label = "Linear: R^2m = 0.0216, R^2c = 0.8430, *", hjust = -1.5, vjust = 30, size = 5, color = "#CE3D32FF")
p1_inv_radom

p1_inv_radom_A6 <- ggplot(aes(x = FIS , y = He), data = es_inv) +
  geom_point(shape = 20, size = 5, alpha = 0.3, color = "black") +
  geom_smooth(method = "lm", size = 0.7, linetype = 1, color = "#CE3D32FF", se = TRUE, fill = "#FFC0CB") +
  geom_smooth(method = "lm", size = 0.7, linetype = 2, color = "#466983FF", se = TRUE, formula = y ~ I(x^2) + x, fill = "#ADD8E6") +
  theme(panel.border = element_rect(fill = NA, color = "black", size = 1, linetype = "solid"),
        axis.text.x = element_text(size = 15, face = "bold"),
        axis.text.y = element_text(size = 15, face = "bold"),
        axis.title.x = element_text(size = 15, face = "bold"),
        axis.title.y = element_text(size = 15, face = "bold"),
        legend.position = "none") +
  xlab(label = "FIS") +
  ylab(label = "He") +
  theme(plot.margin = unit(c(0.5, 0.5, 0.5, 0.5), "cm")) +
  annotate(geom = "text", x = -Inf, y = Inf,
           label = "Quadratic: R^2m = 0.0189, R^2c = 0.8269, ns", hjust = -0.05, vjust = 23, size = 5, color = "#466983FF") +
  annotate(geom = "text", x = -Inf, y = Inf,
           label = "Linear: R^2m = 0.0216, R^2c = 0.8430, *", hjust = -0.15, vjust = 21, size = 5, color = "#CE3D32FF")
p1_inv_radom_A6

#He~Nm
model3.1_inv <- lm(He~Nm,data = es_inv)
AIC(model3.1_inv)#-49.44841
summary(model3.1_inv)#Adjusted R-squared:  0.09062  , p-value: 0.0001128
model3.1_inv_Nc <- lm(He~Nm+Nc,data = es_inv)
AIC(model3.1_inv_Nc)#-12.59088
summary(model3.1_inv_Nc)#Adjusted R-squared: 0.05932,  p-value: 0.2234

es_inv.omit <- na.omit(es_inv)
es_inv.omit <- es_inv.omit[es_inv.omit$Nm != 0, ]
model3.1.1_inv <- lm(He~log(Nm),data = es_inv.omit)
AIC(model3.1.1_inv)#-0.855934
summary(model3.1.1_inv)#Adjusted R-squared: 0.04224   , p-value: 0.3119
model3.1.1_inv_Nc <- lm(He~log(Nm)+Nc,data = es_inv.omit)
AIC(model3.1.1_inv_Nc)#1.018458
summary(model3.1.1_inv_Nc)#Adjusted R-squared:  -0.1759,  p-value: 0.6146

model3.2_inv <- lm(He~Nm+I(Nm^2),data = es_inv)
AIC(model3.2_inv)#-47.81184
summary(model3.2_inv)#Adjusted R-squared:  0.08662,  p-value: 0.0004968
model3.2_inv_Nc <- lm(He~Nc+Nm+I(Nm^2),data = es_inv)
AIC(model3.2_inv_Nc)#-10.80873
summary(model3.2_inv_Nc)#Adjusted R-squared:  0.01427, p-value: 0.3776

model4.1_inv <- lm(Nm~He,data = es_inv)
AIC(model4.1_inv)#647.1241
summary(model4.1_inv)#Adjusted R-squared:  0.09062  , p-value: 0.0001128
model4.1_inv_Nc <- lm(Nm~He+Nc,data = es_inv)
AIC(model4.1_inv_Nc)#86.10266
summary(model4.1_inv_Nc)#Adjusted R-squared:  0.08386  ,  p-value: 0.1761

model4.2_inv <- lm(Nm~He+I(He^2),data = es_inv)
AIC(model4.2_inv)# 647.6978
summary(model4.2_inv)#Adjusted R-squared:  0.09311 ,  p-value: 0.0002952
model4.2_inv_Nc <- lm(Nm~Nc+He+I(He^2),data = es_inv)
AIC(model4.2_inv_Nc)#82.60145
summary(model4.2_inv_Nc)#Adjusted R-squared:  0.2535 , p-value: 0.04712

p2_inv <- ggplot(aes(x = Nm, y = He), data = es_inv) +
  geom_point(shape = 20, size = 5, alpha = 0.3, color = "black") +
  geom_smooth(method = "lm", size = 0.7, linetype = 1, color = "#CE3D32FF", se = TRUE, fill = "#FFC0CB") +
  geom_smooth(method = "lm", size = 0.7, linetype = 1, color = "#466983FF", se = TRUE, formula = y ~ I(x^2) + x, fill = "#ADD8E6") +
  theme(panel.border = element_rect(fill = NA, color = "black", size = 1, linetype = "solid"),
        axis.text.x = element_text(size = 15, face = "bold"),
        axis.text.y = element_text(size = 15, face = "bold"),
        axis.title.x = element_text(size = 15, face = "bold"),
        axis.title.y = element_text(size = 15, face = "bold"),
        legend.position = "none") +
  xlab(label = "Nm") +
  ylab(label = "He") +
  theme(plot.margin = unit(c(0.5, 0.5, 0.5, 0.5), "cm")) +
  annotate(geom = "text", x = -Inf, y = Inf,
           label = "Quadratic: P < 0.001, R^2 = 0.0866", hjust = -1.25, vjust = 32, size = 5, color = "#466983FF") +
  annotate(geom = "text", x = -Inf, y = Inf,
           label = "Linear: P < 0.001, R^2 = 0.0906", hjust = -1.5, vjust = 30, size = 5, color = "#CE3D32FF")
p2_inv

# Compare models that include random effects with models that do not
model3.1_inv_radom3 <- lmer(He ~ Nm + (1 | taxon) + (1 | gene_meth) + (1 | DNA_sou), data = es_inv)
AIC(model3.1_inv_radom3)#-149.9041
summary(model3.1_inv_radom3)#Estimate Std.Error  df   t.value Pr(>|t|) 2.152e-02  5.567e-03 1.442e+02   3.867 0.000166 ***
marginal_r2_model3.1_inv_radom3 <- r.squaredGLMM(model3.1_inv_radom3)
marginal_r2_model3.1_inv_radom3# R2m 0.04914746   R2c 0.8340762

model3.2_inv_radom3 <- lmer(He ~ Nm +I(Nm^2) + (1 | taxon) + (1 | gene_meth) + (1 | DNA_sou), data = es_inv)
AIC(model3.2_inv_radom3)#-137.6061
summary(model3.2_inv_radom3)#Nm 0.033790   0.014622 143.567187   2.311   0.0223 *; I(Nm^2) -0.001393   0.001537 128.017556  -0.907   0.3663
marginal_r2_model3.2_inv_radom3 <- r.squaredGLMM(model3.2_inv_radom3)
marginal_r2_model3.2_inv_radom3# R2m 0.05099608    R2c 0.8357945

p2_inv_radom <- ggplot(aes(x = Nm, y = He), data = es_inv) +
  geom_point(shape = 20, size = 5, alpha = 0.3, color = "black") +
  geom_smooth(method = "lm", size = 0.7, linetype = 1, color = "#CE3D32FF", se = TRUE, fill = "#FFC0CB") +
  geom_smooth(method = "lm", size = 0.7, linetype = 2, color = "#466983FF", se = TRUE, formula = y ~ I(x^2) + x, fill = "#ADD8E6") +
  theme(panel.border = element_rect(fill = NA, color = "black", size = 1, linetype = "solid"),
        axis.text.x = element_text(size = 15, face = "bold"),
        axis.text.y = element_text(size = 15, face = "bold"),
        axis.title.x = element_text(size = 15, face = "bold"),
        axis.title.y = element_text(size = 15, face = "bold"),
        legend.position = "none") +
  xlab(label = "Nm") +
  ylab(label = "He") +
  theme(plot.margin = unit(c(0.5, 0.5, 0.5, 0.5), "cm")) +
  annotate(geom = "text", x = -Inf, y = Inf,
           label = "Quadratic: R^2m = 0.0510, R^2c = 0.8358, ns", hjust = -1.25, vjust = 32, size = 5, color = "#466983FF") +
  annotate(geom = "text", x = -Inf, y = Inf,
           label = "Linear: R^2m = 0.0491, R^2c = 0.8341, ***", hjust = -1.5, vjust = 30, size = 5, color = "#CE3D32FF")
p2_inv_radom

p2_inv_radom_A6 <- ggplot(aes(x = Nm, y = He), data = es_inv) +
  geom_point(shape = 20, size = 5, alpha = 0.3, color = "black") +
  geom_smooth(method = "lm", size = 0.7, linetype = 1, color = "#CE3D32FF", se = TRUE, fill = "#FFC0CB") +
  geom_smooth(method = "lm", size = 0.7, linetype = 2, color = "#466983FF", se = TRUE, formula = y ~ I(x^2) + x, fill = "#ADD8E6") +
  theme(panel.border = element_rect(fill = NA, color = "black", size = 1, linetype = "solid"),
        axis.text.x = element_text(size = 15, face = "bold"),
        axis.text.y = element_text(size = 15, face = "bold"),
        axis.title.x = element_text(size = 15, face = "bold"),
        axis.title.y = element_text(size = 15, face = "bold"),
        legend.position = "none") +
  xlab(label = "Nm") +
  ylab(label = "He") +
  theme(plot.margin = unit(c(0.5, 0.5, 0.5, 0.5), "cm")) +
  annotate(geom = "text", x = -Inf, y = Inf,
           label = "Quadratic: R^2m = 0.0510, R^2c = 0.8358, ns", hjust = -0.16, vjust = 22, size = 5, color = "#466983FF") +
  annotate(geom = "text", x = -Inf, y = Inf,
           label = "Linear: R^2m = 0.0491, R^2c = 0.8341, ***", hjust = -0.25, vjust = 20, size = 5, color = "#CE3D32FF")
p2_inv_radom_A6

#Nm~FIS
model5.1_inv <- lm(Nm~FIS,data = es_inv)
AIC(model5.1_inv)#268.8636
summary(model5.1_inv)#Adjusted R-squared:  -0.006206  , p-value: 0.4284
model5.1_inv_Nc <- lm(Nm~FIS+Nc,data = es_inv)
AIC(model5.1_inv_Nc)#28.96841
summary(model5.1_inv_Nc)#Adjusted R-squared:  -0.1599 ,  p-value: 0.5979

model5.2_inv <- lm(Nm~FIS+I(FIS^2),data = es_inv)
AIC(model5.2_inv)# 265.6561
summary(model5.2_inv)#Adjusted R-squared:  0.06126,  p-value: 0.06176
model5.2_inv_Nc <- lm(Nm~Nc+FIS+I(FIS^2),data = es_inv)
AIC(model5.2_inv_Nc)#30.19218
summary(model5.2_inv_Nc)#Adjusted R-squared:  -0.3842 , p-value: 0.7384

model6.1_inv <- lm(FIS~Nm,data = es_inv)
AIC(model6.1_inv)#44.02597
summary(model6.1_inv)#Adjusted R-squared:  -0.006206 , p-value: 0.4284
model6.1_inv_Nc <- lm(FIS~Nm+Nc,data = es_inv)
AIC(model6.1_inv_Nc)#5.685714
summary(model6.1_inv_Nc)#Adjusted R-squared:  0.09213  ,  p-value: 0.3663

model6.2_inv <- lm(FIS~Nm+I(Nm^2),data = es_inv)
AIC(model6.2_inv)#46.00871
summary(model6.2_inv)#Adjusted R-squared:  -0.02356  ,  p-value: 0.7268
model6.2_inv_Nc <- lm(FIS~Nc+Nm+I(Nm^2),data = es_inv)
AIC(model6.2_inv_Nc)#7.142057
summary(model6.2_inv_Nc)#Adjusted R-squared:  -0.12 , p-value: 0.5762

p3_inv <- ggplot(aes(x = Nm, y = FIS), data = es_inv) +
  geom_point(shape = 20, size = 5, alpha = 0.3, color = "black") +
  geom_smooth(method = "lm", size = 0.7, linetype = 2, color = "#CE3D32FF", se = TRUE, fill = "#FFC0CB") +
  geom_smooth(method = "lm", size = 0.7, linetype = 2, color = "#466983FF", se = TRUE, formula = y ~ I(x^2) + x, fill = "#ADD8E6") +
  theme(panel.border = element_rect(fill = NA, color = "black", size = 1, linetype = "solid"),
        axis.text.x = element_text(size = 15, face = "bold"),
        axis.text.y = element_text(size = 15, face = "bold"),
        axis.title.x = element_text(size = 15, face = "bold"),
        axis.title.y = element_text(size = 15, face = "bold"),
        legend.position = "none") +
  xlab(label = "Nm") +
  ylab(label = "FIS") +
  theme(plot.margin = unit(c(0.5, 0.5, 0.5, 0.5), "cm")) +
  annotate(geom = "text", x = -Inf, y = Inf,
           label = "Quadratic: P > 0.05, R^2 = -0.0236", hjust = -1.25, vjust = 32, size = 5, color = "#466983FF") +
  annotate(geom = "text", x = -Inf, y = Inf,
           label = "Linear: P > 0.05, R^2 = -0.0062", hjust = -1.5, vjust = 30, size = 5, color = "#CE3D32FF")
p3_inv

# Compare models that include random effects with models that do not
model6.1_inv_radom3 <- lmer(FIS ~ Nm + (1 | taxon) + (1 | gene_meth) + (1 | DNA_sou), data = es_inv)
AIC(model6.1_inv_radom3)#22.44946
summary(model6.1_inv_radom3)#Estimate Std.Error  df   t.value Pr(>|t|) -0.02573    0.01823 52.03503  -1.412    0.164
marginal_r2_model6.1_inv_radom3 <- r.squaredGLMM(model6.1_inv_radom3)
marginal_r2_model6.1_inv_radom3# R2m 0.01854301     R2c 0.9005569

model6.2_inv_radom3 <- lmer(FIS ~ Nm+I(Nm^2) + (1 | taxon) + (1 | gene_meth) + (1 | DNA_sou), data = es_inv)
AIC(model6.2_inv_radom3)#30.91642
summary(model6.2_inv_radom3)#Nm -0.106764   0.062604 55.194494  -1.705   0.0937 .; I(Nm^2) 0.009199   0.006846 55.294672   1.344   0.1845
marginal_r2_model6.2_inv_radom3 <- r.squaredGLMM(model6.2_inv_radom3)
marginal_r2_model6.2_inv_radom3# R2m 0.05380329    R2c 0.9163104

p3_inv_radom <- ggplot(aes(x = Nm, y = FIS), data = es_inv) +
  geom_point(shape = 20, size = 5, alpha = 0.3, color = "black") +
  geom_smooth(method = "lm", size = 0.7, linetype = 2, color = "#CE3D32FF", se = TRUE, fill = "#FFC0CB") +
  geom_smooth(method = "lm", size = 0.7, linetype = 2, color = "#466983FF", se = TRUE, formula = y ~ I(x^2) + x, fill = "#ADD8E6") +
  theme(panel.border = element_rect(fill = NA, color = "black", size = 1, linetype = "solid"),
        axis.text.x = element_text(size = 15, face = "bold"),
        axis.text.y = element_text(size = 15, face = "bold"),
        axis.title.x = element_text(size = 15, face = "bold"),
        axis.title.y = element_text(size = 15, face = "bold"),
        legend.position = "none") +
  xlab(label = "Nm") +
  ylab(label = "FIS") +
  theme(plot.margin = unit(c(0.5, 0.5, 0.5, 0.5), "cm")) +
  annotate(geom = "text", x = -Inf, y = Inf,
           label = "Quadratic: R^2m = 0.0538, R^2c = 0.9163, ns", hjust = -0.80, vjust = 32, size = 5, color = "#466983FF") +
  annotate(geom = "text", x = -Inf, y = Inf,
           label = "Linear: R^2m = 0.0185, R^2c = 0.9006, ns", hjust = -0.85, vjust = 30, size = 5, color = "#CE3D32FF")
p3_inv_radom

p3_inv_radom_A6 <- ggplot(aes(x = Nm, y = FIS), data = es_inv) +
  geom_point(shape = 20, size = 5, alpha = 0.3, color = "black") +
  geom_smooth(method = "lm", size = 0.7, linetype = 2, color = "#CE3D32FF", se = TRUE, fill = "#FFC0CB") +
  geom_smooth(method = "lm", size = 0.7, linetype = 2, color = "#466983FF", se = TRUE, formula = y ~ I(x^2) + x, fill = "#ADD8E6") +
  theme(panel.border = element_rect(fill = NA, color = "black", size = 1, linetype = "solid"),
        axis.text.x = element_text(size = 15, face = "bold"),
        axis.text.y = element_text(size = 15, face = "bold"),
        axis.title.x = element_text(size = 15, face = "bold"),
        axis.title.y = element_text(size = 15, face = "bold"),
        legend.position = "none") +
  xlab(label = "Nm") +
  ylab(label = "FIS") +
  theme(plot.margin = unit(c(0.5, 0.5, 0.5, 0.5), "cm")) +
  annotate(geom = "text", x = -Inf, y = Inf,
           label = "Quadratic: R^2m = 0.0538, R^2c = 0.9163, ns", hjust = -0.16, vjust = 22, size = 5, color = "#466983FF") +
  annotate(geom = "text", x = -Inf, y = Inf,
           label = "Linear: R^2m = 0.0185, R^2c = 0.9006, ns", hjust = -0.25, vjust = 20, size = 5, color = "#CE3D32FF")
p3_inv_radom_A6

##NSS
es_NSS <- as.data.frame(es_NSS)
#He~FIS
model1.1_NSS <- lm(He~FIS,data = es_NSS)
AIC(model1.1_NSS)#-14.54881
summary(model1.1_NSS)#Adjusted R-squared:  -0.0006075 , p-value: 0.3293
model1.1_NSS_Nc <- lm(He~FIS+Nc,data = es_NSS)
AIC(model1.1_NSS_Nc)#-16.32807
summary(model1.1_NSS_Nc)#Adjusted R-squared: 0.06205 ,  p-value: 0.1081

model1.2_NSS <- lm(He~FIS+I(FIS^2),data = es_NSS)
AIC(model1.2_NSS)#-12.80407
summary(model1.2_NSS)#Adjusted R-squared:  -0.02005 ,  p-value: 0.5553
model1.2_NSS_Nc <- lm(He~Nc+FIS+I(FIS^2),data = es_NSS)
AIC(model1.2_NSS_Nc)#-14.40758
summary(model1.2_NSS_Nc)#Adjusted R-squared:  0.03919  , p-value: 0.2156

model2.1_NSS <- lm(FIS~He,data = es_NSS)
AIC(model2.1_NSS)#35.83056
summary(model2.1_NSS)#Adjusted R-squared:  -0.0006075 , p-value: 0.3293
model2.1_NSS_Nc <- lm(FIS~He+Nc,data = es_NSS)
AIC(model2.1_NSS_Nc)#37.81198
summary(model2.1_NSS_Nc)#Adjusted R-squared:  -0.02581 ,  p-value: 0.6198

model2.2_NSS <- lm(FIS~He+I(He^2),data = es_NSS)
AIC(model2.2_NSS)#36.46585
summary(model2.2_NSS)#Adjusted R-squared:  0.006546  ,  p-value: 0.3318
model2.2_NSS_Nc <- lm(FIS~Nc+He+I(He^2),data = es_NSS)
AIC(model2.2_NSS_Nc)#38.45312
summary(model2.2_NSS_Nc)#Adjusted R-squared:  -0.01929 , p-value: 0.534

p1_NSS <- ggplot(aes(x = FIS, y = He), data = es_NSS) +
  geom_point(shape = 20, size = 5, alpha = 0.3, color = "#A41B1BFF") +
  geom_smooth(method = "lm", size = 0.7, linetype = 2, color = "#CE3D32FF", se = TRUE, fill = "#FFC0CB") +
  geom_smooth(method = "lm", size = 0.7, linetype = 2, color = "#466983FF", se = TRUE, formula = y ~ I(x^2) + x, fill = "#ADD8E6") +
  theme(panel.border = element_rect(fill = NA, color = "black", size = 1, linetype = "solid"),
        axis.text.x = element_text(size = 15, face = "bold"),
        axis.text.y = element_text(size = 15, face = "bold"),
        axis.title.x = element_text(size = 15, face = "bold"),
        axis.title.y = element_text(size = 15, face = "bold"),
        legend.position = "none") +
  xlab(label = "FIS") +
  ylab(label = "He") +
  theme(plot.margin = unit(c(0.5, 0.5, 0.5, 0.5), "cm")) +
  annotate(geom = "text", x = -Inf, y = Inf,
           label = "Quadratic: P > 0.05, R^2 = -0.0201", hjust = -0.05, vjust = 4, size = 5, color = "#466983FF") +
  annotate(geom = "text", x = -Inf, y = Inf,
           label = "Linear: P > 0.05, R^2 = -0.0006", hjust = -0.05, vjust = 2, size = 5, color = "#CE3D32FF")
p1_NSS

# Compare models that include random effects with models that do not

#es_NSS <- es_endangered[es_endangered$rarity == "NSS", ]
#es_NSS$Na[is.na(es_NSS$Na)] <- es_NSS$Ne[is.na(es_NSS$Na)]
#colnames(es_NSS)[colnames(es_NSS) == "Na"] <- "Nc"

model1.1_NSS_radom3 <- lmer(He ~ FIS + (1 | taxon) + (1 | gene_meth) + (1 | DNA_sou), data = es_NSS)
AIC(model1.1_NSS_radom3)#-17.99016
summary(model1.1_NSS_radom3)#Estimate Std.Error  df   t.value Pr(>|t|) 0.06101    0.07402 29.07586   0.824    0.416
marginal_r2_model1.1_NSS_radom3 <- r.squaredGLMM(model1.1_NSS_radom3)
marginal_r2_model1.1_NSS_radom3# R2m 0.005802    R2c 0.7961316

model1.2_NSS_radom3 <- lmer(He ~ FIS +I(FIS^2) + (1 | taxon) + (1 | gene_meth) + (1 | DNA_sou), data = es_NSS)
AIC(model1.2_NSS_radom3)#-19.80403
summary(model1.2_NSS_radom3)#FIS 0.03838    0.07159 30.45266   0.536   0.5958; I(FIS^2) -0.33020    0.11452 37.20809  -2.883   0.0065 **
marginal_r2_model1.2_NSS_radom3 <- r.squaredGLMM(model1.2_NSS_radom3)
marginal_r2_model1.2_NSS_radom3# R2m 0.05961305    R2c 0.8913815

p1_NSS_radom <- ggplot(aes(x = FIS, y = He), data = es_NSS) +
  geom_point(shape = 20, size = 5, alpha = 0.3, color = "#A41B1BFF") +
  geom_smooth(method = "lm", size = 0.7, linetype = 2, color = "#CE3D32FF", se = TRUE, fill = "#FFC0CB") +
  geom_smooth(method = "lm", size = 0.7, linetype = 1, color = "#466983FF", se = TRUE, formula = y ~ I(x^2) + x, fill = "#ADD8E6") +
  theme(panel.border = element_rect(fill = NA, color = "black", size = 1, linetype = "solid"),
        axis.text.x = element_text(size = 15, face = "bold"),
        axis.text.y = element_text(size = 15, face = "bold"),
        axis.title.x = element_text(size = 15, face = "bold"),
        axis.title.y = element_text(size = 15, face = "bold"),
        legend.position = "none") +
  xlab(label = "FIS") +
  ylab(label = "He") +
  theme(plot.margin = unit(c(0.5, 0.5, 0.5, 0.5), "cm")) +
  annotate(geom = "text", x = -Inf, y = Inf,
           label = "Quadratic: R^2m = 0.0596, R^2c = 0.8914, **", hjust = -0.05, vjust = 4, size = 5, color = "#466983FF") +
  annotate(geom = "text", x = -Inf, y = Inf,
           label = "Linear: R^2m = 0.0058, R^2c = 0.7961, ns", hjust = -0.05, vjust = 2, size = 5, color = "#CE3D32FF")
p1_NSS_radom

#He~Nm
model3.1_NSS <- lm(He~Nm,data = es_NSS)
AIC(model3.1_NSS)#-57.75168
summary(model3.1_NSS)#Adjusted R-squared:  -0.005864  , p-value: 0.4336
model3.1_NSS_Nc <- lm(He~Nm+Nc,data = es_NSS)
AIC(model3.1_NSS_Nc)#-62.83377
summary(model3.1_NSS_Nc)#Adjusted R-squared: 0.08214,  p-value: 0.02511
anova(model3.1_NSS_Nc)
model3.1_NSS_Nc_cov <- vcov(model3.1_NSS_Nc)#Calculated covariance
model3.1_NSS_Nc_cov

es_NSS.omit <- na.omit(es_NSS)
es_NSS.omit <- es_NSS.omit[es_NSS.omit$Nm != 0, ]
model3.1.1_NSS <- lm(He~log(Nm),data = es_NSS.omit)
AIC(model3.1.1_NSS)#-3.68572
summary(model3.1.1_NSS)#Adjusted R-squared:  -0.04256  , p-value: 0.7528
model3.1.1_NSS_Nc <- lm(He~log(Nm)+Nc,data = es_NSS.omit)
AIC(model3.1.1_NSS_Nc)#-5.394796
summary(model3.1.1_NSS_Nc)#Adjusted R-squared:  0.06834 ,  p-value: 0.1899

model3.2_NSS <- lm(He~Nm+I(Nm^2),data = es_NSS)
AIC(model3.2_NSS)#-55.90765
summary(model3.2_NSS)#Adjusted R-squared:  -0.01942,  p-value: 0.6848
model3.2_NSS_Nc <- lm(He~Nc+Nm+I(Nm^2),data = es_NSS)
AIC(model3.2_NSS_Nc)#-61.23457
summary(model3.2_NSS_Nc)#Adjusted R-squared:  0.07298, p-value: 0.0529

model4.1_NSS <- lm(Nm~He,data = es_NSS)
AIC(model4.1_NSS)#346.7312
summary(model4.1_NSS)#Adjusted R-squared:  -0.005864 , p-value: 0.4336
model4.1_NSS_Nc <- lm(Nm~He+Nc,data = es_NSS)
AIC(model4.1_NSS_Nc)#348.5964
summary(model4.1_NSS_Nc)#Adjusted R-squared:  -0.01974 ,  p-value: 0.6917

model4.2_NSS <- lm(Nm~He+I(He^2),data = es_NSS)
AIC(model4.2_NSS)# 347.0216
summary(model4.2_NSS)#Adjusted R-squared:  0.0043  ,  p-value: 0.3262
model4.2_NSS_Nc <- lm(Nm~Nc+He+I(He^2),data = es_NSS)
AIC(model4.2_NSS_Nc)#348.9469
summary(model4.2_NSS_Nc)#Adjusted R-squared:  -0.01062 , p-value: 0.5138

p2_NSS <- ggplot(aes(x = Nm, y = He), data = es_NSS) +
  geom_point(shape = 20, size = 5, alpha = 0.3, color = "#A41B1BFF") +
  geom_smooth(method = "lm", size = 0.7, linetype = 2, color = "#CE3D32FF", se = TRUE, fill = "#FFC0CB") +
  geom_smooth(method = "lm", size = 0.7, linetype = 2, color = "#466983FF", se = TRUE, formula = y ~ I(x^2) + x, fill = "#ADD8E6") +
  theme(panel.border = element_rect(fill = NA, color = "black", size = 1, linetype = "solid"),
        axis.text.x = element_text(size = 15, face = "bold"),
        axis.text.y = element_text(size = 15, face = "bold"),
        axis.title.x = element_text(size = 15, face = "bold"),
        axis.title.y = element_text(size = 15, face = "bold"),
        legend.position = "none") +
  xlab(label = "Nm") +
  ylab(label = "He") +
  theme(plot.margin = unit(c(0.5, 0.5, 0.5, 0.5), "cm")) +
  annotate(geom = "text", x = -Inf, y = Inf,
           label = "Quadratic: P > 0.05, R^2 = -0.0194", hjust = -0.6, vjust = 4, size = 5, color = "#466983FF") +
  annotate(geom = "text", x = -Inf, y = Inf,
           label = "Linear: P > 0.05, R^2 = -0.0059", hjust = -0.67, vjust = 2, size = 5, color = "#CE3D32FF")
p2_NSS

# Compare models that include random effects with models that do not
model3.1_NSS_radom3 <- lmer(He ~ Nm + (1 | taxon) + (1 | gene_meth) + (1 | DNA_sou), data = es_NSS)
AIC(model3.1_NSS_radom3)#-84.58225
summary(model3.1_NSS_radom3)#Estimate Std.Error  df   t.value Pr(>|t|) 0.008324   0.005399 51.928535   1.542   0.1292
marginal_r2_model3.1_NSS_radom3 <- r.squaredGLMM(model3.1_NSS_radom3)
marginal_r2_model3.1_NSS_radom3# R2m 0.0211716    R2c 0.9619641

model3.2_NSS_radom3 <- lmer(He ~ Nm +I(Nm^2) + (1 | taxon) + (1 | gene_meth) + (1 | DNA_sou), data = es_NSS)
AIC(model3.2_NSS_radom3)#-71.52306
summary(model3.2_NSS_radom3)#Nm 0.0265481  0.0122981 46.9518006   2.159   0.0360 *; I(Nm^2) -0.0008518  0.0005431 56.8687122  -1.568   0.1223
marginal_r2_model3.2_NSS_radom3 <- r.squaredGLMM(model3.2_NSS_radom3)
marginal_r2_model3.2_NSS_radom3# R2m 0.03376527    R2c 0.9680116

p2_NSS_radom <- ggplot(aes(x = Nm, y = He), data = es_NSS) +
  geom_point(shape = 20, size = 5, alpha = 0.3, color = "#A41B1BFF") +
  geom_smooth(method = "lm", size = 0.7, linetype = 2, color = "#CE3D32FF", se = TRUE, fill = "#FFC0CB") +
  geom_smooth(method = "lm", size = 0.7, linetype = 2, color = "#466983FF", se = TRUE, formula = y ~ I(x^2) + x, fill = "#ADD8E6") +
  theme(panel.border = element_rect(fill = NA, color = "black", size = 1, linetype = "solid"),
        axis.text.x = element_text(size = 15, face = "bold"),
        axis.text.y = element_text(size = 15, face = "bold"),
        axis.title.x = element_text(size = 15, face = "bold"),
        axis.title.y = element_text(size = 15, face = "bold"),
        legend.position = "none") +
  xlab(label = "Nm") +
  ylab(label = "He") +
  theme(plot.margin = unit(c(0.5, 0.5, 0.5, 0.5), "cm")) +
  annotate(geom = "text", x = -Inf, y = Inf,
           label = "Quadratic: R^2m = 0.0338, R^2c = 0.9680, ns", hjust = -0.6, vjust = 4, size = 5, color = "#466983FF") +
  annotate(geom = "text", x = -Inf, y = Inf,
           label = "Linear: R^2m = 0.0212, R^2c = 0.9620, ns", hjust = -0.67, vjust = 2, size = 5, color = "#CE3D32FF")
p2_NSS_radom

p2_NSS_radom_A6 <- ggplot(aes(x = Nm, y = He), data = es_NSS) +
  geom_point(shape = 20, size = 5, alpha = 0.3, color = "#A41B1BFF") +
  geom_smooth(method = "lm", size = 0.7, linetype = 2, color = "#CE3D32FF", se = TRUE, fill = "#FFC0CB") +
  geom_smooth(method = "lm", size = 0.7, linetype = 2, color = "#466983FF", se = TRUE, formula = y ~ I(x^2) + x, fill = "#ADD8E6") +
  theme(panel.border = element_rect(fill = NA, color = "black", size = 1, linetype = "solid"),
        axis.text.x = element_text(size = 15, face = "bold"),
        axis.text.y = element_text(size = 15, face = "bold"),
        axis.title.x = element_text(size = 15, face = "bold"),
        axis.title.y = element_text(size = 15, face = "bold"),
        legend.position = "none") +
  xlab(label = "Nm") +
  ylab(label = "He") +
  theme(plot.margin = unit(c(0.5, 0.5, 0.5, 0.5), "cm")) +
  annotate(geom = "text", x = -Inf, y = Inf,
           label = "Quadratic: R^2m = 0.0338, R^2c = 0.9680, ns", hjust = -0.2, vjust = 4, size = 5, color = "#466983FF") +
  annotate(geom = "text", x = -Inf, y = Inf,
           label = "Linear: R^2m = 0.0212, R^2c = 0.9620, ns", hjust = -0.25, vjust = 2, size = 5, color = "#CE3D32FF")
p2_NSS_radom_A6

#Nm~FIS
model5.1_NSS <- lm(Nm~FIS,data = es_NSS)
AIC(model5.1_NSS)#87.52577
summary(model5.1_NSS)#Adjusted R-squared:  -0.04252 , p-value: 0.8857
model5.1_NSS_Nc <- lm(Nm~FIS+Nc,data = es_NSS)
AIC(model5.1_NSS_Nc)#89.44583
summary(model5.1_NSS_Nc)#Adjusted R-squared:  -0.08643 ,  p-value: 0.9557

model5.2_NSS <- lm(Nm~FIS+I(FIS^2),data = es_NSS)
AIC(model5.2_NSS)# 82.62334
summary(model5.2_NSS)#Adjusted R-squared:  0.173,  p-value: 0.04749
model5.2_NSS_Nc <- lm(Nm~Nc+FIS+I(FIS^2),data = es_NSS)
AIC(model5.2_NSS_Nc)#83.16588
summary(model5.2_NSS_Nc)#Adjusted R-squared:  0.1827 , p-value: 0.06575

model6.1_NSS <- lm(FIS~Nm,data = es_NSS)
AIC(model6.1_NSS)#-5.937938
summary(model6.1_NSS)#Adjusted R-squared:  -0.04252, p-value: 0.8857
model6.1_NSS_Nc <- lm(FIS~Nm+Nc,data = es_NSS)
AIC(model6.1_NSS_Nc)#-8.40981
summary(model6.1_NSS_Nc)#Adjusted R-squared:  0.08861 ,  p-value: 0.1384

model6.2_NSS <- lm(FIS~Nm+I(Nm^2),data = es_NSS)
AIC(model6.2_NSS)#-7.238641
summary(model6.2_NSS)#Adjusted R-squared:  0.0449 ,  p-value: 0.2317
model6.2_NSS_Nc <- lm(FIS~Nc+Nm+I(Nm^2),data = es_NSS)
AIC(model6.2_NSS_Nc)#-8.601902
summary(model6.2_NSS_Nc)#Adjusted R-squared:  0.1254 , p-value: 0.1247

p3_NSS <- ggplot(aes(x = FIS, y = Nm), data = es_NSS) +
  geom_point(shape = 20, size = 5, alpha = 0.3, color = "#A41B1BFF") +
  geom_smooth(method = "lm", size = 0.7, linetype = 2, color = "#CE3D32FF", se = TRUE, fill = "#FFC0CB") +
  geom_smooth(method = "lm", size = 0.7, linetype = 1, color = "#466983FF", se = TRUE, formula = y ~ I(x^2) + x, fill = "#ADD8E6") +
  theme(panel.border = element_rect(fill = NA, color = "black", size = 1, linetype = "solid"),
        axis.text.x = element_text(size = 15, face = "bold"),
        axis.text.y = element_text(size = 15, face = "bold"),
        axis.title.x = element_text(size = 15, face = "bold"),
        axis.title.y = element_text(size = 15, face = "bold"),
        legend.position = "none") +
  xlab(label = "FIS") +
  ylab(label = "Nm") +
  xlim(-0.1, 0.6) +
  ylim(0, 6) +
  theme(plot.margin = unit(c(0.5, 0.5, 0.5, 0.5), "cm")) +
  annotate(geom = "text", x = -Inf, y = Inf,
           label = "Quadratic: P < 0.05, R^2 = 0.1730", hjust = -0.05, vjust = 4, size = 5, color = "#466983FF") +
  annotate(geom = "text", x = -Inf, y = Inf,
           label = "Linear: P > 0.05, R^2 = -0.0425", hjust = -0.05, vjust = 2, size = 5, color = "#CE3D32FF")
p3_NSS

# Compare models that include random effects with models that do not
model6.1_NSS_radom3 <- lmer(FIS ~ Nm + (1 | taxon) + (1 | gene_meth) + (1 | DNA_sou), data = es_NSS)
AIC(model6.1_NSS_radom3)#-1.619201
summary(model6.1_NSS_radom3)#Estimate Std.Error  df   t.value Pr(>|t|) 0.07919    0.02646 19.11213   2.992  0.00746 **
marginal_r2_model6.1_NSS_radom3 <- r.squaredGLMM(model6.1_NSS_radom3)
marginal_r2_model6.1_NSS_radom3# R2m 0.1951716    R2c 0.8821251

model6.2_NSS_radom3 <- lmer(FIS ~ Nm+I(Nm^2) + (1 | taxon) + (1 | gene_meth) + (1 | DNA_sou), data = es_NSS)
AIC(model6.2_NSS_radom3)#5.654899
summary(model6.2_NSS_radom3)#Nm 0.12718    0.08794 14.79011   1.446    0.169; I(Nm^2) -0.01335    0.02538 20.69639  -0.526    0.605
marginal_r2_model6.2_NSS_radom3 <- r.squaredGLMM(model6.2_NSS_radom3)
marginal_r2_model6.2_NSS_radom3# R2m 0.1834816     R2c 0.8947587

p3_NSS_radom <- ggplot(aes(x = Nm, y = FIS), data = es_NSS) +
  geom_point(shape = 20, size = 5, alpha = 0.3, color = "#A41B1BFF") +
  geom_smooth(method = "lm", size = 0.7, linetype = 1, color = "#CE3D32FF", se = TRUE, fill = "#FFC0CB") +
  geom_smooth(method = "lm", size = 0.7, linetype = 2, color = "#466983FF", se = TRUE, formula = y ~ I(x^2) + x, fill = "#ADD8E6") +
  theme(panel.border = element_rect(fill = NA, color = "black", size = 1, linetype = "solid"),
        axis.text.x = element_text(size = 15, face = "bold"),
        axis.text.y = element_text(size = 15, face = "bold"),
        axis.title.x = element_text(size = 15, face = "bold"),
        axis.title.y = element_text(size = 15, face = "bold"),
        legend.position = "none") +
  xlab(label = "Nm") +
  ylab(label = "FIS") +
  ylim(-0.1, 0.6) +
  xlim(0, 6) +
  theme(plot.margin = unit(c(0.5, 0.5, 0.5, 0.5), "cm")) +
  annotate(geom = "text", x = -Inf, y = Inf,
           label = "Quadratic: R^2m = 0.1835, R^2c = 0.8948, ns", hjust = -0.6, vjust = 4, size = 5, color = "#466983FF") +
  annotate(geom = "text", x = -Inf, y = Inf,
           label = "Linear: R^2m = 0.1952, R^2c = 0.8821, **", hjust = -0.67, vjust = 2, size = 5, color = "#CE3D32FF")
p3_NSS_radom

p3_NSS_radom_A6 <- ggplot(aes(x = Nm, y = FIS), data = es_NSS) +
  geom_point(shape = 20, size = 5, alpha = 0.3, color = "#A41B1BFF") +
  geom_smooth(method = "lm", size = 0.7, linetype = 1, color = "#CE3D32FF", se = TRUE, fill = "#FFC0CB") +
  geom_smooth(method = "lm", size = 0.7, linetype = 2, color = "#466983FF", se = TRUE, formula = y ~ I(x^2) + x, fill = "#ADD8E6") +
  theme(panel.border = element_rect(fill = NA, color = "black", size = 1, linetype = "solid"),
        axis.text.x = element_text(size = 15, face = "bold"),
        axis.text.y = element_text(size = 15, face = "bold"),
        axis.title.x = element_text(size = 15, face = "bold"),
        axis.title.y = element_text(size = 15, face = "bold"),
        legend.position = "none") +
  xlab(label = "Nm") +
  ylab(label = "FIS") +
  ylim(-0.1, 0.6) +
  xlim(0, 6) +
  theme(plot.margin = unit(c(0.5, 0.5, 0.5, 0.5), "cm")) +
  annotate(geom = "text", x = -Inf, y = Inf,
           label = "Quadratic: R^2m = 0.1835, R^2c = 0.8948, ns", hjust = -0.2, vjust = 23, size = 5, color = "#466983FF") +
  annotate(geom = "text", x = -Inf, y = Inf,
           label = "Linear: R^2m = 0.1952, R^2c = 0.8821, **", hjust = -0.3, vjust = 21, size = 5, color = "#CE3D32FF")
p3_NSS_radom_A6

##Influence of Nc####

#Endangered
#He_Nc
model_He_Nc_end_1 <- lm(He~Nc,data = es_end)
AIC(model_He_Nc_end_1)#-99.43678
summary(model_He_Nc_end_1)#Adjusted R-squared:  -0.0001049 , p-value: 0.3272
model_He_Nc_end_2 <- lm(He~Nc+I(Nc^2),data = es_end)
AIC(model_He_Nc_end_2)#-104.3579
summary(model_He_Nc_end_2)#Adjusted R-squared:  0.01628 , p-value: 0.02002

model_He_Nc_end_3 <- lm(He~log(Nc),data = es_end)
AIC(model_He_Nc_end_3)#-98.47035
summary(model_He_Nc_end_3)#Adjusted R-squared:  -0.002808 , p-value: 0.9886
model_He_Nc_end_4 <- lm(He~log(Nc)+I(log(Nc)^2),data = es_end)
AIC(model_He_Nc_end_4)#-107.5772
summary(model_He_Nc_end_4)#Adjusted R-squared:  0.02509 , p-value: 0.004058

p_He_Nc_end <- ggplot(aes(x = Nc, y = He), data = es_end) +
  geom_point(shape = 20, size = 5, alpha = 0.3, color = "gray") +
  geom_smooth(method = "lm", size = 0.7, linetype = 2, color = "#CE3D32FF", se = TRUE, fill = "#FFC0CB") +
  geom_smooth(method = "lm", size = 0.7, linetype = 1, color = "#466983FF", se = TRUE, formula = y ~ I(x^2) + x, fill = "#ADD8E6") +
  theme(panel.border = element_rect(fill = NA, color = "black", size = 1, linetype = "solid"),
        axis.text.x = element_text(size = 15, face = "bold"),
        axis.text.y = element_text(size = 15, face = "bold"),
        axis.title.x = element_text(size = 15, face = "bold"),
        axis.title.y = element_text(size = 15, face = "bold"),
        legend.position = "none") +
  xlab(label = "Nc") +
  ylab(label = "He") +
  theme(plot.margin = unit(c(0.5, 0.5, 0.5, 0.5), "cm")) +
  annotate(geom = "text", x = -Inf, y = Inf,
           label = "Quadratic: P < 0.05, R^2 = 0.0163", hjust = -0.05, vjust = 4, size = 5, color = "#466983FF") +
  annotate(geom = "text", x = -Inf, y = Inf,
           label = "Linear: P > 0.05, R^2 = -0.0001", hjust = -0.05, vjust = 2, size = 5, color = "#CE3D32FF")
p_He_Nc_end

p_He_logNc_end <- ggplot(aes(x = log(Nc), y = He), data = es_end) +
  geom_point(shape = 20, size = 5, alpha = 0.3, color = "gray") +
  geom_smooth(method = "lm", size = 0.7, linetype = 2, color = "#CE3D32FF", se = TRUE, fill = "#FFC0CB") +
  geom_smooth(method = "lm", size = 0.7, linetype = 1, color = "#466983FF", se = TRUE, formula = y ~ I(x^2) + x, fill = "#ADD8E6") +
  theme(panel.border = element_rect(fill = NA, color = "black", size = 1, linetype = "solid"),
        axis.text.x = element_text(size = 15, face = "bold"),
        axis.text.y = element_text(size = 15, face = "bold"),
        axis.title.x = element_text(size = 15, face = "bold"),
        axis.title.y = element_text(size = 15, face = "bold"),
        legend.position = "none") +
  xlab(label = "log(Nc)") +
  ylab(label = "He") +
  theme(plot.margin = unit(c(0.5, 0.5, 0.5, 0.5), "cm")) +
  annotate(geom = "text", x = -Inf, y = Inf,
           label = "Quadratic: P < 0.05, R^2 = 0.0251", hjust = -0.05, vjust = 4, size = 5, color = "#466983FF") +
  annotate(geom = "text", x = -Inf, y = Inf,
           label = "Linear: P > 0.05, R^2 = -0.0028", hjust = -0.05, vjust = 2, size = 5, color = "#CE3D32FF")
p_He_logNc_end

#FIS_Nc
model_FIS_Nc_end_1 <- lm(FIS~Nc,data = es_end)
AIC(model_FIS_Nc_end_1)#35.64122
summary(model_FIS_Nc_end_1)#Adjusted R-squared:  0.007516 ,  p-value: 0.1534
model_FIS_Nc_end_2 <- lm(FIS~Nc+I(Nc^2),data = es_end)
AIC(model_FIS_Nc_end_2)#31.37493
summary(model_FIS_Nc_end_2)#Adjusted R-squared:  0.04378 ,  p-value: 0.01688

model_FIS_Nc_end_3 <- lm(FIS~log(Nc),data = es_end)
AIC(model_FIS_Nc_end_3)#32.49102
summary(model_FIS_Nc_end_3)#Adjusted R-squared:  0.02944,  p-value: 0.02349
model_FIS_Nc_end_4 <- lm(FIS~log(Nc)+I(log(Nc)^2),data = es_end)
AIC(model_FIS_Nc_end_4)#33.46703
summary(model_FIS_Nc_end_4)#Adjusted R-squared:  0.02948,  p-value: 0.04699

p_FIS_Nc_end <- ggplot(aes(x = Nc, y = FIS), data = es_end) +
  geom_point(shape = 20, size = 5, alpha = 0.3, color = "gray") +
  geom_smooth(method = "lm", size = 0.7, linetype = 2, color = "#CE3D32FF", se = TRUE, fill = "#FFC0CB") +
  geom_smooth(method = "lm", size = 0.7, linetype = 1, color = "#466983FF", se = TRUE, formula = y ~ I(x^2) + x, fill = "#ADD8E6") +
  theme(panel.border = element_rect(fill = NA, color = "black", size = 1, linetype = "solid"),
        axis.text.x = element_text(size = 15, face = "bold"),
        axis.text.y = element_text(size = 15, face = "bold"),
        axis.title.x = element_text(size = 15, face = "bold"),
        axis.title.y = element_text(size = 15, face = "bold"),
        legend.position = "none") +
  xlab(label = "Nc") +
  ylab(label = "FIS") +
  xlim(0, 10000) +
  theme(plot.margin = unit(c(0.5, 0.5, 0.5, 0.5), "cm")) +
  annotate(geom = "text", x = -Inf, y = Inf,
           label = "Quadratic: P < 0.05, R^2 = 0.0438", hjust = -0.78, vjust = 4, size = 5, color = "#466983FF") +
  annotate(geom = "text", x = -Inf, y = Inf,
           label = "Linear: P > 0.05, R^2 = 0.0075", hjust = -1, vjust = 2, size = 5, color = "#CE3D32FF")
p_FIS_Nc_end

p_FIS_logNc_end <- ggplot(aes(x = log(Nc), y = FIS), data = es_end) +
  geom_point(shape = 20, size = 5, alpha = 0.3, color = "gray") +
  geom_smooth(method = "lm", size = 0.7, linetype = 1, color = "#CE3D32FF", se = TRUE, fill = "#FFC0CB") +
  geom_smooth(method = "lm", size = 0.7, linetype = 1, color = "#466983FF", se = TRUE, formula = y ~ I(x^2) + x, fill = "#ADD8E6") +
  theme(panel.border = element_rect(fill = NA, color = "black", size = 1, linetype = "solid"),
        axis.text.x = element_text(size = 15, face = "bold"),
        axis.text.y = element_text(size = 15, face = "bold"),
        axis.title.x = element_text(size = 15, face = "bold"),
        axis.title.y = element_text(size = 15, face = "bold"),
        legend.position = "none") +
  xlab(label = "log(Nc)") +
  ylab(label = "FIS") +
  theme(plot.margin = unit(c(0.5, 0.5, 0.5, 0.5), "cm")) +
  annotate(geom = "text", x = -Inf, y = Inf,
           label = "Quadratic: P < 0.05, R^2 = 0.0295", hjust = -0.05, vjust = 4, size = 5, color = "#466983FF") +
  annotate(geom = "text", x = -Inf, y = Inf,
           label = "Linear: P < 0.05, R^2 = 0.0294", hjust = -0.05, vjust = 2, size = 5, color = "#CE3D32FF")
p_FIS_logNc_end

model_Nm_Nc_end_1 <- lm(Nm~Nc,data = es_end)
AIC(model_Nm_Nc_end_1)#786.0148
summary(model_Nm_Nc_end_1)#Adjusted R-squared:  -0.005185 , p-value: 0.5857
model_Nm_Nc_end_2 <- lm(Nm~Nc+I(Nc^2),data = es_end)
AIC(model_Nm_Nc_end_2)#787.9315
summary(model_Nm_Nc_end_2)#Adjusted R-squared:  -0.01207  ,  p-value: 0.828

model_Nm_Nc_end_3 <- lm(Nm~log(Nc),data = es_end)
AIC(model_Nm_Nc_end_3)#783.7582
summary(model_Nm_Nc_end_3)#Adjusted R-squared:  0.01124 , p-value: 0.1129
model_Nm_Nc_end_4 <- lm(Nm~log(Nc)+I(log(Nc)^2),data = es_end)
AIC(model_Nm_Nc_end_4)#784.8191
summary(model_Nm_Nc_end_4)#Adjusted R-squared:  0.01066 ,  p-value: 0.1807

p_Nm_logNc_end <- ggplot(aes(x = log(Nc), y = Nm), data = es_end) +
  geom_point(shape = 20, size = 5, alpha = 0.3, color = "gray") +
  geom_smooth(method = "lm", size = 0.7, linetype = 2, color = "#CE3D32FF", se = TRUE, fill = "#FFC0CB") +
  geom_smooth(method = "lm", size = 0.7, linetype = 2, color = "#466983FF", se = TRUE, formula = y ~ I(x^2) + x, fill = "#ADD8E6") +
  theme(panel.border = element_rect(fill = NA, color = "black", size = 1, linetype = "solid"),
        axis.text.x = element_text(size = 15, face = "bold"),
        axis.text.y = element_text(size = 15, face = "bold"),
        axis.title.x = element_text(size = 15, face = "bold"),
        axis.title.y = element_text(size = 15, face = "bold"),
        legend.position = "none") +
  xlab(label = "log(Nc)") +
  ylab(label = "Nm") +
  theme(plot.margin = unit(c(0.5, 0.5, 0.5, 0.5), "cm")) +
  annotate(geom = "text", x = -Inf, y = Inf,
           label = "Quadratic: P > 0.05, R^2 = 0.0107", hjust = -0.7, vjust = 4, size = 5, color = "#466983FF") +
  annotate(geom = "text", x = -Inf, y = Inf,
           label = "Linear: P > 0.05, R^2 = 0.0112", hjust = -0.9, vjust = 2, size = 5, color = "#CE3D32FF")
p_Nm_logNc_end

#Common
model_He_Nc_com_1 <- lm(He~Nc,data = es_com)
AIC(model_He_Nc_com_1)#-11.63396
summary(model_He_Nc_com_1)#Adjusted R-squared:  -0.0181 , p-value: 0.7033
model_He_Nc_com_2 <- lm(He~Nc+I(Nc^2),data = es_com)
AIC(model_He_Nc_com_2)#-23.45677
summary(model_He_Nc_com_2)#Adjusted R-squared:  0.2155 , p-value: 0.001416

p_He_Nc_com <- ggplot(aes(x = Nc, y = He), data = es_com) +
  geom_point(shape = 20, size = 5, alpha = 0.3, color = "#808080") +
  geom_smooth(method = "lm", size = 0.7, linetype = 2, color = "#CE3D32FF", se = TRUE, fill = "#FFC0CB") +
  geom_smooth(method = "lm", size = 0.7, linetype = 1, color = "#466983FF", se = TRUE, formula = y ~ I(x^2) + x, fill = "#ADD8E6") +
  theme(panel.border = element_rect(fill = NA, color = "black", size = 1, linetype = "solid"),
        axis.text.x = element_text(size = 15, face = "bold"),
        axis.text.y = element_text(size = 15, face = "bold"),
        axis.title.x = element_text(size = 15, face = "bold"),
        axis.title.y = element_text(size = 15, face = "bold"),
        legend.position = "none") +
  xlab(label = "Nc") +
  ylab(label = "He") +
  theme(plot.margin = unit(c(0.5, 0.5, 0.5, 0.5), "cm")) +
  annotate(geom = "text", x = -Inf, y = Inf,
           label = "Quadratic: P < 0.01, R^2 = 0.2155", hjust = -0.05, vjust = 4, size = 5, color = "#466983FF") +
  annotate(geom = "text", x = -Inf, y = Inf,
           label = "Linear: P > 0.05, R^2 = -0.0181", hjust = -0.05, vjust = 2, size = 5, color = "#CE3D32FF")
p_He_Nc_com

model_He_Nc_com_3 <- lm(He~log(Nc),data = es_com)
AIC(model_He_Nc_com_3)#-12.35907
summary(model_He_Nc_com_3)#Adjusted R-squared: -0.003141, p-value: 0.3613
model_He_Nc_com_4 <- lm(He~log(Nc)+I(log(Nc)^2),data = es_com)
AIC(model_He_Nc_com_4)#-10.78649
summary(model_He_Nc_com_4)#Adjusted R-squared:  -0.01605 ,  p-value: 0.5419

p_He_logNc_com <- ggplot(aes(x = log(Nc), y = He), data = es_com) +
  geom_point(shape = 20, size = 5, alpha = 0.3, color = "#808080") +
  geom_smooth(method = "lm", size = 0.7, linetype = 2, color = "#CE3D32FF", se = TRUE, fill = "#FFC0CB") +
  geom_smooth(method = "lm", size = 0.7, linetype = 2, color = "#466983FF", se = TRUE, formula = y ~ I(x^2) + x, fill = "#ADD8E6") +
  theme(panel.border = element_rect(fill = NA, color = "black", size = 1, linetype = "solid"),
        axis.text.x = element_text(size = 15, face = "bold"),
        axis.text.y = element_text(size = 15, face = "bold"),
        axis.title.x = element_text(size = 15, face = "bold"),
        axis.title.y = element_text(size = 15, face = "bold"),
        legend.position = "none") +
  xlab(label = "log(Nc)") +
  ylab(label = "He") +
  theme(plot.margin = unit(c(0.5, 0.5, 0.5, 0.5), "cm")) +
  annotate(geom = "text", x = -Inf, y = Inf,
           label = "Quadratic: P > 0.05, R^2 = -0.0161", hjust = -0.05, vjust = 4, size = 5, color = "#466983FF") +
  annotate(geom = "text", x = -Inf, y = Inf,
           label = "Linear: P > 0.05, R^2 = -0.0031", hjust = -0.05, vjust = 2, size = 5, color = "#CE3D32FF")
p_He_logNc_com

model_FIS_Nc_com_1 <- lm(FIS~Nc,data = es_com)
AIC(model_FIS_Nc_com_1)#4.062281
summary(model_FIS_Nc_com_1)#Adjusted R-squared:  -0.1418  ,  p-value: 0.938
model_FIS_Nc_com_2 <- lm(FIS~Nc+I(Nc^2),data = es_com)
AIC(model_FIS_Nc_com_2)#5.584022
summary(model_FIS_Nc_com_2)#Adjusted R-squared:  -0.2632,  p-value: 0.8503

p_FIS_Nc_com <- ggplot(aes(x = Nc, y = FIS), data = es_com) +
  geom_point(shape = 20, size = 5, alpha = 0.3, color = "#808080") +
  geom_smooth(method = "lm", size = 0.7, linetype = 2, color = "#CE3D32FF", se = TRUE, fill = "#FFC0CB") +
  geom_smooth(method = "lm", size = 0.7, linetype = 2, color = "#466983FF", se = TRUE, formula = y ~ I(x^2) + x, fill = "#ADD8E6") +
  theme(panel.border = element_rect(fill = NA, color = "black", size = 1, linetype = "solid"),
        axis.text.x = element_text(size = 15, face = "bold"),
        axis.text.y = element_text(size = 15, face = "bold"),
        axis.title.x = element_text(size = 15, face = "bold"),
        axis.title.y = element_text(size = 15, face = "bold"),
        legend.position = "none") +
  xlab(label = "Nc") +
  ylab(label = "FIS") +
  theme(plot.margin = unit(c(0.5, 0.5, 0.5, 0.5), "cm")) +
  annotate(geom = "text", x = -Inf, y = Inf,
           label = "Quadratic: P > 0.05, R^2 = -0.2632", hjust = -0.05, vjust = 34, size = 5, color = "#466983FF") +
  annotate(geom = "text", x = -Inf, y = Inf,
           label = "Linear: P > 0.05, R^2 = -0.1418", hjust = -0.05, vjust = 32, size = 5, color = "#CE3D32FF")
p_FIS_Nc_com

model_FIS_Nc_com_3 <- lm(FIS~log(Nc),data = es_com)
AIC(model_FIS_Nc_com_3)#3.99316
summary(model_FIS_Nc_com_3)#Adjusted R-squared:  -0.1331 , p-value: 0.8127
model_FIS_Nc_com_4 <- lm(FIS~log(Nc)+I(log(Nc)^2),data = es_com)
AIC(model_FIS_Nc_com_4)#5.719642
summary(model_FIS_Nc_com_4)#Adjusted R-squared:  -0.2823,  p-value: 0.8896

p_FIS_logNc_com <- ggplot(aes(x = log(Nc), y = FIS), data = es_com) +
  geom_point(shape = 20, size = 5, alpha = 0.3, color = "#808080") +
  geom_smooth(method = "lm", size = 0.7, linetype = 2, color = "#CE3D32FF", se = TRUE, fill = "#FFC0CB") +
  geom_smooth(method = "lm", size = 0.7, linetype = 2, color = "#466983FF", se = TRUE, formula = y ~ I(x^2) + x, fill = "#ADD8E6") +
  theme(panel.border = element_rect(fill = NA, color = "black", size = 1, linetype = "solid"),
        axis.text.x = element_text(size = 15, face = "bold"),
        axis.text.y = element_text(size = 15, face = "bold"),
        axis.title.x = element_text(size = 15, face = "bold"),
        axis.title.y = element_text(size = 15, face = "bold"),
        legend.position = "none") +
  xlab(label = "log(Nc)") +
  ylab(label = "FIS") +
  xlim(4, 8) +
  theme(plot.margin = unit(c(0.5, 0.5, 0.5, 0.5), "cm")) +
  annotate(geom = "text", x = -Inf, y = Inf,
           label = "Quadratic: P > 0.05, R^2 = -0.2823", hjust = -0.05, vjust = 4, size = 5, color = "#466983FF") +
  annotate(geom = "text", x = -Inf, y = Inf,
           label = "Linear: P > 0.05, R^2 = -0.1331", hjust = -0.05, vjust = 2, size = 5, color = "#CE3D32FF")
p_FIS_logNc_com

model_Nm_Nc_com_1 <- lm(Nm~Nc,data = es_com)
AIC(model_Nm_Nc_com_1)#32.22512
summary(model_Nm_Nc_com_1)#Adjusted R-squared:  -0.0541 , p-value: 0.4434
model_Nm_Nc_com_2 <- lm(Nm~Nc+I(Nc^2),data = es_com)
AIC(model_Nm_Nc_com_2)#30.22442
summary(model_Nm_Nc_com_2)#Adjusted R-squared:  0.256 ,  p-value: 0.246

p_Nm_Nc_com <- ggplot(aes(x = Nc, y = Nm), data = es_com) +
  geom_point(shape = 20, size = 5, alpha = 0.3, color = "#808080") +
  geom_smooth(method = "lm", size = 0.7, linetype = 2, color = "#CE3D32FF", se = TRUE, fill = "#FFC0CB") +
  geom_smooth(method = "lm", size = 0.7, linetype = 2, color = "#466983FF", se = TRUE, formula = y ~ I(x^2) + x, fill = "#ADD8E6") +
  theme(panel.border = element_rect(fill = NA, color = "black", size = 1, linetype = "solid"),
        axis.text.x = element_text(size = 15, face = "bold"),
        axis.text.y = element_text(size = 15, face = "bold"),
        axis.title.x = element_text(size = 15, face = "bold"),
        axis.title.y = element_text(size = 15, face = "bold"),
        legend.position = "none") +
  xlab(label = "Nc") +
  ylab(label = "Nm") +
  theme(plot.margin = unit(c(0.5, 0.5, 0.5, 0.5), "cm")) +
  annotate(geom = "text", x = -Inf, y = Inf,
           label = "Quadratic: P > 0.05, R^2 = 0.2560", hjust = -0.05, vjust = 4, size = 5, color = "#466983FF") +
  annotate(geom = "text", x = -Inf, y = Inf,
           label = "Linear: P > 0.05, R^2 = -0.0541", hjust = -0.05, vjust = 2, size = 5, color = "#CE3D32FF")
p_Nm_Nc_com

model_Nm_Nc_com_3 <- lm(Nm~log(Nc),data = es_com)
AIC(model_Nm_Nc_com_3)#32.80901
summary(model_Nm_Nc_com_3)#Adjusted R-squared:  -0.1458  , p-value: 0.6473
model_Nm_Nc_com_4 <- lm(Nm~log(Nc)+I(log(Nc)^2),data = es_com)
AIC(model_Nm_Nc_com_4)#32.55689
summary(model_Nm_Nc_com_4)#Adjusted R-squared:  -0.03823 ,  p-value: 0.4791

p_Nm_logNc_com <- ggplot(aes(x = log(Nc), y = Nm), data = es_com) +
  geom_point(shape = 20, size = 5, alpha = 0.3, color = "#808080") +
  geom_smooth(method = "lm", size = 0.7, linetype = 2, color = "#CE3D32FF", se = TRUE, fill = "#FFC0CB") +
  geom_smooth(method = "lm", size = 0.7, linetype = 2, color = "#466983FF", se = TRUE, formula = y ~ I(x^2) + x, fill = "#ADD8E6") +
  theme(panel.border = element_rect(fill = NA, color = "black", size = 1, linetype = "solid"),
        axis.text.x = element_text(size = 15, face = "bold"),
        axis.text.y = element_text(size = 15, face = "bold"),
        axis.title.x = element_text(size = 15, face = "bold"),
        axis.title.y = element_text(size = 15, face = "bold"),
        legend.position = "none") +
  xlab(label = "log(Nc)") +
  ylab(label = "Nm") +
  xlim(5, 8) +
  theme(plot.margin = unit(c(0.5, 0.5, 0.5, 0.5), "cm")) +
  annotate(geom = "text", x = -Inf, y = Inf,
           label = "Quadratic: P > 0.05, R^2 = -0.0382", hjust = -0.05, vjust = 4, size = 5, color = "#466983FF") +
  annotate(geom = "text", x = -Inf, y = Inf,
           label = "Linear: P > 0.05, R^2 = -0.1458", hjust = -0.05, vjust = 2, size = 5, color = "#CE3D32FF")
p_Nm_logNc_com

#Invasive
model_He_Nc_inv_1 <- lm(He~Nc,data = es_inv)
AIC(model_He_Nc_inv_1)#18.12466
summary(model_He_Nc_inv_1)#Adjusted R-squared:  0.04336 , p-value: 0.04372
model_He_Nc_inv_2 <- lm(He~Nc+I(Nc^2),data = es_inv)
AIC(model_He_Nc_inv_2)#18.6199
summary(model_He_Nc_inv_2)#Adjusted R-squared:  0.04957 , p-value: 0.06458

p_He_Nc_inv <- ggplot(aes(x = Nc, y = He), data = es_inv) +
  geom_point(shape = 20, size = 5, alpha = 0.3, color = "black") +
  geom_smooth(method = "lm", size = 0.7, linetype = 1, color = "#CE3D32FF", se = TRUE, fill = "#FFC0CB") +
  geom_smooth(method = "lm", size = 0.7, linetype = 2, color = "#466983FF", se = TRUE, formula = y ~ I(x^2) + x, fill = "#ADD8E6") +
  theme(panel.border = element_rect(fill = NA, color = "black", size = 1, linetype = "solid"),
        axis.text.x = element_text(size = 15, face = "bold"),
        axis.text.y = element_text(size = 15, face = "bold"),
        axis.title.x = element_text(size = 15, face = "bold"),
        axis.title.y = element_text(size = 15, face = "bold"),
        legend.position = "none") +
  xlab(label = "Nc") +
  ylab(label = "He") +
  theme(plot.margin = unit(c(0.5, 0.5, 0.5, 0.5), "cm")) +
  annotate(geom = "text", x = -Inf, y = Inf,
           label = "Quadratic: P > 0.05, R^2 = 0.0496", hjust = -0.05, vjust = 4, size = 5, color = "#466983FF") +
  annotate(geom = "text", x = -Inf, y = Inf,
           label = "Linear: P < 0.05, R^2 = 0.0434", hjust = -0.05, vjust = 2, size = 5, color = "#CE3D32FF")
p_He_Nc_inv

model_He_Nc_inv_3 <- lm(He~log(Nc),data = es_inv)
AIC(model_He_Nc_inv_3)#22.13427
summary(model_He_Nc_inv_3)#Adjusted R-squared:  -0.01142 , p-value: 0.6575
model_He_Nc_inv_4 <- lm(He~log(Nc)+I(log(Nc)^2),data = es_inv)
AIC(model_He_Nc_inv_4)#20.25265
summary(model_He_Nc_inv_4)#Adjusted R-squared:  0.02777 ,  p-value: 0.1412

p_He_logNc_inv <- ggplot(aes(x = log(Nc), y = He), data = es_inv) +
  geom_point(shape = 20, size = 5, alpha = 0.3, color = "black") +
  geom_smooth(method = "lm", size = 0.7, linetype = 2, color = "#CE3D32FF", se = TRUE, fill = "#FFC0CB") +
  geom_smooth(method = "lm", size = 0.7, linetype = 2, color = "#466983FF", se = TRUE, formula = y ~ I(x^2) + x, fill = "#ADD8E6") +
  theme(panel.border = element_rect(fill = NA, color = "black", size = 1, linetype = "solid"),
        axis.text.x = element_text(size = 15, face = "bold"),
        axis.text.y = element_text(size = 15, face = "bold"),
        axis.title.x = element_text(size = 15, face = "bold"),
        axis.title.y = element_text(size = 15, face = "bold"),
        legend.position = "none") +
  xlab(label = "log(Nc)") +
  ylab(label = "He") +
  theme(plot.margin = unit(c(0.5, 0.5, 0.5, 0.5), "cm")) +
  annotate(geom = "text", x = -Inf, y = Inf,
           label = "Quadratic: P > 0.05, R^2 = 0.0278", hjust = -0.05, vjust = 4, size = 5, color = "#466983FF") +
  annotate(geom = "text", x = -Inf, y = Inf,
           label = "Linear: P > 0.05, R^2 = -0.0114", hjust = -0.05, vjust = 2, size = 5, color = "#CE3D32FF")
p_He_logNc_inv

model_FIS_Nc_inv_1 <- lm(FIS~Nc,data = es_inv)
AIC(model_FIS_Nc_inv_1)#3.815359
summary(model_FIS_Nc_inv_1)#Adjusted R-squared:  0.2601  ,  p-value: 0.1381
model_FIS_Nc_inv_2 <- lm(FIS~Nc+I(Nc^2),data = es_inv)
AIC(model_FIS_Nc_inv_2)#1.925799
summary(model_FIS_Nc_inv_2)#Adjusted R-squared:  0.4694 ,  p-value: 0.1251

p_FIS_Nc_inv <- ggplot(aes(x = Nc, y = FIS), data = es_inv) +
  geom_point(shape = 20, size = 5, alpha = 0.3, color = "black") +
  geom_smooth(method = "lm", size = 0.7, linetype = 2, color = "#CE3D32FF", se = TRUE, fill = "#FFC0CB") +
  geom_smooth(method = "lm", size = 0.7, linetype = 2, color = "#466983FF", se = TRUE, formula = y ~ I(x^2) + x, fill = "#ADD8E6") +
  theme(panel.border = element_rect(fill = NA, color = "black", size = 1, linetype = "solid"),
        axis.text.x = element_text(size = 15, face = "bold"),
        axis.text.y = element_text(size = 15, face = "bold"),
        axis.title.x = element_text(size = 15, face = "bold"),
        axis.title.y = element_text(size = 15, face = "bold"),
        legend.position = "none") +
  xlab(label = "Nc") +
  ylab(label = "FIS") +
  xlim(0, 6000) +
  ylim(-1, 1) +
  theme(plot.margin = unit(c(0.5, 0.5, 0.5, 0.5), "cm")) +
  annotate(geom = "text", x = -Inf, y = Inf,
           label = "Quadratic: P > 0.05, R^2 = 0.4694", hjust = -0.05, vjust = 4, size = 5, color = "#466983FF") +
  annotate(geom = "text", x = -Inf, y = Inf,
           label = "Linear: P > 0.05, R^2 = 0.2601", hjust = -0.05, vjust = 2, size = 5, color = "#CE3D32FF")
p_FIS_Nc_inv

model_FIS_Nc_inv_3 <- lm(FIS~log(Nc),data = es_inv)
AIC(model_FIS_Nc_inv_3)#7.191634
summary(model_FIS_Nc_inv_3)#Adjusted R-squared:  -0.1985  , p-value: 0.9394
model_FIS_Nc_inv_4 <- lm(FIS~log(Nc)+I(log(Nc)^2),data = es_inv)
AIC(model_FIS_Nc_inv_4)#1.909584
summary(model_FIS_Nc_inv_4)#Adjusted R-squared:  0.4707 ,  p-value: 0.1245

p_FIS_logNc_inv <- ggplot(aes(x = log(Nc), y = FIS), data = es_inv) +
  geom_point(shape = 20, size = 5, alpha = 0.3, color = "black") +
  geom_smooth(method = "lm", size = 0.7, linetype = 2, color = "#CE3D32FF", se = TRUE, fill = "#FFC0CB") +
  geom_smooth(method = "lm", size = 0.7, linetype = 2, color = "#466983FF", se = TRUE, formula = y ~ I(x^2) + x, fill = "#ADD8E6") +
  theme(panel.border = element_rect(fill = NA, color = "black", size = 1, linetype = "solid"),
        axis.text.x = element_text(size = 15, face = "bold"),
        axis.text.y = element_text(size = 15, face = "bold"),
        axis.title.x = element_text(size = 15, face = "bold"),
        axis.title.y = element_text(size = 15, face = "bold"),
        legend.position = "none") +
  xlab(label = "log(Nc)") +
  ylab(label = "FIS") +
  theme(plot.margin = unit(c(0.5, 0.5, 0.5, 0.5), "cm")) +
  annotate(geom = "text", x = -Inf, y = Inf,
           label = "Quadratic: P > 0.05, R^2 = 0.4707", hjust = -0.05, vjust = 4, size = 5, color = "#466983FF") +
  annotate(geom = "text", x = -Inf, y = Inf,
           label = "Linear: P > 0.05, R^2 = -0.1985", hjust = -0.05, vjust = 2, size = 5, color = "#CE3D32FF")
p_FIS_logNc_inv

model_Nm_Nc_inv_1 <- lm(Nm~Nc,data = es_inv)
AIC(model_Nm_Nc_inv_1)#87.51533
summary(model_Nm_Nc_inv_1)#Adjusted R-squared:  -0.02107 , p-value: 0.4529
model_Nm_Nc_inv_2 <- lm(Nm~Nc+I(Nc^2),data = es_inv)
AIC(model_Nm_Nc_inv_2)#89.51392
summary(model_Nm_Nc_inv_2)#Adjusted R-squared:  -0.07773 ,  p-value: 0.7599

p_Nm_Nc_inv <- ggplot(aes(x = Nc, y = Nm), data = es_inv) +
  geom_point(shape = 20, size = 5, alpha = 0.3, color = "black") +
  geom_smooth(method = "lm", size = 0.7, linetype = 2, color = "#CE3D32FF", se = TRUE, fill = "#FFC0CB") +
  geom_smooth(method = "lm", size = 0.7, linetype = 2, color = "#466983FF", se = TRUE, formula = y ~ I(x^2) + x, fill = "#ADD8E6") +
  theme(panel.border = element_rect(fill = NA, color = "black", size = 1, linetype = "solid"),
        axis.text.x = element_text(size = 15, face = "bold"),
        axis.text.y = element_text(size = 15, face = "bold"),
        axis.title.x = element_text(size = 15, face = "bold"),
        axis.title.y = element_text(size = 15, face = "bold"),
        legend.position = "none") +
  xlab(label = "Nc") +
  ylab(label = "Nm") +
  xlim(0, 6000) +
  ylim(0, 8) +
  theme(plot.margin = unit(c(0.5, 0.5, 0.5, 0.5), "cm")) +
  annotate(geom = "text", x = -Inf, y = Inf,
           label = "Quadratic: P > 0.05, R^2 = -0.0777", hjust = -0.05, vjust = 4, size = 5, color = "#466983FF") +
  annotate(geom = "text", x = -Inf, y = Inf,
           label = "Linear: P > 0.05, R^2 = -0.0211", hjust = -0.05, vjust = 2, size = 5, color = "#CE3D32FF")
p_Nm_Nc_inv

model_Nm_Nc_inv_3 <- lm(Nm~log(Nc),data = es_inv)
AIC(model_Nm_Nc_inv_3)#87.96033
summary(model_Nm_Nc_inv_3)#Adjusted R-squared:  -0.04294, p-value: 0.6791
model_Nm_Nc_inv_4 <- lm(Nm~log(Nc)+I(log(Nc)^2),data = es_inv)
AIC(model_Nm_Nc_inv_4)#89.5712
summary(model_Nm_Nc_inv_4)#Adjusted R-squared:  -0.08067,  p-value: 0.7788

p_Nm_logNc_inv <- ggplot(aes(x = log(Nc), y = Nm), data = es_inv) +
  geom_point(shape = 20, size = 5, alpha = 0.3, color = "black") +
  geom_smooth(method = "lm", size = 0.7, linetype = 2, color = "#CE3D32FF", se = TRUE, fill = "#FFC0CB") +
  geom_smooth(method = "lm", size = 0.7, linetype = 2, color = "#466983FF", se = TRUE, formula = y ~ I(x^2) + x, fill = "#ADD8E6") +
  theme(panel.border = element_rect(fill = NA, color = "black", size = 1, linetype = "solid"),
        axis.text.x = element_text(size = 15, face = "bold"),
        axis.text.y = element_text(size = 15, face = "bold"),
        axis.title.x = element_text(size = 15, face = "bold"),
        axis.title.y = element_text(size = 15, face = "bold"),
        legend.position = "none") +
  xlab(label = "log(Nc)") +
  ylab(label = "Nm") +
  ylim(0, 10) +
  theme(plot.margin = unit(c(0.5, 0.5, 0.5, 0.5), "cm")) +
  annotate(geom = "text", x = -Inf, y = Inf,
           label = "Quadratic: P > 0.05, R^2 = -0.0807", hjust = -0.05, vjust = 4, size = 5, color = "#466983FF") +
  annotate(geom = "text", x = -Inf, y = Inf,
           label = "Linear: P > 0.05, R^2 = -0.0429", hjust = -0.05, vjust = 2, size = 5, color = "#CE3D32FF")
p_Nm_logNc_inv

#NSS
model_He_Nc_NSS_1 <- lm(He~Nc,data = es_NSS)
AIC(model_He_Nc_NSS_1)#-151.8919
summary(model_He_Nc_NSS_1)#Adjusted R-squared:  0.0006885, p-value: 0.296
model_He_Nc_NSS_2 <- lm(He~Nc+I(Nc^2),data = es_NSS)
AIC(model_He_Nc_NSS_2)#-150.6682
summary(model_He_Nc_NSS_2)#Adjusted R-squared:  -0.0009633, p-value: 0.3968

p_He_Nc_NSS <- ggplot(aes(x = Nc, y = He), data = es_NSS) +
  geom_point(shape = 20, size = 5, alpha = 0.3, color = "#A41B1BFF") +
  geom_smooth(method = "lm", size = 0.7, linetype = 2, color = "#CE3D32FF", se = TRUE, fill = "#FFC0CB") +
  geom_smooth(method = "lm", size = 0.7, linetype = 2, color = "#466983FF", se = TRUE, formula = y ~ I(x^2) + x, fill = "#ADD8E6") +
  theme(panel.border = element_rect(fill = NA, color = "black", size = 1, linetype = "solid"),
        axis.text.x = element_text(size = 15, face = "bold"),
        axis.text.y = element_text(size = 15, face = "bold"),
        axis.title.x = element_text(size = 15, face = "bold"),
        axis.title.y = element_text(size = 15, face = "bold"),
        legend.position = "none") +
  xlab(label = "Nc") +
  ylab(label = "He") +
  theme(plot.margin = unit(c(0.5, 0.5, 0.5, 0.5), "cm")) +
  annotate(geom = "text", x = -Inf, y = Inf,
           label = "Quadratic: P > 0.05, R^2 = -0.0010", hjust = -0.7, vjust = 4, size = 5, color = "#466983FF") +
  annotate(geom = "text", x = -Inf, y = Inf,
           label = "Linear: P > 0.05, R^2 = 0.0007", hjust = -0.9, vjust = 2, size = 5, color = "#CE3D32FF")
p_He_Nc_NSS

model_He_Nc_NSS_3 <- lm(He~log(Nc),data = es_NSS)
AIC(model_He_Nc_NSS_3)#-156.0707
summary(model_He_Nc_NSS_3)#Adjusted R-squared:  0.02889 , p-value: 0.0226
model_He_Nc_NSS_4 <- lm(He~log(Nc)+I(log(Nc)^2),data = es_NSS)
AIC(model_He_Nc_NSS_4)#-160.7557
summary(model_He_Nc_NSS_4)#Adjusted R-squared:  0.06586 ,  p-value: 0.002839

p_He_logNc_NSS <- ggplot(aes(x = log(Nc), y = He), data = es_NSS) +
  geom_point(shape = 20, size = 5, alpha = 0.3, color = "#A41B1BFF") +
  geom_smooth(method = "lm", size = 0.7, linetype = 1, color = "#CE3D32FF", se = TRUE, fill = "#FFC0CB") +
  geom_smooth(method = "lm", size = 0.7, linetype = 1, color = "#466983FF", se = TRUE, formula = y ~ I(x^2) + x, fill = "#ADD8E6") +
  theme(panel.border = element_rect(fill = NA, color = "black", size = 1, linetype = "solid"),
        axis.text.x = element_text(size = 15, face = "bold"),
        axis.text.y = element_text(size = 15, face = "bold"),
        axis.title.x = element_text(size = 15, face = "bold"),
        axis.title.y = element_text(size = 15, face = "bold"),
        legend.position = "none") +
  xlab(label = "log(Nc)") +
  ylab(label = "He") +
  theme(plot.margin = unit(c(0.5, 0.5, 0.5, 0.5), "cm")) +
  annotate(geom = "text", x = -Inf, y = Inf,
           label = "Quadratic: P < 0.01, R^2 = 0.0659", hjust = -0.05, vjust = 4, size = 5, color = "#466983FF") +
  annotate(geom = "text", x = -Inf, y = Inf,
           label = "Linear: P < 0.05, R^2 = 0.0289", hjust = -0.05, vjust = 2, size = 5, color = "#CE3D32FF")
p_He_logNc_NSS

model_FIS_Nc_NSS_1 <- lm(FIS~Nc,data = es_NSS)
AIC(model_FIS_Nc_NSS_1)#36.81494
summary(model_FIS_Nc_NSS_1)#Adjusted R-squared:  -0.02434,  p-value: 0.8729
model_FIS_Nc_NSS_2 <- lm(FIS~Nc+I(Nc^2),data = es_NSS)
AIC(model_FIS_Nc_NSS_2)#38.81491
summary(model_FIS_Nc_NSS_2)#Adjusted R-squared:  -0.0506,  p-value: 0.9874

p_FIS_Nc_NSS <- ggplot(aes(x = Nc, y = FIS), data = es_NSS) +
  geom_point(shape = 20, size = 5, alpha = 0.3, color = "#A41B1BFF") +
  geom_smooth(method = "lm", size = 0.7, linetype = 2, color = "#CE3D32FF", se = TRUE, fill = "#FFC0CB") +
  geom_smooth(method = "lm", size = 0.7, linetype = 2, color = "#466983FF", se = TRUE, formula = y ~ I(x^2) + x, fill = "#ADD8E6") +
  theme(panel.border = element_rect(fill = NA, color = "black", size = 1, linetype = "solid"),
        axis.text.x = element_text(size = 15, face = "bold"),
        axis.text.y = element_text(size = 15, face = "bold"),
        axis.title.x = element_text(size = 15, face = "bold"),
        axis.title.y = element_text(size = 15, face = "bold"),
        legend.position = "none") +
  xlab(label = "Nc") +
  ylab(label = "FIS") +
  theme(plot.margin = unit(c(0.5, 0.5, 0.5, 0.5), "cm")) +
  annotate(geom = "text", x = -Inf, y = Inf,
           label = "Quadratic: P > 0.05, R^2 = -0.0506", hjust = -0.05, vjust = 4, size = 5, color = "#466983FF") +
  annotate(geom = "text", x = -Inf, y = Inf,
           label = "Linear: P > 0.05, R^2 = -0.0243", hjust = -0.05, vjust = 2, size = 5, color = "#CE3D32FF")
p_FIS_Nc_NSS

model_FIS_Nc_NSS_3 <- lm(FIS~log(Nc),data = es_NSS)
AIC(model_FIS_Nc_NSS_3)#36.84212
summary(model_FIS_Nc_NSS_3)#Adjusted R-squared:  -0.025, p-value: 0.9964
model_FIS_Nc_NSS_4 <- lm(FIS~log(Nc)+I(log(Nc)^2),data = es_NSS)
AIC(model_FIS_Nc_NSS_4)#37.77451
summary(model_FIS_Nc_NSS_4)#Adjusted R-squared:  -0.0249,  p-value: 0.6092

p_FIS_logNc_NSS <- ggplot(aes(x = log(Nc), y = FIS), data = es_NSS) +
  geom_point(shape = 20, size = 5, alpha = 0.3, color = "#A41B1BFF") +
  geom_smooth(method = "lm", size = 0.7, linetype = 2, color = "#CE3D32FF", se = TRUE, fill = "#FFC0CB") +
  geom_smooth(method = "lm", size = 0.7, linetype = 2, color = "#466983FF", se = TRUE, formula = y ~ I(x^2) + x, fill = "#ADD8E6") +
  theme(panel.border = element_rect(fill = NA, color = "black", size = 1, linetype = "solid"),
        axis.text.x = element_text(size = 15, face = "bold"),
        axis.text.y = element_text(size = 15, face = "bold"),
        axis.title.x = element_text(size = 15, face = "bold"),
        axis.title.y = element_text(size = 15, face = "bold"),
        legend.position = "none") +
  xlab(label = "log(Nc)") +
  ylab(label = "FIS") +
  theme(plot.margin = unit(c(0.5, 0.5, 0.5, 0.5), "cm")) +
  annotate(geom = "text", x = -Inf, y = Inf,
           label = "Quadratic: P > 0.05, R^2 = -0.0249", hjust = -0.05, vjust = 4, size = 5, color = "#466983FF") +
  annotate(geom = "text", x = -Inf, y = Inf,
           label = "Linear: P > 0.05, R^2 = -0.0250", hjust = -0.05, vjust = 2, size = 5, color = "#CE3D32FF")
p_FIS_logNc_NSS

model_Nm_Nc_NSS_1 <- lm(Nm~Nc,data = es_NSS)
AIC(model_Nm_Nc_NSS_1)#347.0034
summary(model_Nm_Nc_NSS_1)#Adjusted R-squared:  -0.01002 , p-value: 0.5533
model_Nm_Nc_NSS_2 <- lm(Nm~Nc+I(Nc^2),data = es_NSS)
AIC(model_Nm_Nc_NSS_2)#349.0021
summary(model_Nm_Nc_NSS_2)#Adjusted R-squared:  -0.02603,  p-value: 0.8395

p_Nm_Nc_NSS <- ggplot(aes(x = Nc, y = Nm), data = es_NSS) +
  geom_point(shape = 20, size = 5, alpha = 0.3, color = "#A41B1BFF") +
  geom_smooth(method = "lm", size = 0.7, linetype = 2, color = "#CE3D32FF", se = TRUE, fill = "#FFC0CB") +
  geom_smooth(method = "lm", size = 0.7, linetype = 2, color = "#466983FF", se = TRUE, formula = y ~ I(x^2) + x, fill = "#ADD8E6") +
  theme(panel.border = element_rect(fill = NA, color = "black", size = 1, linetype = "solid"),
        axis.text.x = element_text(size = 15, face = "bold"),
        axis.text.y = element_text(size = 15, face = "bold"),
        axis.title.x = element_text(size = 15, face = "bold"),
        axis.title.y = element_text(size = 15, face = "bold"),
        legend.position = "none") +
  xlab(label = "Nc") +
  ylab(label = "Nm") +
  theme(plot.margin = unit(c(0.5, 0.5, 0.5, 0.5), "cm")) +
  annotate(geom = "text", x = -Inf, y = Inf,
           label = "Quadratic: P > 0.05, R^2 = -0.0260", hjust = -0.7, vjust = 4, size = 5, color = "#466983FF") +
  annotate(geom = "text", x = -Inf, y = Inf,
           label = "Linear: P > 0.05, R^2 = -0.0100", hjust = -0.9, vjust = 2, size = 5, color = "#CE3D32FF")
p_Nm_Nc_NSS

model_Nm_Nc_NSS_3 <- lm(Nm~log(Nc),data = es_NSS)
AIC(model_Nm_Nc_NSS_3)#347.2803
summary(model_Nm_Nc_NSS_3)#Adjusted R-squared:  -0.01427 , p-value: 0.7707
model_Nm_Nc_NSS_4 <- lm(Nm~log(Nc)+I(log(Nc)^2),data = es_NSS)
AIC(model_Nm_Nc_NSS_4)#348.2841
summary(model_Nm_Nc_NSS_4)#Adjusted R-squared:  -0.01493 ,  p-value: 0.5959

p_Nm_logNc_NSS <- ggplot(aes(x = log(Nc), y = Nm), data = es_NSS) +
  geom_point(shape = 20, size = 5, alpha = 0.3, color = "#A41B1BFF") +
  geom_smooth(method = "lm", size = 0.7, linetype = 2, color = "#CE3D32FF", se = TRUE, fill = "#FFC0CB") +
  geom_smooth(method = "lm", size = 0.7, linetype = 2, color = "#466983FF", se = TRUE, formula = y ~ I(x^2) + x, fill = "#ADD8E6") +
  theme(panel.border = element_rect(fill = NA, color = "black", size = 1, linetype = "solid"),
        axis.text.x = element_text(size = 15, face = "bold"),
        axis.text.y = element_text(size = 15, face = "bold"),
        axis.title.x = element_text(size = 15, face = "bold"),
        axis.title.y = element_text(size = 15, face = "bold"),
        legend.position = "none") +
  xlab(label = "log(Nc)") +
  ylab(label = "Nm") +
  theme(plot.margin = unit(c(0.5, 0.5, 0.5, 0.5), "cm")) +
  annotate(geom = "text", x = -Inf, y = Inf,
           label = "Quadratic: P > 0.05, R^2 = -0.0149", hjust = -0.05, vjust = 4, size = 5, color = "#466983FF") +
  annotate(geom = "text", x = -Inf, y = Inf,
           label = "Linear: P > 0.05, R^2 = -0.0143", hjust = -0.05, vjust = 2, size = 5, color = "#CE3D32FF")
p_Nm_logNc_NSS

es_NSS_clean <- es_NSS[es_NSS$Nm < 10, ]
model_Nm_Nc_NSS_clean_1 <- lm(Nm~Nc,data = es_NSS_clean)
AIC(model_Nm_Nc_NSS_clean_1)#238.3377
summary(model_Nm_Nc_NSS_clean_1)#Adjusted R-squared:  -0.01483 , p-value: 0.7996
model_Nm_Nc_NSS_clean_2 <- lm(Nm~Nc+I(Nc^2),data = es_NSS_clean)
AIC(model_Nm_Nc_NSS_clean_2)#239.7336
summary(model_Nm_Nc_NSS_clean_2)#Adjusted R-squared:  -0.02166,  p-value: 0.7261

p_Nm_Nc_NSS_clean <- ggplot(aes(x = Nc, y = Nm), data = es_NSS_clean) +
  geom_point(shape = 20, size = 5, alpha = 0.3, color = "#A41B1BFF") +
  geom_smooth(method = "lm", size = 0.7, linetype = 2, color = "#CE3D32FF", se = TRUE, fill = "#FFC0CB") +
  geom_smooth(method = "lm", size = 0.7, linetype = 2, color = "#466983FF", se = TRUE, formula = y ~ I(x^2) + x, fill = "#ADD8E6") +
  theme(panel.border = element_rect(fill = NA, color = "black", size = 1, linetype = "solid"),
        axis.text.x = element_text(size = 15, face = "bold"),
        axis.text.y = element_text(size = 15, face = "bold"),
        axis.title.x = element_text(size = 15, face = "bold"),
        axis.title.y = element_text(size = 15, face = "bold"),
        legend.position = "none") +
  xlab(label = "Nc") +
  ylab(label = "Nm") +
  theme(plot.margin = unit(c(0.5, 0.5, 0.5, 0.5), "cm")) +
  annotate(geom = "text", x = -Inf, y = Inf,
           label = "Quadratic: P > 0.05, R^2 = -0.0217", hjust = -0.7, vjust = 4, size = 5, color = "#466983FF") +
  annotate(geom = "text", x = -Inf, y = Inf,
           label = "Linear: P > 0.05, R^2 = -0.0148", hjust = -0.9, vjust = 2, size = 5, color = "#CE3D32FF")
p_Nm_Nc_NSS_clean

##Influence of Nc (LMM)####

#Endangered
es_end <- cbind(es_end, es_endangered[, c("taxon", "gene_meth", "DNA_sou")])
#He_Nc
model_He_Nc_end_1 <-  lmer(He~Nc + (1 | taxon) + (1 | gene_meth) + (1 | DNA_sou), data = es_end)
AIC(model_He_Nc_end_1)#-628.8614
summary(model_He_Nc_end_1)#Nc 2.947e-07  2.280e-07 2.567e+02   1.293   0.1973
marginal_r2_model_He_Nc_end_1 <- r.squaredGLMM(model_He_Nc_end_1)
marginal_r2_model_He_Nc_end_1# R2m 0.002259828     R2c 0.9351334
model_He_Nc_end_2 <- lmer(He~Nc+I(Nc^2) + (1 | taxon) + (1 | gene_meth) + (1 | DNA_sou),data = es_end)
AIC(model_He_Nc_end_2)#-577.3826
summary(model_He_Nc_end_2)#Nc 1.086e-06  4.607e-07  3.301e+02   2.357   0.0190 *; I(Nc^2) -2.172e-12  1.100e-12  3.433e+02  -1.974   0.0491 *
marginal_r2_model_He_Nc_end_2 <- r.squaredGLMM(model_He_Nc_end_2)
marginal_r2_model_He_Nc_end_2# R2m 0.004148421  R2c 0.93554

p_He_Nc_end <- ggplot(aes(x = Nc, y = He), data = es_end) +
  geom_point(shape = 20, size = 5, alpha = 0.3, color = "gray") +
  geom_smooth(method = "lm", size = 0.7, linetype = 2, color = "#CE3D32FF", se = TRUE, fill = "#FFC0CB") +
  geom_smooth(method = "lm", size = 0.7, linetype = 1, color = "#466983FF", se = TRUE, formula = y ~ I(x^2) + x, fill = "#ADD8E6") +
  theme(panel.border = element_rect(fill = NA, color = "black", size = 1, linetype = "solid"),
        axis.text.x = element_text(size = 15, face = "bold"),
        axis.text.y = element_text(size = 15, face = "bold"),
        axis.title.x = element_text(size = 15, face = "bold"),
        axis.title.y = element_text(size = 15, face = "bold"),
        legend.position = "none") +
  xlab(label = "Nc") +
  ylab(label = "He") +
  theme(plot.margin = unit(c(0.5, 0.5, 0.5, 0.5), "cm"),
        panel.background = element_rect(fill = "white", colour = "black"),
        panel.grid.major = element_line(color = "#F0F0F0", size = 0.25),
        panel.grid.minor = element_line(color = "#F0F0F0", size = 0.15)) +
  annotate(geom = "text", x = -Inf, y = Inf,
           label = "Quadratic: R^2m = 0.0041, R^2c = 0.9355, *", hjust = -0.05, vjust = 22, size = 5, color = "#466983FF") +
  annotate(geom = "text", x = -Inf, y = Inf,
           label = "Linear: R^2m = 0.0023, R^2c = 0.9351, ns", hjust = -0.05, vjust = 20, size = 5, color = "#CE3D32FF")
p_He_Nc_end

model_He_Nc_end_3 <- lmer(He~log(Nc)+ (1 | taxon) + (1 | gene_meth) + (1 | DNA_sou),data = es_end)
AIC(model_He_Nc_end_3)#-649.2081
summary(model_He_Nc_end_3)#log(Nc) 4.216e-03  2.198e-03 2.590e+02   1.918   0.0562 .
marginal_r2_model_He_Nc_end_3 <- r.squaredGLMM(model_He_Nc_end_3)
marginal_r2_model_He_Nc_end_3# R2m 0.001694221   R2c 0.9361512 
model_He_Nc_end_4 <- lmer(He~log(Nc)+I(log(Nc)^2)+ (1 | taxon) + (1 | gene_meth) + (1 | DNA_sou),data = es_end)
AIC(model_He_Nc_end_4)#-634.8352
summary(model_He_Nc_end_4)#log(Nc) 7.038e-03  1.009e-02  2.905e+02   0.698   0.4860; I(log(Nc)^2) -2.262e-04  7.888e-04  2.948e+02  -0.287   0.7745
marginal_r2_model_He_Nc_end_4 <- r.squaredGLMM(model_He_Nc_end_4)
marginal_r2_model_He_Nc_end_4# R2m 0.001725505   R2c 0.9363382

p_He_logNc_end <- ggplot(aes(x = log(Nc), y = He), data = es_end) +
  geom_point(shape = 20, size = 5, alpha = 0.3, color = "gray") +
  geom_smooth(method = "lm", size = 0.7, linetype = 2, color = "#CE3D32FF", se = TRUE, fill = "#FFC0CB") +
  geom_smooth(method = "lm", size = 0.7, linetype = 2, color = "#466983FF", se = TRUE, formula = y ~ I(x^2) + x, fill = "#ADD8E6") +
  theme(panel.border = element_rect(fill = NA, color = "black", size = 1, linetype = "solid"),
        axis.text.x = element_text(size = 15, face = "bold"),
        axis.text.y = element_text(size = 15, face = "bold"),
        axis.title.x = element_text(size = 15, face = "bold"),
        axis.title.y = element_text(size = 15, face = "bold"),
        legend.position = "none") +
  xlab(label = "log(Nc)") +
  ylab(label = "He") +
  theme(plot.margin = unit(c(0.5, 0.5, 0.5, 0.5), "cm"),
        panel.background = element_rect(fill = "white", colour = "black"),
        panel.grid.major = element_line(color = "#F0F0F0", size = 0.25),
        panel.grid.minor = element_line(color = "#F0F0F0", size = 0.15)) +
  annotate(geom = "text", x = -Inf, y = Inf,
           label = "Quadratic: R^2m = 0.0017, R^2c = 0.9363, ns", hjust = -0.05, vjust = 4, size = 5, color = "#466983FF") +
  annotate(geom = "text", x = -Inf, y = Inf,
           label = "Linear: R^2m = 0.0017, R^2c = 0.9362, ns", hjust = -0.05, vjust = 2, size = 5, color = "#CE3D32FF")
p_He_logNc_end

#Outlier removal
es_end_Nc_noout <- es_end[order(-es_end$Nc), ]
View(es_end_Nc_noout)
es_end_Nc_noout <- es_end_Nc_noout[es_end_Nc_noout$Nc <= 6000, , drop = FALSE]

model_He_Nc_end_1_noout <-  lmer(He~Nc + (1 | taxon) + (1 | gene_meth) + (1 | DNA_sou), data = es_end_Nc_noout)
AIC(model_He_Nc_end_1_noout)#-572.3579
summary(model_He_Nc_end_1_noout)#Nc -1.486e-07  4.192e-06  2.049e+02  -0.035   0.9718
marginal_r2_model_He_Nc_end_1_noout <- r.squaredGLMM(model_He_Nc_end_1_noout)
marginal_r2_model_He_Nc_end_1_noout# R2m 4.441279e-07     R2c 0.9343867
model_He_Nc_end_2_noout <- lmer(He~Nc+I(Nc^2) + (1 | taxon) + (1 | gene_meth) + (1 | DNA_sou),data = es_end_Nc_noout)
AIC(model_He_Nc_end_2_noout)#-535.1237
summary(model_He_Nc_end_2_noout)#Nc 1.697e-05  1.209e-05  2.190e+02   1.404   0.1618; I(Nc^2) -4.384e-09  2.906e-09  2.136e+02  -1.509   0.1328
marginal_r2_model_He_Nc_end_2_noout <- r.squaredGLMM(model_He_Nc_end_2_noout)
marginal_r2_model_He_Nc_end_2_noout# R2m 0.00078087   R2c 0.9361277

p_He_Nc_end_noout <- ggplot(aes(x = Nc, y = He), data = es_end_Nc_noout) +
  geom_point(shape = 20, size = 5, alpha = 0.3, color = "gray") +
  geom_smooth(method = "lm", size = 0.7, linetype = 2, color = "#CE3D32FF", se = TRUE, fill = "#FFC0CB") +
  geom_smooth(method = "lm", size = 0.7, linetype = 2, color = "#466983FF", se = TRUE, formula = y ~ I(x^2) + x, fill = "#ADD8E6") +
  theme(panel.border = element_rect(fill = NA, color = "black", size = 1, linetype = "solid"),
        axis.text.x = element_text(size = 15, face = "bold"),
        axis.text.y = element_text(size = 15, face = "bold"),
        axis.title.x = element_text(size = 15, face = "bold"),
        axis.title.y = element_text(size = 15, face = "bold"),
        legend.position = "none") +
  xlab(label = "Nc") +
  ylab(label = "He") +
  theme(plot.margin = unit(c(0.5, 0.5, 0.5, 0.5), "cm"),
        panel.background = element_rect(fill = "white", colour = "black"),
        panel.grid.major = element_line(color = "#F0F0F0", size = 0.25),
        panel.grid.minor = element_line(color = "#F0F0F0", size = 0.15)) +
  annotate(geom = "text", x = -Inf, y = Inf,
           label = "Quadratic: R^2m = 0.0008, R^2c = 0.9361, ns", hjust = -0.15, vjust = 4, size = 5, color = "#466983FF") +
  annotate(geom = "text", x = -Inf, y = Inf,
           label = "Linear: R^2m = 0.0000, R^2c = 0.9344, ns", hjust = -0.25, vjust = 2, size = 5, color = "#CE3D32FF")
p_He_Nc_end_noout

model_He_Nc_end_3_noout <- lmer(He~log(Nc)+ (1 | taxon) + (1 | gene_meth) + (1 | DNA_sou),data = es_end_Nc_noout)
AIC(model_He_Nc_end_3_noout)#-586.7145
summary(model_He_Nc_end_3_noout)#log(Nc) 3.254e-03  2.790e-03 2.254e+02   1.166   0.2448
marginal_r2_model_He_Nc_end_3_noout <- r.squaredGLMM(model_He_Nc_end_3_noout)
marginal_r2_model_He_Nc_end_3_noout# R2m 0.0006180478    R2c 0.9359263 
model_He_Nc_end_4_noout <- lmer(He~log(Nc)+I(log(Nc)^2)+ (1 | taxon) + (1 | gene_meth) + (1 | DNA_sou),data = es_end_Nc_noout)
AIC(model_He_Nc_end_4_noout)#-576.641
summary(model_He_Nc_end_4_noout)#log(Nc) 0.031488   0.015586 251.273818   2.020   0.0444 *; I(log(Nc)^2) -0.002619   0.001425 243.866819  -1.837   0.0674 .
marginal_r2_model_He_Nc_end_4_noout <- r.squaredGLMM(model_He_Nc_end_4_noout)
marginal_r2_model_He_Nc_end_4_noout# R2m 0.002728592   R2c 0.9399186

p_He_logNc_end_noout <- ggplot(aes(x = log(Nc), y = He), data = es_end_Nc_noout) +
  geom_point(shape = 20, size = 5, alpha = 0.3, color = "gray") +
  geom_smooth(method = "lm", size = 0.7, linetype = 2, color = "#CE3D32FF", se = TRUE, fill = "#FFC0CB") +
  geom_smooth(method = "lm", size = 0.7, linetype = 2, color = "#466983FF", se = TRUE, formula = y ~ I(x^2) + x, fill = "#ADD8E6") +
  theme(panel.border = element_rect(fill = NA, color = "black", size = 1, linetype = "solid"),
        axis.text.x = element_text(size = 15, face = "bold"),
        axis.text.y = element_text(size = 15, face = "bold"),
        axis.title.x = element_text(size = 15, face = "bold"),
        axis.title.y = element_text(size = 15, face = "bold"),
        legend.position = "none") +
  xlab(label = "log(Nc)") +
  ylab(label = "He") +
  theme(plot.margin = unit(c(0.5, 0.5, 0.5, 0.5), "cm"),
        panel.background = element_rect(fill = "white", colour = "black"),
        panel.grid.major = element_line(color = "#F0F0F0", size = 0.25),
        panel.grid.minor = element_line(color = "#F0F0F0", size = 0.15)) +
  annotate(geom = "text", x = -Inf, y = Inf,
           label = "Quadratic: R^2m = 0.0027, R^2c = 0.9399, ns", hjust = -0.05, vjust = 4, size = 5, color = "#466983FF") +
  annotate(geom = "text", x = -Inf, y = Inf,
           label = "Linear: R^2m = 0.0006, R^2c = 0.9359, ns", hjust = -0.05, vjust = 2, size = 5, color = "#CE3D32FF")
p_He_logNc_end_noout

#Outlier removal2
es_end_Nc_noout2 <- es_end[order(-es_end$Nc), ]
View(es_end_Nc_noout2)
es_end_Nc_noout2 <- es_end_Nc_noout2[es_end_Nc_noout2$Nc <= 10000, , drop = FALSE]

model_He_Nc_end_1_noout2 <-  lmer(He~Nc + (1 | taxon) + (1 | gene_meth) + (1 | DNA_sou), data = es_end_Nc_noout2)
AIC(model_He_Nc_end_1_noout2)#-606.9266
summary(model_He_Nc_end_1_noout2)#Nc 2.275e-06  2.175e-06 2.101e+02   1.046   0.2968 
marginal_r2_model_He_Nc_end_1_noout2 <- r.squaredGLMM(model_He_Nc_end_1_noout2)
marginal_r2_model_He_Nc_end_1_noout2# R2m 0.0003602817      R2c 0.9344227
model_He_Nc_end_2_noout2 <- lmer(He~Nc+I(Nc^2) + (1 | taxon) + (1 | gene_meth) + (1 | DNA_sou),data = es_end_Nc_noout2)
AIC(model_He_Nc_end_2_noout2)#-565.2543
summary(model_He_Nc_end_2_noout2)#Nc -1.910e-06  6.406e-06  2.171e+02  -0.298   0.7658; I(Nc^2) 5.289e-10  7.617e-10  2.117e+02   0.694   0.4882
marginal_r2_model_He_Nc_end_2_noout2 <- r.squaredGLMM(model_He_Nc_end_2_noout2)
marginal_r2_model_He_Nc_end_2_noout2# R2m 0.0004360455    R2c 0.9341784

p_He_Nc_end_noout2 <- ggplot(aes(x = Nc, y = He), data = es_end_Nc_noout2) +
  geom_point(shape = 20, size = 5, alpha = 0.3, color = "gray") +
  geom_smooth(method = "lm", size = 0.7, linetype = 2, color = "#CE3D32FF", se = TRUE, fill = "#FFC0CB") +
  geom_smooth(method = "lm", size = 0.7, linetype = 2, color = "#466983FF", se = TRUE, formula = y ~ I(x^2) + x, fill = "#ADD8E6") +
  theme(panel.border = element_rect(fill = NA, color = "black", size = 1, linetype = "solid"),
        axis.text.x = element_text(size = 15, face = "bold"),
        axis.text.y = element_text(size = 15, face = "bold"),
        axis.title.x = element_text(size = 15, face = "bold"),
        axis.title.y = element_text(size = 15, face = "bold"),
        legend.position = "none") +
  xlab(label = "Nc") +
  ylab(label = "He") +
  theme(plot.margin = unit(c(0.5, 0.5, 0.5, 0.5), "cm"),
        panel.background = element_rect(fill = "white", colour = "black"),
        panel.grid.major = element_line(color = "#F0F0F0", size = 0.25),
        panel.grid.minor = element_line(color = "#F0F0F0", size = 0.15)) +
  annotate(geom = "text", x = -Inf, y = Inf,
           label = "Quadratic: R^2m = 0.0004, R^2c = 0.9342, ns", hjust = -0.15, vjust = 4, size = 5, color = "#466983FF") +
  annotate(geom = "text", x = -Inf, y = Inf,
           label = "Linear: R^2m = 0.0004, R^2c = 0.9344, ns", hjust = -0.25, vjust = 2, size = 5, color = "#CE3D32FF")
p_He_Nc_end_noout2

model_He_Nc_end_3_noout2 <- lmer(He~log(Nc)+ (1 | taxon) + (1 | gene_meth) + (1 | DNA_sou),data = es_end_Nc_noout2)
AIC(model_He_Nc_end_3_noout2)#-621.8523
summary(model_He_Nc_end_3_noout2)#log(Nc) 3.510e-03  2.552e-03 2.366e+02   1.375   0.1703
marginal_r2_model_He_Nc_end_3_noout2 <- r.squaredGLMM(model_He_Nc_end_3_noout2)
marginal_r2_model_He_Nc_end_3_noout2# R2m 0.0008383645     R2c 0.9358485 
model_He_Nc_end_4_noout2 <- lmer(He~log(Nc)+I(log(Nc)^2)+ (1 | taxon) + (1 | gene_meth) + (1 | DNA_sou),data = es_end_Nc_noout2)
AIC(model_He_Nc_end_4_noout2)#-609.2511
summary(model_He_Nc_end_4_noout2)#log(Nc) 0.017378   0.013246 259.402589   1.312    0.191; I(log(Nc)^2) -0.001221   0.001146 250.586034  -1.066    0.288
marginal_r2_model_He_Nc_end_4_noout2 <- r.squaredGLMM(model_He_Nc_end_4_noout2)
marginal_r2_model_He_Nc_end_4_noout2# R2m 0.001602565    R2c 0.9375911

p_He_logNc_end_noout2 <- ggplot(aes(x = log(Nc), y = He), data = es_end_Nc_noout2) +
  geom_point(shape = 20, size = 5, alpha = 0.3, color = "gray") +
  geom_smooth(method = "lm", size = 0.7, linetype = 2, color = "#CE3D32FF", se = TRUE, fill = "#FFC0CB") +
  geom_smooth(method = "lm", size = 0.7, linetype = 2, color = "#466983FF", se = TRUE, formula = y ~ I(x^2) + x, fill = "#ADD8E6") +
  theme(panel.border = element_rect(fill = NA, color = "black", size = 1, linetype = "solid"),
        axis.text.x = element_text(size = 15, face = "bold"),
        axis.text.y = element_text(size = 15, face = "bold"),
        axis.title.x = element_text(size = 15, face = "bold"),
        axis.title.y = element_text(size = 15, face = "bold"),
        legend.position = "none") +
  xlab(label = "log(Nc)") +
  ylab(label = "He") +
  theme(plot.margin = unit(c(0.5, 0.5, 0.5, 0.5), "cm"),
        panel.background = element_rect(fill = "white", colour = "black"),
        panel.grid.major = element_line(color = "#F0F0F0", size = 0.25),
        panel.grid.minor = element_line(color = "#F0F0F0", size = 0.15)) +
  annotate(geom = "text", x = -Inf, y = Inf,
           label = "Quadratic: R^2m = 0.0016, R^2c = 0.9376, ns", hjust = -0.05, vjust = 4, size = 5, color = "#466983FF") +
  annotate(geom = "text", x = -Inf, y = Inf,
           label = "Linear: R^2m = 0.0008, R^2c = 0.9358, ns", hjust = -0.05, vjust = 2, size = 5, color = "#CE3D32FF")
p_He_logNc_end_noout2

#FIS_Nc
model_FIS_Nc_end_1 <- lmer(FIS~Nc+ (1 | taxon) + (1 | gene_meth) + (1 | DNA_sou),data = es_end)
AIC(model_FIS_Nc_end_1)#10.10987
summary(model_FIS_Nc_end_1)#Nc 6.138e-06  3.876e-06 9.747e+01   1.584    0.117
marginal_r2_model_FIS_Nc_end_1 <- r.squaredGLMM(model_FIS_Nc_end_1)
marginal_r2_model_FIS_Nc_end_1#R2m 0.0150051; R2c 0.822742
model_FIS_Nc_end_2 <- lmer(FIS~Nc+I(Nc^2)+ (1 | taxon) + (1 | gene_meth) + (1 | DNA_sou),data = es_end)
AIC(model_FIS_Nc_end_2)#51.84272
summary(model_FIS_Nc_end_2)#Nc 2.424e-05  1.024e-05  9.947e+01   2.367   0.0199 *; I(Nc^2) -2.980e-10  1.560e-10  1.218e+02  -1.910   0.0585 .
marginal_r2_model_FIS_Nc_end_2 <- r.squaredGLMM(model_FIS_Nc_end_2)
marginal_r2_model_FIS_Nc_end_2#R2m 0.02174377 ; R2c 0.8150992

p_FIS_Nc_end <- ggplot(aes(x = Nc, y = FIS), data = es_end) +
  geom_point(shape = 20, size = 5, alpha = 0.3, color = "gray") +
  geom_smooth(method = "lm", size = 0.7, linetype = 2, color = "#CE3D32FF", se = TRUE, fill = "#FFC0CB") +
  geom_smooth(method = "lm", size = 0.7, linetype = 2, color = "#466983FF", se = TRUE, formula = y ~ I(x^2) + x, fill = "#ADD8E6") +
  theme(panel.border = element_rect(fill = NA, color = "black", size = 1, linetype = "solid"),
        axis.text.x = element_text(size = 15, face = "bold"),
        axis.text.y = element_text(size = 15, face = "bold"),
        axis.title.x = element_text(size = 15, face = "bold"),
        axis.title.y = element_text(size = 15, face = "bold"),
        legend.position = "none") +
  xlab(label = "Nc") +
  ylab(label = "FIS") +
  xlim(0, 10000) +
  theme(plot.margin = unit(c(0.5, 0.5, 0.5, 0.5), "cm"),
        panel.background = element_rect(fill = "white", colour = "black"),
        panel.grid.major = element_line(color = "#F0F0F0", size = 0.25),
        panel.grid.minor = element_line(color = "#F0F0F0", size = 0.15)) +
  annotate(geom = "text", x = -Inf, y = Inf,
           label = "Quadratic: R^2m = 0.0217, R^2c = 0.8151, ns", hjust = -0.18, vjust = 4, size = 5, color = "#466983FF") +
  annotate(geom = "text", x = -Inf, y = Inf,
           label = "Linear: R^2m = 0.0150, R^2c = 0.8227, ns", hjust = -0.25, vjust = 2, size = 5, color = "#CE3D32FF")
p_FIS_Nc_end

model_FIS_Nc_end_3 <- lmer(FIS~log(Nc)+ (1 | taxon) + (1 | gene_meth) + (1 | DNA_sou),data = es_end)
AIC(model_FIS_Nc_end_3)#-7.696974
summary(model_FIS_Nc_end_3)#2.078e-02  9.491e-03 1.122e+02   2.189   0.0306 *
marginal_r2_model_FIS_Nc_end_3 <- r.squaredGLMM(model_FIS_Nc_end_3)
marginal_r2_model_FIS_Nc_end_3#R2m 0.01766327 , R2c 0.8154195
model_FIS_Nc_end_4 <- lmer(FIS~log(Nc)+I(log(Nc)^2)+ (1 | taxon) + (1 | gene_meth) + (1 | DNA_sou),data = es_end)
AIC(model_FIS_Nc_end_4)#2.689415
summary(model_FIS_Nc_end_4)#log(Nc) -0.019726   0.042100 131.432725  -0.469    0.640; I(log(Nc)^2)   0.003657   0.003708 130.196711   0.986    0.326
marginal_r2_model_FIS_Nc_end_4 <- r.squaredGLMM(model_FIS_Nc_end_4)
marginal_r2_model_FIS_Nc_end_4#R2m 0.02050568 , R2c 0.8177863

p_FIS_logNc_end <- ggplot(aes(x = log(Nc), y = FIS), data = es_end) +
  geom_point(shape = 20, size = 5, alpha = 0.3, color = "gray") +
  geom_smooth(method = "lm", size = 0.7, linetype = 1, color = "#CE3D32FF", se = TRUE, fill = "#FFC0CB") +
  geom_smooth(method = "lm", size = 0.7, linetype = 1, color = "#466983FF", se = TRUE, formula = y ~ I(x^2) + x, fill = "#ADD8E6") +
  theme(panel.border = element_rect(fill = NA, color = "black", size = 1, linetype = "solid"),
        axis.text.x = element_text(size = 15, face = "bold"),
        axis.text.y = element_text(size = 15, face = "bold"),
        axis.title.x = element_text(size = 15, face = "bold"),
        axis.title.y = element_text(size = 15, face = "bold"),
        legend.position = "none") +
  xlab(label = "log(Nc)") +
  ylab(label = "FIS") +
  theme(plot.margin = unit(c(0.5, 0.5, 0.5, 0.5), "cm"),
        panel.background = element_rect(fill = "white", colour = "black"),
        panel.grid.major = element_line(color = "#F0F0F0", size = 0.25),
        panel.grid.minor = element_line(color = "#F0F0F0", size = 0.15)) +
  annotate(geom = "text", x = -Inf, y = Inf,
           label = "Quadratic: R^2m = 0.0205, R^2c = 0.8178, ns", hjust = -0.05, vjust = 4, size = 5, color = "#466983FF") +
  annotate(geom = "text", x = -Inf, y = Inf,
           label = "Linear: R^2m = 0.0177, R^2c = 0.8154, *", hjust = -0.05, vjust = 2, size = 5, color = "#CE3D32FF")
p_FIS_logNc_end

#Outlierremoval
model_FIS_Nc_end_1_noout <- lmer(FIS~Nc+ (1 | taxon) + (1 | gene_meth) + (1 | DNA_sou),data = es_end_Nc_noout)
AIC(model_FIS_Nc_end_1_noout)#6.584295
summary(model_FIS_Nc_end_1_noout)#Nc 1.564e-05  1.596e-05 7.671e+01   0.980    0.330
marginal_r2_model_FIS_Nc_end_1_noout <- r.squaredGLMM(model_FIS_Nc_end_1_noout)
marginal_r2_model_FIS_Nc_end_1_noout#R2m 0.002313486 ; R2c 0.8148297
model_FIS_Nc_end_2_noout <- lmer(FIS~Nc+I(Nc^2)+ (1 | taxon) + (1 | gene_meth) + (1 | DNA_sou),data = es_end_Nc_noout)
AIC(model_FIS_Nc_end_2_noout)#43.08005
summary(model_FIS_Nc_end_2_noout)#Nc 3.640e-05  4.864e-05  8.957e+01   0.748    0.456; I(Nc^2) -5.271e-09  1.168e-08  7.977e+01  -0.451    0.653
marginal_r2_model_FIS_Nc_end_2_noout <- r.squaredGLMM(model_FIS_Nc_end_2_noout)
marginal_r2_model_FIS_Nc_end_2_noout#R2m 0.003610661  ; R2c 0.8114988

p_FIS_Nc_end_noout <- ggplot(aes(x = Nc, y = FIS), data = es_end_Nc_noout) +
  geom_point(shape = 20, size = 5, alpha = 0.3, color = "gray") +
  geom_smooth(method = "lm", size = 0.7, linetype = 2, color = "#CE3D32FF", se = TRUE, fill = "#FFC0CB") +
  geom_smooth(method = "lm", size = 0.7, linetype = 2, color = "#466983FF", se = TRUE, formula = y ~ I(x^2) + x, fill = "#ADD8E6") +
  theme(panel.border = element_rect(fill = NA, color = "black", size = 1, linetype = "solid"),
        axis.text.x = element_text(size = 15, face = "bold"),
        axis.text.y = element_text(size = 15, face = "bold"),
        axis.title.x = element_text(size = 15, face = "bold"),
        axis.title.y = element_text(size = 15, face = "bold"),
        legend.position = "none") +
  xlab(label = "Nc") +
  ylab(label = "FIS") +
  xlim(0, 5000) +
  theme(plot.margin = unit(c(0.5, 0.5, 0.5, 0.5), "cm"),
        panel.background = element_rect(fill = "white", colour = "black"),
        panel.grid.major = element_line(color = "#F0F0F0", size = 0.25),
        panel.grid.minor = element_line(color = "#F0F0F0", size = 0.15)) +
  annotate(geom = "text", x = -Inf, y = Inf,
           label = "Quadratic: R^2m = 0.0036, R^2c = 0.8115, ns", hjust = -0.18, vjust = 4, size = 5, color = "#466983FF") +
  annotate(geom = "text", x = -Inf, y = Inf,
           label = "Linear: R^2m = 0.0023, R^2c = 0.8148, ns", hjust = -0.25, vjust = 2, size = 5, color = "#CE3D32FF")
p_FIS_Nc_end_noout

model_FIS_Nc_end_3_noout <- lmer(FIS~log(Nc)+ (1 | taxon) + (1 | gene_meth) + (1 | DNA_sou),data = es_end_Nc_noout)
AIC(model_FIS_Nc_end_3_noout)#-6.810747
summary(model_FIS_Nc_end_3_noout)#0.01232    0.01032 100.22216   1.193    0.236
marginal_r2_model_FIS_Nc_end_3_noout <- r.squaredGLMM(model_FIS_Nc_end_3_noout)
marginal_r2_model_FIS_Nc_end_3_noout#R2m 0.004977386  , R2c 0.8139575
model_FIS_Nc_end_4_noout <- lmer(FIS~log(Nc)+I(log(Nc)^2)+ (1 | taxon) + (1 | gene_meth) + (1 | DNA_sou),data = es_end_Nc_noout)
AIC(model_FIS_Nc_end_4_noout)#4.098033
summary(model_FIS_Nc_end_4_noout)#log(Nc) -0.019726   0.042100 131.432725  -0.469    0.640; I(log(Nc)^2)   0.003657   0.003708 130.196711   0.986    0.326
marginal_r2_model_FIS_Nc_end_4_noout <- r.squaredGLMM(model_FIS_Nc_end_4_noout)
marginal_r2_model_FIS_Nc_end_4_noout#R2m 0.004784139 , R2c 0.8130493

p_FIS_logNc_end_noout <- ggplot(aes(x = log(Nc), y = FIS), data = es_end_Nc_noout) +
  geom_point(shape = 20, size = 5, alpha = 0.3, color = "gray") +
  geom_smooth(method = "lm", size = 0.7, linetype = 2, color = "#CE3D32FF", se = TRUE, fill = "#FFC0CB") +
  geom_smooth(method = "lm", size = 0.7, linetype = 2, color = "#466983FF", se = TRUE, formula = y ~ I(x^2) + x, fill = "#ADD8E6") +
  theme(panel.border = element_rect(fill = NA, color = "black", size = 1, linetype = "solid"),
        axis.text.x = element_text(size = 15, face = "bold"),
        axis.text.y = element_text(size = 15, face = "bold"),
        axis.title.x = element_text(size = 15, face = "bold"),
        axis.title.y = element_text(size = 15, face = "bold"),
        legend.position = "none") +
  xlab(label = "log(Nc)") +
  ylab(label = "FIS") +
  theme(plot.margin = unit(c(0.5, 0.5, 0.5, 0.5), "cm"),
        panel.background = element_rect(fill = "white", colour = "black"),
        panel.grid.major = element_line(color = "#F0F0F0", size = 0.25),
        panel.grid.minor = element_line(color = "#F0F0F0", size = 0.15)) +
  annotate(geom = "text", x = -Inf, y = Inf,
           label = "Quadratic: R^2m = 0.0048, R^2c = 0.8130, ns", hjust = -0.05, vjust = 4, size = 5, color = "#466983FF") +
  annotate(geom = "text", x = -Inf, y = Inf,
           label = "Linear: R^2m = 0.0050, R^2c = 0.8140, ns", hjust = -0.05, vjust = 2, size = 5, color = "#CE3D32FF")
p_FIS_logNc_end_noout

#Nm_Nc
model_Nm_Nc_end_1 <- lmer(Nm~Nc+ (1 | taxon) + (1 | gene_meth) + (1 | DNA_sou) ,data = es_end)
AIC(model_Nm_Nc_end_1)#714.9891
summary(model_Nm_Nc_end_1)#Nc  -2.530e-06  7.430e-06  8.634e+01  -0.340    0.734
marginal_r2_model_Nm_Nc_end_1 <- r.squaredGLMM(model_Nm_Nc_end_1)
marginal_r2_model_Nm_Nc_end_1# R2m 0.0007927844     R2c 0.9835558
model_Nm_Nc_end_2 <- lmer(Nm~Nc+I(Nc^2)+ (1 | taxon) + (1 | gene_meth) + (1 | DNA_sou) ,data = es_end)
AIC(model_Nm_Nc_end_2)#763.0038
summary(model_Nm_Nc_end_2)#Nc 1.524e-07  1.840e-05  1.505e+01   0.008   0.9935;  I(Nc^2) -5.727e-12  4.088e-11  2.388e+01  -0.140   0.8898
marginal_r2_model_Nm_Nc_end_2 <- r.squaredGLMM(model_Nm_Nc_end_2)
marginal_r2_model_Nm_Nc_end_2# R2m 0.000760467    R2c 0.9837529

p_Nm_Nc_end <- ggplot(aes(x = Nc, y = Nm), data = es_end) +
  geom_point(shape = 20, size = 5, alpha = 0.3, color = "gray") +
  geom_smooth(method = "lm", size = 0.7, linetype = 2, color = "#CE3D32FF", se = TRUE, fill = "#FFC0CB") +
  geom_smooth(method = "lm", size = 0.7, linetype = 2, color = "#466983FF", se = TRUE, formula = y ~ I(x^2) + x, fill = "#ADD8E6") +
  theme(panel.border = element_rect(fill = NA, color = "black", size = 1, linetype = "solid"),
        axis.text.x = element_text(size = 15, face = "bold"),
        axis.text.y = element_text(size = 15, face = "bold"),
        axis.title.x = element_text(size = 15, face = "bold"),
        axis.title.y = element_text(size = 15, face = "bold"),
        legend.position = "none") +
  xlab(label = "Nc") +
  ylab(label = "Nm") +
  theme(plot.margin = unit(c(0.5, 0.5, 0.5, 0.5), "cm"),
        panel.background = element_rect(fill = "white", colour = "black"),
        panel.grid.major = element_line(color = "#F0F0F0", size = 0.25),
        panel.grid.minor = element_line(color = "#F0F0F0", size = 0.15)) +
  annotate(geom = "text", x = -Inf, y = Inf,
           label = "Quadratic: R^2m = 0.0008, R^2c = 0.9838, ns", hjust = -0.15, vjust = 4, size = 5, color = "#466983FF") +
  annotate(geom = "text", x = -Inf, y = Inf,
           label = "Linear: R^2m = 0.0008, R^2c = 0.9836, ns", hjust = -0.25, vjust = 2, size = 5, color = "#CE3D32FF")
p_Nm_Nc_end

model_Nm_Nc_end_3 <- lmer(Nm~log(Nc)+ (1 | taxon) + (1 | gene_meth) + (1 | DNA_sou),data = es_end)
AIC(model_Nm_Nc_end_3)#696.0062
summary(model_Nm_Nc_end_3)#log(Nc)      0.06539    0.07062 43.85888   0.926    0.360
marginal_r2_model_Nm_Nc_end_3 <- r.squaredGLMM(model_Nm_Nc_end_3)
marginal_r2_model_Nm_Nc_end_3# R2m 0.0009634263     R2c 0.9845448
model_Nm_Nc_end_4 <- lmer(Nm~log(Nc)+I(log(Nc)^2)+ (1 | taxon) + (1 | gene_meth) + (1 | DNA_sou),data = es_end)
AIC(model_Nm_Nc_end_4)#702.9768
summary(model_Nm_Nc_end_4)#log(Nc)      -0.13440    0.35195 57.73524  -0.382    0.704; I(log(Nc)^2)  0.01719    0.02906 54.45251   0.592    0.557
marginal_r2_model_Nm_Nc_end_4 <- r.squaredGLMM(model_Nm_Nc_end_4)
marginal_r2_model_Nm_Nc_end_4# R2m 0.002755911     R2c 0.9848971

p_Nm_logNc_end <- ggplot(aes(x = log(Nc), y = Nm), data = es_end) +
  geom_point(shape = 20, size = 5, alpha = 0.3, color = "gray") +
  geom_smooth(method = "lm", size = 0.7, linetype = 2, color = "#CE3D32FF", se = TRUE, fill = "#FFC0CB") +
  geom_smooth(method = "lm", size = 0.7, linetype = 2, color = "#466983FF", se = TRUE, formula = y ~ I(x^2) + x, fill = "#ADD8E6") +
  theme(panel.border = element_rect(fill = NA, color = "black", size = 1, linetype = "solid"),
        axis.text.x = element_text(size = 15, face = "bold"),
        axis.text.y = element_text(size = 15, face = "bold"),
        axis.title.x = element_text(size = 15, face = "bold"),
        axis.title.y = element_text(size = 15, face = "bold"),
        legend.position = "none") +
  xlab(label = "log(Nc)") +
  ylab(label = "Nm") +
  theme(plot.margin = unit(c(0.5, 0.5, 0.5, 0.5), "cm"),
        panel.background = element_rect(fill = "white", colour = "black"),
        panel.grid.major = element_line(color = "#F0F0F0", size = 0.25),
        panel.grid.minor = element_line(color = "#F0F0F0", size = 0.15)) +
  annotate(geom = "text", x = -Inf, y = Inf,
           label = "Quadratic: R^2m = 0.0028, R^2c = 0.9849, ns", hjust = -0.15, vjust = 4, size = 5, color = "#466983FF") +
  annotate(geom = "text", x = -Inf, y = Inf,
           label = "Linear: R^2m = 0.0010, R^2c = 0.9845, ns", hjust = -0.25, vjust = 2, size = 5, color = "#CE3D32FF")
p_Nm_logNc_end

#Outlier removal
es_end_Nc_noout_Nm <- es_end_Nc_noout[order(-es_end_Nc_noout$Nm), ]
View(es_end_Nc_noout_Nm)
es_end_Nc_noout_Nm <- es_end_Nc_noout_Nm[es_end_Nc_noout_Nm$Nm <= 20, , drop = FALSE]

model_Nm_Nc_end_1_noout <- lmer(Nm~Nc+ (1 | taxon) + (1 | gene_meth) + (1 | DNA_sou) ,data = es_end_Nc_noout_Nm)
AIC(model_Nm_Nc_end_1_noout)#413.7341
summary(model_Nm_Nc_end_1_noout)#Nc  5.523e-05  9.353e-05 5.317e+01   0.590   0.5574
marginal_r2_model_Nm_Nc_end_1_noout <- r.squaredGLMM(model_Nm_Nc_end_1_noout)
marginal_r2_model_Nm_Nc_end_1_noout# R2m 0.001180998      R2c 0.8778212
model_Nm_Nc_end_2_noout <- lmer(Nm~Nc+I(Nc^2)+ (1 | taxon) + (1 | gene_meth) + (1 | DNA_sou) ,data = es_end_Nc_noout_Nm)
AIC(model_Nm_Nc_end_2_noout)#445.5707
summary(model_Nm_Nc_end_2_noout)#Nc 3.357e-04  2.217e-04  5.253e+01   1.514   0.1360; I(Nc^2) -7.371e-08  5.411e-08  4.955e+01  -1.362   0.1793
marginal_r2_model_Nm_Nc_end_2_noout <- r.squaredGLMM(model_Nm_Nc_end_2_noout)
marginal_r2_model_Nm_Nc_end_2_noout# R2m 0.006736081     R2c 0.8864475

p_Nm_Nc_end_noout <- ggplot(aes(x = Nc, y = Nm), data = es_end_Nc_noout_Nm) +
  geom_point(shape = 20, size = 5, alpha = 0.3, color = "gray") +
  geom_smooth(method = "lm", size = 0.7, linetype = 2, color = "#CE3D32FF", se = TRUE, fill = "#FFC0CB") +
  geom_smooth(method = "lm", size = 0.7, linetype = 2, color = "#466983FF", se = TRUE, formula = y ~ I(x^2) + x, fill = "#ADD8E6") +
  theme(panel.border = element_rect(fill = NA, color = "black", size = 1, linetype = "solid"),
        axis.text.x = element_text(size = 15, face = "bold"),
        axis.text.y = element_text(size = 15, face = "bold"),
        axis.title.x = element_text(size = 15, face = "bold"),
        axis.title.y = element_text(size = 15, face = "bold"),
        legend.position = "none") +
  xlab(label = "Nc") +
  ylab(label = "Nm") +
  theme(plot.margin = unit(c(0.5, 0.5, 0.5, 0.5), "cm"),
        panel.background = element_rect(fill = "white", colour = "black"),
        panel.grid.major = element_line(color = "#F0F0F0", size = 0.25),
        panel.grid.minor = element_line(color = "#F0F0F0", size = 0.15)) +
  annotate(geom = "text", x = -Inf, y = Inf,
           label = "Quadratic: R^2m = 0.0067, R^2c = 0.8864, ns", hjust = -0.15, vjust = 4, size = 5, color = "#466983FF") +
  annotate(geom = "text", x = -Inf, y = Inf,
           label = "Linear: R^2m = 0.0012, R^2c = 0.8778, ns", hjust = -0.25, vjust = 2, size = 5, color = "#CE3D32FF")
p_Nm_Nc_end_noout

model_Nm_Nc_end_3_noout <- lmer(Nm~log(Nc)+ (1 | taxon) + (1 | gene_meth) + (1 | DNA_sou),data = es_end_Nc_noout_Nm)
AIC(model_Nm_Nc_end_3_noout)#400.315
summary(model_Nm_Nc_end_3_noout)#log(Nc)      0.05628    0.05849 64.03760   0.962   0.3395
marginal_r2_model_Nm_Nc_end_3_noout <- r.squaredGLMM(model_Nm_Nc_end_3_noout)
marginal_r2_model_Nm_Nc_end_3_noout# R2m 0.003588296      R2c 0.8812079
model_Nm_Nc_end_4_noout <- lmer(Nm~log(Nc)+I(log(Nc)^2)+ (1 | taxon) + (1 | gene_meth) + (1 | DNA_sou),data = es_end_Nc_noout_Nm)
AIC(model_Nm_Nc_end_4_noout)#407.2473
summary(model_Nm_Nc_end_4_noout)#log(Nc) 0.128402   0.362647 84.713396   0.354    0.724; I(log(Nc)^2)  -0.006784   0.033316 79.608450  -0.204    0.839
marginal_r2_model_Nm_Nc_end_4_noout <- r.squaredGLMM(model_Nm_Nc_end_4_noout)
marginal_r2_model_Nm_Nc_end_4_noout# R2m 0.003890363      R2c 0.8787352

p_Nm_logNc_end_noout <- ggplot(aes(x = log(Nc), y = Nm), data = es_end_Nc_noout_Nm) +
  geom_point(shape = 20, size = 5, alpha = 0.3, color = "gray") +
  geom_smooth(method = "lm", size = 0.7, linetype = 2, color = "#CE3D32FF", se = TRUE, fill = "#FFC0CB") +
  geom_smooth(method = "lm", size = 0.7, linetype = 2, color = "#466983FF", se = TRUE, formula = y ~ I(x^2) + x, fill = "#ADD8E6") +
  theme(panel.border = element_rect(fill = NA, color = "black", size = 1, linetype = "solid"),
        axis.text.x = element_text(size = 15, face = "bold"),
        axis.text.y = element_text(size = 15, face = "bold"),
        axis.title.x = element_text(size = 15, face = "bold"),
        axis.title.y = element_text(size = 15, face = "bold"),
        legend.position = "none") +
  xlab(label = "log(Nc)") +
  ylab(label = "Nm") +
  theme(plot.margin = unit(c(0.5, 0.5, 0.5, 0.5), "cm"),
        panel.background = element_rect(fill = "white", colour = "black"),
        panel.grid.major = element_line(color = "#F0F0F0", size = 0.25),
        panel.grid.minor = element_line(color = "#F0F0F0", size = 0.15)) +
  annotate(geom = "text", x = -Inf, y = Inf,
           label = "Quadratic: R^2m = 0.0039, R^2c = 0.8788, ns", hjust = -0.15, vjust = 4, size = 5, color = "#466983FF") +
  annotate(geom = "text", x = -Inf, y = Inf,
           label = "Linear: R^2m = 0.0036, R^2c = 0.8812, ns", hjust = -0.25, vjust = 2, size = 5, color = "#CE3D32FF")
p_Nm_logNc_end_noout

#Common
model_He_Nc_com_1 <- lmer(He~Nc+ (1 | taxon) + (1 | gene_meth) + (1 | DNA_sou),data = es_com)
AIC(model_He_Nc_com_1)#-35.81615
summary(model_He_Nc_com_1)#Nc 8.728e-05  2.999e-05 4.670e+01   2.910  0.00552 **
marginal_r2_model_He_Nc_com_1 <- r.squaredGLMM(model_He_Nc_com_1)
marginal_r2_model_He_Nc_com_1# R2m 0.05403557     R2c 0.88084
model_He_Nc_com_2 <- lmer(He~Nc+I(Nc^2)+ (1 | taxon) + (1 | gene_meth) + (1 | DNA_sou),data = es_com)
AIC(model_He_Nc_com_2)#-12.39088
summary(model_He_Nc_com_2)#Nc 3.290e-04  6.521e-05  2.555e+01   5.045 3.13e-05 ***;I(Nc^2) -1.299e-07  2.520e-08  4.740e+00  -5.154   0.0042 **
marginal_r2_model_He_Nc_com_2 <- r.squaredGLMM(model_He_Nc_com_2)
marginal_r2_model_He_Nc_com_2# R2m 0.1267969     R2c 0.8395478

p_He_Nc_com <- ggplot(aes(x = Nc, y = He), data = es_com) +
  geom_point(shape = 20, size = 5, alpha = 0.3, color = "#808080") +
  geom_smooth(method = "lm", size = 0.7, linetype = 1, color = "#CE3D32FF", se = TRUE, fill = "#FFC0CB") +
  geom_smooth(method = "lm", size = 0.7, linetype = 1, color = "#466983FF", se = TRUE, formula = y ~ I(x^2) + x, fill = "#ADD8E6") +
  theme(panel.border = element_rect(fill = NA, color = "black", size = 1, linetype = "solid"),
        axis.text.x = element_text(size = 15, face = "bold"),
        axis.text.y = element_text(size = 15, face = "bold"),
        axis.title.x = element_text(size = 15, face = "bold"),
        axis.title.y = element_text(size = 15, face = "bold"),
        legend.position = "none") +
  xlab(label = "Nc") +
  ylab(label = "He") +
  theme(plot.margin = unit(c(0.5, 0.5, 0.5, 0.5), "cm"),
        panel.background = element_rect(fill = "white", colour = "black"),
        panel.grid.major = element_line(color = "#F0F0F0", size = 0.25),
        panel.grid.minor = element_line(color = "#F0F0F0", size = 0.15)) +
  annotate(geom = "text", x = -Inf, y = Inf,
           label = "Quadratic: R^2m = 0.1268, R^2c = 0.8395, **", hjust = -0.05, vjust = 22, size = 5, color = "#466983FF") +
  annotate(geom = "text", x = -Inf, y = Inf,
           label = "Linear: R^2m = 0.0540, R^2c = 0.8808, **", hjust = -0.05, vjust = 20, size = 5, color = "#CE3D32FF")
p_He_Nc_com

model_He_Nc_com_3 <- lmer(He~log(Nc)+ (1 | taxon) + (1 | gene_meth) + (1 | DNA_sou),data = es_com)
AIC(model_He_Nc_com_3)#-58.53433
summary(model_He_Nc_com_3)#log(Nc)      0.04686    0.00990 41.48654   4.733 2.58e-05 ***
marginal_r2_model_He_Nc_com_3 <- r.squaredGLMM(model_He_Nc_com_3)
marginal_r2_model_He_Nc_com_3# R2m 0.06557166     R2c 0.8873529
model_He_Nc_com_4 <- lmer(He~log(Nc)+I(log(Nc)^2)+ (1 | taxon) + (1 | gene_meth) + (1 | DNA_sou),data = es_com)
AIC(model_He_Nc_com_4)#-48.54118
summary(model_He_Nc_com_4)#log(Nc) 0.085872   0.059625 42.970772   1.440    0.157;I(log(Nc)^2) -0.003976   0.005960 43.655054  -0.667    0.508
marginal_r2_model_He_Nc_com_4 <- r.squaredGLMM(model_He_Nc_com_4)
marginal_r2_model_He_Nc_com_4# R2m 0.06213063     R2c 0.8828943

p_He_logNc_com <- ggplot(aes(x = log(Nc), y = He), data = es_com) +
  geom_point(shape = 20, size = 5, alpha = 0.3, color = "#808080") +
  geom_smooth(method = "lm", size = 0.7, linetype = 1, color = "#CE3D32FF", se = TRUE, fill = "#FFC0CB") +
  geom_smooth(method = "lm", size = 0.7, linetype = 2, color = "#466983FF", se = TRUE, formula = y ~ I(x^2) + x, fill = "#ADD8E6") +
  theme(panel.border = element_rect(fill = NA, color = "black", size = 1, linetype = "solid"),
        axis.text.x = element_text(size = 15, face = "bold"),
        axis.text.y = element_text(size = 15, face = "bold"),
        axis.title.x = element_text(size = 15, face = "bold"),
        axis.title.y = element_text(size = 15, face = "bold"),
        legend.position = "none") +
  xlab(label = "log(Nc)") +
  ylab(label = "He") +
  theme(plot.margin = unit(c(0.5, 0.5, 0.5, 0.5), "cm"),
        panel.background = element_rect(fill = "white", colour = "black"),
        panel.grid.major = element_line(color = "#F0F0F0", size = 0.25),
        panel.grid.minor = element_line(color = "#F0F0F0", size = 0.15)) +
  annotate(geom = "text", x = -Inf, y = Inf,
           label = "Quadratic: R^2m = 0.0621, R^2c = 0.8829, ns", hjust = -0.05, vjust = 4, size = 5, color = "#466983FF") +
  annotate(geom = "text", x = -Inf, y = Inf,
           label = "Linear: R^2m = 0.0656, R^2c = 0.8874, ***", hjust = -0.05, vjust = 2, size = 5, color = "#CE3D32FF")
p_He_logNc_com

model_FIS_Nc_com_1 <- lmer(FIS~Nc+ (1 | taxon) + (1 | gene_meth) + (1 | DNA_sou),data = es_com)
AIC(model_FIS_Nc_com_1)#18.76144
summary(model_FIS_Nc_com_1)#Nc   -6.394e-05  8.690e-05  4.599e+00  -0.736   0.4976
marginal_r2_model_FIS_Nc_com_1 <- r.squaredGLMM(model_FIS_Nc_com_1)
marginal_r2_model_FIS_Nc_com_1# R2m 0.07280558     R2c 0.9898231
model_FIS_Nc_com_2 <- lmer(FIS~Nc+I(Nc^2)+ (1 | taxon) + (1 | gene_meth) + (1 | DNA_sou),data = es_com)
AIC(model_FIS_Nc_com_2)#50.64788
summary(model_FIS_Nc_com_2)#Nc          -2.195e-04  3.735e-04  3.922e+00  -0.588   0.5888; I(Nc^2)      5.223e-08  1.209e-07  4.339e+00   0.432   0.6864
marginal_r2_model_FIS_Nc_com_2 <- r.squaredGLMM(model_FIS_Nc_com_2)
marginal_r2_model_FIS_Nc_com_2# R2m 0.06270451     R2c 0.9890377

p_FIS_Nc_com <- ggplot(aes(x = Nc, y = FIS), data = es_com) +
  geom_point(shape = 20, size = 5, alpha = 0.3, color = "#808080") +
  geom_smooth(method = "lm", size = 0.7, linetype = 2, color = "#CE3D32FF", se = TRUE, fill = "#FFC0CB") +
  geom_smooth(method = "lm", size = 0.7, linetype = 2, color = "#466983FF", se = TRUE, formula = y ~ I(x^2) + x, fill = "#ADD8E6") +
  theme(panel.border = element_rect(fill = NA, color = "black", size = 1, linetype = "solid"),
        axis.text.x = element_text(size = 15, face = "bold"),
        axis.text.y = element_text(size = 15, face = "bold"),
        axis.title.x = element_text(size = 15, face = "bold"),
        axis.title.y = element_text(size = 15, face = "bold"),
        legend.position = "none") +
  xlab(label = "Nc") +
  ylab(label = "FIS") +
  theme(plot.margin = unit(c(0.5, 0.5, 0.5, 0.5), "cm"),
        panel.background = element_rect(fill = "white", colour = "black"),
        panel.grid.major = element_line(color = "#F0F0F0", size = 0.25),
        panel.grid.minor = element_line(color = "#F0F0F0", size = 0.15)) +
  annotate(geom = "text", x = -Inf, y = Inf,
           label = "Quadratic: R^2m = 0.0627, R^2c = 0.9890, ns", hjust = -0.05, vjust = 22, size = 5, color = "#466983FF") +
  annotate(geom = "text", x = -Inf, y = Inf,
           label = "Linear: R^2m = 0.0728, R^2c = 0.9898, ns", hjust = -0.05, vjust = 20, size = 5, color = "#CE3D32FF")
p_FIS_Nc_com

model_FIS_Nc_com_3 <- lmer(FIS~log(Nc)+ (1 | taxon) + (1 | gene_meth) + (1 | DNA_sou),data = es_com)
AIC(model_FIS_Nc_com_3)#5.780931
summary(model_FIS_Nc_com_3)#log(Nc)     -0.04320    0.05232  5.29323  -0.826    0.445
marginal_r2_model_FIS_Nc_com_3 <- r.squaredGLMM(model_FIS_Nc_com_3)
marginal_r2_model_FIS_Nc_com_3# R2m 0.04215714     R2c 0.986168
model_FIS_Nc_com_4 <- lmer(FIS~log(Nc)+I(log(Nc)^2)+ (1 | taxon) + (1 | gene_meth) + (1 | DNA_sou),data = es_com)
AIC(model_FIS_Nc_com_4)#12.502
summary(model_FIS_Nc_com_4)#log(Nc)       0.045535   0.437537  5.599966   0.104    0.921;I(log(Nc)^2) -0.007816   0.038229  5.999177  -0.204    0.845
marginal_r2_model_FIS_Nc_com_4 <- r.squaredGLMM(model_FIS_Nc_com_4)
marginal_r2_model_FIS_Nc_com_4# R2m 0.06082178     R2c 0.9866193

p_FIS_logNc_com <- ggplot(aes(x = log(Nc), y = FIS), data = es_com) +
  geom_point(shape = 20, size = 5, alpha = 0.3, color = "#808080") +
  geom_smooth(method = "lm", size = 0.7, linetype = 2, color = "#CE3D32FF", se = TRUE, fill = "#FFC0CB") +
  geom_smooth(method = "lm", size = 0.7, linetype = 2, color = "#466983FF", se = TRUE, formula = y ~ I(x^2) + x, fill = "#ADD8E6") +
  theme(panel.border = element_rect(fill = NA, color = "black", size = 1, linetype = "solid"),
        axis.text.x = element_text(size = 15, face = "bold"),
        axis.text.y = element_text(size = 15, face = "bold"),
        axis.title.x = element_text(size = 15, face = "bold"),
        axis.title.y = element_text(size = 15, face = "bold"),
        legend.position = "none") +
  xlab(label = "log(Nc)") +
  ylab(label = "FIS") +
  xlim(4, 8) +
  theme(plot.margin = unit(c(0.5, 0.5, 0.5, 0.5), "cm"),
        panel.background = element_rect(fill = "white", colour = "black"),
        panel.grid.major = element_line(color = "#F0F0F0", size = 0.25),
        panel.grid.minor = element_line(color = "#F0F0F0", size = 0.15)) +
  annotate(geom = "text", x = -Inf, y = Inf,
           label = "Quadratic: R^2m = 0.0608, R^2c = 0.9866, ns", hjust = -0.05, vjust = 22, size = 5, color = "#466983FF") +
  annotate(geom = "text", x = -Inf, y = Inf,
           label = "Linear: R^2m = 0.0422, R^2c = 0.9862, ns", hjust = -0.05, vjust = 20, size = 5, color = "#CE3D32FF")
p_FIS_logNc_com

model_Nm_Nc_com_1 <- lmer(Nm~Nc+(1 | taxon) + (1 | gene_meth) + (1 | DNA_sou),data = es_com)
AIC(model_Nm_Nc_com_1)#48.59986
summary(model_Nm_Nc_com_1)#Nc    -0.0003424  0.0006590  3.9994241  -0.520   0.6308
marginal_r2_model_Nm_Nc_com_1 <- r.squaredGLMM(model_Nm_Nc_com_1)
marginal_r2_model_Nm_Nc_com_1# R2m 0.05154745     R2c 0.999986
model_Nm_Nc_com_2 <- lmer(Nm~Nc+I(Nc^2)+ (1 | taxon) + (1 | gene_meth) + (1 | DNA_sou),data = es_com)
AIC(model_Nm_Nc_com_2)#73.80327
summary(model_Nm_Nc_com_2)#Nc           1.015e-02  4.732e-03  2.749e+00   2.145    0.130;I(Nc^2)     -3.185e-06  1.357e-06  2.224e+00  -2.348    0.131
marginal_r2_model_Nm_Nc_com_2 <- r.squaredGLMM(model_Nm_Nc_com_2)
marginal_r2_model_Nm_Nc_com_2# R2m 0.406026     R2c 0.9386576

p_Nm_Nc_com <- ggplot(aes(x = Nc, y = Nm), data = es_com) +
  geom_point(shape = 20, size = 5, alpha = 0.3, color = "#808080") +
  geom_smooth(method = "lm", size = 0.7, linetype = 2, color = "#CE3D32FF", se = TRUE, fill = "#FFC0CB") +
  geom_smooth(method = "lm", size = 0.7, linetype = 2, color = "#466983FF", se = TRUE, formula = y ~ I(x^2) + x, fill = "#ADD8E6") +
  theme(panel.border = element_rect(fill = NA, color = "black", size = 1, linetype = "solid"),
        axis.text.x = element_text(size = 15, face = "bold"),
        axis.text.y = element_text(size = 15, face = "bold"),
        axis.title.x = element_text(size = 15, face = "bold"),
        axis.title.y = element_text(size = 15, face = "bold"),
        legend.position = "none") +
  xlab(label = "Nc") +
  ylab(label = "Nm") +
  theme(plot.margin = unit(c(0.5, 0.5, 0.5, 0.5), "cm"),
        panel.background = element_rect(fill = "white", colour = "black"),
        panel.grid.major = element_line(color = "#F0F0F0", size = 0.25),
        panel.grid.minor = element_line(color = "#F0F0F0", size = 0.15)) +
  annotate(geom = "text", x = -Inf, y = Inf,
           label = "Quadratic: R^2m = 0.4060, R^2c = 0.9387, ns", hjust = -0.05, vjust = 4, size = 5, color = "#466983FF") +
  annotate(geom = "text", x = -Inf, y = Inf,
           label = "Linear: R^2m = 0.0515, R^2c = 0.9999, ns", hjust = -0.05, vjust = 2, size = 5, color = "#CE3D32FF")
p_Nm_Nc_com

model_Nm_Nc_com_3 <- lmer(Nm~log(Nc)+ (1 | taxon) + (1 | gene_meth) + (1 | DNA_sou),data = es_com)
AIC(model_Nm_Nc_com_3)#34.80097
summary(model_Nm_Nc_com_3)#log(Nc)  -0.1849     0.7403  3.9994   -0.25    0.815
marginal_r2_model_Nm_Nc_com_3 <- r.squaredGLMM(model_Nm_Nc_com_3)
marginal_r2_model_Nm_Nc_com_3# R2m 0.0117644     R2c 0.9999546
model_Nm_Nc_com_4 <- lmer(Nm~log(Nc)+I(log(Nc)^2)+ (1 | taxon) + (1 | gene_meth) + (1 | DNA_sou),data = es_com)
AIC(model_Nm_Nc_com_4)#33.6407
summary(model_Nm_Nc_com_4)#log(Nc)  24.843032   0.047807   3.406566  519.65 1.82e-09 ***;I(log(Nc)^2)  -1.876045   0.003415   3.406574 -549.33 1.51e-09 ***
marginal_r2_model_Nm_Nc_com_4 <- r.squaredGLMM(model_Nm_Nc_com_4)
marginal_r2_model_Nm_Nc_com_4# R2m 0.3446882     R2c 0.9999964

p_Nm_logNc_com <- ggplot(aes(x = log(Nc), y = Nm), data = es_com) +
  geom_point(shape = 20, size = 5, alpha = 0.3, color = "#808080") +
  geom_smooth(method = "lm", size = 0.7, linetype = 2, color = "#CE3D32FF", se = TRUE, fill = "#FFC0CB") +
  geom_smooth(method = "lm", size = 0.7, linetype = 1, color = "#466983FF", se = TRUE, formula = y ~ I(x^2) + x, fill = "#ADD8E6") +
  theme(panel.border = element_rect(fill = NA, color = "black", size = 1, linetype = "solid"),
        axis.text.x = element_text(size = 15, face = "bold"),
        axis.text.y = element_text(size = 15, face = "bold"),
        axis.title.x = element_text(size = 15, face = "bold"),
        axis.title.y = element_text(size = 15, face = "bold"),
        legend.position = "none") +
  xlab(label = "log(Nc)") +
  ylab(label = "Nm") +
  xlim(5, 8) +
  theme(plot.margin = unit(c(0.5, 0.5, 0.5, 0.5), "cm"),
        panel.background = element_rect(fill = "white", colour = "black"),
        panel.grid.major = element_line(color = "#F0F0F0", size = 0.25),
        panel.grid.minor = element_line(color = "#F0F0F0", size = 0.15)) +
  annotate(geom = "text", x = -Inf, y = Inf,
           label = "Quadratic: R^2m = 0.3447, R^2c = 0.9999, ***", hjust = -0.05, vjust = 4, size = 5, color = "#466983FF") +
  annotate(geom = "text", x = -Inf, y = Inf,
           label = "Linear: R^2m = 0.0118, R^2c = 0.9999, ns", hjust = -0.05, vjust = 2, size = 5, color = "#CE3D32FF")
p_Nm_logNc_com

#Invasive
model_He_Nc_inv_1 <- lmer(He~Nc+ (1 | taxon) + (1 | gene_meth),data = es_inv)
AIC(model_He_Nc_inv_1)#-138.24
summary(model_He_Nc_inv_1)#Nc  2.674e-06  1.680e-06 6.250e+01   1.591   0.1166
marginal_r2_model_He_Nc_inv_1 <- r.squaredGLMM(model_He_Nc_inv_1)
marginal_r2_model_He_Nc_inv_1# R2m 0.00249351     R2c 0.9382209
model_He_Nc_inv_2 <- lmer(He~Nc+I(Nc^2)+ (1 | taxon) + (1 | gene_meth),data = es_inv)
AIC(model_He_Nc_inv_2)#-93.84453
summary(model_He_Nc_inv_2)#Nc          1.468e-06  5.120e-06 6.239e+01   0.287   0.7753  ;I(Nc^2)     6.031e-11  2.416e-10 6.221e+01   0.250   0.8037 
marginal_r2_model_He_Nc_inv_2 <- r.squaredGLMM(model_He_Nc_inv_2)
marginal_r2_model_He_Nc_inv_2# R2m 0.002526726     R2c 0.9371331

p_He_Nc_inv <- ggplot(aes(x = Nc, y = He), data = es_inv) +
  geom_point(shape = 20, size = 5, alpha = 0.3, color = "black") +
  geom_smooth(method = "lm", size = 0.7, linetype = 2, color = "#CE3D32FF", se = TRUE, fill = "#FFC0CB") +
  geom_smooth(method = "lm", size = 0.7, linetype = 2, color = "#466983FF", se = TRUE, formula = y ~ I(x^2) + x, fill = "#ADD8E6") +
  theme(panel.border = element_rect(fill = NA, color = "black", size = 1, linetype = "solid"),
        axis.text.x = element_text(size = 15, face = "bold"),
        axis.text.y = element_text(size = 15, face = "bold"),
        axis.title.x = element_text(size = 15, face = "bold"),
        axis.title.y = element_text(size = 15, face = "bold"),
        legend.position = "none") +
  xlab(label = "Nc") +
  ylab(label = "He") +
  theme(plot.margin = unit(c(0.5, 0.5, 0.5, 0.5), "cm"),
        panel.background = element_rect(fill = "white", colour = "black"),
        panel.grid.major = element_line(color = "#F0F0F0", size = 0.25),
        panel.grid.minor = element_line(color = "#F0F0F0", size = 0.15)) +
  annotate(geom = "text", x = -Inf, y = Inf,
           label = "Quadratic: R^2m = 0.0025, R^2c = 0.9371, ns", hjust = -0.05, vjust = 4, size = 5, color = "#466983FF") +
  annotate(geom = "text", x = -Inf, y = Inf,
           label = "Linear: R^2m = 0.0025, R^2c = 0.9382, ns", hjust = -0.05, vjust = 2, size = 5, color = "#CE3D32FF")
p_He_Nc_inv

model_He_Nc_inv_3 <- lmer(He~log(Nc)+ (1 | taxon) + (1 | gene_meth),data = es_inv)
AIC(model_He_Nc_inv_3)#-155.1307
summary(model_He_Nc_inv_3)#log(Nc)  0.007786   0.003886 63.705191   2.003   0.0494 *
marginal_r2_model_He_Nc_inv_3 <- r.squaredGLMM(model_He_Nc_inv_3)
marginal_r2_model_He_Nc_inv_3# R2m 0.004692433     R2c 0.9409612
model_He_Nc_inv_4 <- lmer(He~log(Nc)+I(log(Nc)^2)+ (1 | taxon) + (1 | gene_meth),data = es_inv)
AIC(model_He_Nc_inv_4)#-143.5223
summary(model_He_Nc_inv_4)#log(Nc)   0.030924   0.020164 62.567698   1.534    0.130;I(log(Nc)^2) -0.001934   0.001655 62.334340  -1.169    0.247
marginal_r2_model_He_Nc_inv_4 <- r.squaredGLMM(model_He_Nc_inv_4)
marginal_r2_model_He_Nc_inv_4# R2m 0.006888352     R2c 0.9413011

p_He_logNc_inv <- ggplot(aes(x = log(Nc), y = He), data = es_inv) +
  geom_point(shape = 20, size = 5, alpha = 0.3, color = "black") +
  geom_smooth(method = "lm", size = 0.7, linetype = 1, color = "#CE3D32FF", se = TRUE, fill = "#FFC0CB") +
  geom_smooth(method = "lm", size = 0.7, linetype = 2, color = "#466983FF", se = TRUE, formula = y ~ I(x^2) + x, fill = "#ADD8E6") +
  theme(panel.border = element_rect(fill = NA, color = "black", size = 1, linetype = "solid"),
        axis.text.x = element_text(size = 15, face = "bold"),
        axis.text.y = element_text(size = 15, face = "bold"),
        axis.title.x = element_text(size = 15, face = "bold"),
        axis.title.y = element_text(size = 15, face = "bold"),
        legend.position = "none") +
  xlab(label = "log(Nc)") +
  ylab(label = "He") +
  theme(plot.margin = unit(c(0.5, 0.5, 0.5, 0.5), "cm"),
        panel.background = element_rect(fill = "white", colour = "black"),
        panel.grid.major = element_line(color = "#F0F0F0", size = 0.25),
        panel.grid.minor = element_line(color = "#F0F0F0", size = 0.15)) +
  annotate(geom = "text", x = -Inf, y = Inf,
           label = "Quadratic: R^2m = 0.0069, R^2c = 0.9413, ns", hjust = -0.05, vjust = 4, size = 5, color = "#466983FF") +
  annotate(geom = "text", x = -Inf, y = Inf,
           label = "Linear: R^2m = 0.0047, R^2c = 0.9410, *", hjust = -0.05, vjust = 2, size = 5, color = "#CE3D32FF")
p_He_logNc_inv

model_FIS_Nc_inv_1 <- lmer(FIS~Nc+ (1 | taxon) + (1 | gene_meth),data = es_inv)
AIC(model_FIS_Nc_inv_1)#26.55508
summary(model_FIS_Nc_inv_1)#Nc  1.426e-04  5.677e-05  2.477e+00   2.512    0.105
marginal_r2_model_FIS_Nc_inv_1 <- r.squaredGLMM(model_FIS_Nc_inv_1)
marginal_r2_model_FIS_Nc_inv_1# R2m 0.3883831     R2c 0.906376
model_FIS_Nc_inv_2 <- lmer(FIS~Nc+I(Nc^2)+ (1 | taxon) + (1 | gene_meth),data = es_inv)
AIC(model_FIS_Nc_inv_2)#59.93274
summary(model_FIS_Nc_inv_2)#Nc  4.067e-04  2.176e-04  2.925e+00   1.869    0.161;I(Nc^2)     -4.903e-08  5.218e-08  2.433e+00  -0.940    0.431
marginal_r2_model_FIS_Nc_inv_2 <- r.squaredGLMM(model_FIS_Nc_inv_2)
marginal_r2_model_FIS_Nc_inv_2# R2m 0.3401867     R2c 0.9692569

p_FIS_Nc_inv <- ggplot(aes(x = Nc, y = FIS), data = es_inv) +
  geom_point(shape = 20, size = 5, alpha = 0.3, color = "black") +
  geom_smooth(method = "lm", size = 0.7, linetype = 2, color = "#CE3D32FF", se = TRUE, fill = "#FFC0CB") +
  geom_smooth(method = "lm", size = 0.7, linetype = 2, color = "#466983FF", se = TRUE, formula = y ~ I(x^2) + x, fill = "#ADD8E6") +
  theme(panel.border = element_rect(fill = NA, color = "black", size = 1, linetype = "solid"),
        axis.text.x = element_text(size = 15, face = "bold"),
        axis.text.y = element_text(size = 15, face = "bold"),
        axis.title.x = element_text(size = 15, face = "bold"),
        axis.title.y = element_text(size = 15, face = "bold"),
        legend.position = "none") +
  xlab(label = "Nc") +
  ylab(label = "FIS") +
  xlim(0, 6000) +
  ylim(-1, 1) +
  theme(plot.margin = unit(c(0.5, 0.5, 0.5, 0.5), "cm"),
        panel.background = element_rect(fill = "white", colour = "black"),
        panel.grid.major = element_line(color = "#F0F0F0", size = 0.25),
        panel.grid.minor = element_line(color = "#F0F0F0", size = 0.15)) +
  annotate(geom = "text", x = -Inf, y = Inf,
           label = "Quadratic: R^2m = 0.3402, R^2c = 0.9693, ns", hjust = -0.05, vjust = 4, size = 5, color = "#466983FF") +
  annotate(geom = "text", x = -Inf, y = Inf,
           label = "Linear: R^2m = 0.3884, R^2c = 0.9064, ns", hjust = -0.05, vjust = 2, size = 5, color = "#CE3D32FF")
p_FIS_Nc_inv

model_FIS_Nc_inv_3 <- lmer(FIS~log(Nc)+ (1 | taxon) + (1 | gene_meth),data = es_inv)
AIC(model_FIS_Nc_inv_3)#16.13857
summary(model_FIS_Nc_inv_3)#log(Nc)    0.06863    0.07211  1.40578   0.952    0.476
marginal_r2_model_FIS_Nc_inv_3 <- r.squaredGLMM(model_FIS_Nc_inv_3)
marginal_r2_model_FIS_Nc_inv_3# R2m 0.1331774     R2c 0.8735506
model_FIS_Nc_inv_4 <- lmer(FIS~log(Nc)+I(log(Nc)^2)+ (1 | taxon) + (1 | gene_meth),data = es_inv)
AIC(model_FIS_Nc_inv_4)#16.67981
summary(model_FIS_Nc_inv_4)#log(Nc) -1.25363    0.17114  3.21066  -7.325  0.00416 **;I(log(Nc)^2)  0.11149    0.01462  3.19568   7.624  0.00374 **
marginal_r2_model_FIS_Nc_inv_4 <- r.squaredGLMM(model_FIS_Nc_inv_4)
marginal_r2_model_FIS_Nc_inv_4# R2m 0.3386575     R2c 0.9923302

p_FIS_logNc_inv <- ggplot(aes(x = log(Nc), y = FIS), data = es_inv) +
  geom_point(shape = 20, size = 5, alpha = 0.3, color = "black") +
  geom_smooth(method = "lm", size = 0.7, linetype = 2, color = "#CE3D32FF", se = TRUE, fill = "#FFC0CB") +
  geom_smooth(method = "lm", size = 0.7, linetype = 1, color = "#466983FF", se = TRUE, formula = y ~ I(x^2) + x, fill = "#ADD8E6") +
  theme(panel.border = element_rect(fill = NA, color = "black", size = 1, linetype = "solid"),
        axis.text.x = element_text(size = 15, face = "bold"),
        axis.text.y = element_text(size = 15, face = "bold"),
        axis.title.x = element_text(size = 15, face = "bold"),
        axis.title.y = element_text(size = 15, face = "bold"),
        legend.position = "none") +
  xlab(label = "log(Nc)") +
  ylab(label = "FIS") +
  theme(plot.margin = unit(c(0.5, 0.5, 0.5, 0.5), "cm"),
        panel.background = element_rect(fill = "white", colour = "black"),
        panel.grid.major = element_line(color = "#F0F0F0", size = 0.25),
        panel.grid.minor = element_line(color = "#F0F0F0", size = 0.15)) +
  annotate(geom = "text", x = -Inf, y = Inf,
           label = "Quadratic: R^2m = 0.3387, R^2c = 0.9923, **", hjust = -0.05, vjust = 4, size = 5, color = "#466983FF") +
  annotate(geom = "text", x = -Inf, y = Inf,
           label = "Linear: R^2m = 0.1332, R^2c = 0.8736, ns", hjust = -0.05, vjust = 2, size = 5, color = "#CE3D32FF")
p_FIS_logNc_inv

model_Nm_Nc_inv_1 <- lmer(Nm~Nc+ (1 | taxon) + (1 | gene_meth),data = es_inv)
AIC(model_Nm_Nc_inv_1)#95.48478
summary(model_Nm_Nc_inv_1)#Nc   -8.174e-05  2.798e-04  9.485e+00  -0.292   0.7765
marginal_r2_model_Nm_Nc_inv_1 <- r.squaredGLMM(model_Nm_Nc_inv_1)
marginal_r2_model_Nm_Nc_inv_1# R2m 0.001797469     R2c 0.7205252
model_Nm_Nc_inv_2 <- lmer(Nm~Nc+I(Nc^2)+ (1 | taxon) + (1 | gene_meth),data = es_inv)
AIC(model_Nm_Nc_inv_2)#126.9781
summary(model_Nm_Nc_inv_2)#Nc  8.609e-05  7.308e-04  1.660e+01   0.118   0.9076;I(Nc^2)     -3.853e-08  1.563e-07  1.337e+01  -0.246   0.8091
marginal_r2_model_Nm_Nc_inv_2 <- r.squaredGLMM(model_Nm_Nc_inv_2)
marginal_r2_model_Nm_Nc_inv_2# R2m 0.003031812     R2c 0.7286888

p_Nm_Nc_inv <- ggplot(aes(x = Nc, y = Nm), data = es_inv) +
  geom_point(shape = 20, size = 5, alpha = 0.3, color = "black") +
  geom_smooth(method = "lm", size = 0.7, linetype = 2, color = "#CE3D32FF", se = TRUE, fill = "#FFC0CB") +
  geom_smooth(method = "lm", size = 0.7, linetype = 2, color = "#466983FF", se = TRUE, formula = y ~ I(x^2) + x, fill = "#ADD8E6") +
  theme(panel.border = element_rect(fill = NA, color = "black", size = 1, linetype = "solid"),
        axis.text.x = element_text(size = 15, face = "bold"),
        axis.text.y = element_text(size = 15, face = "bold"),
        axis.title.x = element_text(size = 15, face = "bold"),
        axis.title.y = element_text(size = 15, face = "bold"),
        legend.position = "none") +
  xlab(label = "Nc") +
  ylab(label = "Nm") +
  xlim(0, 6000) +
  ylim(0, 8) +
  theme(plot.margin = unit(c(0.5, 0.5, 0.5, 0.5), "cm"),
        panel.background = element_rect(fill = "white", colour = "black"),
        panel.grid.major = element_line(color = "#F0F0F0", size = 0.25),
        panel.grid.minor = element_line(color = "#F0F0F0", size = 0.15)) +
  annotate(geom = "text", x = -Inf, y = Inf,
           label = "Quadratic: R^2m = 0.0030, R^2c = 0.7287, ns", hjust = -0.05, vjust = 4, size = 5, color = "#466983FF") +
  annotate(geom = "text", x = -Inf, y = Inf,
           label = "Linear: R^2m = 0.0018, R^2c = 0.7205, ns", hjust = -0.05, vjust = 2, size = 5, color = "#CE3D32FF")
p_Nm_Nc_inv

model_Nm_Nc_inv_3 <- lmer(Nm~log(Nc)+ (1 | taxon) + (1 | gene_meth),data = es_inv)
AIC(model_Nm_Nc_inv_3)#82.89045
summary(model_Nm_Nc_inv_3)#log(Nc)    -0.004378   0.157579 18.340735  -0.028   0.9781
marginal_r2_model_Nm_Nc_inv_3 <- r.squaredGLMM(model_Nm_Nc_inv_3)
marginal_r2_model_Nm_Nc_inv_3# R2m 1.536049e-05    R2c 0.7093515
model_Nm_Nc_inv_4 <- lmer(Nm~log(Nc)+I(log(Nc)^2)+ (1 | taxon) + (1 | gene_meth),data = es_inv)
AIC(model_Nm_Nc_inv_4)#87.29893
summary(model_Nm_Nc_inv_4)#log(Nc) 0.38549    1.21907 15.59756   0.316    0.756;I(log(Nc)^2) -0.03687    0.11529 14.74056  -0.320    0.754
marginal_r2_model_Nm_Nc_inv_4 <- r.squaredGLMM(model_Nm_Nc_inv_4)
marginal_r2_model_Nm_Nc_inv_4# R2m 0.002660597     R2c 0.7135103

p_Nm_logNc_inv <- ggplot(aes(x = log(Nc), y = Nm), data = es_inv) +
  geom_point(shape = 20, size = 5, alpha = 0.3, color = "black") +
  geom_smooth(method = "lm", size = 0.7, linetype = 2, color = "#CE3D32FF", se = TRUE, fill = "#FFC0CB") +
  geom_smooth(method = "lm", size = 0.7, linetype = 2, color = "#466983FF", se = TRUE, formula = y ~ I(x^2) + x, fill = "#ADD8E6") +
  theme(panel.border = element_rect(fill = NA, color = "black", size = 1, linetype = "solid"),
        axis.text.x = element_text(size = 15, face = "bold"),
        axis.text.y = element_text(size = 15, face = "bold"),
        axis.title.x = element_text(size = 15, face = "bold"),
        axis.title.y = element_text(size = 15, face = "bold"),
        legend.position = "none") +
  xlab(label = "log(Nc)") +
  ylab(label = "Nm") +
  ylim(0, 10) +
  theme(plot.margin = unit(c(0.5, 0.5, 0.5, 0.5), "cm"),
        panel.background = element_rect(fill = "white", colour = "black"),
        panel.grid.major = element_line(color = "#F0F0F0", size = 0.25),
        panel.grid.minor = element_line(color = "#F0F0F0", size = 0.15)) +
  annotate(geom = "text", x = -Inf, y = Inf,
           label = "Quadratic: R^2m = 0.0027, R^2c = 0.7135, ns", hjust = -0.05, vjust = 4, size = 5, color = "#466983FF") +
  annotate(geom = "text", x = -Inf, y = Inf,
           label = "Linear: R^2m = 1.5360e-05, R^2c = 0.7094, ns", hjust = -0.05, vjust = 2, size = 5, color = "#CE3D32FF")
p_Nm_logNc_inv

#NSS
model_He_Nc_NSS_1 <- lmer(He~Nc+ (1 | taxon) + (1 | gene_meth) + (1 | DNA_sou) ,data = es_NSS)
AIC(model_He_Nc_NSS_1)#-218.2627
summary(model_He_Nc_NSS_1)#Nc  -1.798e-05  5.384e-05  9.224e+01  -0.334   0.7392 
marginal_r2_model_He_Nc_NSS_1 <- r.squaredGLMM(model_He_Nc_NSS_1)
marginal_r2_model_He_Nc_NSS_1# R2m 0.0001966774     R2c 0.8702441
model_He_Nc_NSS_2 <- lmer(He~Nc+I(Nc^2)+ (1 | taxon) + (1 | gene_meth) + (1 | DNA_sou) ,data = es_NSS)
AIC(model_He_Nc_NSS_2)#-188.5838
summary(model_He_Nc_NSS_2)#Nc  -3.113e-05  1.882e-04  1.028e+02  -0.165    0.869  ;I(Nc^2)      2.783e-08  3.897e-07  9.436e+01   0.071    0.943
marginal_r2_model_He_Nc_NSS_2 <- r.squaredGLMM(model_He_Nc_NSS_2)
marginal_r2_model_He_Nc_NSS_2# R2m 0.0002350288     R2c 0.8686112

p_He_Nc_NSS <- ggplot(aes(x = Nc, y = He), data = es_NSS) +
  geom_point(shape = 20, size = 5, alpha = 0.3, color = "#A41B1BFF") +
  geom_smooth(method = "lm", size = 0.7, linetype = 2, color = "#CE3D32FF", se = TRUE, fill = "#FFC0CB") +
  geom_smooth(method = "lm", size = 0.7, linetype = 2, color = "#466983FF", se = TRUE, formula = y ~ I(x^2) + x, fill = "#ADD8E6") +
  theme(panel.border = element_rect(fill = NA, color = "black", size = 1, linetype = "solid"),
        axis.text.x = element_text(size = 15, face = "bold"),
        axis.text.y = element_text(size = 15, face = "bold"),
        axis.title.x = element_text(size = 15, face = "bold"),
        axis.title.y = element_text(size = 15, face = "bold"),
        legend.position = "none") +
  xlab(label = "Nc") +
  ylab(label = "He") +
  theme(plot.margin = unit(c(0.5, 0.5, 0.5, 0.5), "cm"),
        panel.background = element_rect(fill = "white", colour = "black"),
        panel.grid.major = element_line(color = "#F0F0F0", size = 0.25),
        panel.grid.minor = element_line(color = "#F0F0F0", size = 0.15)) +
  annotate(geom = "text", x = -Inf, y = Inf,
           label = "Quadratic: R^2m = 0.0002, R^2c = 0.8686, ns", hjust = -0.15, vjust = 4, size = 5, color = "#466983FF") +
  annotate(geom = "text", x = -Inf, y = Inf,
           label = "Linear: R^2m = 0.0002, R^2c = 0.8702, ns", hjust = -0.25, vjust = 2, size = 5, color = "#CE3D32FF")
p_He_Nc_NSS

model_He_Nc_NSS_3 <- lmer(He~log(Nc)+ (1 | taxon) + (1 | gene_meth) + (1 | DNA_sou),data = es_NSS)
AIC(model_He_Nc_NSS_3)#-228.2861
summary(model_He_Nc_NSS_3)#log(Nc) -0.004196   0.007270 117.099394  -0.577    0.565 
marginal_r2_model_He_Nc_NSS_3 <- r.squaredGLMM(model_He_Nc_NSS_3)
marginal_r2_model_He_Nc_NSS_3# R2m 0.0008211208     R2c 0.8680252
model_He_Nc_NSS_4 <- lmer(He~log(Nc)+I(log(Nc)^2)+ (1 | taxon) + (1 | gene_meth) + (1 | DNA_sou),data = es_NSS)
AIC(model_He_Nc_NSS_4)#-218.4844
summary(model_He_Nc_NSS_4)#log(Nc)  -0.047617   0.046414 128.023046  -1.026  0.30687   ;I(log(Nc)^2)   0.004917   0.005210 135.874479   0.944  0.34706
marginal_r2_model_He_Nc_NSS_4 <- r.squaredGLMM(model_He_Nc_NSS_4)
marginal_r2_model_He_Nc_NSS_4# R2m 0.005615916     R2c 0.8629978

p_He_logNc_NSS <- ggplot(aes(x = log(Nc), y = He), data = es_NSS) +
  geom_point(shape = 20, size = 5, alpha = 0.3, color = "#A41B1BFF") +
  geom_smooth(method = "lm", size = 0.7, linetype = 2, color = "#CE3D32FF", se = TRUE, fill = "#FFC0CB") +
  geom_smooth(method = "lm", size = 0.7, linetype = 2, color = "#466983FF", se = TRUE, formula = y ~ I(x^2) + x, fill = "#ADD8E6") +
  theme(panel.border = element_rect(fill = NA, color = "black", size = 1, linetype = "solid"),
        axis.text.x = element_text(size = 15, face = "bold"),
        axis.text.y = element_text(size = 15, face = "bold"),
        axis.title.x = element_text(size = 15, face = "bold"),
        axis.title.y = element_text(size = 15, face = "bold"),
        legend.position = "none") +
  xlab(label = "log(Nc)") +
  ylab(label = "He") +
  theme(plot.margin = unit(c(0.5, 0.5, 0.5, 0.5), "cm"),
        panel.background = element_rect(fill = "white", colour = "black"),
        panel.grid.major = element_line(color = "#F0F0F0", size = 0.25),
        panel.grid.minor = element_line(color = "#F0F0F0", size = 0.15)) +
  annotate(geom = "text", x = -Inf, y = Inf,
           label = "Quadratic: R^2m = 0.0056, R^2c = 0.8630, ns", hjust = -0.05, vjust = 4, size = 5, color = "#466983FF") +
  annotate(geom = "text", x = -Inf, y = Inf,
           label = "Linear: R^2m = 0.0008, R^2c = 0.8680, ns", hjust = -0.05, vjust = 2, size = 5, color = "#CE3D32FF")
p_He_logNc_NSS

model_FIS_Nc_NSS_1 <- lmer(FIS~Nc+ (1 | taxon) + (1 | gene_meth) + (1 | DNA_sou),data = es_NSS)
AIC(model_FIS_Nc_NSS_1)#40.42303
summary(model_FIS_Nc_NSS_1)#Nc -0.0002391  0.0003074 19.9348751  -0.778    0.446
marginal_r2_model_FIS_Nc_NSS_1 <- r.squaredGLMM(model_FIS_Nc_NSS_1)
marginal_r2_model_FIS_Nc_NSS_1# R2m 0.003706572     R2c 0.9202768
model_FIS_Nc_NSS_2 <- lmer(FIS~Nc+I(Nc^2)+ (1 | taxon) + (1 | gene_meth) + (1 | DNA_sou),data = es_NSS)
AIC(model_FIS_Nc_NSS_2)#66.93572
summary(model_FIS_Nc_NSS_2)#Nc -3.338e-04  1.001e-03  3.431e+01  -0.333    0.741;I(Nc^2)      1.933e-07  1.904e-06  2.551e+01   0.102    0.920
marginal_r2_model_FIS_Nc_NSS_2 <- r.squaredGLMM(model_FIS_Nc_NSS_2)
marginal_r2_model_FIS_Nc_NSS_2# R2m 0.004379428     R2c 0.9179089

p_FIS_Nc_NSS <- ggplot(aes(x = Nc, y = FIS), data = es_NSS) +
  geom_point(shape = 20, size = 5, alpha = 0.3, color = "#A41B1BFF") +
  geom_smooth(method = "lm", size = 0.7, linetype = 2, color = "#CE3D32FF", se = TRUE, fill = "#FFC0CB") +
  geom_smooth(method = "lm", size = 0.7, linetype = 2, color = "#466983FF", se = TRUE, formula = y ~ I(x^2) + x, fill = "#ADD8E6") +
  theme(panel.border = element_rect(fill = NA, color = "black", size = 1, linetype = "solid"),
        axis.text.x = element_text(size = 15, face = "bold"),
        axis.text.y = element_text(size = 15, face = "bold"),
        axis.title.x = element_text(size = 15, face = "bold"),
        axis.title.y = element_text(size = 15, face = "bold"),
        legend.position = "none") +
  xlab(label = "Nc") +
  ylab(label = "FIS") +
  theme(plot.margin = unit(c(0.5, 0.5, 0.5, 0.5), "cm"),
        panel.background = element_rect(fill = "white", colour = "black"),
        panel.grid.major = element_line(color = "#F0F0F0", size = 0.25),
        panel.grid.minor = element_line(color = "#F0F0F0", size = 0.15)) +
  annotate(geom = "text", x = -Inf, y = Inf,
           label = "Quadratic: R^2m = 0.0044, R^2c = 0.9179, ns", hjust = -0.05, vjust = 4, size = 5, color = "#466983FF") +
  annotate(geom = "text", x = -Inf, y = Inf,
           label = "Linear: R^2m = 0.0037, R^2c = 0.9203, ns", hjust = -0.05, vjust = 2, size = 5, color = "#CE3D32FF")
p_FIS_Nc_NSS

model_FIS_Nc_NSS_3 <- lmer(FIS~log(Nc)+ (1 | taxon) + (1 | gene_meth) + (1 | DNA_sou),data = es_NSS)
AIC(model_FIS_Nc_NSS_3)#31.17322
summary(model_FIS_Nc_NSS_3)#log(Nc)     -0.01494    0.03970 39.30271  -0.376    0.709
marginal_r2_model_FIS_Nc_NSS_3 <- r.squaredGLMM(model_FIS_Nc_NSS_3)
marginal_r2_model_FIS_Nc_NSS_3# R2m 0.001746933     R2c 0.9204324
model_FIS_Nc_NSS_4 <- lmer(FIS~log(Nc)+I(log(Nc)^2)+ (1 | taxon) + (1 | gene_meth) + (1 | DNA_sou),data = es_NSS)
AIC(model_FIS_Nc_NSS_4)#37.57327
summary(model_FIS_Nc_NSS_4)#log(Nc)   0.17710    0.14817 36.59434   1.195    0.240;I(log(Nc)^2) -0.02418    0.01796 37.44461  -1.346    0.186
marginal_r2_model_FIS_Nc_NSS_4 <- r.squaredGLMM(model_FIS_Nc_NSS_4)
marginal_r2_model_FIS_Nc_NSS_4# R2m 0.01643314     R2c 0.9226164

p_FIS_logNc_NSS <- ggplot(aes(x = log(Nc), y = FIS), data = es_NSS) +
  geom_point(shape = 20, size = 5, alpha = 0.3, color = "#A41B1BFF") +
  geom_smooth(method = "lm", size = 0.7, linetype = 2, color = "#CE3D32FF", se = TRUE, fill = "#FFC0CB") +
  geom_smooth(method = "lm", size = 0.7, linetype = 2, color = "#466983FF", se = TRUE, formula = y ~ I(x^2) + x, fill = "#ADD8E6") +
  theme(panel.border = element_rect(fill = NA, color = "black", size = 1, linetype = "solid"),
        axis.text.x = element_text(size = 15, face = "bold"),
        axis.text.y = element_text(size = 15, face = "bold"),
        axis.title.x = element_text(size = 15, face = "bold"),
        axis.title.y = element_text(size = 15, face = "bold"),
        legend.position = "none") +
  xlab(label = "log(Nc)") +
  ylab(label = "FIS") +
  theme(plot.margin = unit(c(0.5, 0.5, 0.5, 0.5), "cm"),
        panel.background = element_rect(fill = "white", colour = "black"),
        panel.grid.major = element_line(color = "#F0F0F0", size = 0.25),
        panel.grid.minor = element_line(color = "#F0F0F0", size = 0.15)) +
  annotate(geom = "text", x = -Inf, y = Inf,
           label = "Quadratic: R^2m = 0.0164, R^2c = 0.9226, ns", hjust = -0.05, vjust = 4, size = 5, color = "#466983FF") +
  annotate(geom = "text", x = -Inf, y = Inf,
           label = "Linear: R^2m = 0.0017, R^2c = 0.9204, ns", hjust = -0.05, vjust = 2, size = 5, color = "#CE3D32FF")
p_FIS_logNc_NSS

model_Nm_Nc_NSS_1 <- lmer(Nm~Nc+ (1 | taxon) + (1 | gene_meth) + (1 | DNA_sou),data = es_NSS)
AIC(model_Nm_Nc_NSS_1)#315.9771
summary(model_Nm_Nc_NSS_1)#Nc -0.0004201  0.0007960 18.9515001  -0.528 0.603826
marginal_r2_model_Nm_Nc_NSS_1 <- r.squaredGLMM(model_Nm_Nc_NSS_1)
marginal_r2_model_Nm_Nc_NSS_1# R2m 0.0002237107     R2c 0.9813873
model_Nm_Nc_NSS_2 <- lmer(Nm~Nc+I(Nc^2)+ (1 | taxon) + (1 | gene_meth) + (1 | DNA_sou),data = es_NSS)
AIC(model_Nm_Nc_NSS_2)#340.3559
summary(model_Nm_Nc_NSS_2)#Nc     -1.014e-04  2.938e-03  1.897e+01  -0.035  0.97282   ;I(Nc^2)     -6.325e-07  5.545e-06  1.853e+01  -0.114  0.91042  
marginal_r2_model_Nm_Nc_NSS_2 <- r.squaredGLMM(model_Nm_Nc_NSS_2)
marginal_r2_model_Nm_Nc_NSS_2# R2m 0.0001904994     R2c 0.9804095

p_Nm_Nc_NSS <- ggplot(aes(x = Nc, y = Nm), data = es_NSS) +
  geom_point(shape = 20, size = 5, alpha = 0.3, color = "#A41B1BFF") +
  geom_smooth(method = "lm", size = 0.7, linetype = 2, color = "#CE3D32FF", se = TRUE, fill = "#FFC0CB") +
  geom_smooth(method = "lm", size = 0.7, linetype = 2, color = "#466983FF", se = TRUE, formula = y ~ I(x^2) + x, fill = "#ADD8E6") +
  theme(panel.border = element_rect(fill = NA, color = "black", size = 1, linetype = "solid"),
        axis.text.x = element_text(size = 15, face = "bold"),
        axis.text.y = element_text(size = 15, face = "bold"),
        axis.title.x = element_text(size = 15, face = "bold"),
        axis.title.y = element_text(size = 15, face = "bold"),
        legend.position = "none") +
  xlab(label = "Nc") +
  ylab(label = "Nm") +
  theme(plot.margin = unit(c(0.5, 0.5, 0.5, 0.5), "cm"),
        panel.background = element_rect(fill = "white", colour = "black"),
        panel.grid.major = element_line(color = "#F0F0F0", size = 0.25),
        panel.grid.minor = element_line(color = "#F0F0F0", size = 0.15)) +
  annotate(geom = "text", x = -Inf, y = Inf,
           label = "Quadratic: R^2m = 0.0002, R^2c = 0.9804, ns", hjust = -0.15, vjust = 4, size = 5, color = "#466983FF") +
  annotate(geom = "text", x = -Inf, y = Inf,
           label = "Linear: R^2m = 0.0002, R^2c = 0.9814, ns", hjust = -0.25, vjust = 2, size = 5, color = "#CE3D32FF")
p_Nm_Nc_NSS

model_Nm_Nc_NSS_3 <- lmer(Nm~log(Nc)+ (1 | taxon) + (1 | gene_meth) + (1 | DNA_sou),data = es_NSS)
AIC(model_Nm_Nc_NSS_3)#306.0812
summary(model_Nm_Nc_NSS_3)#log(Nc)     -0.03035    0.12554 20.52304  -0.242    0.811
marginal_r2_model_Nm_Nc_NSS_3 <- r.squaredGLMM(model_Nm_Nc_NSS_3)
marginal_r2_model_Nm_Nc_NSS_3# R2m 8.410421e-05    R2c 0.9813015
model_Nm_Nc_NSS_4 <- lmer(Nm~log(Nc)+I(log(Nc)^2)+ (1 | taxon) + (1 | gene_meth) + (1 | DNA_sou),data = es_NSS)
AIC(model_Nm_Nc_NSS_4)#309.2463
summary(model_Nm_Nc_NSS_4)#log(Nc)        1.2235     1.1709 24.9756   1.045    0.306;I(log(Nc)^2)  -0.1344     0.1248 24.2097  -1.077    0.292
marginal_r2_model_Nm_Nc_NSS_4 <- r.squaredGLMM(model_Nm_Nc_NSS_4)
marginal_r2_model_Nm_Nc_NSS_4# R2m 0.002785208     R2c 0.9812208

p_Nm_logNc_NSS <- ggplot(aes(x = log(Nc), y = Nm), data = es_NSS) +
  geom_point(shape = 20, size = 5, alpha = 0.3, color = "#A41B1BFF") +
  geom_smooth(method = "lm", size = 0.7, linetype = 2, color = "#CE3D32FF", se = TRUE, fill = "#FFC0CB") +
  geom_smooth(method = "lm", size = 0.7, linetype = 2, color = "#466983FF", se = TRUE, formula = y ~ I(x^2) + x, fill = "#ADD8E6") +
  theme(panel.border = element_rect(fill = NA, color = "black", size = 1, linetype = "solid"),
        axis.text.x = element_text(size = 15, face = "bold"),
        axis.text.y = element_text(size = 15, face = "bold"),
        axis.title.x = element_text(size = 15, face = "bold"),
        axis.title.y = element_text(size = 15, face = "bold"),
        legend.position = "none") +
  xlab(label = "log(Nc)") +
  ylab(label = "Nm") +
  theme(plot.margin = unit(c(0.5, 0.5, 0.5, 0.5), "cm"),
        panel.background = element_rect(fill = "white", colour = "black"),
        panel.grid.major = element_line(color = "#F0F0F0", size = 0.25),
        panel.grid.minor = element_line(color = "#F0F0F0", size = 0.15)) +
  annotate(geom = "text", x = -Inf, y = Inf,
           label = "Quadratic: R^2m = 0.0028, R^2c = 0.9812, ns", hjust = -0.05, vjust = 4, size = 5, color = "#466983FF") +
  annotate(geom = "text", x = -Inf, y = Inf,
           label = "Linear: R^2m = 8.4104e-05, R^2c = 0.9813, ns", hjust = -0.05, vjust = 2, size = 5, color = "#CE3D32FF")
p_Nm_logNc_NSS
